/* Generated by Cython 3.0.12 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "_pydevd_bundle.pydevd_pep_669_tracing_cython",
        "sources": [
            "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx"
        ]
    },
    "module_name": "_pydevd_bundle.pydevd_pep_669_tracing_cython"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_12" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x03000CF0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 0
  #endif
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__;  (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE___pydevd_bundle__pydevd_pep_669_tracing_cython
#define __PYX_HAVE_API___pydevd_bundle__pydevd_pep_669_tracing_cython
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe;

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":168
 * # Cython side in the future.
 * # IFDEF CYTHON -- DONT EDIT THIS FILE (it is automatically generated)
 * cdef _getframe(depth=0):             # <<<<<<<<<<<<<<
 *    return sys._getframe()
 * # ELSE
 */
struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe {
  int __pyx_n;
  PyObject *depth;
};
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyIntCompare.proto */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */

/* Module declarations from "_pydevd_bundle.pydevd_pep_669_tracing_cython" */
static PyObject *__pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe *__pyx_optional_args); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "_pydevd_bundle.pydevd_pep_669_tracing_cython"
extern int __pyx_module_is_main__pydevd_bundle__pydevd_pep_669_tracing_cython;
int __pyx_module_is_main__pydevd_bundle__pydevd_pep_669_tracing_cython = 0;

/* Implementation of "_pydevd_bundle.pydevd_pep_669_tracing_cython" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_AttributeError;
static PyObject *__pyx_builtin_SystemExit;
static PyObject *__pyx_builtin_KeyboardInterrupt;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = "?";
static const char __pyx_k_1[] = "1";
static const char __pyx_k_x[] = "x";
static const char __pyx_k_y[] = "y";
static const char __pyx_k__2[] = "";
static const char __pyx_k__3[] = "*";
static const char __pyx_k__4[] = ".";
static const char __pyx_k_os[] = "os";
static const char __pyx_k_ADD[] = "ADD";
static const char __pyx_k_ALL[] = "ALL";
static const char __pyx_k__31[] = "_";
static const char __pyx_k_cmd[] = "cmd";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_CALL[] = "CALL";
static const char __pyx_k_LINE[] = "LINE";
static const char __pyx_k_None[] = "None";
static const char __pyx_k_arg0[] = "arg0";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_back[] = "back";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_call[] = "call";
static const char __pyx_k_code[] = "code";
static const char __pyx_k_exec[] = "_exec";
static const char __pyx_k_flag[] = "flag";
static const char __pyx_k_info[] = "info";
static const char __pyx_k_line[] = "line";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_path[] = "path";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_RAISE[] = "RAISE";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_event[] = "event";
static const char __pyx_k_frame[] = "frame";
static const char __pyx_k_py_db[] = "py_db";
static const char __pyx_k_reset[] = "reset";
static const char __pyx_k_REMOVE[] = "REMOVE";
static const char __pyx_k_action[] = "action";
static const char __pyx_k_events[] = "events";
static const char __pyx_k_f_back[] = "f_back";
static const char __pyx_k_f_code[] = "f_code";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_lambda[] = "<lambda>";
static const char __pyx_k_module[] = "<module>";
static const char __pyx_k_name_2[] = "name";
static const char __pyx_k_plugin[] = "plugin";
static const char __pyx_k_pydevd[] = "pydevd";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_retval[] = "retval";
static const char __pyx_k_thread[] = "thread";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_writer[] = "writer";
static const char __pyx_k_DISABLE[] = "DISABLE";
static const char __pyx_k_bp_type[] = "bp_type";
static const char __pyx_k_co_name[] = "co_name";
static const char __pyx_k_invalid[] = ".invalid.";
static const char __pyx_k_linesep[] = "linesep";
static const char __pyx_k_os_path[] = "os.path";
static const char __pyx_k_suspend[] = "suspend";
static const char __pyx_k_PY_START[] = "PY_START";
static const char __pyx_k_basename[] = "basename";
static const char __pyx_k_callable[] = "callable";
static const char __pyx_k_callback[] = "callback";
static const char __pyx_k_can_skip[] = "can_skip";
static const char __pyx_k_debugger[] = "debugger";
static const char __pyx_k_end_line[] = "end_line";
static const char __pyx_k_exc_info[] = "exc_info";
static const char __pyx_k_f_lineno[] = "f_lineno";
static const char __pyx_k_filename[] = "filename";
static const char __pyx_k_get_tool[] = "get_tool";
static const char __pyx_k_getframe[] = "_getframe";
static const char __pyx_k_quitting[] = "quitting";
static const char __pyx_k_splitext[] = "splitext";
static const char __pyx_k_step_cmd[] = "step_cmd";
static const char __pyx_k_PY_RETURN[] = "PY_RETURN";
static const char __pyx_k_STATE_RUN[] = "STATE_RUN";
static const char __pyx_k_back_code[] = "back_code";
static const char __pyx_k_exception[] = "exception";
static const char __pyx_k_file_type[] = "file_type";
static const char __pyx_k_func_name[] = "func_name";
static const char __pyx_k_log_event[] = "log_event";
static const char __pyx_k_new_frame[] = "new_frame";
static const char __pyx_k_print_exc[] = "print_exc";
static const char __pyx_k_pydev_log[] = "pydev_log";
static const char __pyx_k_stop_info[] = "stop_info";
static const char __pyx_k_threading[] = "threading";
static const char __pyx_k_traceback[] = "traceback";
static const char __pyx_k_DONT_TRACE[] = "DONT_TRACE";
static const char __pyx_k_IS_CPYTHON[] = "IS_CPYTHON";
static const char __pyx_k_PYDEV_FILE[] = "PYDEV_FILE";
static const char __pyx_k_SystemExit[] = "SystemExit";
static const char __pyx_k_breakpoint[] = "breakpoint";
static const char __pyx_k_call_order[] = "call_order";
static const char __pyx_k_event_type[] = "event_type";
static const char __pyx_k_expression[] = "expression";
static const char __pyx_k_get_events[] = "get_events";
static const char __pyx_k_global_dbg[] = "global_dbg";
static const char __pyx_k_is_tracing[] = "is_tracing";
static const char __pyx_k_monitoring[] = "monitoring";
static const char __pyx_k_set_events[] = "set_events";
static const char __pyx_k_start_line[] = "start_line";
static const char __pyx_k_stop_frame[] = "stop_frame";
static const char __pyx_k_DEBUGGER_ID[] = "DEBUGGER_ID";
static const char __pyx_k_DEBUG_START[] = "DEBUG_START";
static const char __pyx_k_add_command[] = "add_command";
static const char __pyx_k_breakpoints[] = "breakpoints";
static const char __pyx_k_cmd_factory[] = "cmd_factory";
static const char __pyx_k_co_filename[] = "co_filename";
static const char __pyx_k_eval_result[] = "eval_result";
static const char __pyx_k_f_unhandled[] = "f_unhandled";
static const char __pyx_k_is_logpoint[] = "is_logpoint";
static const char __pyx_k_is_stepping[] = "is_stepping";
static const char __pyx_k_line_number[] = "line_number";
static const char __pyx_k_plugin_stop[] = "plugin_stop";
static const char __pyx_k_pydev_state[] = "pydev_state";
static const char __pyx_k_set_suspend[] = "set_suspend";
static const char __pyx_k_should_stop[] = "should_stop";
static const char __pyx_k_traceback_2[] = "__traceback__";
static const char __pyx_k_use_tool_id[] = "use_tool_id";
static const char __pyx_k_can_not_skip[] = "can_not_skip";
static const char __pyx_k_exist_result[] = "exist_result";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_local_events[] = "local_events";
static const char __pyx_k_pydev_bundle[] = "_pydev_bundle";
static const char __pyx_k_CMD_SET_BREAK[] = "CMD_SET_BREAK";
static const char __pyx_k_CMD_STEP_INTO[] = "CMD_STEP_INTO";
static const char __pyx_k_CMD_STEP_OVER[] = "CMD_STEP_OVER";
static const char __pyx_k_EVENT_ACTIONS[] = "_EVENT_ACTIONS";
static const char __pyx_k_STATE_SUSPEND[] = "STATE_SUSPEND";
static const char __pyx_k_back_filename[] = "back_filename";
static const char __pyx_k_call_callback[] = "call_callback";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_cmd_step_into[] = "cmd_step_into";
static const char __pyx_k_cmd_step_over[] = "cmd_step_over";
static const char __pyx_k_get_file_type[] = "get_file_type";
static const char __pyx_k_has_condition[] = "has_condition";
static const char __pyx_k_not_processed[] = "_not_processed";
static const char __pyx_k_pydev_message[] = "pydev_message";
static const char __pyx_k_AttributeError[] = "AttributeError";
static const char __pyx_k_co_firstlineno[] = "co_firstlineno";
static const char __pyx_k_curr_func_name[] = "curr_func_name";
static const char __pyx_k_current_events[] = "current_events";
static const char __pyx_k_current_thread[] = "current_thread";
static const char __pyx_k_get_breakpoint[] = "get_breakpoint";
static const char __pyx_k_line_cache_key[] = "line_cache_key";
static const char __pyx_k_plugin_manager[] = "plugin_manager";
static const char __pyx_k_pydev_step_cmd[] = "pydev_step_cmd";
static const char __pyx_k_restart_events[] = "restart_events";
static const char __pyx_k_suspend_policy[] = "suspend_policy";
static const char __pyx_k_CMD_STEP_RETURN[] = "CMD_STEP_RETURN";
static const char __pyx_k_additional_info[] = "additional_info";
static const char __pyx_k_bootstrap_inner[] = "_bootstrap_inner";
static const char __pyx_k_clear_run_state[] = "_clear_run_state";
static const char __pyx_k_do_wait_suspend[] = "do_wait_suspend";
static const char __pyx_k_frame_cache_key[] = "frame_cache_key";
static const char __pyx_k_is_thread_alive[] = "is_thread_alive";
static const char __pyx_k_make_io_message[] = "make_io_message";
static const char __pyx_k_pydev_func_name[] = "pydev_func_name";
static const char __pyx_k_pydev_step_stop[] = "pydev_step_stop";
static const char __pyx_k_smart_step_stop[] = "smart_step_stop";
static const char __pyx_k_thread_analyser[] = "thread_analyser";
static const char __pyx_k_will_be_stopped[] = "will_be_stopped";
static const char __pyx_k_DEBUG_START_PY3K[] = "DEBUG_START_PY3K";
static const char __pyx_k_PYDEVD_TOOL_NAME[] = "PYDEVD_TOOL_NAME";
static const char __pyx_k_asyncio_analyser[] = "asyncio_analyser";
static const char __pyx_k_context_end_line[] = "context_end_line";
static const char __pyx_k_get_local_events[] = "get_local_events";
static const char __pyx_k_handle_exception[] = "handle_exception";
static const char __pyx_k_in_project_scope[] = "in_project_scope";
static const char __pyx_k_py_line_callback[] = "py_line_callback";
static const char __pyx_k_set_local_events[] = "set_local_events";
static const char __pyx_k_smart_stop_frame[] = "smart_stop_frame";
static const char __pyx_k_KeyboardInterrupt[] = "KeyboardInterrupt";
static const char __pyx_k_is_filter_enabled[] = "is_filter_enabled";
static const char __pyx_k_is_within_context[] = "is_within_context";
static const char __pyx_k_py_raise_callback[] = "py_raise_callback";
static const char __pyx_k_py_start_callback[] = "py_start_callback";
static const char __pyx_k_pydevd_file_utils[] = "pydevd_file_utils";
static const char __pyx_k_register_callback[] = "register_callback";
static const char __pyx_k_remove_breakpoint[] = "remove_breakpoint";
static const char __pyx_k_add_new_breakpoint[] = "add_new_breakpoint";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_base_back_filename[] = "base_back_filename";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_context_start_line[] = "context_start_line";
static const char __pyx_k_get_current_thread[] = "get_current_thread";
static const char __pyx_k_global_cache_skips[] = "global_cache_skips";
static const char __pyx_k_instruction_offset[] = "instruction_offset";
static const char __pyx_k_py_return_callback[] = "py_return_callback";
static const char __pyx_k_show_return_values[] = "show_return_values";
static const char __pyx_k_CMD_SMART_STEP_INTO[] = "CMD_SMART_STEP_INTO";
static const char __pyx_k_enable_line_tracing[] = "_enable_line_tracing";
static const char __pyx_k_find_last_call_name[] = "find_last_call_name";
static const char __pyx_k_get_additional_info[] = "_get_additional_info";
static const char __pyx_k_get_top_level_frame[] = "_get_top_level_frame";
static const char __pyx_k_is_filter_libraries[] = "is_filter_libraries";
static const char __pyx_k_GlobalDebuggerHolder[] = "GlobalDebuggerHolder";
static const char __pyx_k_breakpoints_for_file[] = "breakpoints_for_file";
static const char __pyx_k_make_frame_cache_key[] = "_make_frame_cache_key";
static const char __pyx_k_manage_return_values[] = "manage_return_values";
static const char __pyx_k_modify_global_events[] = "_modify_global_events";
static const char __pyx_k_stop_on_failed_tests[] = "stop_on_failed_tests";
static const char __pyx_k_CMD_STEP_INTO_MY_CODE[] = "CMD_STEP_INTO_MY_CODE";
static const char __pyx_k_enable_return_tracing[] = "_enable_return_tracing";
static const char __pyx_k_is_ignored_by_filters[] = "is_ignored_by_filters";
static const char __pyx_k_suspend_other_threads[] = "suspend_other_threads";
static const char __pyx_k_has_plugin_line_breaks[] = "has_plugin_line_breaks";
static const char __pyx_k_suspended_at_unhandled[] = "suspended_at_unhandled";
static const char __pyx_k_CMD_STEP_INTO_COROUTINE[] = "CMD_STEP_INTO_COROUTINE";
static const char __pyx_k_has_breakpoint_in_frame[] = "has_breakpoint_in_frame";
static const char __pyx_k_enable_pep669_monitoring[] = "enable_pep669_monitoring";
static const char __pyx_k_finish_debugging_session[] = "_finish_debugging_session";
static const char __pyx_k_global_cache_frame_skips[] = "global_cache_frame_skips";
static const char __pyx_k_pydev_smart_step_context[] = "pydev_smart_step_context";
static const char __pyx_k_should_stop_on_exception[] = "should_stop_on_exception";
static const char __pyx_k_breakpoints_for_back_file[] = "breakpoints_for_back_file";
static const char __pyx_k_breakpoints_in_line_cache[] = "breakpoints_in_line_cache";
static const char __pyx_k_find_last_func_call_order[] = "find_last_func_call_order";
static const char __pyx_k_has_exception_breakpoints[] = "has_exception_breakpoints";
static const char __pyx_k_remove_return_values_flag[] = "remove_return_values_flag";
static const char __pyx_k_break_on_caught_exceptions[] = "break_on_caught_exceptions";
static const char __pyx_k_breakpoints_in_frame_cache[] = "breakpoints_in_frame_cache";
static const char __pyx_k_set_additional_thread_info[] = "set_additional_thread_info";
static const char __pyx_k_abs_path_real_path_and_base[] = "abs_path_real_path_and_base";
static const char __pyx_k_handle_breakpoint_condition[] = "handle_breakpoint_condition";
static const char __pyx_k_has_plugin_exception_breaks[] = "has_plugin_exception_breaks";
static const char __pyx_k_stop_on_unhandled_exception[] = "stop_on_unhandled_exception";
static const char __pyx_k_handle_breakpoint_expression[] = "handle_breakpoint_expression";
static const char __pyx_k_is_pep669_monitoring_enabled[] = "is_pep669_monitoring_enabled";
static const char __pyx_k_NORM_PATHS_AND_BASE_CONTAINER[] = "NORM_PATHS_AND_BASE_CONTAINER";
static const char __pyx_k_stop_on_unhandled_exception_2[] = "_stop_on_unhandled_exception";
static const char __pyx_k_pydevd_bundle_pydevd_constants[] = "_pydevd_bundle.pydevd_constants";
static const char __pyx_k_get_abs_path_real_path_and_base[] = "get_abs_path_real_path_and_base_from_frame";
static const char __pyx_k_pydev_bundle_pydev_is_thread_al[] = "_pydev_bundle.pydev_is_thread_alive";
static const char __pyx_k_pydevd_bundle_pydevd_breakpoint[] = "_pydevd_bundle.pydevd_breakpoints";
static const char __pyx_k_pydevd_bundle_pydevd_bytecode_u[] = "_pydevd_bundle.pydevd_bytecode_utils";
static const char __pyx_k_pydevd_bundle_pydevd_comm_const[] = "_pydevd_bundle.pydevd_comm_constants";
static const char __pyx_k_pydevd_bundle_pydevd_dont_trace[] = "_pydevd_bundle.pydevd_dont_trace_files";
static const char __pyx_k_pydevd_bundle_pydevd_pep_669_tr[] = "_pydevd_bundle.pydevd_pep_669_tracing_cython";
static const char __pyx_k_pydevd_bundle_pydevd_trace_disp[] = "_pydevd_bundle.pydevd_trace_dispatch";
static const char __pyx_k_should_enable_line_events_for_c[] = "_should_enable_line_events_for_code";
static const char __pyx_k_Exception_while_handling_smart_s[] = "Exception while handling smart step into in frame tracer, step into will be performed instead.";
static const char __pyx_k_get_abs_path_real_path_and_base_2[] = "_get_abs_path_real_path_and_base_from_frame";
static const char __pyx_k_pydevd_bundle_pydevd_pep_669_tr_2[] = "_pydevd_bundle\\pydevd_pep_669_tracing_cython.pyx";
/* #### Code section: decls ### */
static PyObject *__pyx_lambda_funcdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_lambda(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x, PyObject *__pyx_v_y); /* proto */
static PyObject *__pyx_lambda_funcdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_lambda1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x, PyObject *__pyx_v_y); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__make_frame_cache_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_2_get_additional_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_thread); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_4_get_abs_path_real_path_and_base_from_frame(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_6_should_enable_line_events_for_code(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame, PyObject *__pyx_v_code, PyObject *__pyx_v_filename, PyObject *__pyx_v_info, PyObject *__pyx_v_will_be_stopped); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_8_clear_run_state(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_info); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_10_get_top_level_frame(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_12_stop_on_unhandled_exception(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_exc_info, PyObject *__pyx_v_py_db, PyObject *__pyx_v_thread); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_14enable_pep669_monitoring(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_16add_new_breakpoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_breakpoint); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_18remove_breakpoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_breakpoint); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_20_modify_global_events(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_action, PyObject *__pyx_v_event); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_22_enable_return_tracing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_24_enable_line_tracing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_26call_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset, CYTHON_UNUSED PyObject *__pyx_v_callable, CYTHON_UNUSED PyObject *__pyx_v_arg0); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_28py_start_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_30py_line_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code, PyObject *__pyx_v_line_number); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_32py_raise_callback(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset, PyObject *__pyx_v_exception); /* proto */
static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_34py_return_callback(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset, PyObject *__pyx_v_retval); /* proto */
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyObject *__pyx_kp_s_;
  PyObject *__pyx_kp_s_1;
  PyObject *__pyx_n_s_ADD;
  PyObject *__pyx_n_s_ALL;
  PyObject *__pyx_n_s_AttributeError;
  PyObject *__pyx_n_s_CALL;
  PyObject *__pyx_n_s_CMD_SET_BREAK;
  PyObject *__pyx_n_s_CMD_SMART_STEP_INTO;
  PyObject *__pyx_n_s_CMD_STEP_INTO;
  PyObject *__pyx_n_s_CMD_STEP_INTO_COROUTINE;
  PyObject *__pyx_n_s_CMD_STEP_INTO_MY_CODE;
  PyObject *__pyx_n_s_CMD_STEP_OVER;
  PyObject *__pyx_n_s_CMD_STEP_RETURN;
  PyObject *__pyx_n_s_DEBUGGER_ID;
  PyObject *__pyx_n_s_DEBUG_START;
  PyObject *__pyx_n_s_DEBUG_START_PY3K;
  PyObject *__pyx_n_s_DISABLE;
  PyObject *__pyx_n_s_DONT_TRACE;
  PyObject *__pyx_n_s_EVENT_ACTIONS;
  PyObject *__pyx_kp_s_Exception_while_handling_smart_s;
  PyObject *__pyx_n_s_GlobalDebuggerHolder;
  PyObject *__pyx_n_s_IS_CPYTHON;
  PyObject *__pyx_n_s_KeyboardInterrupt;
  PyObject *__pyx_n_s_LINE;
  PyObject *__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER;
  PyObject *__pyx_n_s_None;
  PyObject *__pyx_n_s_PYDEVD_TOOL_NAME;
  PyObject *__pyx_n_s_PYDEV_FILE;
  PyObject *__pyx_n_s_PY_RETURN;
  PyObject *__pyx_n_s_PY_START;
  PyObject *__pyx_n_s_RAISE;
  PyObject *__pyx_n_s_REMOVE;
  PyObject *__pyx_n_s_STATE_RUN;
  PyObject *__pyx_n_s_STATE_SUSPEND;
  PyObject *__pyx_n_s_SystemExit;
  PyObject *__pyx_kp_s__2;
  PyObject *__pyx_n_s__3;
  PyObject *__pyx_n_s__31;
  PyObject *__pyx_kp_u__4;
  PyObject *__pyx_n_s_abs_path_real_path_and_base;
  PyObject *__pyx_n_s_action;
  PyObject *__pyx_n_s_add_command;
  PyObject *__pyx_n_s_add_new_breakpoint;
  PyObject *__pyx_n_s_additional_info;
  PyObject *__pyx_n_s_arg0;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_asyncio_analyser;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_back;
  PyObject *__pyx_n_s_back_code;
  PyObject *__pyx_n_s_back_filename;
  PyObject *__pyx_n_s_base;
  PyObject *__pyx_n_s_base_back_filename;
  PyObject *__pyx_n_s_basename;
  PyObject *__pyx_n_s_bootstrap_inner;
  PyObject *__pyx_n_s_bp_type;
  PyObject *__pyx_n_s_break_on_caught_exceptions;
  PyObject *__pyx_n_s_breakpoint;
  PyObject *__pyx_n_s_breakpoints;
  PyObject *__pyx_n_s_breakpoints_for_back_file;
  PyObject *__pyx_n_s_breakpoints_for_file;
  PyObject *__pyx_n_s_breakpoints_in_frame_cache;
  PyObject *__pyx_n_s_breakpoints_in_line_cache;
  PyObject *__pyx_n_s_call;
  PyObject *__pyx_n_s_call_callback;
  PyObject *__pyx_n_s_call_order;
  PyObject *__pyx_n_s_callable;
  PyObject *__pyx_n_s_callback;
  PyObject *__pyx_n_s_can_not_skip;
  PyObject *__pyx_n_s_can_skip;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_clear_run_state;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_cmd;
  PyObject *__pyx_n_s_cmd_factory;
  PyObject *__pyx_n_s_cmd_step_into;
  PyObject *__pyx_n_s_cmd_step_over;
  PyObject *__pyx_n_s_co_filename;
  PyObject *__pyx_n_s_co_firstlineno;
  PyObject *__pyx_n_s_co_name;
  PyObject *__pyx_n_s_code;
  PyObject *__pyx_n_s_context_end_line;
  PyObject *__pyx_n_s_context_start_line;
  PyObject *__pyx_n_s_curr_func_name;
  PyObject *__pyx_n_s_current_events;
  PyObject *__pyx_n_s_current_thread;
  PyObject *__pyx_n_s_debug;
  PyObject *__pyx_n_s_debugger;
  PyObject *__pyx_n_s_do_wait_suspend;
  PyObject *__pyx_n_s_enable_line_tracing;
  PyObject *__pyx_n_s_enable_pep669_monitoring;
  PyObject *__pyx_n_s_enable_return_tracing;
  PyObject *__pyx_n_s_end_line;
  PyObject *__pyx_n_s_eval_result;
  PyObject *__pyx_n_s_event;
  PyObject *__pyx_n_s_event_type;
  PyObject *__pyx_n_s_events;
  PyObject *__pyx_n_s_exc_info;
  PyObject *__pyx_n_s_exception;
  PyObject *__pyx_n_s_exec;
  PyObject *__pyx_n_s_exist_result;
  PyObject *__pyx_n_s_expression;
  PyObject *__pyx_n_s_f_back;
  PyObject *__pyx_n_s_f_code;
  PyObject *__pyx_n_s_f_lineno;
  PyObject *__pyx_n_s_f_unhandled;
  PyObject *__pyx_n_s_file_type;
  PyObject *__pyx_n_s_filename;
  PyObject *__pyx_n_s_find_last_call_name;
  PyObject *__pyx_n_s_find_last_func_call_order;
  PyObject *__pyx_n_s_finish_debugging_session;
  PyObject *__pyx_n_s_flag;
  PyObject *__pyx_n_s_frame;
  PyObject *__pyx_n_s_frame_cache_key;
  PyObject *__pyx_n_s_func_name;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_get_abs_path_real_path_and_base;
  PyObject *__pyx_n_s_get_abs_path_real_path_and_base_2;
  PyObject *__pyx_n_s_get_additional_info;
  PyObject *__pyx_n_s_get_breakpoint;
  PyObject *__pyx_n_s_get_current_thread;
  PyObject *__pyx_n_s_get_events;
  PyObject *__pyx_n_s_get_file_type;
  PyObject *__pyx_n_s_get_local_events;
  PyObject *__pyx_n_s_get_tool;
  PyObject *__pyx_n_s_get_top_level_frame;
  PyObject *__pyx_n_s_getframe;
  PyObject *__pyx_n_s_global_cache_frame_skips;
  PyObject *__pyx_n_s_global_cache_skips;
  PyObject *__pyx_n_s_global_dbg;
  PyObject *__pyx_n_s_handle_breakpoint_condition;
  PyObject *__pyx_n_s_handle_breakpoint_expression;
  PyObject *__pyx_n_s_handle_exception;
  PyObject *__pyx_n_s_has_breakpoint_in_frame;
  PyObject *__pyx_n_s_has_condition;
  PyObject *__pyx_n_s_has_exception_breakpoints;
  PyObject *__pyx_n_s_has_plugin_exception_breaks;
  PyObject *__pyx_n_s_has_plugin_line_breaks;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_in_project_scope;
  PyObject *__pyx_n_s_info;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_instruction_offset;
  PyObject *__pyx_kp_s_invalid;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_n_s_is_filter_enabled;
  PyObject *__pyx_n_s_is_filter_libraries;
  PyObject *__pyx_n_s_is_ignored_by_filters;
  PyObject *__pyx_n_s_is_logpoint;
  PyObject *__pyx_n_s_is_pep669_monitoring_enabled;
  PyObject *__pyx_n_s_is_stepping;
  PyObject *__pyx_n_s_is_thread_alive;
  PyObject *__pyx_n_s_is_tracing;
  PyObject *__pyx_n_s_is_within_context;
  PyObject *__pyx_kp_s_lambda;
  PyObject *__pyx_n_s_line;
  PyObject *__pyx_n_s_line_cache_key;
  PyObject *__pyx_n_s_line_number;
  PyObject *__pyx_n_s_linesep;
  PyObject *__pyx_n_s_local_events;
  PyObject *__pyx_n_s_log_event;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_make_frame_cache_key;
  PyObject *__pyx_n_s_make_io_message;
  PyObject *__pyx_n_s_manage_return_values;
  PyObject *__pyx_n_s_modify_global_events;
  PyObject *__pyx_kp_s_module;
  PyObject *__pyx_n_s_monitoring;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_s_new_frame;
  PyObject *__pyx_n_s_not_processed;
  PyObject *__pyx_n_s_os;
  PyObject *__pyx_n_s_os_path;
  PyObject *__pyx_n_s_path;
  PyObject *__pyx_n_s_plugin;
  PyObject *__pyx_n_s_plugin_manager;
  PyObject *__pyx_n_s_plugin_stop;
  PyObject *__pyx_n_s_print_exc;
  PyObject *__pyx_n_s_py_db;
  PyObject *__pyx_n_s_py_line_callback;
  PyObject *__pyx_n_s_py_raise_callback;
  PyObject *__pyx_n_s_py_return_callback;
  PyObject *__pyx_n_s_py_start_callback;
  PyObject *__pyx_n_s_pydev_bundle;
  PyObject *__pyx_n_s_pydev_bundle_pydev_is_thread_al;
  PyObject *__pyx_n_s_pydev_func_name;
  PyObject *__pyx_n_s_pydev_log;
  PyObject *__pyx_n_s_pydev_message;
  PyObject *__pyx_n_s_pydev_smart_step_context;
  PyObject *__pyx_n_s_pydev_state;
  PyObject *__pyx_n_s_pydev_step_cmd;
  PyObject *__pyx_n_s_pydev_step_stop;
  PyObject *__pyx_n_s_pydevd;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_breakpoint;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_bytecode_u;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_comm_const;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_constants;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_dont_trace;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_pep_669_tr;
  PyObject *__pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2;
  PyObject *__pyx_n_s_pydevd_bundle_pydevd_trace_disp;
  PyObject *__pyx_n_s_pydevd_file_utils;
  PyObject *__pyx_n_s_quitting;
  PyObject *__pyx_n_s_register_callback;
  PyObject *__pyx_n_s_remove_breakpoint;
  PyObject *__pyx_n_s_remove_return_values_flag;
  PyObject *__pyx_n_s_reset;
  PyObject *__pyx_n_s_restart_events;
  PyObject *__pyx_n_s_result;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_retval;
  PyObject *__pyx_n_s_set_additional_thread_info;
  PyObject *__pyx_n_s_set_events;
  PyObject *__pyx_n_s_set_local_events;
  PyObject *__pyx_n_s_set_suspend;
  PyObject *__pyx_n_s_should_enable_line_events_for_c;
  PyObject *__pyx_n_s_should_stop;
  PyObject *__pyx_n_s_should_stop_on_exception;
  PyObject *__pyx_n_s_show_return_values;
  PyObject *__pyx_n_s_smart_step_stop;
  PyObject *__pyx_n_s_smart_stop_frame;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_splitext;
  PyObject *__pyx_n_s_start_line;
  PyObject *__pyx_n_s_step_cmd;
  PyObject *__pyx_n_s_stop;
  PyObject *__pyx_n_s_stop_frame;
  PyObject *__pyx_n_s_stop_info;
  PyObject *__pyx_n_s_stop_on_failed_tests;
  PyObject *__pyx_n_s_stop_on_unhandled_exception;
  PyObject *__pyx_n_s_stop_on_unhandled_exception_2;
  PyObject *__pyx_n_s_suspend;
  PyObject *__pyx_n_s_suspend_other_threads;
  PyObject *__pyx_n_s_suspend_policy;
  PyObject *__pyx_n_s_suspended_at_unhandled;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_thread;
  PyObject *__pyx_n_s_thread_analyser;
  PyObject *__pyx_n_s_threading;
  PyObject *__pyx_n_s_traceback;
  PyObject *__pyx_n_s_traceback_2;
  PyObject *__pyx_n_s_use_tool_id;
  PyObject *__pyx_n_s_values;
  PyObject *__pyx_n_s_will_be_stopped;
  PyObject *__pyx_n_s_writer;
  PyObject *__pyx_n_s_x;
  PyObject *__pyx_n_s_y;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_108;
  PyObject *__pyx_int_109;
  PyObject *__pyx_int_neg_1;
  PyObject *__pyx_tuple__5;
  PyObject *__pyx_tuple__7;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__15;
  PyObject *__pyx_tuple__17;
  PyObject *__pyx_tuple__19;
  PyObject *__pyx_tuple__21;
  PyObject *__pyx_tuple__24;
  PyObject *__pyx_tuple__26;
  PyObject *__pyx_tuple__29;
  PyObject *__pyx_tuple__32;
  PyObject *__pyx_tuple__34;
  PyObject *__pyx_tuple__36;
  PyObject *__pyx_tuple__38;
  PyObject *__pyx_codeobj__6;
  PyObject *__pyx_codeobj__8;
  PyObject *__pyx_codeobj__10;
  PyObject *__pyx_codeobj__12;
  PyObject *__pyx_codeobj__14;
  PyObject *__pyx_codeobj__16;
  PyObject *__pyx_codeobj__18;
  PyObject *__pyx_codeobj__20;
  PyObject *__pyx_codeobj__22;
  PyObject *__pyx_codeobj__23;
  PyObject *__pyx_codeobj__25;
  PyObject *__pyx_codeobj__27;
  PyObject *__pyx_codeobj__28;
  PyObject *__pyx_codeobj__30;
  PyObject *__pyx_codeobj__33;
  PyObject *__pyx_codeobj__35;
  PyObject *__pyx_codeobj__37;
  PyObject *__pyx_codeobj__39;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_kp_s_);
  Py_CLEAR(clear_module_state->__pyx_kp_s_1);
  Py_CLEAR(clear_module_state->__pyx_n_s_ADD);
  Py_CLEAR(clear_module_state->__pyx_n_s_ALL);
  Py_CLEAR(clear_module_state->__pyx_n_s_AttributeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_CALL);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_SET_BREAK);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_SMART_STEP_INTO);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_STEP_INTO);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_STEP_INTO_COROUTINE);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_STEP_INTO_MY_CODE);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_STEP_OVER);
  Py_CLEAR(clear_module_state->__pyx_n_s_CMD_STEP_RETURN);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEBUGGER_ID);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEBUG_START);
  Py_CLEAR(clear_module_state->__pyx_n_s_DEBUG_START_PY3K);
  Py_CLEAR(clear_module_state->__pyx_n_s_DISABLE);
  Py_CLEAR(clear_module_state->__pyx_n_s_DONT_TRACE);
  Py_CLEAR(clear_module_state->__pyx_n_s_EVENT_ACTIONS);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Exception_while_handling_smart_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_GlobalDebuggerHolder);
  Py_CLEAR(clear_module_state->__pyx_n_s_IS_CPYTHON);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyboardInterrupt);
  Py_CLEAR(clear_module_state->__pyx_n_s_LINE);
  Py_CLEAR(clear_module_state->__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER);
  Py_CLEAR(clear_module_state->__pyx_n_s_None);
  Py_CLEAR(clear_module_state->__pyx_n_s_PYDEVD_TOOL_NAME);
  Py_CLEAR(clear_module_state->__pyx_n_s_PYDEV_FILE);
  Py_CLEAR(clear_module_state->__pyx_n_s_PY_RETURN);
  Py_CLEAR(clear_module_state->__pyx_n_s_PY_START);
  Py_CLEAR(clear_module_state->__pyx_n_s_RAISE);
  Py_CLEAR(clear_module_state->__pyx_n_s_REMOVE);
  Py_CLEAR(clear_module_state->__pyx_n_s_STATE_RUN);
  Py_CLEAR(clear_module_state->__pyx_n_s_STATE_SUSPEND);
  Py_CLEAR(clear_module_state->__pyx_n_s_SystemExit);
  Py_CLEAR(clear_module_state->__pyx_kp_s__2);
  Py_CLEAR(clear_module_state->__pyx_n_s__3);
  Py_CLEAR(clear_module_state->__pyx_n_s__31);
  Py_CLEAR(clear_module_state->__pyx_kp_u__4);
  Py_CLEAR(clear_module_state->__pyx_n_s_abs_path_real_path_and_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_action);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_command);
  Py_CLEAR(clear_module_state->__pyx_n_s_add_new_breakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_additional_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_arg0);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_analyser);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_back);
  Py_CLEAR(clear_module_state->__pyx_n_s_back_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_back_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_base_back_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_basename);
  Py_CLEAR(clear_module_state->__pyx_n_s_bootstrap_inner);
  Py_CLEAR(clear_module_state->__pyx_n_s_bp_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_break_on_caught_exceptions);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoints);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoints_for_back_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoints_for_file);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoints_in_frame_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_breakpoints_in_line_cache);
  Py_CLEAR(clear_module_state->__pyx_n_s_call);
  Py_CLEAR(clear_module_state->__pyx_n_s_call_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_call_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_callable);
  Py_CLEAR(clear_module_state->__pyx_n_s_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_can_not_skip);
  Py_CLEAR(clear_module_state->__pyx_n_s_can_skip);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_clear_run_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_cmd);
  Py_CLEAR(clear_module_state->__pyx_n_s_cmd_factory);
  Py_CLEAR(clear_module_state->__pyx_n_s_cmd_step_into);
  Py_CLEAR(clear_module_state->__pyx_n_s_cmd_step_over);
  Py_CLEAR(clear_module_state->__pyx_n_s_co_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_co_firstlineno);
  Py_CLEAR(clear_module_state->__pyx_n_s_co_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_context_end_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_context_start_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_curr_func_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_current_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_debug);
  Py_CLEAR(clear_module_state->__pyx_n_s_debugger);
  Py_CLEAR(clear_module_state->__pyx_n_s_do_wait_suspend);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_line_tracing);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_pep669_monitoring);
  Py_CLEAR(clear_module_state->__pyx_n_s_enable_return_tracing);
  Py_CLEAR(clear_module_state->__pyx_n_s_end_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_eval_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_event_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_exc_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_exec);
  Py_CLEAR(clear_module_state->__pyx_n_s_exist_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_expression);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_back);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_code);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_lineno);
  Py_CLEAR(clear_module_state->__pyx_n_s_f_unhandled);
  Py_CLEAR(clear_module_state->__pyx_n_s_file_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_filename);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_last_call_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_find_last_func_call_order);
  Py_CLEAR(clear_module_state->__pyx_n_s_finish_debugging_session);
  Py_CLEAR(clear_module_state->__pyx_n_s_flag);
  Py_CLEAR(clear_module_state->__pyx_n_s_frame);
  Py_CLEAR(clear_module_state->__pyx_n_s_frame_cache_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_func_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_abs_path_real_path_and_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_abs_path_real_path_and_base_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_additional_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_breakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_current_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_file_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_local_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_tool);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_top_level_frame);
  Py_CLEAR(clear_module_state->__pyx_n_s_getframe);
  Py_CLEAR(clear_module_state->__pyx_n_s_global_cache_frame_skips);
  Py_CLEAR(clear_module_state->__pyx_n_s_global_cache_skips);
  Py_CLEAR(clear_module_state->__pyx_n_s_global_dbg);
  Py_CLEAR(clear_module_state->__pyx_n_s_handle_breakpoint_condition);
  Py_CLEAR(clear_module_state->__pyx_n_s_handle_breakpoint_expression);
  Py_CLEAR(clear_module_state->__pyx_n_s_handle_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_breakpoint_in_frame);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_condition);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_exception_breakpoints);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_plugin_exception_breaks);
  Py_CLEAR(clear_module_state->__pyx_n_s_has_plugin_line_breaks);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_in_project_scope);
  Py_CLEAR(clear_module_state->__pyx_n_s_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_instruction_offset);
  Py_CLEAR(clear_module_state->__pyx_kp_s_invalid);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_filter_enabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_filter_libraries);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_ignored_by_filters);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_logpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_pep669_monitoring_enabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_stepping);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_thread_alive);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_tracing);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_within_context);
  Py_CLEAR(clear_module_state->__pyx_kp_s_lambda);
  Py_CLEAR(clear_module_state->__pyx_n_s_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_cache_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_line_number);
  Py_CLEAR(clear_module_state->__pyx_n_s_linesep);
  Py_CLEAR(clear_module_state->__pyx_n_s_local_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_log_event);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_frame_cache_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_make_io_message);
  Py_CLEAR(clear_module_state->__pyx_n_s_manage_return_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_modify_global_events);
  Py_CLEAR(clear_module_state->__pyx_kp_s_module);
  Py_CLEAR(clear_module_state->__pyx_n_s_monitoring);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_new_frame);
  Py_CLEAR(clear_module_state->__pyx_n_s_not_processed);
  Py_CLEAR(clear_module_state->__pyx_n_s_os);
  Py_CLEAR(clear_module_state->__pyx_n_s_os_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_path);
  Py_CLEAR(clear_module_state->__pyx_n_s_plugin);
  Py_CLEAR(clear_module_state->__pyx_n_s_plugin_manager);
  Py_CLEAR(clear_module_state->__pyx_n_s_plugin_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_print_exc);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_db);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_line_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_raise_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_return_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_py_start_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_bundle);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_bundle_pydev_is_thread_al);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_func_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_log);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_message);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_smart_step_context);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_step_cmd);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydev_step_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_breakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_bytecode_u);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_comm_const);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_constants);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_dont_trace);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_pep_669_tr);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_bundle_pydevd_trace_disp);
  Py_CLEAR(clear_module_state->__pyx_n_s_pydevd_file_utils);
  Py_CLEAR(clear_module_state->__pyx_n_s_quitting);
  Py_CLEAR(clear_module_state->__pyx_n_s_register_callback);
  Py_CLEAR(clear_module_state->__pyx_n_s_remove_breakpoint);
  Py_CLEAR(clear_module_state->__pyx_n_s_remove_return_values_flag);
  Py_CLEAR(clear_module_state->__pyx_n_s_reset);
  Py_CLEAR(clear_module_state->__pyx_n_s_restart_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_retval);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_additional_thread_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_local_events);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_suspend);
  Py_CLEAR(clear_module_state->__pyx_n_s_should_enable_line_events_for_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_should_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_should_stop_on_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_show_return_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_smart_step_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_smart_stop_frame);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_splitext);
  Py_CLEAR(clear_module_state->__pyx_n_s_start_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_step_cmd);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop_frame);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop_on_failed_tests);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop_on_unhandled_exception);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop_on_unhandled_exception_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_suspend);
  Py_CLEAR(clear_module_state->__pyx_n_s_suspend_other_threads);
  Py_CLEAR(clear_module_state->__pyx_n_s_suspend_policy);
  Py_CLEAR(clear_module_state->__pyx_n_s_suspended_at_unhandled);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_thread);
  Py_CLEAR(clear_module_state->__pyx_n_s_thread_analyser);
  Py_CLEAR(clear_module_state->__pyx_n_s_threading);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_traceback_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_tool_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_will_be_stopped);
  Py_CLEAR(clear_module_state->__pyx_n_s_writer);
  Py_CLEAR(clear_module_state->__pyx_n_s_x);
  Py_CLEAR(clear_module_state->__pyx_n_s_y);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_108);
  Py_CLEAR(clear_module_state->__pyx_int_109);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_tuple__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__7);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__15);
  Py_CLEAR(clear_module_state->__pyx_tuple__17);
  Py_CLEAR(clear_module_state->__pyx_tuple__19);
  Py_CLEAR(clear_module_state->__pyx_tuple__21);
  Py_CLEAR(clear_module_state->__pyx_tuple__24);
  Py_CLEAR(clear_module_state->__pyx_tuple__26);
  Py_CLEAR(clear_module_state->__pyx_tuple__29);
  Py_CLEAR(clear_module_state->__pyx_tuple__32);
  Py_CLEAR(clear_module_state->__pyx_tuple__34);
  Py_CLEAR(clear_module_state->__pyx_tuple__36);
  Py_CLEAR(clear_module_state->__pyx_tuple__38);
  Py_CLEAR(clear_module_state->__pyx_codeobj__6);
  Py_CLEAR(clear_module_state->__pyx_codeobj__8);
  Py_CLEAR(clear_module_state->__pyx_codeobj__10);
  Py_CLEAR(clear_module_state->__pyx_codeobj__12);
  Py_CLEAR(clear_module_state->__pyx_codeobj__14);
  Py_CLEAR(clear_module_state->__pyx_codeobj__16);
  Py_CLEAR(clear_module_state->__pyx_codeobj__18);
  Py_CLEAR(clear_module_state->__pyx_codeobj__20);
  Py_CLEAR(clear_module_state->__pyx_codeobj__22);
  Py_CLEAR(clear_module_state->__pyx_codeobj__23);
  Py_CLEAR(clear_module_state->__pyx_codeobj__25);
  Py_CLEAR(clear_module_state->__pyx_codeobj__27);
  Py_CLEAR(clear_module_state->__pyx_codeobj__28);
  Py_CLEAR(clear_module_state->__pyx_codeobj__30);
  Py_CLEAR(clear_module_state->__pyx_codeobj__33);
  Py_CLEAR(clear_module_state->__pyx_codeobj__35);
  Py_CLEAR(clear_module_state->__pyx_codeobj__37);
  Py_CLEAR(clear_module_state->__pyx_codeobj__39);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_kp_s_);
  Py_VISIT(traverse_module_state->__pyx_kp_s_1);
  Py_VISIT(traverse_module_state->__pyx_n_s_ADD);
  Py_VISIT(traverse_module_state->__pyx_n_s_ALL);
  Py_VISIT(traverse_module_state->__pyx_n_s_AttributeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_CALL);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_SET_BREAK);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_SMART_STEP_INTO);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_STEP_INTO);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_STEP_INTO_COROUTINE);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_STEP_INTO_MY_CODE);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_STEP_OVER);
  Py_VISIT(traverse_module_state->__pyx_n_s_CMD_STEP_RETURN);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEBUGGER_ID);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEBUG_START);
  Py_VISIT(traverse_module_state->__pyx_n_s_DEBUG_START_PY3K);
  Py_VISIT(traverse_module_state->__pyx_n_s_DISABLE);
  Py_VISIT(traverse_module_state->__pyx_n_s_DONT_TRACE);
  Py_VISIT(traverse_module_state->__pyx_n_s_EVENT_ACTIONS);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Exception_while_handling_smart_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_GlobalDebuggerHolder);
  Py_VISIT(traverse_module_state->__pyx_n_s_IS_CPYTHON);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyboardInterrupt);
  Py_VISIT(traverse_module_state->__pyx_n_s_LINE);
  Py_VISIT(traverse_module_state->__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER);
  Py_VISIT(traverse_module_state->__pyx_n_s_None);
  Py_VISIT(traverse_module_state->__pyx_n_s_PYDEVD_TOOL_NAME);
  Py_VISIT(traverse_module_state->__pyx_n_s_PYDEV_FILE);
  Py_VISIT(traverse_module_state->__pyx_n_s_PY_RETURN);
  Py_VISIT(traverse_module_state->__pyx_n_s_PY_START);
  Py_VISIT(traverse_module_state->__pyx_n_s_RAISE);
  Py_VISIT(traverse_module_state->__pyx_n_s_REMOVE);
  Py_VISIT(traverse_module_state->__pyx_n_s_STATE_RUN);
  Py_VISIT(traverse_module_state->__pyx_n_s_STATE_SUSPEND);
  Py_VISIT(traverse_module_state->__pyx_n_s_SystemExit);
  Py_VISIT(traverse_module_state->__pyx_kp_s__2);
  Py_VISIT(traverse_module_state->__pyx_n_s__3);
  Py_VISIT(traverse_module_state->__pyx_n_s__31);
  Py_VISIT(traverse_module_state->__pyx_kp_u__4);
  Py_VISIT(traverse_module_state->__pyx_n_s_abs_path_real_path_and_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_action);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_command);
  Py_VISIT(traverse_module_state->__pyx_n_s_add_new_breakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_additional_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_arg0);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_analyser);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_back);
  Py_VISIT(traverse_module_state->__pyx_n_s_back_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_back_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_base_back_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_basename);
  Py_VISIT(traverse_module_state->__pyx_n_s_bootstrap_inner);
  Py_VISIT(traverse_module_state->__pyx_n_s_bp_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_break_on_caught_exceptions);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoints);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoints_for_back_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoints_for_file);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoints_in_frame_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_breakpoints_in_line_cache);
  Py_VISIT(traverse_module_state->__pyx_n_s_call);
  Py_VISIT(traverse_module_state->__pyx_n_s_call_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_call_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_callable);
  Py_VISIT(traverse_module_state->__pyx_n_s_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_can_not_skip);
  Py_VISIT(traverse_module_state->__pyx_n_s_can_skip);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_clear_run_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_cmd);
  Py_VISIT(traverse_module_state->__pyx_n_s_cmd_factory);
  Py_VISIT(traverse_module_state->__pyx_n_s_cmd_step_into);
  Py_VISIT(traverse_module_state->__pyx_n_s_cmd_step_over);
  Py_VISIT(traverse_module_state->__pyx_n_s_co_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_co_firstlineno);
  Py_VISIT(traverse_module_state->__pyx_n_s_co_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_context_end_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_context_start_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_curr_func_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_current_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_debug);
  Py_VISIT(traverse_module_state->__pyx_n_s_debugger);
  Py_VISIT(traverse_module_state->__pyx_n_s_do_wait_suspend);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_line_tracing);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_pep669_monitoring);
  Py_VISIT(traverse_module_state->__pyx_n_s_enable_return_tracing);
  Py_VISIT(traverse_module_state->__pyx_n_s_end_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_eval_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_event_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_exc_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_exec);
  Py_VISIT(traverse_module_state->__pyx_n_s_exist_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_expression);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_back);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_code);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_lineno);
  Py_VISIT(traverse_module_state->__pyx_n_s_f_unhandled);
  Py_VISIT(traverse_module_state->__pyx_n_s_file_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_filename);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_last_call_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_find_last_func_call_order);
  Py_VISIT(traverse_module_state->__pyx_n_s_finish_debugging_session);
  Py_VISIT(traverse_module_state->__pyx_n_s_flag);
  Py_VISIT(traverse_module_state->__pyx_n_s_frame);
  Py_VISIT(traverse_module_state->__pyx_n_s_frame_cache_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_func_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_abs_path_real_path_and_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_abs_path_real_path_and_base_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_additional_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_breakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_current_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_file_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_local_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_tool);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_top_level_frame);
  Py_VISIT(traverse_module_state->__pyx_n_s_getframe);
  Py_VISIT(traverse_module_state->__pyx_n_s_global_cache_frame_skips);
  Py_VISIT(traverse_module_state->__pyx_n_s_global_cache_skips);
  Py_VISIT(traverse_module_state->__pyx_n_s_global_dbg);
  Py_VISIT(traverse_module_state->__pyx_n_s_handle_breakpoint_condition);
  Py_VISIT(traverse_module_state->__pyx_n_s_handle_breakpoint_expression);
  Py_VISIT(traverse_module_state->__pyx_n_s_handle_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_breakpoint_in_frame);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_condition);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_exception_breakpoints);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_plugin_exception_breaks);
  Py_VISIT(traverse_module_state->__pyx_n_s_has_plugin_line_breaks);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_in_project_scope);
  Py_VISIT(traverse_module_state->__pyx_n_s_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_instruction_offset);
  Py_VISIT(traverse_module_state->__pyx_kp_s_invalid);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_filter_enabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_filter_libraries);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_ignored_by_filters);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_logpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_pep669_monitoring_enabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_stepping);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_thread_alive);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_tracing);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_within_context);
  Py_VISIT(traverse_module_state->__pyx_kp_s_lambda);
  Py_VISIT(traverse_module_state->__pyx_n_s_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_cache_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_line_number);
  Py_VISIT(traverse_module_state->__pyx_n_s_linesep);
  Py_VISIT(traverse_module_state->__pyx_n_s_local_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_log_event);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_frame_cache_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_make_io_message);
  Py_VISIT(traverse_module_state->__pyx_n_s_manage_return_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_modify_global_events);
  Py_VISIT(traverse_module_state->__pyx_kp_s_module);
  Py_VISIT(traverse_module_state->__pyx_n_s_monitoring);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_new_frame);
  Py_VISIT(traverse_module_state->__pyx_n_s_not_processed);
  Py_VISIT(traverse_module_state->__pyx_n_s_os);
  Py_VISIT(traverse_module_state->__pyx_n_s_os_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_path);
  Py_VISIT(traverse_module_state->__pyx_n_s_plugin);
  Py_VISIT(traverse_module_state->__pyx_n_s_plugin_manager);
  Py_VISIT(traverse_module_state->__pyx_n_s_plugin_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_print_exc);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_db);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_line_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_raise_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_return_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_py_start_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_bundle);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_bundle_pydev_is_thread_al);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_func_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_log);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_message);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_smart_step_context);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_step_cmd);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydev_step_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_breakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_bytecode_u);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_comm_const);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_constants);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_dont_trace);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_pep_669_tr);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_bundle_pydevd_trace_disp);
  Py_VISIT(traverse_module_state->__pyx_n_s_pydevd_file_utils);
  Py_VISIT(traverse_module_state->__pyx_n_s_quitting);
  Py_VISIT(traverse_module_state->__pyx_n_s_register_callback);
  Py_VISIT(traverse_module_state->__pyx_n_s_remove_breakpoint);
  Py_VISIT(traverse_module_state->__pyx_n_s_remove_return_values_flag);
  Py_VISIT(traverse_module_state->__pyx_n_s_reset);
  Py_VISIT(traverse_module_state->__pyx_n_s_restart_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_retval);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_additional_thread_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_local_events);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_suspend);
  Py_VISIT(traverse_module_state->__pyx_n_s_should_enable_line_events_for_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_should_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_should_stop_on_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_show_return_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_smart_step_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_smart_stop_frame);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_splitext);
  Py_VISIT(traverse_module_state->__pyx_n_s_start_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_step_cmd);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop_frame);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop_on_failed_tests);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop_on_unhandled_exception);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop_on_unhandled_exception_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_suspend);
  Py_VISIT(traverse_module_state->__pyx_n_s_suspend_other_threads);
  Py_VISIT(traverse_module_state->__pyx_n_s_suspend_policy);
  Py_VISIT(traverse_module_state->__pyx_n_s_suspended_at_unhandled);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_thread);
  Py_VISIT(traverse_module_state->__pyx_n_s_thread_analyser);
  Py_VISIT(traverse_module_state->__pyx_n_s_threading);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_traceback_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_tool_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_will_be_stopped);
  Py_VISIT(traverse_module_state->__pyx_n_s_writer);
  Py_VISIT(traverse_module_state->__pyx_n_s_x);
  Py_VISIT(traverse_module_state->__pyx_n_s_y);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_108);
  Py_VISIT(traverse_module_state->__pyx_int_109);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_tuple__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__7);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__15);
  Py_VISIT(traverse_module_state->__pyx_tuple__17);
  Py_VISIT(traverse_module_state->__pyx_tuple__19);
  Py_VISIT(traverse_module_state->__pyx_tuple__21);
  Py_VISIT(traverse_module_state->__pyx_tuple__24);
  Py_VISIT(traverse_module_state->__pyx_tuple__26);
  Py_VISIT(traverse_module_state->__pyx_tuple__29);
  Py_VISIT(traverse_module_state->__pyx_tuple__32);
  Py_VISIT(traverse_module_state->__pyx_tuple__34);
  Py_VISIT(traverse_module_state->__pyx_tuple__36);
  Py_VISIT(traverse_module_state->__pyx_tuple__38);
  Py_VISIT(traverse_module_state->__pyx_codeobj__6);
  Py_VISIT(traverse_module_state->__pyx_codeobj__8);
  Py_VISIT(traverse_module_state->__pyx_codeobj__10);
  Py_VISIT(traverse_module_state->__pyx_codeobj__12);
  Py_VISIT(traverse_module_state->__pyx_codeobj__14);
  Py_VISIT(traverse_module_state->__pyx_codeobj__16);
  Py_VISIT(traverse_module_state->__pyx_codeobj__18);
  Py_VISIT(traverse_module_state->__pyx_codeobj__20);
  Py_VISIT(traverse_module_state->__pyx_codeobj__22);
  Py_VISIT(traverse_module_state->__pyx_codeobj__23);
  Py_VISIT(traverse_module_state->__pyx_codeobj__25);
  Py_VISIT(traverse_module_state->__pyx_codeobj__27);
  Py_VISIT(traverse_module_state->__pyx_codeobj__28);
  Py_VISIT(traverse_module_state->__pyx_codeobj__30);
  Py_VISIT(traverse_module_state->__pyx_codeobj__33);
  Py_VISIT(traverse_module_state->__pyx_codeobj__35);
  Py_VISIT(traverse_module_state->__pyx_codeobj__37);
  Py_VISIT(traverse_module_state->__pyx_codeobj__39);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_kp_s_ __pyx_mstate_global->__pyx_kp_s_
#define __pyx_kp_s_1 __pyx_mstate_global->__pyx_kp_s_1
#define __pyx_n_s_ADD __pyx_mstate_global->__pyx_n_s_ADD
#define __pyx_n_s_ALL __pyx_mstate_global->__pyx_n_s_ALL
#define __pyx_n_s_AttributeError __pyx_mstate_global->__pyx_n_s_AttributeError
#define __pyx_n_s_CALL __pyx_mstate_global->__pyx_n_s_CALL
#define __pyx_n_s_CMD_SET_BREAK __pyx_mstate_global->__pyx_n_s_CMD_SET_BREAK
#define __pyx_n_s_CMD_SMART_STEP_INTO __pyx_mstate_global->__pyx_n_s_CMD_SMART_STEP_INTO
#define __pyx_n_s_CMD_STEP_INTO __pyx_mstate_global->__pyx_n_s_CMD_STEP_INTO
#define __pyx_n_s_CMD_STEP_INTO_COROUTINE __pyx_mstate_global->__pyx_n_s_CMD_STEP_INTO_COROUTINE
#define __pyx_n_s_CMD_STEP_INTO_MY_CODE __pyx_mstate_global->__pyx_n_s_CMD_STEP_INTO_MY_CODE
#define __pyx_n_s_CMD_STEP_OVER __pyx_mstate_global->__pyx_n_s_CMD_STEP_OVER
#define __pyx_n_s_CMD_STEP_RETURN __pyx_mstate_global->__pyx_n_s_CMD_STEP_RETURN
#define __pyx_n_s_DEBUGGER_ID __pyx_mstate_global->__pyx_n_s_DEBUGGER_ID
#define __pyx_n_s_DEBUG_START __pyx_mstate_global->__pyx_n_s_DEBUG_START
#define __pyx_n_s_DEBUG_START_PY3K __pyx_mstate_global->__pyx_n_s_DEBUG_START_PY3K
#define __pyx_n_s_DISABLE __pyx_mstate_global->__pyx_n_s_DISABLE
#define __pyx_n_s_DONT_TRACE __pyx_mstate_global->__pyx_n_s_DONT_TRACE
#define __pyx_n_s_EVENT_ACTIONS __pyx_mstate_global->__pyx_n_s_EVENT_ACTIONS
#define __pyx_kp_s_Exception_while_handling_smart_s __pyx_mstate_global->__pyx_kp_s_Exception_while_handling_smart_s
#define __pyx_n_s_GlobalDebuggerHolder __pyx_mstate_global->__pyx_n_s_GlobalDebuggerHolder
#define __pyx_n_s_IS_CPYTHON __pyx_mstate_global->__pyx_n_s_IS_CPYTHON
#define __pyx_n_s_KeyboardInterrupt __pyx_mstate_global->__pyx_n_s_KeyboardInterrupt
#define __pyx_n_s_LINE __pyx_mstate_global->__pyx_n_s_LINE
#define __pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER __pyx_mstate_global->__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER
#define __pyx_n_s_None __pyx_mstate_global->__pyx_n_s_None
#define __pyx_n_s_PYDEVD_TOOL_NAME __pyx_mstate_global->__pyx_n_s_PYDEVD_TOOL_NAME
#define __pyx_n_s_PYDEV_FILE __pyx_mstate_global->__pyx_n_s_PYDEV_FILE
#define __pyx_n_s_PY_RETURN __pyx_mstate_global->__pyx_n_s_PY_RETURN
#define __pyx_n_s_PY_START __pyx_mstate_global->__pyx_n_s_PY_START
#define __pyx_n_s_RAISE __pyx_mstate_global->__pyx_n_s_RAISE
#define __pyx_n_s_REMOVE __pyx_mstate_global->__pyx_n_s_REMOVE
#define __pyx_n_s_STATE_RUN __pyx_mstate_global->__pyx_n_s_STATE_RUN
#define __pyx_n_s_STATE_SUSPEND __pyx_mstate_global->__pyx_n_s_STATE_SUSPEND
#define __pyx_n_s_SystemExit __pyx_mstate_global->__pyx_n_s_SystemExit
#define __pyx_kp_s__2 __pyx_mstate_global->__pyx_kp_s__2
#define __pyx_n_s__3 __pyx_mstate_global->__pyx_n_s__3
#define __pyx_n_s__31 __pyx_mstate_global->__pyx_n_s__31
#define __pyx_kp_u__4 __pyx_mstate_global->__pyx_kp_u__4
#define __pyx_n_s_abs_path_real_path_and_base __pyx_mstate_global->__pyx_n_s_abs_path_real_path_and_base
#define __pyx_n_s_action __pyx_mstate_global->__pyx_n_s_action
#define __pyx_n_s_add_command __pyx_mstate_global->__pyx_n_s_add_command
#define __pyx_n_s_add_new_breakpoint __pyx_mstate_global->__pyx_n_s_add_new_breakpoint
#define __pyx_n_s_additional_info __pyx_mstate_global->__pyx_n_s_additional_info
#define __pyx_n_s_arg0 __pyx_mstate_global->__pyx_n_s_arg0
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_asyncio_analyser __pyx_mstate_global->__pyx_n_s_asyncio_analyser
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_back __pyx_mstate_global->__pyx_n_s_back
#define __pyx_n_s_back_code __pyx_mstate_global->__pyx_n_s_back_code
#define __pyx_n_s_back_filename __pyx_mstate_global->__pyx_n_s_back_filename
#define __pyx_n_s_base __pyx_mstate_global->__pyx_n_s_base
#define __pyx_n_s_base_back_filename __pyx_mstate_global->__pyx_n_s_base_back_filename
#define __pyx_n_s_basename __pyx_mstate_global->__pyx_n_s_basename
#define __pyx_n_s_bootstrap_inner __pyx_mstate_global->__pyx_n_s_bootstrap_inner
#define __pyx_n_s_bp_type __pyx_mstate_global->__pyx_n_s_bp_type
#define __pyx_n_s_break_on_caught_exceptions __pyx_mstate_global->__pyx_n_s_break_on_caught_exceptions
#define __pyx_n_s_breakpoint __pyx_mstate_global->__pyx_n_s_breakpoint
#define __pyx_n_s_breakpoints __pyx_mstate_global->__pyx_n_s_breakpoints
#define __pyx_n_s_breakpoints_for_back_file __pyx_mstate_global->__pyx_n_s_breakpoints_for_back_file
#define __pyx_n_s_breakpoints_for_file __pyx_mstate_global->__pyx_n_s_breakpoints_for_file
#define __pyx_n_s_breakpoints_in_frame_cache __pyx_mstate_global->__pyx_n_s_breakpoints_in_frame_cache
#define __pyx_n_s_breakpoints_in_line_cache __pyx_mstate_global->__pyx_n_s_breakpoints_in_line_cache
#define __pyx_n_s_call __pyx_mstate_global->__pyx_n_s_call
#define __pyx_n_s_call_callback __pyx_mstate_global->__pyx_n_s_call_callback
#define __pyx_n_s_call_order __pyx_mstate_global->__pyx_n_s_call_order
#define __pyx_n_s_callable __pyx_mstate_global->__pyx_n_s_callable
#define __pyx_n_s_callback __pyx_mstate_global->__pyx_n_s_callback
#define __pyx_n_s_can_not_skip __pyx_mstate_global->__pyx_n_s_can_not_skip
#define __pyx_n_s_can_skip __pyx_mstate_global->__pyx_n_s_can_skip
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_clear_run_state __pyx_mstate_global->__pyx_n_s_clear_run_state
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_cmd __pyx_mstate_global->__pyx_n_s_cmd
#define __pyx_n_s_cmd_factory __pyx_mstate_global->__pyx_n_s_cmd_factory
#define __pyx_n_s_cmd_step_into __pyx_mstate_global->__pyx_n_s_cmd_step_into
#define __pyx_n_s_cmd_step_over __pyx_mstate_global->__pyx_n_s_cmd_step_over
#define __pyx_n_s_co_filename __pyx_mstate_global->__pyx_n_s_co_filename
#define __pyx_n_s_co_firstlineno __pyx_mstate_global->__pyx_n_s_co_firstlineno
#define __pyx_n_s_co_name __pyx_mstate_global->__pyx_n_s_co_name
#define __pyx_n_s_code __pyx_mstate_global->__pyx_n_s_code
#define __pyx_n_s_context_end_line __pyx_mstate_global->__pyx_n_s_context_end_line
#define __pyx_n_s_context_start_line __pyx_mstate_global->__pyx_n_s_context_start_line
#define __pyx_n_s_curr_func_name __pyx_mstate_global->__pyx_n_s_curr_func_name
#define __pyx_n_s_current_events __pyx_mstate_global->__pyx_n_s_current_events
#define __pyx_n_s_current_thread __pyx_mstate_global->__pyx_n_s_current_thread
#define __pyx_n_s_debug __pyx_mstate_global->__pyx_n_s_debug
#define __pyx_n_s_debugger __pyx_mstate_global->__pyx_n_s_debugger
#define __pyx_n_s_do_wait_suspend __pyx_mstate_global->__pyx_n_s_do_wait_suspend
#define __pyx_n_s_enable_line_tracing __pyx_mstate_global->__pyx_n_s_enable_line_tracing
#define __pyx_n_s_enable_pep669_monitoring __pyx_mstate_global->__pyx_n_s_enable_pep669_monitoring
#define __pyx_n_s_enable_return_tracing __pyx_mstate_global->__pyx_n_s_enable_return_tracing
#define __pyx_n_s_end_line __pyx_mstate_global->__pyx_n_s_end_line
#define __pyx_n_s_eval_result __pyx_mstate_global->__pyx_n_s_eval_result
#define __pyx_n_s_event __pyx_mstate_global->__pyx_n_s_event
#define __pyx_n_s_event_type __pyx_mstate_global->__pyx_n_s_event_type
#define __pyx_n_s_events __pyx_mstate_global->__pyx_n_s_events
#define __pyx_n_s_exc_info __pyx_mstate_global->__pyx_n_s_exc_info
#define __pyx_n_s_exception __pyx_mstate_global->__pyx_n_s_exception
#define __pyx_n_s_exec __pyx_mstate_global->__pyx_n_s_exec
#define __pyx_n_s_exist_result __pyx_mstate_global->__pyx_n_s_exist_result
#define __pyx_n_s_expression __pyx_mstate_global->__pyx_n_s_expression
#define __pyx_n_s_f_back __pyx_mstate_global->__pyx_n_s_f_back
#define __pyx_n_s_f_code __pyx_mstate_global->__pyx_n_s_f_code
#define __pyx_n_s_f_lineno __pyx_mstate_global->__pyx_n_s_f_lineno
#define __pyx_n_s_f_unhandled __pyx_mstate_global->__pyx_n_s_f_unhandled
#define __pyx_n_s_file_type __pyx_mstate_global->__pyx_n_s_file_type
#define __pyx_n_s_filename __pyx_mstate_global->__pyx_n_s_filename
#define __pyx_n_s_find_last_call_name __pyx_mstate_global->__pyx_n_s_find_last_call_name
#define __pyx_n_s_find_last_func_call_order __pyx_mstate_global->__pyx_n_s_find_last_func_call_order
#define __pyx_n_s_finish_debugging_session __pyx_mstate_global->__pyx_n_s_finish_debugging_session
#define __pyx_n_s_flag __pyx_mstate_global->__pyx_n_s_flag
#define __pyx_n_s_frame __pyx_mstate_global->__pyx_n_s_frame
#define __pyx_n_s_frame_cache_key __pyx_mstate_global->__pyx_n_s_frame_cache_key
#define __pyx_n_s_func_name __pyx_mstate_global->__pyx_n_s_func_name
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_get_abs_path_real_path_and_base __pyx_mstate_global->__pyx_n_s_get_abs_path_real_path_and_base
#define __pyx_n_s_get_abs_path_real_path_and_base_2 __pyx_mstate_global->__pyx_n_s_get_abs_path_real_path_and_base_2
#define __pyx_n_s_get_additional_info __pyx_mstate_global->__pyx_n_s_get_additional_info
#define __pyx_n_s_get_breakpoint __pyx_mstate_global->__pyx_n_s_get_breakpoint
#define __pyx_n_s_get_current_thread __pyx_mstate_global->__pyx_n_s_get_current_thread
#define __pyx_n_s_get_events __pyx_mstate_global->__pyx_n_s_get_events
#define __pyx_n_s_get_file_type __pyx_mstate_global->__pyx_n_s_get_file_type
#define __pyx_n_s_get_local_events __pyx_mstate_global->__pyx_n_s_get_local_events
#define __pyx_n_s_get_tool __pyx_mstate_global->__pyx_n_s_get_tool
#define __pyx_n_s_get_top_level_frame __pyx_mstate_global->__pyx_n_s_get_top_level_frame
#define __pyx_n_s_getframe __pyx_mstate_global->__pyx_n_s_getframe
#define __pyx_n_s_global_cache_frame_skips __pyx_mstate_global->__pyx_n_s_global_cache_frame_skips
#define __pyx_n_s_global_cache_skips __pyx_mstate_global->__pyx_n_s_global_cache_skips
#define __pyx_n_s_global_dbg __pyx_mstate_global->__pyx_n_s_global_dbg
#define __pyx_n_s_handle_breakpoint_condition __pyx_mstate_global->__pyx_n_s_handle_breakpoint_condition
#define __pyx_n_s_handle_breakpoint_expression __pyx_mstate_global->__pyx_n_s_handle_breakpoint_expression
#define __pyx_n_s_handle_exception __pyx_mstate_global->__pyx_n_s_handle_exception
#define __pyx_n_s_has_breakpoint_in_frame __pyx_mstate_global->__pyx_n_s_has_breakpoint_in_frame
#define __pyx_n_s_has_condition __pyx_mstate_global->__pyx_n_s_has_condition
#define __pyx_n_s_has_exception_breakpoints __pyx_mstate_global->__pyx_n_s_has_exception_breakpoints
#define __pyx_n_s_has_plugin_exception_breaks __pyx_mstate_global->__pyx_n_s_has_plugin_exception_breaks
#define __pyx_n_s_has_plugin_line_breaks __pyx_mstate_global->__pyx_n_s_has_plugin_line_breaks
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_in_project_scope __pyx_mstate_global->__pyx_n_s_in_project_scope
#define __pyx_n_s_info __pyx_mstate_global->__pyx_n_s_info
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_instruction_offset __pyx_mstate_global->__pyx_n_s_instruction_offset
#define __pyx_kp_s_invalid __pyx_mstate_global->__pyx_kp_s_invalid
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_n_s_is_filter_enabled __pyx_mstate_global->__pyx_n_s_is_filter_enabled
#define __pyx_n_s_is_filter_libraries __pyx_mstate_global->__pyx_n_s_is_filter_libraries
#define __pyx_n_s_is_ignored_by_filters __pyx_mstate_global->__pyx_n_s_is_ignored_by_filters
#define __pyx_n_s_is_logpoint __pyx_mstate_global->__pyx_n_s_is_logpoint
#define __pyx_n_s_is_pep669_monitoring_enabled __pyx_mstate_global->__pyx_n_s_is_pep669_monitoring_enabled
#define __pyx_n_s_is_stepping __pyx_mstate_global->__pyx_n_s_is_stepping
#define __pyx_n_s_is_thread_alive __pyx_mstate_global->__pyx_n_s_is_thread_alive
#define __pyx_n_s_is_tracing __pyx_mstate_global->__pyx_n_s_is_tracing
#define __pyx_n_s_is_within_context __pyx_mstate_global->__pyx_n_s_is_within_context
#define __pyx_kp_s_lambda __pyx_mstate_global->__pyx_kp_s_lambda
#define __pyx_n_s_line __pyx_mstate_global->__pyx_n_s_line
#define __pyx_n_s_line_cache_key __pyx_mstate_global->__pyx_n_s_line_cache_key
#define __pyx_n_s_line_number __pyx_mstate_global->__pyx_n_s_line_number
#define __pyx_n_s_linesep __pyx_mstate_global->__pyx_n_s_linesep
#define __pyx_n_s_local_events __pyx_mstate_global->__pyx_n_s_local_events
#define __pyx_n_s_log_event __pyx_mstate_global->__pyx_n_s_log_event
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_make_frame_cache_key __pyx_mstate_global->__pyx_n_s_make_frame_cache_key
#define __pyx_n_s_make_io_message __pyx_mstate_global->__pyx_n_s_make_io_message
#define __pyx_n_s_manage_return_values __pyx_mstate_global->__pyx_n_s_manage_return_values
#define __pyx_n_s_modify_global_events __pyx_mstate_global->__pyx_n_s_modify_global_events
#define __pyx_kp_s_module __pyx_mstate_global->__pyx_kp_s_module
#define __pyx_n_s_monitoring __pyx_mstate_global->__pyx_n_s_monitoring
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_s_new_frame __pyx_mstate_global->__pyx_n_s_new_frame
#define __pyx_n_s_not_processed __pyx_mstate_global->__pyx_n_s_not_processed
#define __pyx_n_s_os __pyx_mstate_global->__pyx_n_s_os
#define __pyx_n_s_os_path __pyx_mstate_global->__pyx_n_s_os_path
#define __pyx_n_s_path __pyx_mstate_global->__pyx_n_s_path
#define __pyx_n_s_plugin __pyx_mstate_global->__pyx_n_s_plugin
#define __pyx_n_s_plugin_manager __pyx_mstate_global->__pyx_n_s_plugin_manager
#define __pyx_n_s_plugin_stop __pyx_mstate_global->__pyx_n_s_plugin_stop
#define __pyx_n_s_print_exc __pyx_mstate_global->__pyx_n_s_print_exc
#define __pyx_n_s_py_db __pyx_mstate_global->__pyx_n_s_py_db
#define __pyx_n_s_py_line_callback __pyx_mstate_global->__pyx_n_s_py_line_callback
#define __pyx_n_s_py_raise_callback __pyx_mstate_global->__pyx_n_s_py_raise_callback
#define __pyx_n_s_py_return_callback __pyx_mstate_global->__pyx_n_s_py_return_callback
#define __pyx_n_s_py_start_callback __pyx_mstate_global->__pyx_n_s_py_start_callback
#define __pyx_n_s_pydev_bundle __pyx_mstate_global->__pyx_n_s_pydev_bundle
#define __pyx_n_s_pydev_bundle_pydev_is_thread_al __pyx_mstate_global->__pyx_n_s_pydev_bundle_pydev_is_thread_al
#define __pyx_n_s_pydev_func_name __pyx_mstate_global->__pyx_n_s_pydev_func_name
#define __pyx_n_s_pydev_log __pyx_mstate_global->__pyx_n_s_pydev_log
#define __pyx_n_s_pydev_message __pyx_mstate_global->__pyx_n_s_pydev_message
#define __pyx_n_s_pydev_smart_step_context __pyx_mstate_global->__pyx_n_s_pydev_smart_step_context
#define __pyx_n_s_pydev_state __pyx_mstate_global->__pyx_n_s_pydev_state
#define __pyx_n_s_pydev_step_cmd __pyx_mstate_global->__pyx_n_s_pydev_step_cmd
#define __pyx_n_s_pydev_step_stop __pyx_mstate_global->__pyx_n_s_pydev_step_stop
#define __pyx_n_s_pydevd __pyx_mstate_global->__pyx_n_s_pydevd
#define __pyx_n_s_pydevd_bundle_pydevd_breakpoint __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_breakpoint
#define __pyx_n_s_pydevd_bundle_pydevd_bytecode_u __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_bytecode_u
#define __pyx_n_s_pydevd_bundle_pydevd_comm_const __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_comm_const
#define __pyx_n_s_pydevd_bundle_pydevd_constants __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_constants
#define __pyx_n_s_pydevd_bundle_pydevd_dont_trace __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_dont_trace
#define __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_pep_669_tr
#define __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2 __pyx_mstate_global->__pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2
#define __pyx_n_s_pydevd_bundle_pydevd_trace_disp __pyx_mstate_global->__pyx_n_s_pydevd_bundle_pydevd_trace_disp
#define __pyx_n_s_pydevd_file_utils __pyx_mstate_global->__pyx_n_s_pydevd_file_utils
#define __pyx_n_s_quitting __pyx_mstate_global->__pyx_n_s_quitting
#define __pyx_n_s_register_callback __pyx_mstate_global->__pyx_n_s_register_callback
#define __pyx_n_s_remove_breakpoint __pyx_mstate_global->__pyx_n_s_remove_breakpoint
#define __pyx_n_s_remove_return_values_flag __pyx_mstate_global->__pyx_n_s_remove_return_values_flag
#define __pyx_n_s_reset __pyx_mstate_global->__pyx_n_s_reset
#define __pyx_n_s_restart_events __pyx_mstate_global->__pyx_n_s_restart_events
#define __pyx_n_s_result __pyx_mstate_global->__pyx_n_s_result
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_retval __pyx_mstate_global->__pyx_n_s_retval
#define __pyx_n_s_set_additional_thread_info __pyx_mstate_global->__pyx_n_s_set_additional_thread_info
#define __pyx_n_s_set_events __pyx_mstate_global->__pyx_n_s_set_events
#define __pyx_n_s_set_local_events __pyx_mstate_global->__pyx_n_s_set_local_events
#define __pyx_n_s_set_suspend __pyx_mstate_global->__pyx_n_s_set_suspend
#define __pyx_n_s_should_enable_line_events_for_c __pyx_mstate_global->__pyx_n_s_should_enable_line_events_for_c
#define __pyx_n_s_should_stop __pyx_mstate_global->__pyx_n_s_should_stop
#define __pyx_n_s_should_stop_on_exception __pyx_mstate_global->__pyx_n_s_should_stop_on_exception
#define __pyx_n_s_show_return_values __pyx_mstate_global->__pyx_n_s_show_return_values
#define __pyx_n_s_smart_step_stop __pyx_mstate_global->__pyx_n_s_smart_step_stop
#define __pyx_n_s_smart_stop_frame __pyx_mstate_global->__pyx_n_s_smart_stop_frame
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_splitext __pyx_mstate_global->__pyx_n_s_splitext
#define __pyx_n_s_start_line __pyx_mstate_global->__pyx_n_s_start_line
#define __pyx_n_s_step_cmd __pyx_mstate_global->__pyx_n_s_step_cmd
#define __pyx_n_s_stop __pyx_mstate_global->__pyx_n_s_stop
#define __pyx_n_s_stop_frame __pyx_mstate_global->__pyx_n_s_stop_frame
#define __pyx_n_s_stop_info __pyx_mstate_global->__pyx_n_s_stop_info
#define __pyx_n_s_stop_on_failed_tests __pyx_mstate_global->__pyx_n_s_stop_on_failed_tests
#define __pyx_n_s_stop_on_unhandled_exception __pyx_mstate_global->__pyx_n_s_stop_on_unhandled_exception
#define __pyx_n_s_stop_on_unhandled_exception_2 __pyx_mstate_global->__pyx_n_s_stop_on_unhandled_exception_2
#define __pyx_n_s_suspend __pyx_mstate_global->__pyx_n_s_suspend
#define __pyx_n_s_suspend_other_threads __pyx_mstate_global->__pyx_n_s_suspend_other_threads
#define __pyx_n_s_suspend_policy __pyx_mstate_global->__pyx_n_s_suspend_policy
#define __pyx_n_s_suspended_at_unhandled __pyx_mstate_global->__pyx_n_s_suspended_at_unhandled
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_thread __pyx_mstate_global->__pyx_n_s_thread
#define __pyx_n_s_thread_analyser __pyx_mstate_global->__pyx_n_s_thread_analyser
#define __pyx_n_s_threading __pyx_mstate_global->__pyx_n_s_threading
#define __pyx_n_s_traceback __pyx_mstate_global->__pyx_n_s_traceback
#define __pyx_n_s_traceback_2 __pyx_mstate_global->__pyx_n_s_traceback_2
#define __pyx_n_s_use_tool_id __pyx_mstate_global->__pyx_n_s_use_tool_id
#define __pyx_n_s_values __pyx_mstate_global->__pyx_n_s_values
#define __pyx_n_s_will_be_stopped __pyx_mstate_global->__pyx_n_s_will_be_stopped
#define __pyx_n_s_writer __pyx_mstate_global->__pyx_n_s_writer
#define __pyx_n_s_x __pyx_mstate_global->__pyx_n_s_x
#define __pyx_n_s_y __pyx_mstate_global->__pyx_n_s_y
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_108 __pyx_mstate_global->__pyx_int_108
#define __pyx_int_109 __pyx_mstate_global->__pyx_int_109
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_tuple__5 __pyx_mstate_global->__pyx_tuple__5
#define __pyx_tuple__7 __pyx_mstate_global->__pyx_tuple__7
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__15 __pyx_mstate_global->__pyx_tuple__15
#define __pyx_tuple__17 __pyx_mstate_global->__pyx_tuple__17
#define __pyx_tuple__19 __pyx_mstate_global->__pyx_tuple__19
#define __pyx_tuple__21 __pyx_mstate_global->__pyx_tuple__21
#define __pyx_tuple__24 __pyx_mstate_global->__pyx_tuple__24
#define __pyx_tuple__26 __pyx_mstate_global->__pyx_tuple__26
#define __pyx_tuple__29 __pyx_mstate_global->__pyx_tuple__29
#define __pyx_tuple__32 __pyx_mstate_global->__pyx_tuple__32
#define __pyx_tuple__34 __pyx_mstate_global->__pyx_tuple__34
#define __pyx_tuple__36 __pyx_mstate_global->__pyx_tuple__36
#define __pyx_tuple__38 __pyx_mstate_global->__pyx_tuple__38
#define __pyx_codeobj__6 __pyx_mstate_global->__pyx_codeobj__6
#define __pyx_codeobj__8 __pyx_mstate_global->__pyx_codeobj__8
#define __pyx_codeobj__10 __pyx_mstate_global->__pyx_codeobj__10
#define __pyx_codeobj__12 __pyx_mstate_global->__pyx_codeobj__12
#define __pyx_codeobj__14 __pyx_mstate_global->__pyx_codeobj__14
#define __pyx_codeobj__16 __pyx_mstate_global->__pyx_codeobj__16
#define __pyx_codeobj__18 __pyx_mstate_global->__pyx_codeobj__18
#define __pyx_codeobj__20 __pyx_mstate_global->__pyx_codeobj__20
#define __pyx_codeobj__22 __pyx_mstate_global->__pyx_codeobj__22
#define __pyx_codeobj__23 __pyx_mstate_global->__pyx_codeobj__23
#define __pyx_codeobj__25 __pyx_mstate_global->__pyx_codeobj__25
#define __pyx_codeobj__27 __pyx_mstate_global->__pyx_codeobj__27
#define __pyx_codeobj__28 __pyx_mstate_global->__pyx_codeobj__28
#define __pyx_codeobj__30 __pyx_mstate_global->__pyx_codeobj__30
#define __pyx_codeobj__33 __pyx_mstate_global->__pyx_codeobj__33
#define __pyx_codeobj__35 __pyx_mstate_global->__pyx_codeobj__35
#define __pyx_codeobj__37 __pyx_mstate_global->__pyx_codeobj__37
#define __pyx_codeobj__39 __pyx_mstate_global->__pyx_codeobj__39
/* #### Code section: module_code ### */

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":45
 * 
 * _EVENT_ACTIONS = {
 *     "ADD": lambda x, y: x | y,             # <<<<<<<<<<<<<<
 *     "REMOVE": lambda x, y: x & ~y,
 * }
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_36lambda(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_36lambda = {"lambda", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_36lambda, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_36lambda(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x = 0;
  PyObject *__pyx_v_y = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x,&__pyx_n_s_y,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 45, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_y)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 45, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda", 1, 2, 2, 1); __PYX_ERR(0, 45, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda") < 0)) __PYX_ERR(0, 45, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_x = values[0];
    __pyx_v_y = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 45, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.lambda", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_lambda(__pyx_self, __pyx_v_x, __pyx_v_y);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_lambda(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x, PyObject *__pyx_v_y) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Or(__pyx_v_x, __pyx_v_y); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.lambda", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":46
 * _EVENT_ACTIONS = {
 *     "ADD": lambda x, y: x | y,
 *     "REMOVE": lambda x, y: x & ~y,             # <<<<<<<<<<<<<<
 * }
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_37lambda1(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_37lambda1 = {"lambda1", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_37lambda1, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_37lambda1(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_x = 0;
  PyObject *__pyx_v_y = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lambda1 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_x,&__pyx_n_s_y,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_x)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 46, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_y)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 46, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("lambda1", 1, 2, 2, 1); __PYX_ERR(0, 46, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lambda1") < 0)) __PYX_ERR(0, 46, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_x = values[0];
    __pyx_v_y = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lambda1", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 46, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.lambda1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_lambda_funcdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_lambda1(__pyx_self, __pyx_v_x, __pyx_v_y);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_lambda_funcdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_lambda1(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_x, PyObject *__pyx_v_y) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lambda1", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Invert(__pyx_v_y); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_And(__pyx_v_x, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.lambda1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":49
 * }
 * 
 * def _make_frame_cache_key(code):             # <<<<<<<<<<<<<<
 *     return code.co_firstlineno, code.co_name, code.co_filename
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_1_make_frame_cache_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_1_make_frame_cache_key = {"_make_frame_cache_key", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_1_make_frame_cache_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_1_make_frame_cache_key(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_make_frame_cache_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 49, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_make_frame_cache_key") < 0)) __PYX_ERR(0, 49, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_make_frame_cache_key", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 49, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._make_frame_cache_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__make_frame_cache_key(__pyx_self, __pyx_v_code);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__make_frame_cache_key(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_make_frame_cache_key", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":50
 * 
 * def _make_frame_cache_key(code):
 *     return code.co_firstlineno, code.co_name, code.co_filename             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_n_s_co_firstlineno); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_n_s_co_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_code, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 50, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1)) __PYX_ERR(0, 50, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2)) __PYX_ERR(0, 50, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3)) __PYX_ERR(0, 50, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":49
 * }
 * 
 * def _make_frame_cache_key(code):             # <<<<<<<<<<<<<<
 *     return code.co_firstlineno, code.co_name, code.co_filename
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._make_frame_cache_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":53
 * 
 * 
 * def _get_additional_info(thread):             # <<<<<<<<<<<<<<
 *     try:
 *         additional_info = thread.additional_info
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_3_get_additional_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_3_get_additional_info = {"_get_additional_info", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_3_get_additional_info, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_3_get_additional_info(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_thread = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_additional_info (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_thread,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_thread)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 53, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_additional_info") < 0)) __PYX_ERR(0, 53, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_thread = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_additional_info", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 53, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_additional_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_2_get_additional_info(__pyx_self, __pyx_v_thread);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_2_get_additional_info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_thread) {
  PyObject *__pyx_v_additional_info = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  unsigned int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_additional_info", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":54
 * 
 * def _get_additional_info(thread):
 *     try:             # <<<<<<<<<<<<<<
 *         additional_info = thread.additional_info
 *         if additional_info is None:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":55
 * def _get_additional_info(thread):
 *     try:
 *         additional_info = thread.additional_info             # <<<<<<<<<<<<<<
 *         if additional_info is None:
 *             raise AttributeError()
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_thread, __pyx_n_s_additional_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 55, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_additional_info = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":56
 *     try:
 *         additional_info = thread.additional_info
 *         if additional_info is None:             # <<<<<<<<<<<<<<
 *             raise AttributeError()
 *     except:
 */
      __pyx_t_5 = (__pyx_v_additional_info == Py_None);
      if (unlikely(__pyx_t_5)) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":57
 *         additional_info = thread.additional_info
 *         if additional_info is None:
 *             raise AttributeError()             # <<<<<<<<<<<<<<
 *     except:
 *         additional_info = set_additional_thread_info(thread)
 */
        __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_builtin_AttributeError); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 57, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(0, 57, __pyx_L3_error)

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":56
 *     try:
 *         additional_info = thread.additional_info
 *         if additional_info is None:             # <<<<<<<<<<<<<<
 *             raise AttributeError()
 *     except:
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":54
 * 
 * def _get_additional_info(thread):
 *     try:             # <<<<<<<<<<<<<<
 *         additional_info = thread.additional_info
 *         if additional_info is None:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":58
 *         if additional_info is None:
 *             raise AttributeError()
 *     except:             # <<<<<<<<<<<<<<
 *         additional_info = set_additional_thread_info(thread)
 *     return additional_info
 */
    /*except:*/ {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_additional_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(0, 58, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":59
 *             raise AttributeError()
 *     except:
 *         additional_info = set_additional_thread_info(thread)             # <<<<<<<<<<<<<<
 *     return additional_info
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_set_additional_thread_info); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 59, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = NULL;
      __pyx_t_11 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_11 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_v_thread};
        __pyx_t_8 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 59, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_additional_info, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":54
 * 
 * def _get_additional_info(thread):
 *     try:             # <<<<<<<<<<<<<<
 *         additional_info = thread.additional_info
 *         if additional_info is None:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":60
 *     except:
 *         additional_info = set_additional_thread_info(thread)
 *     return additional_info             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_additional_info);
  __pyx_r = __pyx_v_additional_info;
  goto __pyx_L0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":53
 * 
 * 
 * def _get_additional_info(thread):             # <<<<<<<<<<<<<<
 *     try:
 *         additional_info = thread.additional_info
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_additional_info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_additional_info);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":63
 * 
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):             # <<<<<<<<<<<<<<
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_5_get_abs_path_real_path_and_base_from_frame(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_5_get_abs_path_real_path_and_base_from_frame = {"_get_abs_path_real_path_and_base_from_frame", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_5_get_abs_path_real_path_and_base_from_frame, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_5_get_abs_path_real_path_and_base_from_frame(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_frame = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_abs_path_real_path_and_base_from_frame (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_frame,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_frame)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 63, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_get_abs_path_real_path_and_base_from_frame") < 0)) __PYX_ERR(0, 63, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_frame = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_get_abs_path_real_path_and_base_from_frame", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 63, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_abs_path_real_path_and_base_from_frame", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_4_get_abs_path_real_path_and_base_from_frame(__pyx_self, __pyx_v_frame);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_4_get_abs_path_real_path_and_base_from_frame(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame) {
  PyObject *__pyx_v_abs_path_real_path_and_base = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  unsigned int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_abs_path_real_path_and_base_from_frame", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":64
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):
 *     try:             # <<<<<<<<<<<<<<
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 *             frame.f_code.co_filename]
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":65
 * def _get_abs_path_real_path_and_base_from_frame(frame):
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[             # <<<<<<<<<<<<<<
 *             frame.f_code.co_filename]
 *     except:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 65, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":66
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 *             frame.f_code.co_filename]             # <<<<<<<<<<<<<<
 *     except:
 *         abs_path_real_path_and_base \
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_code); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 66, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 66, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":65
 * def _get_abs_path_real_path_and_base_from_frame(frame):
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[             # <<<<<<<<<<<<<<
 *             frame.f_code.co_filename]
 *     except:
 */
      __pyx_t_5 = __Pyx_PyObject_GetItem(__pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_abs_path_real_path_and_base = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":64
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):
 *     try:             # <<<<<<<<<<<<<<
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 *             frame.f_code.co_filename]
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":67
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 *             frame.f_code.co_filename]
 *     except:             # <<<<<<<<<<<<<<
 *         abs_path_real_path_and_base \
 *             = get_abs_path_real_path_and_base_from_frame(frame)
 */
    /*except:*/ {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_abs_path_real_path_and_base_from_frame", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(0, 67, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_4);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":69
 *     except:
 *         abs_path_real_path_and_base \
 *             = get_abs_path_real_path_and_base_from_frame(frame)             # <<<<<<<<<<<<<<
 * 
 *     return abs_path_real_path_and_base
 */
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_get_abs_path_real_path_and_base); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 69, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_9)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_v_frame};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_8, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 69, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_XDECREF_SET(__pyx_v_abs_path_real_path_and_base, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L4_exception_handled;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":64
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):
 *     try:             # <<<<<<<<<<<<<<
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 *             frame.f_code.co_filename]
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":71
 *             = get_abs_path_real_path_and_base_from_frame(frame)
 * 
 *     return abs_path_real_path_and_base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_abs_path_real_path_and_base);
  __pyx_r = __pyx_v_abs_path_real_path_and_base;
  goto __pyx_L0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":63
 * 
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):             # <<<<<<<<<<<<<<
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_abs_path_real_path_and_base_from_frame", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_abs_path_real_path_and_base);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":74
 * 
 * 
 * def _should_enable_line_events_for_code(frame, code, filename, info, will_be_stopped=False):             # <<<<<<<<<<<<<<
 *     line_number = frame.f_lineno
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_7_should_enable_line_events_for_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_7_should_enable_line_events_for_code = {"_should_enable_line_events_for_code", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_7_should_enable_line_events_for_code, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_7_should_enable_line_events_for_code(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_frame = 0;
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_filename = 0;
  PyObject *__pyx_v_info = 0;
  PyObject *__pyx_v_will_be_stopped = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_should_enable_line_events_for_code (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_frame,&__pyx_n_s_code,&__pyx_n_s_filename,&__pyx_n_s_info,&__pyx_n_s_will_be_stopped,0};
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_frame)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 74, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 74, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_should_enable_line_events_for_code", 0, 4, 5, 1); __PYX_ERR(0, 74, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_filename)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 74, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_should_enable_line_events_for_code", 0, 4, 5, 2); __PYX_ERR(0, 74, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_info)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 74, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_should_enable_line_events_for_code", 0, 4, 5, 3); __PYX_ERR(0, 74, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_will_be_stopped);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 74, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_should_enable_line_events_for_code") < 0)) __PYX_ERR(0, 74, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_frame = values[0];
    __pyx_v_code = values[1];
    __pyx_v_filename = values[2];
    __pyx_v_info = values[3];
    __pyx_v_will_be_stopped = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_should_enable_line_events_for_code", 0, 4, 5, __pyx_nargs); __PYX_ERR(0, 74, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._should_enable_line_events_for_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_6_should_enable_line_events_for_code(__pyx_self, __pyx_v_frame, __pyx_v_code, __pyx_v_filename, __pyx_v_info, __pyx_v_will_be_stopped);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_6_should_enable_line_events_for_code(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_frame, PyObject *__pyx_v_code, PyObject *__pyx_v_filename, PyObject *__pyx_v_info, PyObject *__pyx_v_will_be_stopped) {
  PyObject *__pyx_v_line_number = NULL;
  PyObject *__pyx_v_py_db = NULL;
  PyObject *__pyx_v_plugin_manager = NULL;
  PyObject *__pyx_v_stop_frame = NULL;
  PyObject *__pyx_v_step_cmd = NULL;
  PyObject *__pyx_v_breakpoints_for_file = NULL;
  PyObject *__pyx_v_can_skip = NULL;
  PyObject *__pyx_v_frame_cache_key = NULL;
  PyObject *__pyx_v_line_cache_key = NULL;
  PyObject *__pyx_v_breakpoints_in_line_cache = NULL;
  PyObject *__pyx_v_breakpoints_in_frame_cache = NULL;
  PyObject *__pyx_v_has_breakpoint_in_frame = NULL;
  PyObject *__pyx_v_curr_func_name = NULL;
  PyObject *__pyx_v_breakpoint = NULL;
  PyObject *__pyx_v_f_code = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_should_enable_line_events_for_code", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":75
 * 
 * def _should_enable_line_events_for_code(frame, code, filename, info, will_be_stopped=False):
 *     line_number = frame.f_lineno             # <<<<<<<<<<<<<<
 * 
 *     # print('PY_START (should enable line events check) %s %s %s %s' % (line_number, code.co_name, filename, info.pydev_step_cmd))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_lineno); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_line_number = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":79
 *     # print('PY_START (should enable line events check) %s %s %s %s' % (line_number, code.co_name, filename, info.pydev_step_cmd))
 * 
 *     py_db = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 * 
 *     plugin_manager = py_db.plugin
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_py_db = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":81
 *     py_db = GlobalDebuggerHolder.global_dbg
 * 
 *     plugin_manager = py_db.plugin             # <<<<<<<<<<<<<<
 * 
 *     stop_frame = info.pydev_step_stop
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_plugin_manager = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":83
 *     plugin_manager = py_db.plugin
 * 
 *     stop_frame = info.pydev_step_stop             # <<<<<<<<<<<<<<
 *     step_cmd = info.pydev_step_cmd
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 83, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_stop_frame = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":84
 * 
 *     stop_frame = info.pydev_step_stop
 *     step_cmd = info.pydev_step_cmd             # <<<<<<<<<<<<<<
 * 
 *     breakpoints_for_file = py_db.breakpoints.get(filename)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 84, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_step_cmd = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":86
 *     step_cmd = info.pydev_step_cmd
 * 
 *     breakpoints_for_file = py_db.breakpoints.get(filename)             # <<<<<<<<<<<<<<
 * 
 *     can_skip = False
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_breakpoints); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_filename};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 86, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_breakpoints_for_file = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":88
 *     breakpoints_for_file = py_db.breakpoints.get(filename)
 * 
 *     can_skip = False             # <<<<<<<<<<<<<<
 * 
 *     if info.pydev_state == 1 and not will_be_stopped:  # STATE_RUN = 1
 */
  __Pyx_INCREF(Py_False);
  __pyx_v_can_skip = Py_False;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":90
 *     can_skip = False
 * 
 *     if info.pydev_state == 1 and not will_be_stopped:  # STATE_RUN = 1             # <<<<<<<<<<<<<<
 *         can_skip = (step_cmd == -1 and stop_frame is None) \
 *                    or (step_cmd in (109, 108) and stop_frame is not frame)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 90, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {
  } else {
    __pyx_t_5 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_will_be_stopped); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 90, __pyx_L1_error)
  __pyx_t_7 = (!__pyx_t_6);
  __pyx_t_5 = __pyx_t_7;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_5) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":91
 * 
 *     if info.pydev_state == 1 and not will_be_stopped:  # STATE_RUN = 1
 *         can_skip = (step_cmd == -1 and stop_frame is None) \             # <<<<<<<<<<<<<<
 *                    or (step_cmd in (109, 108) and stop_frame is not frame)
 * 
 */
    __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_step_cmd, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (!__pyx_t_5) {
      goto __pyx_L7_next_or;
    } else {
    }
    __pyx_t_5 = (__pyx_v_stop_frame == Py_None);
    if (!__pyx_t_5) {
    } else {
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 91, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_L7_next_or:;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":92
 *     if info.pydev_state == 1 and not will_be_stopped:  # STATE_RUN = 1
 *         can_skip = (step_cmd == -1 and stop_frame is None) \
 *                    or (step_cmd in (109, 108) and stop_frame is not frame)             # <<<<<<<<<<<<<<
 * 
 *         if can_skip:
 */
    __Pyx_INCREF(__pyx_v_step_cmd);
    __pyx_t_3 = __pyx_v_step_cmd;
    __pyx_t_7 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_109, 0x6D, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 92, __pyx_L1_error)
    if (!__pyx_t_7) {
    } else {
      __pyx_t_5 = __pyx_t_7;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_7 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_3, __pyx_int_108, 0x6C, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 92, __pyx_L1_error)
    __pyx_t_5 = __pyx_t_7;
    __pyx_L10_bool_binop_done:;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __pyx_t_5;
    if (__pyx_t_7) {
    } else {
      __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 92, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_7 = (__pyx_v_stop_frame != __pyx_v_frame);
    __pyx_t_3 = __Pyx_PyBool_FromLong(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_L6_bool_binop_done:;
    __Pyx_DECREF_SET(__pyx_v_can_skip, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":94
 *                    or (step_cmd in (109, 108) and stop_frame is not frame)
 * 
 *         if can_skip:             # <<<<<<<<<<<<<<
 *             if plugin_manager is not None and py_db.has_plugin_line_breaks:
 *                 can_skip = not plugin_manager.can_not_skip(py_db, frame, info)
 */
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_can_skip); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 94, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":95
 * 
 *         if can_skip:
 *             if plugin_manager is not None and py_db.has_plugin_line_breaks:             # <<<<<<<<<<<<<<
 *                 can_skip = not plugin_manager.can_not_skip(py_db, frame, info)
 * 
 */
      __pyx_t_5 = (__pyx_v_plugin_manager != Py_None);
      if (__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L14_bool_binop_done;
      }
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_has_plugin_line_breaks); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __pyx_t_5;
      __pyx_L14_bool_binop_done:;
      if (__pyx_t_7) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":96
 *         if can_skip:
 *             if plugin_manager is not None and py_db.has_plugin_line_breaks:
 *                 can_skip = not plugin_manager.can_not_skip(py_db, frame, info)             # <<<<<<<<<<<<<<
 * 
 *             # CMD_STEP_OVER = 108
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_plugin_manager, __pyx_n_s_can_not_skip); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 96, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = NULL;
        __pyx_t_4 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_4 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_py_db, __pyx_v_frame, __pyx_v_info};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 96, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyBool_FromLong((!__pyx_t_7)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 96, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_can_skip, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":95
 * 
 *         if can_skip:
 *             if plugin_manager is not None and py_db.has_plugin_line_breaks:             # <<<<<<<<<<<<<<
 *                 can_skip = not plugin_manager.can_not_skip(py_db, frame, info)
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":99
 * 
 *             # CMD_STEP_OVER = 108
 *             if (can_skip and py_db.show_return_values             # <<<<<<<<<<<<<<
 *                     and info.pydev_step_cmd == 108
 *                     and frame.f_back is info.pydev_step_stop):
 */
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_can_skip); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 99, __pyx_L1_error)
      if (__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L17_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":100
 *             # CMD_STEP_OVER = 108
 *             if (can_skip and py_db.show_return_values
 *                     and info.pydev_step_cmd == 108             # <<<<<<<<<<<<<<
 *                     and frame.f_back is info.pydev_step_stop):
 *                 # trace function for showing return values after step over
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_show_return_values); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 99, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":99
 * 
 *             # CMD_STEP_OVER = 108
 *             if (can_skip and py_db.show_return_values             # <<<<<<<<<<<<<<
 *                     and info.pydev_step_cmd == 108
 *                     and frame.f_back is info.pydev_step_stop):
 */
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 99, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L17_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":100
 *             # CMD_STEP_OVER = 108
 *             if (can_skip and py_db.show_return_values
 *                     and info.pydev_step_cmd == 108             # <<<<<<<<<<<<<<
 *                     and frame.f_back is info.pydev_step_stop):
 *                 # trace function for showing return values after step over
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 100, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = (__Pyx_PyInt_BoolEqObjC(__pyx_t_2, __pyx_int_108, 0x6C, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 100, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L17_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":101
 *             if (can_skip and py_db.show_return_values
 *                     and info.pydev_step_cmd == 108
 *                     and frame.f_back is info.pydev_step_stop):             # <<<<<<<<<<<<<<
 *                 # trace function for showing return values after step over
 *                 can_skip = False
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 101, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = (__pyx_t_2 == __pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __pyx_t_5;
      __pyx_L17_bool_binop_done:;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":99
 * 
 *             # CMD_STEP_OVER = 108
 *             if (can_skip and py_db.show_return_values             # <<<<<<<<<<<<<<
 *                     and info.pydev_step_cmd == 108
 *                     and frame.f_back is info.pydev_step_stop):
 */
      if (__pyx_t_7) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":103
 *                     and frame.f_back is info.pydev_step_stop):
 *                 # trace function for showing return values after step over
 *                 can_skip = False             # <<<<<<<<<<<<<<
 * 
 *     frame_cache_key = _make_frame_cache_key(code)
 */
        __Pyx_INCREF(Py_False);
        __Pyx_DECREF_SET(__pyx_v_can_skip, Py_False);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":99
 * 
 *             # CMD_STEP_OVER = 108
 *             if (can_skip and py_db.show_return_values             # <<<<<<<<<<<<<<
 *                     and info.pydev_step_cmd == 108
 *                     and frame.f_back is info.pydev_step_stop):
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":94
 *                    or (step_cmd in (109, 108) and stop_frame is not frame)
 * 
 *         if can_skip:             # <<<<<<<<<<<<<<
 *             if plugin_manager is not None and py_db.has_plugin_line_breaks:
 *                 can_skip = not plugin_manager.can_not_skip(py_db, frame, info)
 */
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":90
 *     can_skip = False
 * 
 *     if info.pydev_state == 1 and not will_be_stopped:  # STATE_RUN = 1             # <<<<<<<<<<<<<<
 *         can_skip = (step_cmd == -1 and stop_frame is None) \
 *                    or (step_cmd in (109, 108) and stop_frame is not frame)
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":105
 *                 can_skip = False
 * 
 *     frame_cache_key = _make_frame_cache_key(code)             # <<<<<<<<<<<<<<
 *     line_cache_key = (frame_cache_key, line_number)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_make_frame_cache_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_code};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 105, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_frame_cache_key = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":106
 * 
 *     frame_cache_key = _make_frame_cache_key(code)
 *     line_cache_key = (frame_cache_key, line_number)             # <<<<<<<<<<<<<<
 * 
 *     if breakpoints_for_file:
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_frame_cache_key);
  __Pyx_GIVEREF(__pyx_v_frame_cache_key);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_frame_cache_key)) __PYX_ERR(0, 106, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_line_number);
  __Pyx_GIVEREF(__pyx_v_line_number);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_line_number)) __PYX_ERR(0, 106, __pyx_L1_error);
  __pyx_v_line_cache_key = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":108
 *     line_cache_key = (frame_cache_key, line_number)
 * 
 *     if breakpoints_for_file:             # <<<<<<<<<<<<<<
 *         # When cached, 0 means we don't have a breakpoint
 *         # and 1 means we have.
 */
  __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoints_for_file); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 108, __pyx_L1_error)
  if (__pyx_t_7) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":111
 *         # When cached, 0 means we don't have a breakpoint
 *         # and 1 means we have.
 *         if can_skip:             # <<<<<<<<<<<<<<
 *             breakpoints_in_line_cache = global_cache_frame_skips.get(line_cache_key, -1)
 *             if breakpoints_in_line_cache == 0:
 */
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_can_skip); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 111, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":112
 *         # and 1 means we have.
 *         if can_skip:
 *             breakpoints_in_line_cache = global_cache_frame_skips.get(line_cache_key, -1)             # <<<<<<<<<<<<<<
 *             if breakpoints_in_line_cache == 0:
 *                 return False
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_global_cache_frame_skips); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 112, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_v_line_cache_key, __pyx_int_neg_1};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 112, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __pyx_v_breakpoints_in_line_cache = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":113
 *         if can_skip:
 *             breakpoints_in_line_cache = global_cache_frame_skips.get(line_cache_key, -1)
 *             if breakpoints_in_line_cache == 0:             # <<<<<<<<<<<<<<
 *                 return False
 * 
 */
      __pyx_t_7 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_breakpoints_in_line_cache, __pyx_int_0, 0, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 113, __pyx_L1_error)
      if (__pyx_t_7) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":114
 *             breakpoints_in_line_cache = global_cache_frame_skips.get(line_cache_key, -1)
 *             if breakpoints_in_line_cache == 0:
 *                 return False             # <<<<<<<<<<<<<<
 * 
 *         breakpoints_in_frame_cache = global_cache_frame_skips.get(frame_cache_key, -1)
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        goto __pyx_L0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":113
 *         if can_skip:
 *             breakpoints_in_line_cache = global_cache_frame_skips.get(line_cache_key, -1)
 *             if breakpoints_in_line_cache == 0:             # <<<<<<<<<<<<<<
 *                 return False
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":111
 *         # When cached, 0 means we don't have a breakpoint
 *         # and 1 means we have.
 *         if can_skip:             # <<<<<<<<<<<<<<
 *             breakpoints_in_line_cache = global_cache_frame_skips.get(line_cache_key, -1)
 *             if breakpoints_in_line_cache == 0:
 */
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":116
 *                 return False
 * 
 *         breakpoints_in_frame_cache = global_cache_frame_skips.get(frame_cache_key, -1)             # <<<<<<<<<<<<<<
 *         if breakpoints_in_frame_cache != -1:
 *             # Gotten from cache.
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_global_cache_frame_skips); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_v_frame_cache_key, __pyx_int_neg_1};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_v_breakpoints_in_frame_cache = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":117
 * 
 *         breakpoints_in_frame_cache = global_cache_frame_skips.get(frame_cache_key, -1)
 *         if breakpoints_in_frame_cache != -1:             # <<<<<<<<<<<<<<
 *             # Gotten from cache.
 *             has_breakpoint_in_frame = breakpoints_in_frame_cache == 1
 */
    __pyx_t_7 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_breakpoints_in_frame_cache, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 117, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":119
 *         if breakpoints_in_frame_cache != -1:
 *             # Gotten from cache.
 *             has_breakpoint_in_frame = breakpoints_in_frame_cache == 1             # <<<<<<<<<<<<<<
 *         else:
 *             has_breakpoint_in_frame = False
 */
      __pyx_t_3 = __Pyx_PyInt_EqObjC(__pyx_v_breakpoints_in_frame_cache, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 119, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_has_breakpoint_in_frame = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":117
 * 
 *         breakpoints_in_frame_cache = global_cache_frame_skips.get(frame_cache_key, -1)
 *         if breakpoints_in_frame_cache != -1:             # <<<<<<<<<<<<<<
 *             # Gotten from cache.
 *             has_breakpoint_in_frame = breakpoints_in_frame_cache == 1
 */
      goto __pyx_L24;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":121
 *             has_breakpoint_in_frame = breakpoints_in_frame_cache == 1
 *         else:
 *             has_breakpoint_in_frame = False             # <<<<<<<<<<<<<<
 *             # Checks the breakpoint to see if there is a context
 *             # match in some function.
 */
    /*else*/ {
      __Pyx_INCREF(Py_False);
      __pyx_v_has_breakpoint_in_frame = Py_False;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":124
 *             # Checks the breakpoint to see if there is a context
 *             # match in some function.
 *             curr_func_name = frame.f_code.co_name             # <<<<<<<<<<<<<<
 * 
 *             # global context is set with an empty name
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_co_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_curr_func_name = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":127
 * 
 *             # global context is set with an empty name
 *             if curr_func_name in ('?', '<module>', '<lambda>'):             # <<<<<<<<<<<<<<
 *                 curr_func_name = ''
 * 
 */
      __Pyx_INCREF(__pyx_v_curr_func_name);
      __pyx_t_2 = __pyx_v_curr_func_name;
      __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 127, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L26_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_module, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 127, __pyx_L1_error)
      if (!__pyx_t_5) {
      } else {
        __pyx_t_7 = __pyx_t_5;
        goto __pyx_L26_bool_binop_done;
      }
      __pyx_t_5 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s_lambda, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 127, __pyx_L1_error)
      __pyx_t_7 = __pyx_t_5;
      __pyx_L26_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_5 = __pyx_t_7;
      if (__pyx_t_5) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":128
 *             # global context is set with an empty name
 *             if curr_func_name in ('?', '<module>', '<lambda>'):
 *                 curr_func_name = ''             # <<<<<<<<<<<<<<
 * 
 *             for breakpoint in breakpoints_for_file.values():
 */
        __Pyx_INCREF(__pyx_kp_s__2);
        __Pyx_DECREF_SET(__pyx_v_curr_func_name, __pyx_kp_s__2);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":127
 * 
 *             # global context is set with an empty name
 *             if curr_func_name in ('?', '<module>', '<lambda>'):             # <<<<<<<<<<<<<<
 *                 curr_func_name = ''
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":130
 *                 curr_func_name = ''
 * 
 *             for breakpoint in breakpoints_for_file.values():             # <<<<<<<<<<<<<<
 *                 # will match either global or some function
 *                 if breakpoint.func_name in ('None', curr_func_name):
 */
      __pyx_t_8 = 0;
      if (unlikely(__pyx_v_breakpoints_for_file == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
        __PYX_ERR(0, 130, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_dict_iterator(__pyx_v_breakpoints_for_file, 0, __pyx_n_s_values, (&__pyx_t_9), (&__pyx_t_10)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 130, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_2);
      __pyx_t_2 = __pyx_t_3;
      __pyx_t_3 = 0;
      while (1) {
        __pyx_t_11 = __Pyx_dict_iter_next(__pyx_t_2, __pyx_t_9, &__pyx_t_8, NULL, &__pyx_t_3, NULL, __pyx_t_10);
        if (unlikely(__pyx_t_11 == 0)) break;
        if (unlikely(__pyx_t_11 == -1)) __PYX_ERR(0, 130, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_XDECREF_SET(__pyx_v_breakpoint, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":132
 *             for breakpoint in breakpoints_for_file.values():
 *                 # will match either global or some function
 *                 if breakpoint.func_name in ('None', curr_func_name):             # <<<<<<<<<<<<<<
 *                     has_breakpoint_in_frame = True
 *                     # New breakpoint was processed -> stop tracing monitoring.events.INSTRUCTION
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_func_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 132, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_7 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_n_s_None, Py_EQ)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 132, __pyx_L1_error)
        if (!__pyx_t_7) {
        } else {
          __pyx_t_5 = __pyx_t_7;
          goto __pyx_L32_bool_binop_done;
        }
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_v_curr_func_name, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 132, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_5 = __pyx_t_7;
        __pyx_L32_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_7 = __pyx_t_5;
        if (__pyx_t_7) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":133
 *                 # will match either global or some function
 *                 if breakpoint.func_name in ('None', curr_func_name):
 *                     has_breakpoint_in_frame = True             # <<<<<<<<<<<<<<
 *                     # New breakpoint was processed -> stop tracing monitoring.events.INSTRUCTION
 *                     remove_breakpoint(breakpoint)
 */
          __Pyx_INCREF(Py_True);
          __Pyx_DECREF_SET(__pyx_v_has_breakpoint_in_frame, Py_True);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":135
 *                     has_breakpoint_in_frame = True
 *                     # New breakpoint was processed -> stop tracing monitoring.events.INSTRUCTION
 *                     remove_breakpoint(breakpoint)             # <<<<<<<<<<<<<<
 *                     break
 * 
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_remove_breakpoint); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 135, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = NULL;
          __pyx_t_4 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_4 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_v_breakpoint};
            __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 135, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":136
 *                     # New breakpoint was processed -> stop tracing monitoring.events.INSTRUCTION
 *                     remove_breakpoint(breakpoint)
 *                     break             # <<<<<<<<<<<<<<
 * 
 *                 # Check is f_back has a breakpoint => need register return event
 */
          goto __pyx_L30_break;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":132
 *             for breakpoint in breakpoints_for_file.values():
 *                 # will match either global or some function
 *                 if breakpoint.func_name in ('None', curr_func_name):             # <<<<<<<<<<<<<<
 *                     has_breakpoint_in_frame = True
 *                     # New breakpoint was processed -> stop tracing monitoring.events.INSTRUCTION
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":139
 * 
 *                 # Check is f_back has a breakpoint => need register return event
 *                 if hasattr(frame, "f_back"):             # <<<<<<<<<<<<<<
 *                     f_code = getattr(frame.f_back, "f_code", None)
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:
 */
        __pyx_t_7 = __Pyx_HasAttr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 139, __pyx_L1_error)
        if (__pyx_t_7) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":140
 *                 # Check is f_back has a breakpoint => need register return event
 *                 if hasattr(frame, "f_back"):
 *                     f_code = getattr(frame.f_back, "f_code", None)             # <<<<<<<<<<<<<<
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:
 *                         can_skip = False
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 140, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = __Pyx_GetAttr3(__pyx_t_3, __pyx_n_s_f_code, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 140, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_XDECREF_SET(__pyx_v_f_code, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":141
 *                 if hasattr(frame, "f_back"):
 *                     f_code = getattr(frame.f_back, "f_code", None)
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:             # <<<<<<<<<<<<<<
 *                         can_skip = False
 *                         break
 */
          __pyx_t_5 = (__pyx_v_f_code != Py_None);
          if (__pyx_t_5) {
          } else {
            __pyx_t_7 = __pyx_t_5;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_func_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 141, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_code, __pyx_n_s_co_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 141, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_12 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 141, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 141, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_7 = __pyx_t_5;
          __pyx_L36_bool_binop_done:;
          if (__pyx_t_7) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":142
 *                     f_code = getattr(frame.f_back, "f_code", None)
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:
 *                         can_skip = False             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
            __Pyx_INCREF(Py_False);
            __Pyx_DECREF_SET(__pyx_v_can_skip, Py_False);

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":143
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:
 *                         can_skip = False
 *                         break             # <<<<<<<<<<<<<<
 * 
 *             # Cache the value (1 or 0 or -1 for default because of cython).
 */
            goto __pyx_L30_break;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":141
 *                 if hasattr(frame, "f_back"):
 *                     f_code = getattr(frame.f_back, "f_code", None)
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:             # <<<<<<<<<<<<<<
 *                         can_skip = False
 *                         break
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":139
 * 
 *                 # Check is f_back has a breakpoint => need register return event
 *                 if hasattr(frame, "f_back"):             # <<<<<<<<<<<<<<
 *                     f_code = getattr(frame.f_back, "f_code", None)
 *                     if f_code is not None and breakpoint.func_name == f_code.co_name:
 */
        }
      }
      __pyx_L30_break:;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":146
 * 
 *             # Cache the value (1 or 0 or -1 for default because of cython).
 *             if has_breakpoint_in_frame:             # <<<<<<<<<<<<<<
 *                 global_cache_frame_skips[frame_cache_key] = 1
 *             else:
 */
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_v_has_breakpoint_in_frame); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(0, 146, __pyx_L1_error)
      if (__pyx_t_7) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":147
 *             # Cache the value (1 or 0 or -1 for default because of cython).
 *             if has_breakpoint_in_frame:
 *                 global_cache_frame_skips[frame_cache_key] = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 global_cache_frame_skips[frame_cache_key] = 0
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_global_cache_frame_skips); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 147, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_v_frame_cache_key, __pyx_int_1) < 0))) __PYX_ERR(0, 147, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":146
 * 
 *             # Cache the value (1 or 0 or -1 for default because of cython).
 *             if has_breakpoint_in_frame:             # <<<<<<<<<<<<<<
 *                 global_cache_frame_skips[frame_cache_key] = 1
 *             else:
 */
        goto __pyx_L38;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":149
 *                 global_cache_frame_skips[frame_cache_key] = 1
 *             else:
 *                 global_cache_frame_skips[frame_cache_key] = 0             # <<<<<<<<<<<<<<
 * 
 *         if can_skip and not has_breakpoint_in_frame:
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_global_cache_frame_skips); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 149, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        if (unlikely((PyObject_SetItem(__pyx_t_2, __pyx_v_frame_cache_key, __pyx_int_0) < 0))) __PYX_ERR(0, 149, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_L38:;
    }
    __pyx_L24:;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":151
 *                 global_cache_frame_skips[frame_cache_key] = 0
 * 
 *         if can_skip and not has_breakpoint_in_frame:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_can_skip); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 151, __pyx_L1_error)
    if (__pyx_t_5) {
    } else {
      __pyx_t_7 = __pyx_t_5;
      goto __pyx_L40_bool_binop_done;
    }
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_has_breakpoint_in_frame); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 151, __pyx_L1_error)
    __pyx_t_6 = (!__pyx_t_5);
    __pyx_t_7 = __pyx_t_6;
    __pyx_L40_bool_binop_done:;
    if (__pyx_t_7) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":152
 * 
 *         if can_skip and not has_breakpoint_in_frame:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *     return True
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      goto __pyx_L0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":151
 *                 global_cache_frame_skips[frame_cache_key] = 0
 * 
 *         if can_skip and not has_breakpoint_in_frame:             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":108
 *     line_cache_key = (frame_cache_key, line_number)
 * 
 *     if breakpoints_for_file:             # <<<<<<<<<<<<<<
 *         # When cached, 0 means we don't have a breakpoint
 *         # and 1 means we have.
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":154
 *             return False
 * 
 *     return True             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":74
 * 
 * 
 * def _should_enable_line_events_for_code(frame, code, filename, info, will_be_stopped=False):             # <<<<<<<<<<<<<<
 *     line_number = frame.f_lineno
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._should_enable_line_events_for_code", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line_number);
  __Pyx_XDECREF(__pyx_v_py_db);
  __Pyx_XDECREF(__pyx_v_plugin_manager);
  __Pyx_XDECREF(__pyx_v_stop_frame);
  __Pyx_XDECREF(__pyx_v_step_cmd);
  __Pyx_XDECREF(__pyx_v_breakpoints_for_file);
  __Pyx_XDECREF(__pyx_v_can_skip);
  __Pyx_XDECREF(__pyx_v_frame_cache_key);
  __Pyx_XDECREF(__pyx_v_line_cache_key);
  __Pyx_XDECREF(__pyx_v_breakpoints_in_line_cache);
  __Pyx_XDECREF(__pyx_v_breakpoints_in_frame_cache);
  __Pyx_XDECREF(__pyx_v_has_breakpoint_in_frame);
  __Pyx_XDECREF(__pyx_v_curr_func_name);
  __Pyx_XDECREF(__pyx_v_breakpoint);
  __Pyx_XDECREF(__pyx_v_f_code);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":157
 * 
 * 
 * def _clear_run_state(info):             # <<<<<<<<<<<<<<
 *     info.pydev_step_stop = None
 *     info.pydev_step_cmd = -1
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_9_clear_run_state(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_9_clear_run_state = {"_clear_run_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_9_clear_run_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_9_clear_run_state(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_info = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_clear_run_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_info,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_info)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 157, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_clear_run_state") < 0)) __PYX_ERR(0, 157, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_info = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_clear_run_state", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 157, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._clear_run_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_8_clear_run_state(__pyx_self, __pyx_v_info);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_8_clear_run_state(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_info) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_clear_run_state", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":158
 * 
 * def _clear_run_state(info):
 *     info.pydev_step_stop = None             # <<<<<<<<<<<<<<
 *     info.pydev_step_cmd = -1
 *     info.pydev_state = STATE_RUN
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop, Py_None) < 0) __PYX_ERR(0, 158, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":159
 * def _clear_run_state(info):
 *     info.pydev_step_stop = None
 *     info.pydev_step_cmd = -1             # <<<<<<<<<<<<<<
 *     info.pydev_state = STATE_RUN
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd, __pyx_int_neg_1) < 0) __PYX_ERR(0, 159, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":160
 *     info.pydev_step_stop = None
 *     info.pydev_step_cmd = -1
 *     info.pydev_state = STATE_RUN             # <<<<<<<<<<<<<<
 * 
 * # Cythonnized functions live in C the call stack rather than in the Python call stack.
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_STATE_RUN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_state, __pyx_t_1) < 0) __PYX_ERR(0, 160, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":157
 * 
 * 
 * def _clear_run_state(info):             # <<<<<<<<<<<<<<
 *     info.pydev_step_stop = None
 *     info.pydev_step_cmd = -1
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._clear_run_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":168
 * # Cython side in the future.
 * # IFDEF CYTHON -- DONT EDIT THIS FILE (it is automatically generated)
 * cdef _getframe(depth=0):             # <<<<<<<<<<<<<<
 *    return sys._getframe()
 * # ELSE
 */

static PyObject *__pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe *__pyx_optional_args) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_getframe", 1);
  if (__pyx_optional_args) {
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":169
 * # IFDEF CYTHON -- DONT EDIT THIS FILE (it is automatically generated)
 * cdef _getframe(depth=0):
 *    return sys._getframe()             # <<<<<<<<<<<<<<
 * # ELSE
 * # _getframe = sys._getframe
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getframe); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 169, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":168
 * # Cython side in the future.
 * # IFDEF CYTHON -- DONT EDIT THIS FILE (it is automatically generated)
 * cdef _getframe(depth=0):             # <<<<<<<<<<<<<<
 *    return sys._getframe()
 * # ELSE
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._getframe", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":175
 * 
 * 
 * def _get_top_level_frame():             # <<<<<<<<<<<<<<
 *     f_unhandled = _getframe()
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_11_get_top_level_frame(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_11_get_top_level_frame = {"_get_top_level_frame", (PyCFunction)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_11_get_top_level_frame, METH_NOARGS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_11_get_top_level_frame(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_top_level_frame (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_10_get_top_level_frame(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_10_get_top_level_frame(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_f_unhandled = NULL;
  PyObject *__pyx_v_filename = NULL;
  PyObject *__pyx_v_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_get_top_level_frame", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":176
 * 
 * def _get_top_level_frame():
 *     f_unhandled = _getframe()             # <<<<<<<<<<<<<<
 * 
 *     while f_unhandled:
 */
  __pyx_t_1 = __pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_f_unhandled = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":178
 *     f_unhandled = _getframe()
 * 
 *     while f_unhandled:             # <<<<<<<<<<<<<<
 *         filename = f_unhandled.f_code.co_filename
 *         name = splitext(basename(filename))[0]
 */
  while (1) {
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_f_unhandled); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 178, __pyx_L1_error)
    if (!__pyx_t_2) break;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":179
 * 
 *     while f_unhandled:
 *         filename = f_unhandled.f_code.co_filename             # <<<<<<<<<<<<<<
 *         name = splitext(basename(filename))[0]
 *         if name == 'pydevd':
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_unhandled, __pyx_n_s_f_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_filename, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":180
 *     while f_unhandled:
 *         filename = f_unhandled.f_code.co_filename
 *         name = splitext(basename(filename))[0]             # <<<<<<<<<<<<<<
 *         if name == 'pydevd':
 *             if f_unhandled.f_code.co_name == '_exec':
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_splitext); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_basename); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_filename};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __pyx_t_5 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 180, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":181
 *         filename = f_unhandled.f_code.co_filename
 *         name = splitext(basename(filename))[0]
 *         if name == 'pydevd':             # <<<<<<<<<<<<<<
 *             if f_unhandled.f_code.co_name == '_exec':
 *                 break
 */
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_name, __pyx_n_s_pydevd, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 181, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":182
 *         name = splitext(basename(filename))[0]
 *         if name == 'pydevd':
 *             if f_unhandled.f_code.co_name == '_exec':             # <<<<<<<<<<<<<<
 *                 break
 *         elif name == 'threading':
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_unhandled, __pyx_n_s_f_code); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_co_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_n_s_exec, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_2) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":183
 *         if name == 'pydevd':
 *             if f_unhandled.f_code.co_name == '_exec':
 *                 break             # <<<<<<<<<<<<<<
 *         elif name == 'threading':
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':
 */
        goto __pyx_L4_break;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":182
 *         name = splitext(basename(filename))[0]
 *         if name == 'pydevd':
 *             if f_unhandled.f_code.co_name == '_exec':             # <<<<<<<<<<<<<<
 *                 break
 *         elif name == 'threading':
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":181
 *         filename = f_unhandled.f_code.co_filename
 *         name = splitext(basename(filename))[0]
 *         if name == 'pydevd':             # <<<<<<<<<<<<<<
 *             if f_unhandled.f_code.co_name == '_exec':
 *                 break
 */
      goto __pyx_L5;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":184
 *             if f_unhandled.f_code.co_name == '_exec':
 *                 break
 *         elif name == 'threading':             # <<<<<<<<<<<<<<
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':
 *                 break
 */
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_name, __pyx_n_s_threading, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 184, __pyx_L1_error)
    if (__pyx_t_2) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":185
 *                 break
 *         elif name == 'threading':
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':             # <<<<<<<<<<<<<<
 *                 break
 *         f_unhandled = f_unhandled.f_back
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_unhandled, __pyx_n_s_f_code); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_co_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_bootstrap_inner, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 185, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_2) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":186
 *         elif name == 'threading':
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':
 *                 break             # <<<<<<<<<<<<<<
 *         f_unhandled = f_unhandled.f_back
 * 
 */
        goto __pyx_L4_break;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":185
 *                 break
 *         elif name == 'threading':
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':             # <<<<<<<<<<<<<<
 *                 break
 *         f_unhandled = f_unhandled.f_back
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":184
 *             if f_unhandled.f_code.co_name == '_exec':
 *                 break
 *         elif name == 'threading':             # <<<<<<<<<<<<<<
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':
 *                 break
 */
    }
    __pyx_L5:;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":187
 *             if f_unhandled.f_code.co_name == '_bootstrap_inner':
 *                 break
 *         f_unhandled = f_unhandled.f_back             # <<<<<<<<<<<<<<
 * 
 *     return f_unhandled
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_unhandled, __pyx_n_s_f_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 187, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_f_unhandled, __pyx_t_1);
    __pyx_t_1 = 0;
  }
  __pyx_L4_break:;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":189
 *         f_unhandled = f_unhandled.f_back
 * 
 *     return f_unhandled             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_f_unhandled);
  __pyx_r = __pyx_v_f_unhandled;
  goto __pyx_L0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":175
 * 
 * 
 * def _get_top_level_frame():             # <<<<<<<<<<<<<<
 *     f_unhandled = _getframe()
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._get_top_level_frame", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_f_unhandled);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XDECREF(__pyx_v_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":192
 * 
 * 
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):             # <<<<<<<<<<<<<<
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_13_stop_on_unhandled_exception(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_13_stop_on_unhandled_exception = {"_stop_on_unhandled_exception", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_13_stop_on_unhandled_exception, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_13_stop_on_unhandled_exception(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_exc_info = 0;
  PyObject *__pyx_v_py_db = 0;
  PyObject *__pyx_v_thread = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_stop_on_unhandled_exception (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_exc_info,&__pyx_n_s_py_db,&__pyx_n_s_thread,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exc_info)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 192, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_py_db)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 192, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_stop_on_unhandled_exception", 1, 3, 3, 1); __PYX_ERR(0, 192, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_thread)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 192, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_stop_on_unhandled_exception", 1, 3, 3, 2); __PYX_ERR(0, 192, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_stop_on_unhandled_exception") < 0)) __PYX_ERR(0, 192, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_exc_info = values[0];
    __pyx_v_py_db = values[1];
    __pyx_v_thread = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_stop_on_unhandled_exception", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 192, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._stop_on_unhandled_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_12_stop_on_unhandled_exception(__pyx_self, __pyx_v_exc_info, __pyx_v_py_db, __pyx_v_thread);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_12_stop_on_unhandled_exception(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_exc_info, PyObject *__pyx_v_py_db, PyObject *__pyx_v_thread) {
  PyObject *__pyx_v_additional_info = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_stop_on_unhandled_exception", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":193
 * 
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):
 *     additional_info = _get_additional_info(thread)             # <<<<<<<<<<<<<<
 *     if not additional_info.suspended_at_unhandled:
 *         additional_info.suspended_at_unhandled = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_additional_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_thread};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_additional_info = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":194
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:             # <<<<<<<<<<<<<<
 *         additional_info.suspended_at_unhandled = True
 *         stop_on_unhandled_exception(py_db, thread, additional_info,
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_additional_info, __pyx_n_s_suspended_at_unhandled); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 194, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":195
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:
 *         additional_info.suspended_at_unhandled = True             # <<<<<<<<<<<<<<
 *         stop_on_unhandled_exception(py_db, thread, additional_info,
 *                                     exc_info)
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_additional_info, __pyx_n_s_suspended_at_unhandled, Py_True) < 0) __PYX_ERR(0, 195, __pyx_L1_error)

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":196
 *     if not additional_info.suspended_at_unhandled:
 *         additional_info.suspended_at_unhandled = True
 *         stop_on_unhandled_exception(py_db, thread, additional_info,             # <<<<<<<<<<<<<<
 *                                     exc_info)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_stop_on_unhandled_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":197
 *         additional_info.suspended_at_unhandled = True
 *         stop_on_unhandled_exception(py_db, thread, additional_info,
 *                                     exc_info)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_py_db, __pyx_v_thread, __pyx_v_additional_info, __pyx_v_exc_info};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_4, 4+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 196, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":194
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:             # <<<<<<<<<<<<<<
 *         additional_info.suspended_at_unhandled = True
 *         stop_on_unhandled_exception(py_db, thread, additional_info,
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":192
 * 
 * 
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):             # <<<<<<<<<<<<<<
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._stop_on_unhandled_exception", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_additional_info);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":200
 * 
 * 
 * def enable_pep669_monitoring():             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_15enable_pep669_monitoring(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_15enable_pep669_monitoring = {"enable_pep669_monitoring", (PyCFunction)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_15enable_pep669_monitoring, METH_NOARGS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_15enable_pep669_monitoring(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("enable_pep669_monitoring (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_14enable_pep669_monitoring(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_14enable_pep669_monitoring(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_v_DEBUGGER_ID = NULL;
  PyObject *__pyx_v_event_type = NULL;
  PyObject *__pyx_v_callback = NULL;
  PyObject *__pyx_v_debugger = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("enable_pep669_monitoring", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":201
 * 
 * def enable_pep669_monitoring():
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID             # <<<<<<<<<<<<<<
 *     if not monitoring.get_tool(DEBUGGER_ID):
 *         monitoring.use_tool_id(DEBUGGER_ID, PYDEVD_TOOL_NAME)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEBUGGER_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_DEBUGGER_ID = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":202
 * def enable_pep669_monitoring():
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):             # <<<<<<<<<<<<<<
 *         monitoring.use_tool_id(DEBUGGER_ID, PYDEVD_TOOL_NAME)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_tool); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_DEBUGGER_ID};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":203
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 *         monitoring.use_tool_id(DEBUGGER_ID, PYDEVD_TOOL_NAME)             # <<<<<<<<<<<<<<
 * 
 *         monitoring.set_events(
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_use_tool_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_PYDEVD_TOOL_NAME); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 203, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_DEBUGGER_ID, __pyx_t_3};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 203, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":205
 *         monitoring.use_tool_id(DEBUGGER_ID, PYDEVD_TOOL_NAME)
 * 
 *         monitoring.set_events(             # <<<<<<<<<<<<<<
 *             DEBUGGER_ID,
 *             monitoring.events.PY_START | monitoring.events.RAISE
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_set_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 205, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":207
 *         monitoring.set_events(
 *             DEBUGGER_ID,
 *             monitoring.events.PY_START | monitoring.events.RAISE             # <<<<<<<<<<<<<<
 *         )
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_events); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_PY_START); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_events); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_RAISE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyNumber_Or(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    __pyx_t_4 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_4 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_DEBUGGER_ID, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":211
 * 
 *         for event_type, callback in (
 *             (monitoring.events.PY_START, py_start_callback),             # <<<<<<<<<<<<<<
 *             (monitoring.events.LINE, py_line_callback),
 *             (monitoring.events.PY_RETURN, py_return_callback),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PY_START); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_py_start_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":212
 *         for event_type, callback in (
 *             (monitoring.events.PY_START, py_start_callback),
 *             (monitoring.events.LINE, py_line_callback),             # <<<<<<<<<<<<<<
 *             (monitoring.events.PY_RETURN, py_return_callback),
 *             (monitoring.events.RAISE, py_raise_callback),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_events); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_LINE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_py_line_callback); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3)) __PYX_ERR(0, 212, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_2)) __PYX_ERR(0, 212, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":213
 *             (monitoring.events.PY_START, py_start_callback),
 *             (monitoring.events.LINE, py_line_callback),
 *             (monitoring.events.PY_RETURN, py_return_callback),             # <<<<<<<<<<<<<<
 *             (monitoring.events.RAISE, py_raise_callback),
 *             (monitoring.events.CALL, call_callback),
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_PY_RETURN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_py_return_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(0, 213, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(0, 213, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":214
 *             (monitoring.events.LINE, py_line_callback),
 *             (monitoring.events.PY_RETURN, py_return_callback),
 *             (monitoring.events.RAISE, py_raise_callback),             # <<<<<<<<<<<<<<
 *             (monitoring.events.CALL, call_callback),
 *         ):
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_events); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_RAISE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_py_raise_callback); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_t_2)) __PYX_ERR(0, 214, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_2 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":215
 *             (monitoring.events.PY_RETURN, py_return_callback),
 *             (monitoring.events.RAISE, py_raise_callback),
 *             (monitoring.events.CALL, call_callback),             # <<<<<<<<<<<<<<
 *         ):
 *             monitoring.register_callback(DEBUGGER_ID, event_type, callback)
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_CALL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_call_callback); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = PyTuple_New(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_3)) __PYX_ERR(0, 215, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":211
 * 
 *         for event_type, callback in (
 *             (monitoring.events.PY_START, py_start_callback),             # <<<<<<<<<<<<<<
 *             (monitoring.events.LINE, py_line_callback),
 *             (monitoring.events.PY_RETURN, py_return_callback),
 */
    __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_8);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_8)) __PYX_ERR(0, 211, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_7);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(0, 211, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_9);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_9)) __PYX_ERR(0, 211, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_10);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_t_10)) __PYX_ERR(0, 211, __pyx_L1_error);
    __pyx_t_8 = 0;
    __pyx_t_7 = 0;
    __pyx_t_1 = 0;
    __pyx_t_9 = 0;
    __pyx_t_10 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":210
 *         )
 * 
 *         for event_type, callback in (             # <<<<<<<<<<<<<<
 *             (monitoring.events.PY_START, py_start_callback),
 *             (monitoring.events.LINE, py_line_callback),
 */
    __pyx_t_10 = __pyx_t_3; __Pyx_INCREF(__pyx_t_10);
    __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (__pyx_t_11 >= 5) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_11); __Pyx_INCREF(__pyx_t_3); __pyx_t_11++; if (unlikely((0 < 0))) __PYX_ERR(0, 210, __pyx_L1_error)
      #else
      __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_10, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      if (likely(__pyx_t_3 != Py_None)) {
        PyObject* sequence = __pyx_t_3;
        Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          __PYX_ERR(0, 210, __pyx_L1_error)
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_1);
        #else
        __pyx_t_9 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 210, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 210, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      } else {
        __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(0, 210, __pyx_L1_error)
      }
      __Pyx_XDECREF_SET(__pyx_v_event_type, __pyx_t_9);
      __pyx_t_9 = 0;
      __Pyx_XDECREF_SET(__pyx_v_callback, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":217
 *             (monitoring.events.CALL, call_callback),
 *         ):
 *             monitoring.register_callback(DEBUGGER_ID, event_type, callback)             # <<<<<<<<<<<<<<
 * 
 *     debugger = GlobalDebuggerHolder.global_dbg
 */
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_register_callback); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 217, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      __pyx_t_4 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_9, function);
          __pyx_t_4 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_DEBUGGER_ID, __pyx_v_event_type, __pyx_v_callback};
        __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_9, __pyx_callargs+1-__pyx_t_4, 3+__pyx_t_4);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 217, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":210
 *         )
 * 
 *         for event_type, callback in (             # <<<<<<<<<<<<<<
 *             (monitoring.events.PY_START, py_start_callback),
 *             (monitoring.events.LINE, py_line_callback),
 */
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":202
 * def enable_pep669_monitoring():
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):             # <<<<<<<<<<<<<<
 *         monitoring.use_tool_id(DEBUGGER_ID, PYDEVD_TOOL_NAME)
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":219
 *             monitoring.register_callback(DEBUGGER_ID, event_type, callback)
 * 
 *     debugger = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 *     if debugger:
 *         debugger.is_pep669_monitoring_enabled = True
 */
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_v_debugger = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":220
 * 
 *     debugger = GlobalDebuggerHolder.global_dbg
 *     if debugger:             # <<<<<<<<<<<<<<
 *         debugger.is_pep669_monitoring_enabled = True
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_debugger); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 220, __pyx_L1_error)
  if (__pyx_t_6) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":221
 *     debugger = GlobalDebuggerHolder.global_dbg
 *     if debugger:
 *         debugger.is_pep669_monitoring_enabled = True             # <<<<<<<<<<<<<<
 * 
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_debugger, __pyx_n_s_is_pep669_monitoring_enabled, Py_True) < 0) __PYX_ERR(0, 221, __pyx_L1_error)

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":220
 * 
 *     debugger = GlobalDebuggerHolder.global_dbg
 *     if debugger:             # <<<<<<<<<<<<<<
 *         debugger.is_pep669_monitoring_enabled = True
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":200
 * 
 * 
 * def enable_pep669_monitoring():             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.enable_pep669_monitoring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_DEBUGGER_ID);
  __Pyx_XDECREF(__pyx_v_event_type);
  __Pyx_XDECREF(__pyx_v_callback);
  __Pyx_XDECREF(__pyx_v_debugger);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":224
 * 
 * 
 * def add_new_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     breakpoint._not_processed = True
 *     monitoring.restart_events()
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_17add_new_breakpoint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_17add_new_breakpoint = {"add_new_breakpoint", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_17add_new_breakpoint, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_17add_new_breakpoint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_breakpoint = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("add_new_breakpoint (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_breakpoint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_breakpoint)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 224, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "add_new_breakpoint") < 0)) __PYX_ERR(0, 224, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_breakpoint = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("add_new_breakpoint", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 224, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.add_new_breakpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_16add_new_breakpoint(__pyx_self, __pyx_v_breakpoint);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_16add_new_breakpoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_breakpoint) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add_new_breakpoint", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":225
 * 
 * def add_new_breakpoint(breakpoint):
 *     breakpoint._not_processed = True             # <<<<<<<<<<<<<<
 *     monitoring.restart_events()
 *     _modify_global_events(_EVENT_ACTIONS["ADD"], monitoring.events.CALL)
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_breakpoint, __pyx_n_s_not_processed, Py_True) < 0) __PYX_ERR(0, 225, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":226
 * def add_new_breakpoint(breakpoint):
 *     breakpoint._not_processed = True
 *     monitoring.restart_events()             # <<<<<<<<<<<<<<
 *     _modify_global_events(_EVENT_ACTIONS["ADD"], monitoring.events.CALL)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_restart_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 0+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":227
 *     breakpoint._not_processed = True
 *     monitoring.restart_events()
 *     _modify_global_events(_EVENT_ACTIONS["ADD"], monitoring.events.CALL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_modify_global_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_EVENT_ACTIONS); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_ADD); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_events); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_CALL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_5, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":224
 * 
 * 
 * def add_new_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     breakpoint._not_processed = True
 *     monitoring.restart_events()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.add_new_breakpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":230
 * 
 * 
 * def remove_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     if getattr(breakpoint, '_not_processed', None):
 *         breakpoint._not_processed = False
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_19remove_breakpoint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_19remove_breakpoint = {"remove_breakpoint", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_19remove_breakpoint, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_19remove_breakpoint(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_breakpoint = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("remove_breakpoint (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_breakpoint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_breakpoint)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 230, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "remove_breakpoint") < 0)) __PYX_ERR(0, 230, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_breakpoint = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("remove_breakpoint", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 230, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.remove_breakpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_18remove_breakpoint(__pyx_self, __pyx_v_breakpoint);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_18remove_breakpoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_breakpoint) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  unsigned int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("remove_breakpoint", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":231
 * 
 * def remove_breakpoint(breakpoint):
 *     if getattr(breakpoint, '_not_processed', None):             # <<<<<<<<<<<<<<
 *         breakpoint._not_processed = False
 *         _modify_global_events(_EVENT_ACTIONS["REMOVE"], monitoring.events.CALL)
 */
  __pyx_t_1 = __Pyx_GetAttr3(__pyx_v_breakpoint, __pyx_n_s_not_processed, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(0, 231, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":232
 * def remove_breakpoint(breakpoint):
 *     if getattr(breakpoint, '_not_processed', None):
 *         breakpoint._not_processed = False             # <<<<<<<<<<<<<<
 *         _modify_global_events(_EVENT_ACTIONS["REMOVE"], monitoring.events.CALL)
 * 
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_breakpoint, __pyx_n_s_not_processed, Py_False) < 0) __PYX_ERR(0, 232, __pyx_L1_error)

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":233
 *     if getattr(breakpoint, '_not_processed', None):
 *         breakpoint._not_processed = False
 *         _modify_global_events(_EVENT_ACTIONS["REMOVE"], monitoring.events.CALL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_modify_global_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_EVENT_ACTIONS); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_t_4, __pyx_n_s_REMOVE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_events); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_CALL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 233, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_5, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":231
 * 
 * def remove_breakpoint(breakpoint):
 *     if getattr(breakpoint, '_not_processed', None):             # <<<<<<<<<<<<<<
 *         breakpoint._not_processed = False
 *         _modify_global_events(_EVENT_ACTIONS["REMOVE"], monitoring.events.CALL)
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":230
 * 
 * 
 * def remove_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     if getattr(breakpoint, '_not_processed', None):
 *         breakpoint._not_processed = False
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.remove_breakpoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":236
 * 
 * 
 * def _modify_global_events(action, event):             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_21_modify_global_events(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_21_modify_global_events = {"_modify_global_events", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_21_modify_global_events, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_21_modify_global_events(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_action = 0;
  PyObject *__pyx_v_event = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_modify_global_events (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_action,&__pyx_n_s_event,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_action)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 236, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_event)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 236, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_modify_global_events", 1, 2, 2, 1); __PYX_ERR(0, 236, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_modify_global_events") < 0)) __PYX_ERR(0, 236, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_action = values[0];
    __pyx_v_event = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_modify_global_events", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 236, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._modify_global_events", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_20_modify_global_events(__pyx_self, __pyx_v_action, __pyx_v_event);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_20_modify_global_events(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_action, PyObject *__pyx_v_event) {
  PyObject *__pyx_v_DEBUGGER_ID = NULL;
  PyObject *__pyx_v_current_events = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  unsigned int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_modify_global_events", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":237
 * 
 * def _modify_global_events(action, event):
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID             # <<<<<<<<<<<<<<
 *     if not monitoring.get_tool(DEBUGGER_ID):
 *         return
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DEBUGGER_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_DEBUGGER_ID = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":238
 * def _modify_global_events(action, event):
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get_tool); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_DEBUGGER_ID};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 238, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_6 = (!__pyx_t_5);
  if (__pyx_t_6) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":239
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 *         return             # <<<<<<<<<<<<<<
 * 
 *     current_events = monitoring.get_events(DEBUGGER_ID)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":238
 * def _modify_global_events(action, event):
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":241
 *         return
 * 
 *     current_events = monitoring.get_events(DEBUGGER_ID)             # <<<<<<<<<<<<<<
 *     monitoring.set_events(DEBUGGER_ID, action(current_events, event))
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get_events); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_DEBUGGER_ID};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_4, 1+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 241, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_v_current_events = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":242
 * 
 *     current_events = monitoring.get_events(DEBUGGER_ID)
 *     monitoring.set_events(DEBUGGER_ID, action(current_events, event))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_set_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_INCREF(__pyx_v_action);
  __pyx_t_7 = __pyx_v_action; __pyx_t_8 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_8, __pyx_v_current_events, __pyx_v_event};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = NULL;
  __pyx_t_4 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_4 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_v_DEBUGGER_ID, __pyx_t_1};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_4, 2+__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":236
 * 
 * 
 * def _modify_global_events(action, event):             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._modify_global_events", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_DEBUGGER_ID);
  __Pyx_XDECREF(__pyx_v_current_events);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":245
 * 
 * 
 * def _enable_return_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_23_enable_return_tracing(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_23_enable_return_tracing = {"_enable_return_tracing", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_23_enable_return_tracing, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_23_enable_return_tracing(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_enable_return_tracing (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 245, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_enable_return_tracing") < 0)) __PYX_ERR(0, 245, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_enable_return_tracing", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 245, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._enable_return_tracing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_22_enable_return_tracing(__pyx_self, __pyx_v_code);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_22_enable_return_tracing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code) {
  PyObject *__pyx_v_local_events = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_enable_return_tracing", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":246
 * 
 * def _enable_return_tracing(code):
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)             # <<<<<<<<<<<<<<
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 *                                 local_events | monitoring.events.PY_RETURN)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_local_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEBUGGER_ID); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_4, __pyx_v_code};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_local_events = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":247
 * def _enable_return_tracing(code):
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,             # <<<<<<<<<<<<<<
 *                                 local_events | monitoring.events.PY_RETURN)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_set_local_events); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DEBUGGER_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":248
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 *                                 local_events | monitoring.events.PY_RETURN)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_events); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_PY_RETURN); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Or(__pyx_v_local_events, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_t_2, __pyx_v_code, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 3+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":245
 * 
 * 
 * def _enable_return_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._enable_return_tracing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_local_events);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":251
 * 
 * 
 * def _enable_line_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_25_enable_line_tracing(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_25_enable_line_tracing = {"_enable_line_tracing", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_25_enable_line_tracing, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_25_enable_line_tracing(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_enable_line_tracing (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 251, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_enable_line_tracing") < 0)) __PYX_ERR(0, 251, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_code = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_enable_line_tracing", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 251, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._enable_line_tracing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_24_enable_line_tracing(__pyx_self, __pyx_v_code);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_24_enable_line_tracing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code) {
  PyObject *__pyx_v_local_events = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_enable_line_tracing", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":252
 * 
 * def _enable_line_tracing(code):
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)             # <<<<<<<<<<<<<<
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 *                                 local_events | monitoring.events.LINE)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_local_events); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_DEBUGGER_ID); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_4, __pyx_v_code};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 252, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_local_events = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":253
 * def _enable_line_tracing(code):
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,             # <<<<<<<<<<<<<<
 *                                 local_events | monitoring.events.LINE)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_set_local_events); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DEBUGGER_ID); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":254
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 *                                 local_events | monitoring.events.LINE)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_events); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_LINE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyNumber_Or(__pyx_v_local_events, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[4] = {__pyx_t_3, __pyx_t_2, __pyx_v_code, __pyx_t_6};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 3+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 253, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":251
 * 
 * 
 * def _enable_line_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython._enable_line_tracing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_local_events);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":257
 * 
 * 
 * def call_callback(code, instruction_offset, callable, arg0):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_27call_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_27call_callback = {"call_callback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_27call_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_27call_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instruction_offset = 0;
  CYTHON_UNUSED PyObject *__pyx_v_callable = 0;
  CYTHON_UNUSED PyObject *__pyx_v_arg0 = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("call_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,&__pyx_n_s_instruction_offset,&__pyx_n_s_callable,&__pyx_n_s_arg0,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instruction_offset)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("call_callback", 1, 4, 4, 1); __PYX_ERR(0, 257, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_callable)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("call_callback", 1, 4, 4, 2); __PYX_ERR(0, 257, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arg0)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 257, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("call_callback", 1, 4, 4, 3); __PYX_ERR(0, 257, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "call_callback") < 0)) __PYX_ERR(0, 257, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 4)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
      values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
    }
    __pyx_v_code = values[0];
    __pyx_v_instruction_offset = values[1];
    __pyx_v_callable = values[2];
    __pyx_v_arg0 = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("call_callback", 1, 4, 4, __pyx_nargs); __PYX_ERR(0, 257, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.call_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_26call_callback(__pyx_self, __pyx_v_code, __pyx_v_instruction_offset, __pyx_v_callable, __pyx_v_arg0);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_26call_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset, CYTHON_UNUSED PyObject *__pyx_v_callable, CYTHON_UNUSED PyObject *__pyx_v_arg0) {
  PyObject *__pyx_v_py_db = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_thread = NULL;
  PyObject *__pyx_v_frame_cache_key = NULL;
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_pydev_step_cmd = NULL;
  PyObject *__pyx_v_is_stepping = NULL;
  PyObject *__pyx_v_abs_path_real_path_and_base = NULL;
  PyObject *__pyx_v_filename = NULL;
  PyObject *__pyx_v_breakpoints_for_file = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe __pyx_t_9;
  unsigned int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("call_callback", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":258
 * 
 * def call_callback(code, instruction_offset, callable, arg0):
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":259
 * def call_callback(code, instruction_offset, callable, arg0):
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 259, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 259, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_py_db = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":258
 * 
 * def call_callback(code, instruction_offset, callable, arg0):
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":260
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         return
 *     if py_db is None:
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.call_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 260, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":261
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 *         return             # <<<<<<<<<<<<<<
 *     if py_db is None:
 *         return monitoring.DISABLE
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":258
 * 
 * def call_callback(code, instruction_offset, callable, arg0):
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":262
 *     except AttributeError:
 *         return
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 * 
 */
  __pyx_t_8 = (__pyx_v_py_db == Py_None);
  if (__pyx_t_8) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":263
 *         return
 *     if py_db is None:
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *     frame = _getframe(1)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":262
 *     except AttributeError:
 *         return
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":265
 *         return monitoring.DISABLE
 * 
 *     frame = _getframe(1)             # <<<<<<<<<<<<<<
 *     # print('ENTER: CALL ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 */
  __pyx_t_9.__pyx_n = 1;
  __pyx_t_9.depth = __pyx_int_1;
  __pyx_t_4 = __pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(&__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_frame = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":268
 *     # print('ENTER: CALL ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":269
 * 
 *     try:
 *         if py_db._finish_debugging_session:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_finish_debugging_session); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 269, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 269, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":270
 *     try:
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *         thread = get_current_thread()
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 270, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 270, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_7;
        __pyx_t_7 = 0;
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":269
 * 
 *     try:
 *         if py_db._finish_debugging_session:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":272
 *             return monitoring.DISABLE
 * 
 *         thread = get_current_thread()             # <<<<<<<<<<<<<<
 * 
 *         if not is_thread_alive(thread):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_current_thread); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 272, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 272, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_thread = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":274
 *         thread = get_current_thread()
 * 
 *         if not is_thread_alive(thread):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_is_thread_alive); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 274, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_thread};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 274, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 274, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = (!__pyx_t_8);
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":275
 * 
 *         if not is_thread_alive(thread):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         frame_cache_key = _make_frame_cache_key(code)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":274
 *         thread = get_current_thread()
 * 
 *         if not is_thread_alive(thread):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":277
 *             return
 * 
 *         frame_cache_key = _make_frame_cache_key(code)             # <<<<<<<<<<<<<<
 * 
 *         info = _get_additional_info(thread)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_make_frame_cache_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 277, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_code};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 277, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_frame_cache_key = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":279
 *         frame_cache_key = _make_frame_cache_key(code)
 * 
 *         info = _get_additional_info(thread)             # <<<<<<<<<<<<<<
 *         pydev_step_cmd = info.pydev_step_cmd
 *         is_stepping = pydev_step_cmd != -1
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_additional_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 279, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_thread};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 279, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_info = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":280
 * 
 *         info = _get_additional_info(thread)
 *         pydev_step_cmd = info.pydev_step_cmd             # <<<<<<<<<<<<<<
 *         is_stepping = pydev_step_cmd != -1
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 280, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_pydev_step_cmd = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":281
 *         info = _get_additional_info(thread)
 *         pydev_step_cmd = info.pydev_step_cmd
 *         is_stepping = pydev_step_cmd != -1             # <<<<<<<<<<<<<<
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:
 */
      __pyx_t_7 = __Pyx_PyInt_NeObjC(__pyx_v_pydev_step_cmd, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 281, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_is_stepping = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":283
 *         is_stepping = pydev_step_cmd != -1
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_is_stepping); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 283, __pyx_L12_error)
      __pyx_t_12 = (!__pyx_t_8);
      if (__pyx_t_12) {
      } else {
        __pyx_t_11 = __pyx_t_12;
        goto __pyx_L21_bool_binop_done;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_global_cache_skips); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 283, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_v_frame_cache_key, __pyx_t_7, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 283, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = __pyx_t_12;
      __pyx_L21_bool_binop_done:;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":284
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:
 *             return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 284, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 284, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_r = __pyx_t_4;
        __pyx_t_4 = 0;
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":283
 *         is_stepping = pydev_step_cmd != -1
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":286
 *             return monitoring.DISABLE
 * 
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)             # <<<<<<<<<<<<<<
 *         filename = abs_path_real_path_and_base[1]
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_get_abs_path_real_path_and_base_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 286, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_frame};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 286, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      }
      __pyx_v_abs_path_real_path_and_base = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":287
 * 
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)
 *         filename = abs_path_real_path_and_base[1]             # <<<<<<<<<<<<<<
 * 
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_abs_path_real_path_and_base, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 287, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_filename = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":289
 *         filename = abs_path_real_path_and_base[1]
 * 
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)             # <<<<<<<<<<<<<<
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_breakpoints); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 289, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 289, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_filename};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 289, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 289, __pyx_L12_error)
      if (!__pyx_t_11) {
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_4 = __pyx_t_7;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L23_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":290
 * 
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 *                                 or py_db.has_plugin_line_breaks)             # <<<<<<<<<<<<<<
 *         if not breakpoints_for_file and not is_stepping:
 *             return monitoring.DISABLE
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_has_plugin_line_breaks); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 290, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_7);
      __pyx_t_4 = __pyx_t_7;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_L23_bool_binop_done:;
      __pyx_v_breakpoints_for_file = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":291
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoints_for_file); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 291, __pyx_L12_error)
      __pyx_t_8 = (!__pyx_t_12);
      if (__pyx_t_8) {
      } else {
        __pyx_t_11 = __pyx_t_8;
        goto __pyx_L26_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_is_stepping); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 291, __pyx_L12_error)
      __pyx_t_12 = (!__pyx_t_8);
      __pyx_t_11 = __pyx_t_12;
      __pyx_L26_bool_binop_done:;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":292
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:
 *             return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 292, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 292, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_7;
        __pyx_t_7 = 0;
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":291
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":294
 *             return monitoring.DISABLE
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):             # <<<<<<<<<<<<<<
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_should_enable_line_events_for_c); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 294, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_13, __pyx_v_frame, __pyx_v_code, __pyx_v_filename, __pyx_v_info};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 294, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 294, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":295
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):
 *             _enable_line_tracing(code)             # <<<<<<<<<<<<<<
 *             _enable_return_tracing(code)
 *     except SystemExit:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_enable_line_tracing); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 295, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_13 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_code};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 295, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":296
 *         if _should_enable_line_events_for_code(frame, code, filename, info):
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)             # <<<<<<<<<<<<<<
 *     except SystemExit:
 *         return monitoring.DISABLE
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_enable_return_tracing); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 296, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_13 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_code};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 296, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":294
 *             return monitoring.DISABLE
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):             # <<<<<<<<<<<<<<
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":268
 *     # print('ENTER: CALL ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L17_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":297
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)
 *     except SystemExit:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 *     except Exception:
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_SystemExit);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.call_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_4, &__pyx_t_13) < 0) __PYX_ERR(0, 297, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_13);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":298
 *             _enable_return_tracing(code)
 *     except SystemExit:
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 *     except Exception:
 *         try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 298, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 298, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_r = __pyx_t_14;
      __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L15_except_return;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":299
 *     except SystemExit:
 *         return monitoring.DISABLE
 *     except Exception:             # <<<<<<<<<<<<<<
 *         try:
 *             if traceback is not None:
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.call_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 299, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":300
 *         return monitoring.DISABLE
 *     except Exception:
 *         try:             # <<<<<<<<<<<<<<
 *             if traceback is not None:
 *                 traceback.print_exc()
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        /*try:*/ {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":301
 *     except Exception:
 *         try:
 *             if traceback is not None:             # <<<<<<<<<<<<<<
 *                 traceback.print_exc()
 *         except:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_traceback); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 301, __pyx_L33_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_11 = (__pyx_t_14 != Py_None);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (__pyx_t_11) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":302
 *         try:
 *             if traceback is not None:
 *                 traceback.print_exc()             # <<<<<<<<<<<<<<
 *         except:
 *             pass
 */
            __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_traceback); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 302, __pyx_L33_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 302, __pyx_L33_error)
            __Pyx_GOTREF(__pyx_t_18);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_5 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_18))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_18);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_18);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_18, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
              __pyx_t_14 = __Pyx_PyObject_FastCall(__pyx_t_18, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 302, __pyx_L33_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
            }
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":301
 *     except Exception:
 *         try:
 *             if traceback is not None:             # <<<<<<<<<<<<<<
 *                 traceback.print_exc()
 *         except:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":300
 *         return monitoring.DISABLE
 *     except Exception:
 *         try:             # <<<<<<<<<<<<<<
 *             if traceback is not None:
 *                 traceback.print_exc()
 */
        }
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        goto __pyx_L40_try_end;
        __pyx_L33_error:;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":303
 *             if traceback is not None:
 *                 traceback.print_exc()
 *         except:             # <<<<<<<<<<<<<<
 *             pass
 *         return monitoring.DISABLE
 */
        /*except:*/ {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L34_exception_handled;
        }
        __pyx_L34_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        __pyx_L40_try_end:;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":305
 *         except:
 *             pass
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 305, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_18 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_18)) __PYX_ERR(0, 305, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_r = __pyx_t_18;
      __pyx_t_18 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L15_except_return;
    }
    goto __pyx_L14_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":268
 *     # print('ENTER: CALL ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE
 */
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L16_try_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L0;
    __pyx_L15_except_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L0;
    __pyx_L17_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":257
 * 
 * 
 * def call_callback(code, instruction_offset, callable, arg0):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_18);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.call_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_db);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_thread);
  __Pyx_XDECREF(__pyx_v_frame_cache_key);
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_pydev_step_cmd);
  __Pyx_XDECREF(__pyx_v_is_stepping);
  __Pyx_XDECREF(__pyx_v_abs_path_real_path_and_base);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XDECREF(__pyx_v_breakpoints_for_file);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":308
 * 
 * 
 * def py_start_callback(code, instruction_offset):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_29py_start_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_29py_start_callback = {"py_start_callback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_29py_start_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_29py_start_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instruction_offset = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("py_start_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,&__pyx_n_s_instruction_offset,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 308, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instruction_offset)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 308, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("py_start_callback", 1, 2, 2, 1); __PYX_ERR(0, 308, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "py_start_callback") < 0)) __PYX_ERR(0, 308, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_code = values[0];
    __pyx_v_instruction_offset = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("py_start_callback", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 308, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_start_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_28py_start_callback(__pyx_self, __pyx_v_code, __pyx_v_instruction_offset);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_28py_start_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset) {
  PyObject *__pyx_v_py_db = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_thread = NULL;
  PyObject *__pyx_v_frame_cache_key = NULL;
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_pydev_step_cmd = NULL;
  PyObject *__pyx_v_is_stepping = NULL;
  PyObject *__pyx_v_abs_path_real_path_and_base = NULL;
  PyObject *__pyx_v_filename = NULL;
  PyObject *__pyx_v_file_type = NULL;
  PyObject *__pyx_v_breakpoints_for_file = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_flag = NULL;
  PyObject *__pyx_v_breakpoint = NULL;
  PyObject *__pyx_v_new_frame = NULL;
  PyObject *__pyx_v_bp_type = NULL;
  PyObject *__pyx_v_eval_result = NULL;
  PyObject *__pyx_v_cmd = NULL;
  PyObject *__pyx_v_stop_info = NULL;
  PyObject *__pyx_v_stop_frame = NULL;
  PyObject *__pyx_v_plugin_stop = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe __pyx_t_9;
  unsigned int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *(*__pyx_t_15)(PyObject *);
  Py_ssize_t __pyx_t_16;
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_start_callback", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":309
 * 
 * def py_start_callback(code, instruction_offset):
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":310
 * def py_start_callback(code, instruction_offset):
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         return
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 310, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 310, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_py_db = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":309
 * 
 * def py_start_callback(code, instruction_offset):
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":311
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_start_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 311, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":312
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     if py_db is None:
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L6_except_return;
    }
    goto __pyx_L5_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":309
 * 
 * def py_start_callback(code, instruction_offset):
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L8_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":314
 *         return
 * 
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 * 
 */
  __pyx_t_8 = (__pyx_v_py_db == Py_None);
  if (__pyx_t_8) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":315
 * 
 *     if py_db is None:
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *     frame = _getframe(1)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 315, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":314
 *         return
 * 
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":317
 *         return monitoring.DISABLE
 * 
 *     frame = _getframe(1)             # <<<<<<<<<<<<<<
 * 
 *     # print('ENTER: PY_START ', code.co_filename, frame.f_lineno, code.co_name)
 */
  __pyx_t_9.__pyx_n = 1;
  __pyx_t_9.depth = __pyx_int_1;
  __pyx_t_4 = __pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(&__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_frame = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":321
 *     # print('ENTER: PY_START ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":322
 * 
 *     try:
 *         if py_db._finish_debugging_session:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_finish_debugging_session); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 322, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":323
 *     try:
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *         thread = get_current_thread()
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 323, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 323, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_r = __pyx_t_7;
        __pyx_t_7 = 0;
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":322
 * 
 *     try:
 *         if py_db._finish_debugging_session:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":325
 *             return monitoring.DISABLE
 * 
 *         thread = get_current_thread()             # <<<<<<<<<<<<<<
 * 
 *         if not is_thread_alive(thread):
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_current_thread); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 325, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 325, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_thread = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":327
 *         thread = get_current_thread()
 * 
 *         if not is_thread_alive(thread):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_is_thread_alive); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 327, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_thread};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 327, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 327, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = (!__pyx_t_8);
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":328
 * 
 *         if not is_thread_alive(thread):
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if py_db.thread_analyser is not None:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":327
 *         thread = get_current_thread()
 * 
 *         if not is_thread_alive(thread):             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":330
 *             return
 * 
 *         if py_db.thread_analyser is not None:             # <<<<<<<<<<<<<<
 *             py_db.thread_analyser.log_event(frame)
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_thread_analyser); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 330, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = (__pyx_t_7 != Py_None);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":331
 * 
 *         if py_db.thread_analyser is not None:
 *             py_db.thread_analyser.log_event(frame)             # <<<<<<<<<<<<<<
 * 
 *         if py_db.asyncio_analyser is not None:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_thread_analyser); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 331, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_log_event); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 331, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_frame};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 331, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":330
 *             return
 * 
 *         if py_db.thread_analyser is not None:             # <<<<<<<<<<<<<<
 *             py_db.thread_analyser.log_event(frame)
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":333
 *             py_db.thread_analyser.log_event(frame)
 * 
 *         if py_db.asyncio_analyser is not None:             # <<<<<<<<<<<<<<
 *             py_db.asyncio_analyser.log_event(frame)
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_asyncio_analyser); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 333, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = (__pyx_t_7 != Py_None);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":334
 * 
 *         if py_db.asyncio_analyser is not None:
 *             py_db.asyncio_analyser.log_event(frame)             # <<<<<<<<<<<<<<
 * 
 *         frame_cache_key = _make_frame_cache_key(code)
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_asyncio_analyser); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 334, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_log_event); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 334, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_frame};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 334, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":333
 *             py_db.thread_analyser.log_event(frame)
 * 
 *         if py_db.asyncio_analyser is not None:             # <<<<<<<<<<<<<<
 *             py_db.asyncio_analyser.log_event(frame)
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":336
 *             py_db.asyncio_analyser.log_event(frame)
 * 
 *         frame_cache_key = _make_frame_cache_key(code)             # <<<<<<<<<<<<<<
 * 
 *         info = _get_additional_info(thread)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_make_frame_cache_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 336, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_code};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 336, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_frame_cache_key = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":338
 *         frame_cache_key = _make_frame_cache_key(code)
 * 
 *         info = _get_additional_info(thread)             # <<<<<<<<<<<<<<
 *         pydev_step_cmd = info.pydev_step_cmd
 *         is_stepping = pydev_step_cmd != -1
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_additional_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 338, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_thread};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 338, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_info = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":339
 * 
 *         info = _get_additional_info(thread)
 *         pydev_step_cmd = info.pydev_step_cmd             # <<<<<<<<<<<<<<
 *         is_stepping = pydev_step_cmd != -1
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 339, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_pydev_step_cmd = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":340
 *         info = _get_additional_info(thread)
 *         pydev_step_cmd = info.pydev_step_cmd
 *         is_stepping = pydev_step_cmd != -1             # <<<<<<<<<<<<<<
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:
 */
      __pyx_t_7 = __Pyx_PyInt_NeObjC(__pyx_v_pydev_step_cmd, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 340, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_is_stepping = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":342
 *         is_stepping = pydev_step_cmd != -1
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:             # <<<<<<<<<<<<<<
 *             # print('skipped: PY_START (cache hit)', frame_cache_key, frame.f_lineno, code.co_name)
 *             return
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_is_stepping); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 342, __pyx_L12_error)
      __pyx_t_12 = (!__pyx_t_8);
      if (__pyx_t_12) {
      } else {
        __pyx_t_11 = __pyx_t_12;
        goto __pyx_L23_bool_binop_done;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_global_cache_skips); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 342, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_v_frame_cache_key, __pyx_t_7, Py_EQ)); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 342, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = __pyx_t_12;
      __pyx_L23_bool_binop_done:;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":344
 *         if not is_stepping and frame_cache_key in global_cache_skips:
 *             # print('skipped: PY_START (cache hit)', frame_cache_key, frame.f_lineno, code.co_name)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":342
 *         is_stepping = pydev_step_cmd != -1
 * 
 *         if not is_stepping and frame_cache_key in global_cache_skips:             # <<<<<<<<<<<<<<
 *             # print('skipped: PY_START (cache hit)', frame_cache_key, frame.f_lineno, code.co_name)
 *             return
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":346
 *             return
 * 
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)             # <<<<<<<<<<<<<<
 *         filename = abs_path_real_path_and_base[1]
 *         file_type = get_file_type(abs_path_real_path_and_base[-1])
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_abs_path_real_path_and_base_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 346, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_frame};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 346, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_abs_path_real_path_and_base = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":347
 * 
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)
 *         filename = abs_path_real_path_and_base[1]             # <<<<<<<<<<<<<<
 *         file_type = get_file_type(abs_path_real_path_and_base[-1])
 * 
 */
      __pyx_t_7 = __Pyx_GetItemInt(__pyx_v_abs_path_real_path_and_base, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 347, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_filename = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":348
 *         abs_path_real_path_and_base = _get_abs_path_real_path_and_base_from_frame(frame)
 *         filename = abs_path_real_path_and_base[1]
 *         file_type = get_file_type(abs_path_real_path_and_base[-1])             # <<<<<<<<<<<<<<
 * 
 *         if file_type is not None:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_get_file_type); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 348, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_GetItemInt(__pyx_v_abs_path_real_path_and_base, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 348, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_5};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 348, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_v_file_type = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":350
 *         file_type = get_file_type(abs_path_real_path_and_base[-1])
 * 
 *         if file_type is not None:             # <<<<<<<<<<<<<<
 *             if file_type == 1:  # inlining LIB_FILE = 1
 *                 if not py_db.in_project_scope(filename):
 */
      __pyx_t_11 = (__pyx_v_file_type != Py_None);
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":351
 * 
 *         if file_type is not None:
 *             if file_type == 1:  # inlining LIB_FILE = 1             # <<<<<<<<<<<<<<
 *                 if not py_db.in_project_scope(filename):
 *                     # print('skipped: PY_START (not in scope)', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 */
        __pyx_t_11 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_file_type, __pyx_int_1, 1, 0)); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 351, __pyx_L12_error)
        if (__pyx_t_11) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":352
 *         if file_type is not None:
 *             if file_type == 1:  # inlining LIB_FILE = 1
 *                 if not py_db.in_project_scope(filename):             # <<<<<<<<<<<<<<
 *                     # print('skipped: PY_START (not in scope)', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 *                     global_cache_skips[frame_cache_key] = 1
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 352, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_5)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_filename};
            __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 352, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 352, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_12 = (!__pyx_t_11);
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":354
 *                 if not py_db.in_project_scope(filename):
 *                     # print('skipped: PY_START (not in scope)', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 *                     global_cache_skips[frame_cache_key] = 1             # <<<<<<<<<<<<<<
 *                     return monitoring.DISABLE
 *             else:
 */
            __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_global_cache_skips); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 354, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            if (unlikely((PyObject_SetItem(__pyx_t_7, __pyx_v_frame_cache_key, __pyx_int_1) < 0))) __PYX_ERR(0, 354, __pyx_L12_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":355
 *                     # print('skipped: PY_START (not in scope)', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 *                     global_cache_skips[frame_cache_key] = 1
 *                     return monitoring.DISABLE             # <<<<<<<<<<<<<<
 *             else:
 *                 # print('skipped: PY_START', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 */
            __Pyx_XDECREF(__pyx_r);
            __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 355, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 355, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_r = __pyx_t_4;
            __pyx_t_4 = 0;
            goto __pyx_L16_try_return;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":352
 *         if file_type is not None:
 *             if file_type == 1:  # inlining LIB_FILE = 1
 *                 if not py_db.in_project_scope(filename):             # <<<<<<<<<<<<<<
 *                     # print('skipped: PY_START (not in scope)', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 *                     global_cache_skips[frame_cache_key] = 1
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":351
 * 
 *         if file_type is not None:
 *             if file_type == 1:  # inlining LIB_FILE = 1             # <<<<<<<<<<<<<<
 *                 if not py_db.in_project_scope(filename):
 *                     # print('skipped: PY_START (not in scope)', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 */
          goto __pyx_L26;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":358
 *             else:
 *                 # print('skipped: PY_START', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 *                 global_cache_skips[frame_cache_key] = 1             # <<<<<<<<<<<<<<
 *                 return monitoring.DISABLE
 * 
 */
        /*else*/ {
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_global_cache_skips); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 358, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely((PyObject_SetItem(__pyx_t_4, __pyx_v_frame_cache_key, __pyx_int_1) < 0))) __PYX_ERR(0, 358, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":359
 *                 # print('skipped: PY_START', abs_path_real_path_and_base[-1], frame.f_lineno, code.co_name, file_type)
 *                 global_cache_skips[frame_cache_key] = 1
 *                 return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 359, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 359, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_r = __pyx_t_7;
          __pyx_t_7 = 0;
          goto __pyx_L16_try_return;
        }
        __pyx_L26:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":350
 *         file_type = get_file_type(abs_path_real_path_and_base[-1])
 * 
 *         if file_type is not None:             # <<<<<<<<<<<<<<
 *             if file_type == 1:  # inlining LIB_FILE = 1
 *                 if not py_db.in_project_scope(filename):
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":361
 *                 return monitoring.DISABLE
 * 
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)             # <<<<<<<<<<<<<<
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_breakpoints); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 361, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_get); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 361, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_5)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_filename};
        __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 361, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 361, __pyx_L12_error)
      if (!__pyx_t_12) {
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_4);
        __pyx_t_7 = __pyx_t_4;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        goto __pyx_L28_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":362
 * 
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 *                                 or py_db.has_plugin_line_breaks)             # <<<<<<<<<<<<<<
 *         if not breakpoints_for_file and not is_stepping:
 *             return
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_has_plugin_line_breaks); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 362, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_4);
      __pyx_t_7 = __pyx_t_4;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_L28_bool_binop_done:;
      __pyx_v_breakpoints_for_file = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":363
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoints_for_file); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 363, __pyx_L12_error)
      __pyx_t_8 = (!__pyx_t_11);
      if (__pyx_t_8) {
      } else {
        __pyx_t_12 = __pyx_t_8;
        goto __pyx_L31_bool_binop_done;
      }
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_is_stepping); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 363, __pyx_L12_error)
      __pyx_t_11 = (!__pyx_t_8);
      __pyx_t_12 = __pyx_t_11;
      __pyx_L31_bool_binop_done:;
      if (__pyx_t_12) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":364
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if py_db.plugin and py_db.has_plugin_line_breaks:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":363
 *         breakpoints_for_file = (py_db.breakpoints.get(filename)
 *                                 or py_db.has_plugin_line_breaks)
 *         if not breakpoints_for_file and not is_stepping:             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":366
 *             return
 * 
 *         if py_db.plugin and py_db.has_plugin_line_breaks:             # <<<<<<<<<<<<<<
 *             args = (py_db, filename, info, thread)
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 366, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 366, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_11) {
      } else {
        __pyx_t_12 = __pyx_t_11;
        goto __pyx_L34_bool_binop_done;
      }
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_has_plugin_line_breaks); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 366, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 366, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_12 = __pyx_t_11;
      __pyx_L34_bool_binop_done:;
      if (__pyx_t_12) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":367
 * 
 *         if py_db.plugin and py_db.has_plugin_line_breaks:
 *             args = (py_db, filename, info, thread)             # <<<<<<<<<<<<<<
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)
 *             if result is not None:
 */
        __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 367, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_v_py_db);
        __Pyx_GIVEREF(__pyx_v_py_db);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_py_db)) __PYX_ERR(0, 367, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_filename);
        __Pyx_GIVEREF(__pyx_v_filename);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_filename)) __PYX_ERR(0, 367, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_info);
        __Pyx_GIVEREF(__pyx_v_info);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_v_info)) __PYX_ERR(0, 367, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_thread);
        __Pyx_GIVEREF(__pyx_v_thread);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_v_thread)) __PYX_ERR(0, 367, __pyx_L12_error);
        __pyx_v_args = ((PyObject*)__pyx_t_7);
        __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":368
 *         if py_db.plugin and py_db.has_plugin_line_breaks:
 *             args = (py_db, filename, info, thread)
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)             # <<<<<<<<<<<<<<
 *             if result is not None:
 *                 flag, breakpoint, new_frame, bp_type = result
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 368, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_get_breakpoint); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 368, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_13);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_13, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_call, __pyx_v_args};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 368, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __pyx_v_result = __pyx_t_7;
        __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":369
 *             args = (py_db, filename, info, thread)
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)
 *             if result is not None:             # <<<<<<<<<<<<<<
 *                 flag, breakpoint, new_frame, bp_type = result
 *                 if breakpoint:
 */
        __pyx_t_12 = (__pyx_v_result != Py_None);
        if (__pyx_t_12) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":370
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)
 *             if result is not None:
 *                 flag, breakpoint, new_frame, bp_type = result             # <<<<<<<<<<<<<<
 *                 if breakpoint:
 *                     eval_result = False
 */
          if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
            PyObject* sequence = __pyx_v_result;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 4)) {
              if (size > 4) __Pyx_RaiseTooManyValuesError(4);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 370, __pyx_L12_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_13 = PyTuple_GET_ITEM(sequence, 1); 
              __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
              __pyx_t_5 = PyTuple_GET_ITEM(sequence, 3); 
            } else {
              __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_13 = PyList_GET_ITEM(sequence, 1); 
              __pyx_t_4 = PyList_GET_ITEM(sequence, 2); 
              __pyx_t_5 = PyList_GET_ITEM(sequence, 3); 
            }
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            #else
            {
              Py_ssize_t i;
              PyObject** temps[4] = {&__pyx_t_7,&__pyx_t_13,&__pyx_t_4,&__pyx_t_5};
              for (i=0; i < 4; i++) {
                PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 370, __pyx_L12_error)
                __Pyx_GOTREF(item);
                *(temps[i]) = item;
              }
            }
            #endif
          } else {
            Py_ssize_t index = -1;
            PyObject** temps[4] = {&__pyx_t_7,&__pyx_t_13,&__pyx_t_4,&__pyx_t_5};
            __pyx_t_14 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 370, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_14);
            for (index=0; index < 4; index++) {
              PyObject* item = __pyx_t_15(__pyx_t_14); if (unlikely(!item)) goto __pyx_L37_unpacking_failed;
              __Pyx_GOTREF(item);
              *(temps[index]) = item;
            }
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_14), 4) < 0) __PYX_ERR(0, 370, __pyx_L12_error)
            __pyx_t_15 = NULL;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            goto __pyx_L38_unpacking_done;
            __pyx_L37_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_15 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 370, __pyx_L12_error)
            __pyx_L38_unpacking_done:;
          }
          __pyx_v_flag = __pyx_t_7;
          __pyx_t_7 = 0;
          __pyx_v_breakpoint = __pyx_t_13;
          __pyx_t_13 = 0;
          __pyx_v_new_frame = __pyx_t_4;
          __pyx_t_4 = 0;
          __pyx_v_bp_type = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":371
 *             if result is not None:
 *                 flag, breakpoint, new_frame, bp_type = result
 *                 if breakpoint:             # <<<<<<<<<<<<<<
 *                     eval_result = False
 *                     if breakpoint.has_condition:
 */
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoint); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 371, __pyx_L12_error)
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":372
 *                 flag, breakpoint, new_frame, bp_type = result
 *                 if breakpoint:
 *                     eval_result = False             # <<<<<<<<<<<<<<
 *                     if breakpoint.has_condition:
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 */
            __Pyx_INCREF(Py_False);
            __pyx_v_eval_result = Py_False;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":373
 *                 if breakpoint:
 *                     eval_result = False
 *                     if breakpoint.has_condition:             # <<<<<<<<<<<<<<
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_has_condition); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 373, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 373, __pyx_L12_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_12) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":374
 *                     eval_result = False
 *                     if breakpoint.has_condition:
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)             # <<<<<<<<<<<<<<
 * 
 *                     if breakpoint.expression is not None:
 */
              __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_handle_breakpoint_condition); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 374, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_13 = NULL;
              __pyx_t_10 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
                if (likely(__pyx_t_13)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_13);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_4, function);
                  __pyx_t_10 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[5] = {__pyx_t_13, __pyx_v_py_db, __pyx_v_info, __pyx_v_breakpoint, __pyx_v_new_frame};
                __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 374, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __Pyx_DECREF_SET(__pyx_v_eval_result, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":373
 *                 if breakpoint:
 *                     eval_result = False
 *                     if breakpoint.has_condition:             # <<<<<<<<<<<<<<
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":376
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 *                     if breakpoint.expression is not None:             # <<<<<<<<<<<<<<
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_expression); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 376, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_12 = (__pyx_t_5 != Py_None);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_12) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":377
 * 
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)             # <<<<<<<<<<<<<<
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:
 */
              __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_handle_breakpoint_expression); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 377, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_13 = NULL;
              __pyx_t_10 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
                if (likely(__pyx_t_13)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_13);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_4, function);
                  __pyx_t_10 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[4] = {__pyx_t_13, __pyx_v_breakpoint, __pyx_v_info, __pyx_v_new_frame};
                __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 3+__pyx_t_10);
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 377, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":378
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_is_logpoint); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 378, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 378, __pyx_L12_error)
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (__pyx_t_11) {
              } else {
                __pyx_t_12 = __pyx_t_11;
                goto __pyx_L43_bool_binop_done;
              }
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 378, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_11 = (__pyx_t_5 != Py_None);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (__pyx_t_11) {
              } else {
                __pyx_t_12 = __pyx_t_11;
                goto __pyx_L43_bool_binop_done;
              }

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":379
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:             # <<<<<<<<<<<<<<
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 *                             py_db.writer.add_command(cmd)
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_message); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 379, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":378
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              __pyx_t_16 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_16 == ((Py_ssize_t)-1))) __PYX_ERR(0, 378, __pyx_L12_error)
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":379
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:             # <<<<<<<<<<<<<<
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 *                             py_db.writer.add_command(cmd)
 */
              __pyx_t_11 = (__pyx_t_16 > 0);
              __pyx_t_12 = __pyx_t_11;
              __pyx_L43_bool_binop_done:;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":378
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              if (__pyx_t_12) {

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":380
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')             # <<<<<<<<<<<<<<
 *                             py_db.writer.add_command(cmd)
 * 
 */
                __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_cmd_factory); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 380, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_make_io_message); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 380, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_13);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 380, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_os); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 380, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_7);
                __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_linesep); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 380, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __pyx_t_7 = PyNumber_Add(__pyx_t_4, __pyx_t_14); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 380, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __pyx_t_14 = NULL;
                __pyx_t_10 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_13))) {
                  __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
                  if (likely(__pyx_t_14)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                    __Pyx_INCREF(__pyx_t_14);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_13, function);
                    __pyx_t_10 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[3] = {__pyx_t_14, __pyx_t_7, __pyx_kp_s_1};
                  __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
                  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 380, __pyx_L12_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                }
                __pyx_v_cmd = __pyx_t_5;
                __pyx_t_5 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":381
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 *                             py_db.writer.add_command(cmd)             # <<<<<<<<<<<<<<
 * 
 *                     if breakpoint.has_condition and not eval_result:
 */
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_writer); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 381, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_add_command); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 381, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_7);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                __pyx_t_13 = NULL;
                __pyx_t_10 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_7))) {
                  __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
                  if (likely(__pyx_t_13)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                    __Pyx_INCREF(__pyx_t_13);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_7, function);
                    __pyx_t_10 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_cmd};
                  __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
                  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                  if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 381, __pyx_L12_error)
                  __Pyx_GOTREF(__pyx_t_5);
                  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                }
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":378
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              }

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":376
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 *                     if breakpoint.expression is not None:             # <<<<<<<<<<<<<<
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":383
 *                             py_db.writer.add_command(cmd)
 * 
 *                     if breakpoint.has_condition and not eval_result:             # <<<<<<<<<<<<<<
 *                         return
 * 
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_has_condition); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 383, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 383, __pyx_L12_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_11) {
            } else {
              __pyx_t_12 = __pyx_t_11;
              goto __pyx_L47_bool_binop_done;
            }
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_eval_result); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 383, __pyx_L12_error)
            __pyx_t_8 = (!__pyx_t_11);
            __pyx_t_12 = __pyx_t_8;
            __pyx_L47_bool_binop_done:;
            if (__pyx_t_12) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":384
 * 
 *                     if breakpoint.has_condition and not eval_result:
 *                         return             # <<<<<<<<<<<<<<
 * 
 *                 if flag:
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_r = Py_None; __Pyx_INCREF(Py_None);
              goto __pyx_L16_try_return;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":383
 *                             py_db.writer.add_command(cmd)
 * 
 *                     if breakpoint.has_condition and not eval_result:             # <<<<<<<<<<<<<<
 *                         return
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":371
 *             if result is not None:
 *                 flag, breakpoint, new_frame, bp_type = result
 *                 if breakpoint:             # <<<<<<<<<<<<<<
 *                     eval_result = False
 *                     if breakpoint.has_condition:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":386
 *                         return
 * 
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                     if result is not None:
 */
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 386, __pyx_L12_error)
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":387
 * 
 *                 if flag:
 *                     result = py_db.plugin.suspend(py_db, thread, frame, bp_type)             # <<<<<<<<<<<<<<
 *                     if result is not None:
 *                         frame = result
 */
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 387, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_suspend); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 387, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_13);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_7 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_py_db, __pyx_v_thread, __pyx_v_frame, __pyx_v_bp_type};
              __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 387, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":388
 *                 if flag:
 *                     result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                     if result is not None:             # <<<<<<<<<<<<<<
 *                         frame = result
 * 
 */
            __pyx_t_12 = (__pyx_v_result != Py_None);
            if (__pyx_t_12) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":389
 *                     result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                     if result is not None:
 *                         frame = result             # <<<<<<<<<<<<<<
 * 
 *                 if info.pydev_state == STATE_SUSPEND:
 */
              __Pyx_INCREF(__pyx_v_result);
              __Pyx_DECREF_SET(__pyx_v_frame, __pyx_v_result);

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":388
 *                 if flag:
 *                     result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                     if result is not None:             # <<<<<<<<<<<<<<
 *                         frame = result
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":386
 *                         return
 * 
 *                 if flag:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                     if result is not None:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":391
 *                         frame = result
 * 
 *                 if info.pydev_state == STATE_SUSPEND:             # <<<<<<<<<<<<<<
 *                     py_db.do_wait_suspend(thread, frame, 'call', None)
 *                     return
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_state); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 391, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_STATE_SUSPEND); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 391, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_t_13, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 391, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 391, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":392
 * 
 *                 if info.pydev_state == STATE_SUSPEND:
 *                     py_db.do_wait_suspend(thread, frame, 'call', None)             # <<<<<<<<<<<<<<
 *                     return
 * 
 */
            __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_do_wait_suspend); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 392, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_5 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_thread, __pyx_v_frame, __pyx_n_s_call, Py_None};
              __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 392, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":393
 *                 if info.pydev_state == STATE_SUSPEND:
 *                     py_db.do_wait_suspend(thread, frame, 'call', None)
 *                     return             # <<<<<<<<<<<<<<
 * 
 *         if is_stepping:
 */
            __Pyx_XDECREF(__pyx_r);
            __pyx_r = Py_None; __Pyx_INCREF(Py_None);
            goto __pyx_L16_try_return;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":391
 *                         frame = result
 * 
 *                 if info.pydev_state == STATE_SUSPEND:             # <<<<<<<<<<<<<<
 *                     py_db.do_wait_suspend(thread, frame, 'call', None)
 *                     return
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":369
 *             args = (py_db, filename, info, thread)
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)
 *             if result is not None:             # <<<<<<<<<<<<<<
 *                 flag, breakpoint, new_frame, bp_type = result
 *                 if breakpoint:
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":366
 *             return
 * 
 *         if py_db.plugin and py_db.has_plugin_line_breaks:             # <<<<<<<<<<<<<<
 *             args = (py_db, filename, info, thread)
 *             result = py_db.plugin.get_breakpoint(py_db, frame, 'call', args)
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":395
 *                     return
 * 
 *         if is_stepping:             # <<<<<<<<<<<<<<
 *             if (pydev_step_cmd == CMD_STEP_OVER
 *                     and frame is not info.pydev_step_stop):
 */
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_is_stepping); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 395, __pyx_L12_error)
      if (__pyx_t_12) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":396
 * 
 *         if is_stepping:
 *             if (pydev_step_cmd == CMD_STEP_OVER             # <<<<<<<<<<<<<<
 *                     and frame is not info.pydev_step_stop):
 *                 if frame.f_back is info.pydev_step_stop:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 396, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_13 = PyObject_RichCompare(__pyx_v_pydev_step_cmd, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 396, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 396, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_12 = __pyx_t_8;
          goto __pyx_L54_bool_binop_done;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":397
 *         if is_stepping:
 *             if (pydev_step_cmd == CMD_STEP_OVER
 *                     and frame is not info.pydev_step_stop):             # <<<<<<<<<<<<<<
 *                 if frame.f_back is info.pydev_step_stop:
 *                     _enable_return_tracing(code)
 */
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 397, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_8 = (__pyx_v_frame != __pyx_t_13);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_12 = __pyx_t_8;
        __pyx_L54_bool_binop_done:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":396
 * 
 *         if is_stepping:
 *             if (pydev_step_cmd == CMD_STEP_OVER             # <<<<<<<<<<<<<<
 *                     and frame is not info.pydev_step_stop):
 *                 if frame.f_back is info.pydev_step_stop:
 */
        if (__pyx_t_12) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":398
 *             if (pydev_step_cmd == CMD_STEP_OVER
 *                     and frame is not info.pydev_step_stop):
 *                 if frame.f_back is info.pydev_step_stop:             # <<<<<<<<<<<<<<
 *                     _enable_return_tracing(code)
 *             if (py_db.is_filter_enabled
 */
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 398, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 398, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_12 = (__pyx_t_13 == __pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":399
 *                     and frame is not info.pydev_step_stop):
 *                 if frame.f_back is info.pydev_step_stop:
 *                     _enable_return_tracing(code)             # <<<<<<<<<<<<<<
 *             if (py_db.is_filter_enabled
 *                     and py_db.is_ignored_by_filters(filename)):
 */
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_enable_return_tracing); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 399, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_5 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_5)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_5);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_code};
              __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 399, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_7);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":398
 *             if (pydev_step_cmd == CMD_STEP_OVER
 *                     and frame is not info.pydev_step_stop):
 *                 if frame.f_back is info.pydev_step_stop:             # <<<<<<<<<<<<<<
 *                     _enable_return_tracing(code)
 *             if (py_db.is_filter_enabled
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":396
 * 
 *         if is_stepping:
 *             if (pydev_step_cmd == CMD_STEP_OVER             # <<<<<<<<<<<<<<
 *                     and frame is not info.pydev_step_stop):
 *                 if frame.f_back is info.pydev_step_stop:
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":400
 *                 if frame.f_back is info.pydev_step_stop:
 *                     _enable_return_tracing(code)
 *             if (py_db.is_filter_enabled             # <<<<<<<<<<<<<<
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_is_filter_enabled); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 400, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 400, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_12 = __pyx_t_8;
          goto __pyx_L58_bool_binop_done;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":401
 *                     _enable_return_tracing(code)
 *             if (py_db.is_filter_enabled
 *                     and py_db.is_ignored_by_filters(filename)):             # <<<<<<<<<<<<<<
 *                 return monitoring.DISABLE
 *             if (py_db.is_filter_libraries
 */
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_is_ignored_by_filters); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 401, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_5 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_13, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_filename};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 401, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 401, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_12 = __pyx_t_8;
        __pyx_L58_bool_binop_done:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":400
 *                 if frame.f_back is info.pydev_step_stop:
 *                     _enable_return_tracing(code)
 *             if (py_db.is_filter_enabled             # <<<<<<<<<<<<<<
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE
 */
        if (__pyx_t_12) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":402
 *             if (py_db.is_filter_enabled
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE             # <<<<<<<<<<<<<<
 *             if (py_db.is_filter_libraries
 *                     and not py_db.in_project_scope(filename)):
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 402, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 402, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_r = __pyx_t_13;
          __pyx_t_13 = 0;
          goto __pyx_L16_try_return;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":400
 *                 if frame.f_back is info.pydev_step_stop:
 *                     _enable_return_tracing(code)
 *             if (py_db.is_filter_enabled             # <<<<<<<<<<<<<<
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":403
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE
 *             if (py_db.is_filter_libraries             # <<<<<<<<<<<<<<
 *                     and not py_db.in_project_scope(filename)):
 *                 return monitoring.DISABLE
 */
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_is_filter_libraries); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 403, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 403, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_12 = __pyx_t_8;
          goto __pyx_L61_bool_binop_done;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":404
 *                 return monitoring.DISABLE
 *             if (py_db.is_filter_libraries
 *                     and not py_db.in_project_scope(filename)):             # <<<<<<<<<<<<<<
 *                 return monitoring.DISABLE
 *             # We are stepping, and there is no reason to skip the frame
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 404, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_filename};
          __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 404, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 404, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_11 = (!__pyx_t_8);
        __pyx_t_12 = __pyx_t_11;
        __pyx_L61_bool_binop_done:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":403
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE
 *             if (py_db.is_filter_libraries             # <<<<<<<<<<<<<<
 *                     and not py_db.in_project_scope(filename)):
 *                 return monitoring.DISABLE
 */
        if (__pyx_t_12) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":405
 *             if (py_db.is_filter_libraries
 *                     and not py_db.in_project_scope(filename)):
 *                 return monitoring.DISABLE             # <<<<<<<<<<<<<<
 *             # We are stepping, and there is no reason to skip the frame
 *             # at this point.
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 405, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 405, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_r = __pyx_t_7;
          __pyx_t_7 = 0;
          goto __pyx_L16_try_return;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":403
 *                     and py_db.is_ignored_by_filters(filename)):
 *                 return monitoring.DISABLE
 *             if (py_db.is_filter_libraries             # <<<<<<<<<<<<<<
 *                     and not py_db.in_project_scope(filename)):
 *                 return monitoring.DISABLE
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":408
 *             # We are stepping, and there is no reason to skip the frame
 *             # at this point.
 *             _enable_line_tracing(code)             # <<<<<<<<<<<<<<
 *             _enable_return_tracing(code)
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_enable_line_tracing); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 408, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_5 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_13, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_code};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 408, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":409
 *             # at this point.
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)             # <<<<<<<<<<<<<<
 * 
 *             # Process plugins stepping
 */
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_enable_return_tracing); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 409, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_5 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_13))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_13);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_13, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_code};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 409, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":412
 * 
 *             # Process plugins stepping
 *             stop_info = {}             # <<<<<<<<<<<<<<
 *             args = (py_db, filename, info, thread)
 *             stop_frame = info.pydev_step_stop
 */
        __pyx_t_7 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 412, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_v_stop_info = ((PyObject*)__pyx_t_7);
        __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":413
 *             # Process plugins stepping
 *             stop_info = {}
 *             args = (py_db, filename, info, thread)             # <<<<<<<<<<<<<<
 *             stop_frame = info.pydev_step_stop
 *             plugin_stop = False
 */
        __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 413, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_v_py_db);
        __Pyx_GIVEREF(__pyx_v_py_db);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_py_db)) __PYX_ERR(0, 413, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_filename);
        __Pyx_GIVEREF(__pyx_v_filename);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_filename)) __PYX_ERR(0, 413, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_info);
        __Pyx_GIVEREF(__pyx_v_info);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_v_info)) __PYX_ERR(0, 413, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_thread);
        __Pyx_GIVEREF(__pyx_v_thread);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_v_thread)) __PYX_ERR(0, 413, __pyx_L12_error);
        __Pyx_XDECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_7));
        __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":414
 *             stop_info = {}
 *             args = (py_db, filename, info, thread)
 *             stop_frame = info.pydev_step_stop             # <<<<<<<<<<<<<<
 *             plugin_stop = False
 * 
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 414, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_v_stop_frame = __pyx_t_7;
        __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":415
 *             args = (py_db, filename, info, thread)
 *             stop_frame = info.pydev_step_stop
 *             plugin_stop = False             # <<<<<<<<<<<<<<
 * 
 *             if py_db.plugin is not None:
 */
        __Pyx_INCREF(Py_False);
        __pyx_v_plugin_stop = Py_False;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":417
 *             plugin_stop = False
 * 
 *             if py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 if pydev_step_cmd == CMD_STEP_INTO:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 417, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_12 = (__pyx_t_7 != Py_None);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (__pyx_t_12) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":418
 * 
 *             if py_db.plugin is not None:
 *                 if pydev_step_cmd == CMD_STEP_INTO:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 *                     if result:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CMD_STEP_INTO); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 418, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_13 = PyObject_RichCompare(__pyx_v_pydev_step_cmd, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 418, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 418, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":419
 *             if py_db.plugin is not None:
 *                 if pydev_step_cmd == CMD_STEP_INTO:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)             # <<<<<<<<<<<<<<
 *                     if result:
 *                         _, plugin_stop = result
 */
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 419, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_cmd_step_into); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 419, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_7 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_5))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_5, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[7] = {__pyx_t_7, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_call, __pyx_v_args, __pyx_v_stop_info, Py_False};
              __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 6+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 419, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_13);
            __pyx_t_13 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":420
 *                 if pydev_step_cmd == CMD_STEP_INTO:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         _, plugin_stop = result
 *                 if pydev_step_cmd == CMD_STEP_OVER:
 */
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 420, __pyx_L12_error)
            if (__pyx_t_12) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":421
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 *                     if result:
 *                         _, plugin_stop = result             # <<<<<<<<<<<<<<
 *                 if pydev_step_cmd == CMD_STEP_OVER:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)
 */
              if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
                PyObject* sequence = __pyx_v_result;
                Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                if (unlikely(size != 2)) {
                  if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                  else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                  __PYX_ERR(0, 421, __pyx_L12_error)
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                if (likely(PyTuple_CheckExact(sequence))) {
                  __pyx_t_13 = PyTuple_GET_ITEM(sequence, 0); 
                  __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
                } else {
                  __pyx_t_13 = PyList_GET_ITEM(sequence, 0); 
                  __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
                }
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_5);
                #else
                __pyx_t_13 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 421, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 421, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                #endif
              } else {
                Py_ssize_t index = -1;
                __pyx_t_7 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 421, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_7);
                __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
                index = 0; __pyx_t_13 = __pyx_t_15(__pyx_t_7); if (unlikely(!__pyx_t_13)) goto __pyx_L66_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_13);
                index = 1; __pyx_t_5 = __pyx_t_15(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L66_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_5);
                if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_7), 2) < 0) __PYX_ERR(0, 421, __pyx_L12_error)
                __pyx_t_15 = NULL;
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                goto __pyx_L67_unpacking_done;
                __pyx_L66_unpacking_failed:;
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                __pyx_t_15 = NULL;
                if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                __PYX_ERR(0, 421, __pyx_L12_error)
                __pyx_L67_unpacking_done:;
              }
              __pyx_v__ = __pyx_t_13;
              __pyx_t_13 = 0;
              __Pyx_DECREF_SET(__pyx_v_plugin_stop, __pyx_t_5);
              __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":420
 *                 if pydev_step_cmd == CMD_STEP_INTO:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         _, plugin_stop = result
 *                 if pydev_step_cmd == CMD_STEP_OVER:
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":418
 * 
 *             if py_db.plugin is not None:
 *                 if pydev_step_cmd == CMD_STEP_INTO:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 *                     if result:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":422
 *                     if result:
 *                         _, plugin_stop = result
 *                 if pydev_step_cmd == CMD_STEP_OVER:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)
 *                     if result:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 422, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_13 = PyObject_RichCompare(__pyx_v_pydev_step_cmd, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 422, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 422, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":423
 *                         _, plugin_stop = result
 *                 if pydev_step_cmd == CMD_STEP_OVER:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)             # <<<<<<<<<<<<<<
 *                     if result:
 *                         _, plugin_stop = result
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 423, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_cmd_step_over); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 423, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_12 = (__pyx_v_stop_frame == __pyx_v_frame);
            __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_t_12); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 423, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_14 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_7))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_7);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_7, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[7] = {__pyx_t_14, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_call, __pyx_v_args, __pyx_v_stop_info, __pyx_t_5};
              __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 6+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 423, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_13);
            __pyx_t_13 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":424
 *                 if pydev_step_cmd == CMD_STEP_OVER:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         _, plugin_stop = result
 * 
 */
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 424, __pyx_L12_error)
            if (__pyx_t_12) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":425
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)
 *                     if result:
 *                         _, plugin_stop = result             # <<<<<<<<<<<<<<
 * 
 *             if plugin_stop:
 */
              if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
                PyObject* sequence = __pyx_v_result;
                Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                if (unlikely(size != 2)) {
                  if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                  else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                  __PYX_ERR(0, 425, __pyx_L12_error)
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                if (likely(PyTuple_CheckExact(sequence))) {
                  __pyx_t_13 = PyTuple_GET_ITEM(sequence, 0); 
                  __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
                } else {
                  __pyx_t_13 = PyList_GET_ITEM(sequence, 0); 
                  __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
                }
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_7);
                #else
                __pyx_t_13 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 425, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 425, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_7);
                #endif
              } else {
                Py_ssize_t index = -1;
                __pyx_t_5 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 425, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_15 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
                index = 0; __pyx_t_13 = __pyx_t_15(__pyx_t_5); if (unlikely(!__pyx_t_13)) goto __pyx_L70_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_13);
                index = 1; __pyx_t_7 = __pyx_t_15(__pyx_t_5); if (unlikely(!__pyx_t_7)) goto __pyx_L70_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_7);
                if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_5), 2) < 0) __PYX_ERR(0, 425, __pyx_L12_error)
                __pyx_t_15 = NULL;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                goto __pyx_L71_unpacking_done;
                __pyx_L70_unpacking_failed:;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                __pyx_t_15 = NULL;
                if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                __PYX_ERR(0, 425, __pyx_L12_error)
                __pyx_L71_unpacking_done:;
              }
              __Pyx_XDECREF_SET(__pyx_v__, __pyx_t_13);
              __pyx_t_13 = 0;
              __Pyx_DECREF_SET(__pyx_v_plugin_stop, __pyx_t_7);
              __pyx_t_7 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":424
 *                 if pydev_step_cmd == CMD_STEP_OVER:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         _, plugin_stop = result
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":422
 *                     if result:
 *                         _, plugin_stop = result
 *                 if pydev_step_cmd == CMD_STEP_OVER:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'call', args, stop_info, stop_frame is frame)
 *                     if result:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":417
 *             plugin_stop = False
 * 
 *             if py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 if pydev_step_cmd == CMD_STEP_INTO:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'call', args, stop_info, False)
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":427
 *                         _, plugin_stop = result
 * 
 *             if plugin_stop:             # <<<<<<<<<<<<<<
 *                 py_db.plugin.stop(py_db, frame, 'call', args, stop_info, None, pydev_step_cmd)
 * 
 */
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_plugin_stop); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 427, __pyx_L12_error)
        if (__pyx_t_12) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":428
 * 
 *             if plugin_stop:
 *                 py_db.plugin.stop(py_db, frame, 'call', args, stop_info, None, pydev_step_cmd)             # <<<<<<<<<<<<<<
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):
 */
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 428, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_stop); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 428, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[8] = {__pyx_t_13, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_call, __pyx_v_args, __pyx_v_stop_info, Py_None, __pyx_v_pydev_step_cmd};
            __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 7+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 428, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":427
 *                         _, plugin_stop = result
 * 
 *             if plugin_stop:             # <<<<<<<<<<<<<<
 *                 py_db.plugin.stop(py_db, frame, 'call', args, stop_info, None, pydev_step_cmd)
 * 
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":395
 *                     return
 * 
 *         if is_stepping:             # <<<<<<<<<<<<<<
 *             if (pydev_step_cmd == CMD_STEP_OVER
 *                     and frame is not info.pydev_step_stop):
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":430
 *                 py_db.plugin.stop(py_db, frame, 'call', args, stop_info, None, pydev_step_cmd)
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):             # <<<<<<<<<<<<<<
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)
 */
      __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_should_enable_line_events_for_c); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 430, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_13 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_13)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_13);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_13, __pyx_v_frame, __pyx_v_code, __pyx_v_filename, __pyx_v_info};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 430, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(0, 430, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_12) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":431
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):
 *             _enable_line_tracing(code)             # <<<<<<<<<<<<<<
 *             _enable_return_tracing(code)
 *         else:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_enable_line_tracing); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 431, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_13 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_code};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 431, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":432
 *         if _should_enable_line_events_for_code(frame, code, filename, info):
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)             # <<<<<<<<<<<<<<
 *         else:
 *             global_cache_skips[frame_cache_key] = 1
 */
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_enable_return_tracing); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 432, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_13 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_code};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 432, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":430
 *                 py_db.plugin.stop(py_db, frame, 'call', args, stop_info, None, pydev_step_cmd)
 * 
 *         if _should_enable_line_events_for_code(frame, code, filename, info):             # <<<<<<<<<<<<<<
 *             _enable_line_tracing(code)
 *             _enable_return_tracing(code)
 */
        goto __pyx_L73;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":434
 *             _enable_return_tracing(code)
 *         else:
 *             global_cache_skips[frame_cache_key] = 1             # <<<<<<<<<<<<<<
 *             return
 * 
 */
      /*else*/ {
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_global_cache_skips); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 434, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        if (unlikely((PyObject_SetItem(__pyx_t_7, __pyx_v_frame_cache_key, __pyx_int_1) < 0))) __PYX_ERR(0, 434, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":435
 *         else:
 *             global_cache_skips[frame_cache_key] = 1
 *             return             # <<<<<<<<<<<<<<
 * 
 *     except SystemExit:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L16_try_return;
      }
      __pyx_L73:;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":321
 *     # print('ENTER: PY_START ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L17_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":437
 *             return
 * 
 *     except SystemExit:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 *     except Exception:
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_SystemExit);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_start_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_5, &__pyx_t_13) < 0) __PYX_ERR(0, 437, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_13);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":438
 * 
 *     except SystemExit:
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 *     except Exception:
 *         try:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 438, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 438, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L15_except_return;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":439
 *     except SystemExit:
 *         return monitoring.DISABLE
 *     except Exception:             # <<<<<<<<<<<<<<
 *         try:
 *             if traceback is not None:
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_start_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_5, &__pyx_t_7) < 0) __PYX_ERR(0, 439, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":440
 *         return monitoring.DISABLE
 *     except Exception:
 *         try:             # <<<<<<<<<<<<<<
 *             if traceback is not None:
 *                 traceback.print_exc()
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        /*try:*/ {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":441
 *     except Exception:
 *         try:
 *             if traceback is not None:             # <<<<<<<<<<<<<<
 *                 traceback.print_exc()
 *         except:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_traceback); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 441, __pyx_L78_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = (__pyx_t_4 != Py_None);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (__pyx_t_12) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":442
 *         try:
 *             if traceback is not None:
 *                 traceback.print_exc()             # <<<<<<<<<<<<<<
 *         except:
 *             pass
 */
            __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_traceback); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 442, __pyx_L78_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 442, __pyx_L78_error)
            __Pyx_GOTREF(__pyx_t_20);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_14 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_20))) {
              __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_20);
              if (likely(__pyx_t_14)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_20);
                __Pyx_INCREF(__pyx_t_14);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_20, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_14, NULL};
              __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_20, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L78_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
            }
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":441
 *     except Exception:
 *         try:
 *             if traceback is not None:             # <<<<<<<<<<<<<<
 *                 traceback.print_exc()
 *         except:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":440
 *         return monitoring.DISABLE
 *     except Exception:
 *         try:             # <<<<<<<<<<<<<<
 *             if traceback is not None:
 *                 traceback.print_exc()
 */
        }
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        goto __pyx_L85_try_end;
        __pyx_L78_error:;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":443
 *             if traceback is not None:
 *                 traceback.print_exc()
 *         except:             # <<<<<<<<<<<<<<
 *             pass
 *         return monitoring.DISABLE
 */
        /*except:*/ {
          __Pyx_ErrRestore(0,0,0);
          goto __pyx_L79_exception_handled;
        }
        __pyx_L79_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
        __pyx_L85_try_end:;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":445
 *         except:
 *             pass
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 445, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_20 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_20)) __PYX_ERR(0, 445, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_20);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_20;
      __pyx_t_20 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      goto __pyx_L15_except_return;
    }
    goto __pyx_L14_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":321
 *     # print('ENTER: PY_START ', code.co_filename, frame.f_lineno, code.co_name)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE
 */
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L16_try_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L0;
    __pyx_L15_except_return:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L0;
    __pyx_L17_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":308
 * 
 * 
 * def py_start_callback(code, instruction_offset):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_start_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_db);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_thread);
  __Pyx_XDECREF(__pyx_v_frame_cache_key);
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_pydev_step_cmd);
  __Pyx_XDECREF(__pyx_v_is_stepping);
  __Pyx_XDECREF(__pyx_v_abs_path_real_path_and_base);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XDECREF(__pyx_v_file_type);
  __Pyx_XDECREF(__pyx_v_breakpoints_for_file);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_flag);
  __Pyx_XDECREF(__pyx_v_breakpoint);
  __Pyx_XDECREF(__pyx_v_new_frame);
  __Pyx_XDECREF(__pyx_v_bp_type);
  __Pyx_XDECREF(__pyx_v_eval_result);
  __Pyx_XDECREF(__pyx_v_cmd);
  __Pyx_XDECREF(__pyx_v_stop_info);
  __Pyx_XDECREF(__pyx_v_stop_frame);
  __Pyx_XDECREF(__pyx_v_plugin_stop);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":448
 * 
 * 
 * def py_line_callback(code, line_number):             # <<<<<<<<<<<<<<
 *     frame = _getframe(1)
 *     thread = get_current_thread()
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_31py_line_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_31py_line_callback = {"py_line_callback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_31py_line_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_31py_line_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_code = 0;
  PyObject *__pyx_v_line_number = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("py_line_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,&__pyx_n_s_line_number,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 448, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_line_number)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 448, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("py_line_callback", 1, 2, 2, 1); __PYX_ERR(0, 448, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "py_line_callback") < 0)) __PYX_ERR(0, 448, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_code = values[0];
    __pyx_v_line_number = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("py_line_callback", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 448, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_30py_line_callback(__pyx_self, __pyx_v_code, __pyx_v_line_number);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_30py_line_callback(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_code, PyObject *__pyx_v_line_number) {
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_thread = NULL;
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_py_db = NULL;
  PyObject *__pyx_v_stop_frame = NULL;
  PyObject *__pyx_v_step_cmd = NULL;
  PyObject *__pyx_v_filename = NULL;
  PyObject *__pyx_v_breakpoints_for_file = NULL;
  PyObject *__pyx_v_frame_cache_key = NULL;
  PyObject *__pyx_v_line_cache_key = NULL;
  PyObject *__pyx_v_flag = NULL;
  PyObject *__pyx_v_breakpoint = NULL;
  PyObject *__pyx_v_stop = NULL;
  int __pyx_v_exist_result;
  PyObject *__pyx_v_bp_type = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_smart_stop_frame = NULL;
  PyObject *__pyx_v_context_start_line = NULL;
  PyObject *__pyx_v_context_end_line = NULL;
  PyObject *__pyx_v_is_within_context = NULL;
  PyObject *__pyx_v_new_frame = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_eval_result = NULL;
  PyObject *__pyx_v_cmd = NULL;
  PyObject *__pyx_v_plugin_stop = NULL;
  PyObject *__pyx_v_stop_info = NULL;
  PyObject *__pyx_v_curr_func_name = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  unsigned int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *(*__pyx_t_13)(PyObject *);
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  int __pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  PyObject *__pyx_t_20 = NULL;
  int __pyx_t_21;
  char const *__pyx_t_22;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_line_callback", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":449
 * 
 * def py_line_callback(code, line_number):
 *     frame = _getframe(1)             # <<<<<<<<<<<<<<
 *     thread = get_current_thread()
 *     info = _get_additional_info(thread)
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.depth = __pyx_int_1;
  __pyx_t_1 = __pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(&__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_frame = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":450
 * def py_line_callback(code, line_number):
 *     frame = _getframe(1)
 *     thread = get_current_thread()             # <<<<<<<<<<<<<<
 *     info = _get_additional_info(thread)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_get_current_thread); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 450, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 450, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_thread = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":451
 *     frame = _getframe(1)
 *     thread = get_current_thread()
 *     info = _get_additional_info(thread)             # <<<<<<<<<<<<<<
 * 
 *     # print('LINE %s %s %s %s' % (frame.f_lineno, code.co_name, code.co_filename, info.pydev_step_cmd))
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_get_additional_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_thread};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 451, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v_info = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":455
 *     # print('LINE %s %s %s %s' % (frame.f_lineno, code.co_name, code.co_filename, info.pydev_step_cmd))
 * 
 *     if info.is_tracing:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_is_tracing); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 455, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":456
 * 
 *     if info.is_tracing:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":455
 *     # print('LINE %s %s %s %s' % (frame.f_lineno, code.co_name, code.co_filename, info.pydev_step_cmd))
 * 
 *     if info.is_tracing:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":458
 *         return
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         info.is_tracing = True
 * 
 */
  /*try:*/ {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":459
 * 
 *     try:
 *         info.is_tracing = True             # <<<<<<<<<<<<<<
 * 
 *         py_db = GlobalDebuggerHolder.global_dbg
 */
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_is_tracing, Py_True) < 0) __PYX_ERR(0, 459, __pyx_L5_error)

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":461
 *         info.is_tracing = True
 * 
 *         py_db = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 * 
 *         if py_db._finish_debugging_session:
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 461, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 461, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_py_db = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":463
 *         py_db = GlobalDebuggerHolder.global_dbg
 * 
 *         if py_db._finish_debugging_session:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_finish_debugging_session); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 463, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 463, __pyx_L5_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_6) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":464
 * 
 *         if py_db._finish_debugging_session:
 *             return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *         stop_frame = info.pydev_step_stop
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 464, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 464, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L4_return;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":463
 *         py_db = GlobalDebuggerHolder.global_dbg
 * 
 *         if py_db._finish_debugging_session:             # <<<<<<<<<<<<<<
 *             return monitoring.DISABLE
 * 
 */
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":466
 *             return monitoring.DISABLE
 * 
 *         stop_frame = info.pydev_step_stop             # <<<<<<<<<<<<<<
 *         step_cmd = info.pydev_step_cmd
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_stop_frame = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":467
 * 
 *         stop_frame = info.pydev_step_stop
 *         step_cmd = info.pydev_step_cmd             # <<<<<<<<<<<<<<
 * 
 *         filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 467, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_step_cmd = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":469
 *         step_cmd = info.pydev_step_cmd
 * 
 *         filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]             # <<<<<<<<<<<<<<
 *         breakpoints_for_file = py_db.breakpoints.get(filename)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_get_abs_path_real_path_and_base_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 469, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_frame};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 469, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_1, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 469, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_filename = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":470
 * 
 *         filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]
 *         breakpoints_for_file = py_db.breakpoints.get(filename)             # <<<<<<<<<<<<<<
 * 
 *         frame_cache_key = _make_frame_cache_key(code)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_breakpoints); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 470, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 470, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_filename};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 470, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_breakpoints_for_file = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":472
 *         breakpoints_for_file = py_db.breakpoints.get(filename)
 * 
 *         frame_cache_key = _make_frame_cache_key(code)             # <<<<<<<<<<<<<<
 *         line_cache_key = (frame_cache_key, line_number)
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_make_frame_cache_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 472, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = NULL;
    __pyx_t_5 = 0;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_code};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 472, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_v_frame_cache_key = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":473
 * 
 *         frame_cache_key = _make_frame_cache_key(code)
 *         line_cache_key = (frame_cache_key, line_number)             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 473, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_frame_cache_key);
    __Pyx_GIVEREF(__pyx_v_frame_cache_key);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_frame_cache_key)) __PYX_ERR(0, 473, __pyx_L5_error);
    __Pyx_INCREF(__pyx_v_line_number);
    __Pyx_GIVEREF(__pyx_v_line_number);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_line_number)) __PYX_ERR(0, 473, __pyx_L5_error);
    __pyx_v_line_cache_key = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":475
 *         line_cache_key = (frame_cache_key, line_number)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             flag = False
 *             breakpoint = None
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      /*try:*/ {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":476
 * 
 *         try:
 *             flag = False             # <<<<<<<<<<<<<<
 *             breakpoint = None
 *             stop = False
 */
        __Pyx_INCREF(Py_False);
        __pyx_v_flag = Py_False;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":477
 *         try:
 *             flag = False
 *             breakpoint = None             # <<<<<<<<<<<<<<
 *             stop = False
 *             exist_result = False
 */
        __Pyx_INCREF(Py_None);
        __pyx_v_breakpoint = Py_None;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":478
 *             flag = False
 *             breakpoint = None
 *             stop = False             # <<<<<<<<<<<<<<
 *             exist_result = False
 *             bp_type = None
 */
        __Pyx_INCREF(Py_False);
        __pyx_v_stop = Py_False;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":479
 *             breakpoint = None
 *             stop = False
 *             exist_result = False             # <<<<<<<<<<<<<<
 *             bp_type = None
 *             args = (py_db, filename, info, thread)
 */
        __pyx_v_exist_result = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":480
 *             stop = False
 *             exist_result = False
 *             bp_type = None             # <<<<<<<<<<<<<<
 *             args = (py_db, filename, info, thread)
 *             smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 */
        __Pyx_INCREF(Py_None);
        __pyx_v_bp_type = Py_None;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":481
 *             exist_result = False
 *             bp_type = None
 *             args = (py_db, filename, info, thread)             # <<<<<<<<<<<<<<
 *             smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 *             context_start_line = info.pydev_smart_step_context.start_line
 */
        __pyx_t_3 = PyTuple_New(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 481, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_v_py_db);
        __Pyx_GIVEREF(__pyx_v_py_db);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_py_db)) __PYX_ERR(0, 481, __pyx_L8_error);
        __Pyx_INCREF(__pyx_v_filename);
        __Pyx_GIVEREF(__pyx_v_filename);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_filename)) __PYX_ERR(0, 481, __pyx_L8_error);
        __Pyx_INCREF(__pyx_v_info);
        __Pyx_GIVEREF(__pyx_v_info);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_v_info)) __PYX_ERR(0, 481, __pyx_L8_error);
        __Pyx_INCREF(__pyx_v_thread);
        __Pyx_GIVEREF(__pyx_v_thread);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_thread)) __PYX_ERR(0, 481, __pyx_L8_error);
        __pyx_v_args = ((PyObject*)__pyx_t_3);
        __pyx_t_3 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":482
 *             bp_type = None
 *             args = (py_db, filename, info, thread)
 *             smart_stop_frame = info.pydev_smart_step_context.smart_step_stop             # <<<<<<<<<<<<<<
 *             context_start_line = info.pydev_smart_step_context.start_line
 *             context_end_line = info.pydev_smart_step_context.end_line
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_smart_step_context); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 482, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_smart_step_stop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 482, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_smart_stop_frame = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":483
 *             args = (py_db, filename, info, thread)
 *             smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 *             context_start_line = info.pydev_smart_step_context.start_line             # <<<<<<<<<<<<<<
 *             context_end_line = info.pydev_smart_step_context.end_line
 *             is_within_context = (context_start_line <= line_number
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_smart_step_context); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 483, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_start_line); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 483, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_context_start_line = __pyx_t_3;
        __pyx_t_3 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":484
 *             smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 *             context_start_line = info.pydev_smart_step_context.start_line
 *             context_end_line = info.pydev_smart_step_context.end_line             # <<<<<<<<<<<<<<
 *             is_within_context = (context_start_line <= line_number
 *                                  <= context_end_line)
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_smart_step_context); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 484, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_end_line); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 484, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_context_end_line = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":485
 *             context_start_line = info.pydev_smart_step_context.start_line
 *             context_end_line = info.pydev_smart_step_context.end_line
 *             is_within_context = (context_start_line <= line_number             # <<<<<<<<<<<<<<
 *                                  <= context_end_line)
 * 
 */
        __pyx_t_4 = PyObject_RichCompare(__pyx_v_context_start_line, __pyx_v_line_number, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 485, __pyx_L8_error)
        if (__Pyx_PyObject_IsTrue(__pyx_t_4)) {
          __Pyx_DECREF(__pyx_t_4);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":486
 *             context_end_line = info.pydev_smart_step_context.end_line
 *             is_within_context = (context_start_line <= line_number
 *                                  <= context_end_line)             # <<<<<<<<<<<<<<
 * 
 *             if info.pydev_state != STATE_SUSPEND and breakpoints_for_file is not None and line_number in breakpoints_for_file:
 */
          __pyx_t_4 = PyObject_RichCompare(__pyx_v_line_number, __pyx_v_context_end_line, Py_LE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 486, __pyx_L8_error)
        }
        __pyx_v_is_within_context = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":488
 *                                  <= context_end_line)
 * 
 *             if info.pydev_state != STATE_SUSPEND and breakpoints_for_file is not None and line_number in breakpoints_for_file:             # <<<<<<<<<<<<<<
 *                 breakpoint = breakpoints_for_file[line_number]
 *                 new_frame = frame
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_state); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 488, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_STATE_SUSPEND); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 488, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 488, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_10) {
        } else {
          __pyx_t_6 = __pyx_t_10;
          goto __pyx_L15_bool_binop_done;
        }
        __pyx_t_10 = (__pyx_v_breakpoints_for_file != Py_None);
        if (__pyx_t_10) {
        } else {
          __pyx_t_6 = __pyx_t_10;
          goto __pyx_L15_bool_binop_done;
        }
        __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_v_line_number, __pyx_v_breakpoints_for_file, Py_EQ)); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 488, __pyx_L8_error)
        __pyx_t_6 = __pyx_t_10;
        __pyx_L15_bool_binop_done:;
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":489
 * 
 *             if info.pydev_state != STATE_SUSPEND and breakpoints_for_file is not None and line_number in breakpoints_for_file:
 *                 breakpoint = breakpoints_for_file[line_number]             # <<<<<<<<<<<<<<
 *                 new_frame = frame
 *                 stop = True
 */
          __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_breakpoints_for_file, __pyx_v_line_number); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 489, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF_SET(__pyx_v_breakpoint, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":490
 *             if info.pydev_state != STATE_SUSPEND and breakpoints_for_file is not None and line_number in breakpoints_for_file:
 *                 breakpoint = breakpoints_for_file[line_number]
 *                 new_frame = frame             # <<<<<<<<<<<<<<
 *                 stop = True
 *                 if step_cmd == CMD_STEP_OVER:
 */
          __Pyx_INCREF(__pyx_v_frame);
          __pyx_v_new_frame = __pyx_v_frame;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":491
 *                 breakpoint = breakpoints_for_file[line_number]
 *                 new_frame = frame
 *                 stop = True             # <<<<<<<<<<<<<<
 *                 if step_cmd == CMD_STEP_OVER:
 *                     if stop_frame is frame:
 */
          __Pyx_INCREF(Py_True);
          __Pyx_DECREF_SET(__pyx_v_stop, Py_True);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":492
 *                 new_frame = frame
 *                 stop = True
 *                 if step_cmd == CMD_STEP_OVER:             # <<<<<<<<<<<<<<
 *                     if stop_frame is frame:
 *                         stop = False
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 492, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_3 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 492, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 492, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (__pyx_t_6) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":493
 *                 stop = True
 *                 if step_cmd == CMD_STEP_OVER:
 *                     if stop_frame is frame:             # <<<<<<<<<<<<<<
 *                         stop = False
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (
 */
            __pyx_t_6 = (__pyx_v_stop_frame == __pyx_v_frame);
            if (__pyx_t_6) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":494
 *                 if step_cmd == CMD_STEP_OVER:
 *                     if stop_frame is frame:
 *                         stop = False             # <<<<<<<<<<<<<<
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (
 *                         frame.f_back is smart_stop_frame and is_within_context):
 */
              __Pyx_INCREF(Py_False);
              __Pyx_DECREF_SET(__pyx_v_stop, Py_False);

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":493
 *                 stop = True
 *                 if step_cmd == CMD_STEP_OVER:
 *                     if stop_frame is frame:             # <<<<<<<<<<<<<<
 *                         stop = False
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":492
 *                 new_frame = frame
 *                 stop = True
 *                 if step_cmd == CMD_STEP_OVER:             # <<<<<<<<<<<<<<
 *                     if stop_frame is frame:
 *                         stop = False
 */
            goto __pyx_L18;
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":495
 *                     if stop_frame is frame:
 *                         stop = False
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (             # <<<<<<<<<<<<<<
 *                         frame.f_back is smart_stop_frame and is_within_context):
 *                     stop = False
 */
          __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_CMD_SMART_STEP_INTO); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 495, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 495, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 495, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_10) {
          } else {
            __pyx_t_6 = __pyx_t_10;
            goto __pyx_L20_bool_binop_done;
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":496
 *                         stop = False
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (
 *                         frame.f_back is smart_stop_frame and is_within_context):             # <<<<<<<<<<<<<<
 *                     stop = False
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 496, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_10 = (__pyx_t_1 == __pyx_v_smart_stop_frame);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (__pyx_t_10) {
          } else {
            __pyx_t_6 = __pyx_t_10;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_is_within_context); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 496, __pyx_L8_error)
          __pyx_t_6 = __pyx_t_10;
          __pyx_L20_bool_binop_done:;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":495
 *                     if stop_frame is frame:
 *                         stop = False
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (             # <<<<<<<<<<<<<<
 *                         frame.f_back is smart_stop_frame and is_within_context):
 *                     stop = False
 */
          if (__pyx_t_6) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":497
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (
 *                         frame.f_back is smart_stop_frame and is_within_context):
 *                     stop = False             # <<<<<<<<<<<<<<
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)
 */
            __Pyx_INCREF(Py_False);
            __Pyx_DECREF_SET(__pyx_v_stop, Py_False);

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":495
 *                     if stop_frame is frame:
 *                         stop = False
 *                 elif step_cmd == CMD_SMART_STEP_INTO and (             # <<<<<<<<<<<<<<
 *                         frame.f_back is smart_stop_frame and is_within_context):
 *                     stop = False
 */
          }
          __pyx_L18:;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":488
 *                                  <= context_end_line)
 * 
 *             if info.pydev_state != STATE_SUSPEND and breakpoints_for_file is not None and line_number in breakpoints_for_file:             # <<<<<<<<<<<<<<
 *                 breakpoint = breakpoints_for_file[line_number]
 *                 new_frame = frame
 */
          goto __pyx_L14;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":498
 *                         frame.f_back is smart_stop_frame and is_within_context):
 *                     stop = False
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)
 *                 if result:
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = (__pyx_t_1 != Py_None);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_10) {
        } else {
          __pyx_t_6 = __pyx_t_10;
          goto __pyx_L23_bool_binop_done;
        }
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_has_plugin_line_breaks); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 498, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 498, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_6 = __pyx_t_10;
        __pyx_L23_bool_binop_done:;
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":499
 *                     stop = False
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)             # <<<<<<<<<<<<<<
 *                 if result:
 *                     exist_result = True
 */
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 499, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get_breakpoint); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 499, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_3 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_3)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_3, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_line, __pyx_v_args};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 499, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __pyx_v_result = __pyx_t_1;
          __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":500
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     exist_result = True
 *                     flag, breakpoint, new_frame, bp_type = result
 */
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 500, __pyx_L8_error)
          if (__pyx_t_6) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":501
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)
 *                 if result:
 *                     exist_result = True             # <<<<<<<<<<<<<<
 *                     flag, breakpoint, new_frame, bp_type = result
 * 
 */
            __pyx_v_exist_result = 1;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":502
 *                 if result:
 *                     exist_result = True
 *                     flag, breakpoint, new_frame, bp_type = result             # <<<<<<<<<<<<<<
 * 
 *             if breakpoint:
 */
            if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
              PyObject* sequence = __pyx_v_result;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 4)) {
                if (size > 4) __Pyx_RaiseTooManyValuesError(4);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 502, __pyx_L8_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
                __pyx_t_3 = PyTuple_GET_ITEM(sequence, 2); 
                __pyx_t_11 = PyTuple_GET_ITEM(sequence, 3); 
              } else {
                __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
                __pyx_t_3 = PyList_GET_ITEM(sequence, 2); 
                __pyx_t_11 = PyList_GET_ITEM(sequence, 3); 
              }
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_3);
              __Pyx_INCREF(__pyx_t_11);
              #else
              {
                Py_ssize_t i;
                PyObject** temps[4] = {&__pyx_t_1,&__pyx_t_4,&__pyx_t_3,&__pyx_t_11};
                for (i=0; i < 4; i++) {
                  PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 502, __pyx_L8_error)
                  __Pyx_GOTREF(item);
                  *(temps[i]) = item;
                }
              }
              #endif
            } else {
              Py_ssize_t index = -1;
              PyObject** temps[4] = {&__pyx_t_1,&__pyx_t_4,&__pyx_t_3,&__pyx_t_11};
              __pyx_t_12 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 502, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_12);
              for (index=0; index < 4; index++) {
                PyObject* item = __pyx_t_13(__pyx_t_12); if (unlikely(!item)) goto __pyx_L26_unpacking_failed;
                __Pyx_GOTREF(item);
                *(temps[index]) = item;
              }
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_12), 4) < 0) __PYX_ERR(0, 502, __pyx_L8_error)
              __pyx_t_13 = NULL;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              goto __pyx_L27_unpacking_done;
              __pyx_L26_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              __pyx_t_13 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 502, __pyx_L8_error)
              __pyx_L27_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_flag, __pyx_t_1);
            __pyx_t_1 = 0;
            __Pyx_DECREF_SET(__pyx_v_breakpoint, __pyx_t_4);
            __pyx_t_4 = 0;
            __pyx_v_new_frame = __pyx_t_3;
            __pyx_t_3 = 0;
            __Pyx_DECREF_SET(__pyx_v_bp_type, __pyx_t_11);
            __pyx_t_11 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":500
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     exist_result = True
 *                     flag, breakpoint, new_frame, bp_type = result
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":498
 *                         frame.f_back is smart_stop_frame and is_within_context):
 *                     stop = False
 *             elif py_db.plugin is not None and py_db.has_plugin_line_breaks:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.get_breakpoint(py_db, frame, 'line', args)
 *                 if result:
 */
        }
        __pyx_L14:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":504
 *                     flag, breakpoint, new_frame, bp_type = result
 * 
 *             if breakpoint:             # <<<<<<<<<<<<<<
 *                 if stop or exist_result:
 *                     eval_result = False
 */
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoint); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 504, __pyx_L8_error)
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":505
 * 
 *             if breakpoint:
 *                 if stop or exist_result:             # <<<<<<<<<<<<<<
 *                     eval_result = False
 *                     if breakpoint.has_condition:
 */
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 505, __pyx_L8_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_6 = __pyx_t_10;
            goto __pyx_L30_bool_binop_done;
          }
          __pyx_t_6 = __pyx_v_exist_result;
          __pyx_L30_bool_binop_done:;
          if (__pyx_t_6) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":506
 *             if breakpoint:
 *                 if stop or exist_result:
 *                     eval_result = False             # <<<<<<<<<<<<<<
 *                     if breakpoint.has_condition:
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 */
            __Pyx_INCREF(Py_False);
            __pyx_v_eval_result = Py_False;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":507
 *                 if stop or exist_result:
 *                     eval_result = False
 *                     if breakpoint.has_condition:             # <<<<<<<<<<<<<<
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_has_condition); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 507, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 507, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_6) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":508
 *                     eval_result = False
 *                     if breakpoint.has_condition:
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)             # <<<<<<<<<<<<<<
 * 
 *                     if breakpoint.expression is not None:
 */
              __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_handle_breakpoint_condition); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 508, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_3);
              if (unlikely(!__pyx_v_new_frame)) { __Pyx_RaiseUnboundLocalError("new_frame"); __PYX_ERR(0, 508, __pyx_L8_error) }
              __pyx_t_4 = NULL;
              __pyx_t_5 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_3, function);
                  __pyx_t_5 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_py_db, __pyx_v_info, __pyx_v_breakpoint, __pyx_v_new_frame};
                __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 508, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_11);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              }
              __Pyx_DECREF_SET(__pyx_v_eval_result, __pyx_t_11);
              __pyx_t_11 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":507
 *                 if stop or exist_result:
 *                     eval_result = False
 *                     if breakpoint.has_condition:             # <<<<<<<<<<<<<<
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":510
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 *                     if breakpoint.expression is not None:             # <<<<<<<<<<<<<<
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_expression); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 510, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_6 = (__pyx_t_11 != Py_None);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_6) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":511
 * 
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)             # <<<<<<<<<<<<<<
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:
 */
              __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_handle_breakpoint_expression); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 511, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_3);
              if (unlikely(!__pyx_v_new_frame)) { __Pyx_RaiseUnboundLocalError("new_frame"); __PYX_ERR(0, 511, __pyx_L8_error) }
              __pyx_t_4 = NULL;
              __pyx_t_5 = 0;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
                if (likely(__pyx_t_4)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                  __Pyx_INCREF(__pyx_t_4);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_3, function);
                  __pyx_t_5 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[4] = {__pyx_t_4, __pyx_v_breakpoint, __pyx_v_info, __pyx_v_new_frame};
                __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 3+__pyx_t_5);
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 511, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_11);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
              }
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":512
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_is_logpoint); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 512, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_11);
              __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 512, __pyx_L8_error)
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              if (__pyx_t_10) {
              } else {
                __pyx_t_6 = __pyx_t_10;
                goto __pyx_L35_bool_binop_done;
              }
              __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_message); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 512, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_11);
              __pyx_t_10 = (__pyx_t_11 != Py_None);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              if (__pyx_t_10) {
              } else {
                __pyx_t_6 = __pyx_t_10;
                goto __pyx_L35_bool_binop_done;
              }

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":513
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:             # <<<<<<<<<<<<<<
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 *                             py_db.writer.add_command(cmd)
 */
              __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_message); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 513, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_11);

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":512
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              __pyx_t_14 = PyObject_Length(__pyx_t_11); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(0, 512, __pyx_L8_error)
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":513
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:             # <<<<<<<<<<<<<<
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 *                             py_db.writer.add_command(cmd)
 */
              __pyx_t_10 = (__pyx_t_14 > 0);
              __pyx_t_6 = __pyx_t_10;
              __pyx_L35_bool_binop_done:;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":512
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              if (__pyx_t_6) {

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":514
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')             # <<<<<<<<<<<<<<
 *                             py_db.writer.add_command(cmd)
 * 
 */
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_cmd_factory); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_3);
                __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_make_io_message); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 514, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_message); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 514, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_3);
                __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_os); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_1);
                __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_linesep); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 514, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_12);
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_t_12); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 514, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
                __pyx_t_12 = NULL;
                __pyx_t_5 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_4))) {
                  __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
                  if (likely(__pyx_t_12)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                    __Pyx_INCREF(__pyx_t_12);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_4, function);
                    __pyx_t_5 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[3] = {__pyx_t_12, __pyx_t_1, __pyx_kp_s_1};
                  __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
                  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 514, __pyx_L8_error)
                  __Pyx_GOTREF(__pyx_t_11);
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                }
                __pyx_v_cmd = __pyx_t_11;
                __pyx_t_11 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":515
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 *                             py_db.writer.add_command(cmd)             # <<<<<<<<<<<<<<
 * 
 *                     if breakpoint.has_condition and not eval_result:
 */
                __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_writer); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 515, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_add_command); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L8_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_4 = NULL;
                __pyx_t_5 = 0;
                #if CYTHON_UNPACK_METHODS
                if (likely(PyMethod_Check(__pyx_t_1))) {
                  __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
                  if (likely(__pyx_t_4)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                    __Pyx_INCREF(__pyx_t_4);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_1, function);
                    __pyx_t_5 = 1;
                  }
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_cmd};
                  __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 515, __pyx_L8_error)
                  __Pyx_GOTREF(__pyx_t_11);
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                }
                __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":512
 *                     if breakpoint.expression is not None:
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(             # <<<<<<<<<<<<<<
 *                                 info.pydev_message) > 0:
 *                             cmd = py_db.cmd_factory.make_io_message(info.pydev_message + os.linesep, '1')
 */
              }

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":510
 *                         eval_result = handle_breakpoint_condition(py_db, info, breakpoint, new_frame)
 * 
 *                     if breakpoint.expression is not None:             # <<<<<<<<<<<<<<
 *                         handle_breakpoint_expression(breakpoint, info, new_frame)
 *                         if breakpoint.is_logpoint and info.pydev_message is not None and len(
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":517
 *                             py_db.writer.add_command(cmd)
 * 
 *                     if breakpoint.has_condition and not eval_result:             # <<<<<<<<<<<<<<
 *                         return
 *             else:
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_has_condition); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 517, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 517, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_10) {
            } else {
              __pyx_t_6 = __pyx_t_10;
              goto __pyx_L39_bool_binop_done;
            }
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_eval_result); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 517, __pyx_L8_error)
            __pyx_t_15 = (!__pyx_t_10);
            __pyx_t_6 = __pyx_t_15;
            __pyx_L39_bool_binop_done:;
            if (__pyx_t_6) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":518
 * 
 *                     if breakpoint.has_condition and not eval_result:
 *                         return             # <<<<<<<<<<<<<<
 *             else:
 *                 if step_cmd != -1:
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_r = Py_None; __Pyx_INCREF(Py_None);
              goto __pyx_L12_try_return;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":517
 *                             py_db.writer.add_command(cmd)
 * 
 *                     if breakpoint.has_condition and not eval_result:             # <<<<<<<<<<<<<<
 *                         return
 *             else:
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":505
 * 
 *             if breakpoint:
 *                 if stop or exist_result:             # <<<<<<<<<<<<<<
 *                     eval_result = False
 *                     if breakpoint.has_condition:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":504
 *                     flag, breakpoint, new_frame, bp_type = result
 * 
 *             if breakpoint:             # <<<<<<<<<<<<<<
 *                 if stop or exist_result:
 *                     eval_result = False
 */
          goto __pyx_L28;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":520
 *                         return
 *             else:
 *                 if step_cmd != -1:             # <<<<<<<<<<<<<<
 *                     if (py_db.is_filter_enabled
 *                             and py_db.is_ignored_by_filters(filename)):
 */
        /*else*/ {
          __pyx_t_6 = (__Pyx_PyInt_BoolNeObjC(__pyx_v_step_cmd, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 520, __pyx_L8_error)
          if (__pyx_t_6) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":521
 *             else:
 *                 if step_cmd != -1:
 *                     if (py_db.is_filter_enabled             # <<<<<<<<<<<<<<
 *                             and py_db.is_ignored_by_filters(filename)):
 *                         # ignore files matching stepping filters
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_is_filter_enabled); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 521, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 521, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (__pyx_t_15) {
            } else {
              __pyx_t_6 = __pyx_t_15;
              goto __pyx_L43_bool_binop_done;
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":522
 *                 if step_cmd != -1:
 *                     if (py_db.is_filter_enabled
 *                             and py_db.is_ignored_by_filters(filename)):             # <<<<<<<<<<<<<<
 *                         # ignore files matching stepping filters
 *                         return monitoring.DISABLE
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_is_ignored_by_filters); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 522, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_4 = NULL;
            __pyx_t_5 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_5 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_filename};
              __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 522, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 522, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_6 = __pyx_t_15;
            __pyx_L43_bool_binop_done:;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":521
 *             else:
 *                 if step_cmd != -1:
 *                     if (py_db.is_filter_enabled             # <<<<<<<<<<<<<<
 *                             and py_db.is_ignored_by_filters(filename)):
 *                         # ignore files matching stepping filters
 */
            if (__pyx_t_6) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":524
 *                             and py_db.is_ignored_by_filters(filename)):
 *                         # ignore files matching stepping filters
 *                         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 *                     if (py_db.is_filter_libraries
 *                             and not py_db.in_project_scope(filename)):
 */
              __Pyx_XDECREF(__pyx_r);
              __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 524, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_11);
              __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 524, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __pyx_r = __pyx_t_1;
              __pyx_t_1 = 0;
              goto __pyx_L12_try_return;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":521
 *             else:
 *                 if step_cmd != -1:
 *                     if (py_db.is_filter_enabled             # <<<<<<<<<<<<<<
 *                             and py_db.is_ignored_by_filters(filename)):
 *                         # ignore files matching stepping filters
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":525
 *                         # ignore files matching stepping filters
 *                         return monitoring.DISABLE
 *                     if (py_db.is_filter_libraries             # <<<<<<<<<<<<<<
 *                             and not py_db.in_project_scope(filename)):
 *                         # ignore library files while stepping
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_is_filter_libraries); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 525, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 525, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_15) {
            } else {
              __pyx_t_6 = __pyx_t_15;
              goto __pyx_L46_bool_binop_done;
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":526
 *                         return monitoring.DISABLE
 *                     if (py_db.is_filter_libraries
 *                             and not py_db.in_project_scope(filename)):             # <<<<<<<<<<<<<<
 *                         # ignore library files while stepping
 *                         return monitoring.DISABLE
 */
            __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 526, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_11);
            __pyx_t_4 = NULL;
            __pyx_t_5 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_11))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_11);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_11, function);
                __pyx_t_5 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_filename};
              __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_11, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 526, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            }
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 526, __pyx_L8_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_10 = (!__pyx_t_15);
            __pyx_t_6 = __pyx_t_10;
            __pyx_L46_bool_binop_done:;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":525
 *                         # ignore files matching stepping filters
 *                         return monitoring.DISABLE
 *                     if (py_db.is_filter_libraries             # <<<<<<<<<<<<<<
 *                             and not py_db.in_project_scope(filename)):
 *                         # ignore library files while stepping
 */
            if (__pyx_t_6) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":528
 *                             and not py_db.in_project_scope(filename)):
 *                         # ignore library files while stepping
 *                         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *             if py_db.show_return_values or py_db.remove_return_values_flag:
 */
              __Pyx_XDECREF(__pyx_r);
              __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 528, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 528, __pyx_L8_error)
              __Pyx_GOTREF(__pyx_t_11);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_r = __pyx_t_11;
              __pyx_t_11 = 0;
              goto __pyx_L12_try_return;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":525
 *                         # ignore files matching stepping filters
 *                         return monitoring.DISABLE
 *                     if (py_db.is_filter_libraries             # <<<<<<<<<<<<<<
 *                             and not py_db.in_project_scope(filename)):
 *                         # ignore library files while stepping
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":520
 *                         return
 *             else:
 *                 if step_cmd != -1:             # <<<<<<<<<<<<<<
 *                     if (py_db.is_filter_enabled
 *                             and py_db.is_ignored_by_filters(filename)):
 */
          }
        }
        __pyx_L28:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":530
 *                         return monitoring.DISABLE
 * 
 *             if py_db.show_return_values or py_db.remove_return_values_flag:             # <<<<<<<<<<<<<<
 *                 manage_return_values(py_db, frame, 'line', None)
 * 
 */
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_show_return_values); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 530, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 530, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (!__pyx_t_10) {
        } else {
          __pyx_t_6 = __pyx_t_10;
          goto __pyx_L49_bool_binop_done;
        }
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_remove_return_values_flag); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 530, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 530, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_6 = __pyx_t_10;
        __pyx_L49_bool_binop_done:;
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":531
 * 
 *             if py_db.show_return_values or py_db.remove_return_values_flag:
 *                 manage_return_values(py_db, frame, 'line', None)             # <<<<<<<<<<<<<<
 * 
 *             if stop:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_manage_return_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 531, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_line, Py_None};
            __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 531, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":530
 *                         return monitoring.DISABLE
 * 
 *             if py_db.show_return_values or py_db.remove_return_values_flag:             # <<<<<<<<<<<<<<
 *                 manage_return_values(py_db, frame, 'line', None)
 * 
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":533
 *                 manage_return_values(py_db, frame, 'line', None)
 * 
 *             if stop:             # <<<<<<<<<<<<<<
 *                 py_db.set_suspend(
 *                     thread,
 */
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 533, __pyx_L8_error)
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":534
 * 
 *             if stop:
 *                 py_db.set_suspend(             # <<<<<<<<<<<<<<
 *                     thread,
 *                     CMD_SET_BREAK,
 */
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_set_suspend); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 534, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_11);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":536
 *                 py_db.set_suspend(
 *                     thread,
 *                     CMD_SET_BREAK,             # <<<<<<<<<<<<<<
 *                     suspend_other_threads=breakpoint
 *                                           and breakpoint.suspend_policy == "ALL",
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CMD_SET_BREAK); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 536, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":534
 * 
 *             if stop:
 *                 py_db.set_suspend(             # <<<<<<<<<<<<<<
 *                     thread,
 *                     CMD_SET_BREAK,
 */
          __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 534, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_INCREF(__pyx_v_thread);
          __Pyx_GIVEREF(__pyx_v_thread);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_thread)) __PYX_ERR(0, 534, __pyx_L8_error);
          __Pyx_GIVEREF(__pyx_t_1);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(0, 534, __pyx_L8_error);
          __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":537
 *                     thread,
 *                     CMD_SET_BREAK,
 *                     suspend_other_threads=breakpoint             # <<<<<<<<<<<<<<
 *                                           and breakpoint.suspend_policy == "ALL",
 *                 )
 */
          __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 537, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":538
 *                     CMD_SET_BREAK,
 *                     suspend_other_threads=breakpoint
 *                                           and breakpoint.suspend_policy == "ALL",             # <<<<<<<<<<<<<<
 *                 )
 *             elif flag and py_db.plugin is not None:
 */
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoint); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 537, __pyx_L8_error)
          if (__pyx_t_6) {
          } else {
            __Pyx_INCREF(__pyx_v_breakpoint);
            __pyx_t_12 = __pyx_v_breakpoint;
            goto __pyx_L52_bool_binop_done;
          }
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_suspend_policy); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 538, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_16 = PyObject_RichCompare(__pyx_t_3, __pyx_n_s_ALL, Py_EQ); __Pyx_XGOTREF(__pyx_t_16); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 538, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_INCREF(__pyx_t_16);
          __pyx_t_12 = __pyx_t_16;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_L52_bool_binop_done:;
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_suspend_other_threads, __pyx_t_12) < 0) __PYX_ERR(0, 537, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":534
 * 
 *             if stop:
 *                 py_db.set_suspend(             # <<<<<<<<<<<<<<
 *                     thread,
 *                     CMD_SET_BREAK,
 */
          __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_11, __pyx_t_4, __pyx_t_1); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 534, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":533
 *                 manage_return_values(py_db, frame, 'line', None)
 * 
 *             if stop:             # <<<<<<<<<<<<<<
 *                 py_db.set_suspend(
 *                     thread,
 */
          goto __pyx_L51;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":540
 *                                           and breakpoint.suspend_policy == "ALL",
 *                 )
 *             elif flag and py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                 if result:
 */
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_flag); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 540, __pyx_L8_error)
        if (__pyx_t_10) {
        } else {
          __pyx_t_6 = __pyx_t_10;
          goto __pyx_L54_bool_binop_done;
        }
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 540, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_10 = (__pyx_t_12 != Py_None);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_6 = __pyx_t_10;
        __pyx_L54_bool_binop_done:;
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":541
 *                 )
 *             elif flag and py_db.plugin is not None:
 *                 result = py_db.plugin.suspend(py_db, thread, frame, bp_type)             # <<<<<<<<<<<<<<
 *                 if result:
 *                     frame = result
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_suspend); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 541, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_1, __pyx_v_py_db, __pyx_v_thread, __pyx_v_frame, __pyx_v_bp_type};
            __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 541, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":542
 *             elif flag and py_db.plugin is not None:
 *                 result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     frame = result
 * 
 */
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 542, __pyx_L8_error)
          if (__pyx_t_6) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":543
 *                 result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                 if result:
 *                     frame = result             # <<<<<<<<<<<<<<
 * 
 *             # if thread has a suspend flag, we suspend with a busy wait
 */
            __Pyx_INCREF(__pyx_v_result);
            __Pyx_DECREF_SET(__pyx_v_frame, __pyx_v_result);

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":542
 *             elif flag and py_db.plugin is not None:
 *                 result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     frame = result
 * 
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":540
 *                                           and breakpoint.suspend_policy == "ALL",
 *                 )
 *             elif flag and py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.suspend(py_db, thread, frame, bp_type)
 *                 if result:
 */
        }
        __pyx_L51:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":546
 * 
 *             # if thread has a suspend flag, we suspend with a busy wait
 *             if info.pydev_state == STATE_SUSPEND:             # <<<<<<<<<<<<<<
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 *                 return
 */
        __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_state); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 546, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_STATE_SUSPEND); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 546, __pyx_L8_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_12, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 546, __pyx_L8_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (__pyx_t_6) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":547
 *             # if thread has a suspend flag, we suspend with a busy wait
 *             if info.pydev_state == STATE_SUSPEND:
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)             # <<<<<<<<<<<<<<
 *                 return
 *             elif not breakpoint:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_do_wait_suspend); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 547, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_12 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_12, __pyx_v_thread, __pyx_v_frame, __pyx_n_s_line, Py_None};
            __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L8_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":548
 *             if info.pydev_state == STATE_SUSPEND:
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 *                 return             # <<<<<<<<<<<<<<
 *             elif not breakpoint:
 *                 # No stop from anyone and no breakpoint found in line (cache that).
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_r = Py_None; __Pyx_INCREF(Py_None);
          goto __pyx_L12_try_return;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":546
 * 
 *             # if thread has a suspend flag, we suspend with a busy wait
 *             if info.pydev_state == STATE_SUSPEND:             # <<<<<<<<<<<<<<
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 *                 return
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":549
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 *                 return
 *             elif not breakpoint:             # <<<<<<<<<<<<<<
 *                 # No stop from anyone and no breakpoint found in line (cache that).
 *                 global_cache_frame_skips[line_cache_key] = 0
 */
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_breakpoint); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 549, __pyx_L8_error)
        __pyx_t_10 = (!__pyx_t_6);
        if (__pyx_t_10) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":551
 *             elif not breakpoint:
 *                 # No stop from anyone and no breakpoint found in line (cache that).
 *                 global_cache_frame_skips[line_cache_key] = 0             # <<<<<<<<<<<<<<
 *         except KeyboardInterrupt:
 *             _clear_run_state(info)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_global_cache_frame_skips); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 551, __pyx_L8_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_line_cache_key, __pyx_int_0) < 0))) __PYX_ERR(0, 551, __pyx_L8_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":549
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 *                 return
 *             elif not breakpoint:             # <<<<<<<<<<<<<<
 *                 # No stop from anyone and no breakpoint found in line (cache that).
 *                 global_cache_frame_skips[line_cache_key] = 0
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":475
 *         line_cache_key = (frame_cache_key, line_number)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             flag = False
 *             breakpoint = None
 */
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L13_try_end;
      __pyx_L8_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":552
 *                 # No stop from anyone and no breakpoint found in line (cache that).
 *                 global_cache_frame_skips[line_cache_key] = 0
 *         except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *             _clear_run_state(info)
 *             raise
 */
      __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
      if (__pyx_t_17) {
        __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_4, &__pyx_t_12) < 0) __PYX_ERR(0, 552, __pyx_L10_except_error)
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_12);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":553
 *                 global_cache_frame_skips[line_cache_key] = 0
 *         except KeyboardInterrupt:
 *             _clear_run_state(info)             # <<<<<<<<<<<<<<
 *             raise
 *         except:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_clear_run_state); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 553, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_3 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_16))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_16);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_16, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_info};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 553, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":554
 *         except KeyboardInterrupt:
 *             _clear_run_state(info)
 *             raise             # <<<<<<<<<<<<<<
 *         except:
 *             traceback.print_exc()
 */
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ErrRestoreWithState(__pyx_t_1, __pyx_t_4, __pyx_t_12);
        __pyx_t_1 = 0; __pyx_t_4 = 0; __pyx_t_12 = 0; 
        __PYX_ERR(0, 554, __pyx_L10_except_error)
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":555
 *             _clear_run_state(info)
 *             raise
 *         except:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *             raise
 */
      /*except:*/ {
        __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_4, &__pyx_t_1) < 0) __PYX_ERR(0, 555, __pyx_L10_except_error)
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_1);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":556
 *             raise
 *         except:
 *             traceback.print_exc()             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_n_s_traceback); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 556, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 556, __pyx_L10_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_16 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_16)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_16);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_16, NULL};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 556, __pyx_L10_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":557
 *         except:
 *             traceback.print_exc()
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         # Step handling. We stop when we hit the right frame.
 */
        __Pyx_GIVEREF(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_XGIVEREF(__pyx_t_1);
        __Pyx_ErrRestoreWithState(__pyx_t_12, __pyx_t_4, __pyx_t_1);
        __pyx_t_12 = 0; __pyx_t_4 = 0; __pyx_t_1 = 0; 
        __PYX_ERR(0, 557, __pyx_L10_except_error)
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":475
 *         line_cache_key = (frame_cache_key, line_number)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             flag = False
 *             breakpoint = None
 */
      __pyx_L10_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L5_error;
      __pyx_L12_try_return:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      goto __pyx_L4_return;
      __pyx_L13_try_end:;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":560
 * 
 *         # Step handling. We stop when we hit the right frame.
 *         try:             # <<<<<<<<<<<<<<
 *             plugin_stop = False
 *             args = (py_db, filename, info, thread)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":561
 *         # Step handling. We stop when we hit the right frame.
 *         try:
 *             plugin_stop = False             # <<<<<<<<<<<<<<
 *             args = (py_db, filename, info, thread)
 *             stop_info = {}
 */
        __Pyx_INCREF(Py_False);
        __pyx_v_plugin_stop = Py_False;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":562
 *         try:
 *             plugin_stop = False
 *             args = (py_db, filename, info, thread)             # <<<<<<<<<<<<<<
 *             stop_info = {}
 *             stop = False
 */
        __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 562, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_v_py_db);
        __Pyx_GIVEREF(__pyx_v_py_db);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_py_db)) __PYX_ERR(0, 562, __pyx_L62_error);
        __Pyx_INCREF(__pyx_v_filename);
        __Pyx_GIVEREF(__pyx_v_filename);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_filename)) __PYX_ERR(0, 562, __pyx_L62_error);
        __Pyx_INCREF(__pyx_v_info);
        __Pyx_GIVEREF(__pyx_v_info);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_info)) __PYX_ERR(0, 562, __pyx_L62_error);
        __Pyx_INCREF(__pyx_v_thread);
        __Pyx_GIVEREF(__pyx_v_thread);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_thread)) __PYX_ERR(0, 562, __pyx_L62_error);
        __Pyx_DECREF_SET(__pyx_v_args, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":563
 *             plugin_stop = False
 *             args = (py_db, filename, info, thread)
 *             stop_info = {}             # <<<<<<<<<<<<<<
 *             stop = False
 * 
 */
        __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 563, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_v_stop_info = ((PyObject*)__pyx_t_1);
        __pyx_t_1 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":564
 *             args = (py_db, filename, info, thread)
 *             stop_info = {}
 *             stop = False             # <<<<<<<<<<<<<<
 * 
 *             if step_cmd == CMD_SMART_STEP_INTO:
 */
        __Pyx_INCREF(Py_False);
        __Pyx_DECREF_SET(__pyx_v_stop, Py_False);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":566
 *             stop = False
 * 
 *             if step_cmd == CMD_SMART_STEP_INTO:             # <<<<<<<<<<<<<<
 *                 if smart_stop_frame is frame and not is_within_context:
 *                     # We don't stop on jumps in multiline statements, which
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CMD_SMART_STEP_INTO); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 566, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 566, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 566, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_10) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":567
 * 
 *             if step_cmd == CMD_SMART_STEP_INTO:
 *                 if smart_stop_frame is frame and not is_within_context:             # <<<<<<<<<<<<<<
 *                     # We don't stop on jumps in multiline statements, which
 *                     # the Python interpreter does in some cases, if we they
 */
          __pyx_t_6 = (__pyx_v_smart_stop_frame == __pyx_v_frame);
          if (__pyx_t_6) {
          } else {
            __pyx_t_10 = __pyx_t_6;
            goto __pyx_L70_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_is_within_context); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 567, __pyx_L62_error)
          __pyx_t_15 = (!__pyx_t_6);
          __pyx_t_10 = __pyx_t_15;
          __pyx_L70_bool_binop_done:;
          if (__pyx_t_10) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":571
 *                     # the Python interpreter does in some cases, if we they
 *                     # happen in smart step into context.
 *                     info.pydev_func_name = '.invalid.'  # Must match the type in cython             # <<<<<<<<<<<<<<
 *                     stop = True  # act as if we did a step into
 * 
 */
            if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_func_name, __pyx_kp_s_invalid) < 0) __PYX_ERR(0, 571, __pyx_L62_error)

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":572
 *                     # happen in smart step into context.
 *                     info.pydev_func_name = '.invalid.'  # Must match the type in cython
 *                     stop = True  # act as if we did a step into             # <<<<<<<<<<<<<<
 * 
 *                 curr_func_name = frame.f_code.co_name
 */
            __Pyx_INCREF(Py_True);
            __Pyx_DECREF_SET(__pyx_v_stop, Py_True);

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":567
 * 
 *             if step_cmd == CMD_SMART_STEP_INTO:
 *                 if smart_stop_frame is frame and not is_within_context:             # <<<<<<<<<<<<<<
 *                     # We don't stop on jumps in multiline statements, which
 *                     # the Python interpreter does in some cases, if we they
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":574
 *                     stop = True  # act as if we did a step into
 * 
 *                 curr_func_name = frame.f_code.co_name             # <<<<<<<<<<<<<<
 * 
 *                 if curr_func_name in ('?', '<module>') or curr_func_name is None:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 574, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_co_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 574, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_v_curr_func_name = __pyx_t_1;
          __pyx_t_1 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":576
 *                 curr_func_name = frame.f_code.co_name
 * 
 *                 if curr_func_name in ('?', '<module>') or curr_func_name is None:             # <<<<<<<<<<<<<<
 *                     curr_func_name = ''
 * 
 */
          __Pyx_INCREF(__pyx_v_curr_func_name);
          __pyx_t_1 = __pyx_v_curr_func_name;
          __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 576, __pyx_L62_error)
          if (!__pyx_t_6) {
          } else {
            __pyx_t_15 = __pyx_t_6;
            goto __pyx_L75_bool_binop_done;
          }
          __pyx_t_6 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_kp_s_module, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 576, __pyx_L62_error)
          __pyx_t_15 = __pyx_t_6;
          __pyx_L75_bool_binop_done:;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_6 = __pyx_t_15;
          if (!__pyx_t_6) {
          } else {
            __pyx_t_10 = __pyx_t_6;
            goto __pyx_L73_bool_binop_done;
          }
          __pyx_t_6 = (__pyx_v_curr_func_name == Py_None);
          __pyx_t_10 = __pyx_t_6;
          __pyx_L73_bool_binop_done:;
          if (__pyx_t_10) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":577
 * 
 *                 if curr_func_name in ('?', '<module>') or curr_func_name is None:
 *                     curr_func_name = ''             # <<<<<<<<<<<<<<
 * 
 *                 if smart_stop_frame and smart_stop_frame is frame.f_back:
 */
            __Pyx_INCREF(__pyx_kp_s__2);
            __Pyx_DECREF_SET(__pyx_v_curr_func_name, __pyx_kp_s__2);

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":576
 *                 curr_func_name = frame.f_code.co_name
 * 
 *                 if curr_func_name in ('?', '<module>') or curr_func_name is None:             # <<<<<<<<<<<<<<
 *                     curr_func_name = ''
 * 
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":579
 *                     curr_func_name = ''
 * 
 *                 if smart_stop_frame and smart_stop_frame is frame.f_back:             # <<<<<<<<<<<<<<
 *                     if curr_func_name == info.pydev_func_name and not IS_CPYTHON:
 *                         stop = True
 */
          __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_smart_stop_frame); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 579, __pyx_L62_error)
          if (__pyx_t_6) {
          } else {
            __pyx_t_10 = __pyx_t_6;
            goto __pyx_L78_bool_binop_done;
          }
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 579, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_6 = (__pyx_v_smart_stop_frame == __pyx_t_1);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_10 = __pyx_t_6;
          __pyx_L78_bool_binop_done:;
          if (__pyx_t_10) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":580
 * 
 *                 if smart_stop_frame and smart_stop_frame is frame.f_back:
 *                     if curr_func_name == info.pydev_func_name and not IS_CPYTHON:             # <<<<<<<<<<<<<<
 *                         stop = True
 *                     else:
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_func_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_4 = PyObject_RichCompare(__pyx_v_curr_func_name, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 580, __pyx_L62_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 580, __pyx_L62_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (__pyx_t_6) {
            } else {
              __pyx_t_10 = __pyx_t_6;
              goto __pyx_L81_bool_binop_done;
            }
            __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_IS_CPYTHON); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 580, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 580, __pyx_L62_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_15 = (!__pyx_t_6);
            __pyx_t_10 = __pyx_t_15;
            __pyx_L81_bool_binop_done:;
            if (__pyx_t_10) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":581
 *                 if smart_stop_frame and smart_stop_frame is frame.f_back:
 *                     if curr_func_name == info.pydev_func_name and not IS_CPYTHON:
 *                         stop = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         try:
 */
              __Pyx_INCREF(Py_True);
              __Pyx_DECREF_SET(__pyx_v_stop, Py_True);

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":580
 * 
 *                 if smart_stop_frame and smart_stop_frame is frame.f_back:
 *                     if curr_func_name == info.pydev_func_name and not IS_CPYTHON:             # <<<<<<<<<<<<<<
 *                         stop = True
 *                     else:
 */
              goto __pyx_L80;
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":583
 *                         stop = True
 *                     else:
 *                         try:             # <<<<<<<<<<<<<<
 *                             if curr_func_name != info.pydev_func_name and frame.f_back:
 *                                 # try to find function call name using bytecode analysis
 */
            /*else*/ {
              {
                __Pyx_PyThreadState_declare
                __Pyx_PyThreadState_assign
                __Pyx_ExceptionSave(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
                __Pyx_XGOTREF(__pyx_t_18);
                __Pyx_XGOTREF(__pyx_t_19);
                __Pyx_XGOTREF(__pyx_t_20);
                /*try:*/ {

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":584
 *                     else:
 *                         try:
 *                             if curr_func_name != info.pydev_func_name and frame.f_back:             # <<<<<<<<<<<<<<
 *                                 # try to find function call name using bytecode analysis
 *                                 curr_func_name = find_last_call_name(frame.f_back)
 */
                  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_func_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 584, __pyx_L83_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __pyx_t_1 = PyObject_RichCompare(__pyx_v_curr_func_name, __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L83_error)
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 584, __pyx_L83_error)
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  if (__pyx_t_15) {
                  } else {
                    __pyx_t_10 = __pyx_t_15;
                    goto __pyx_L90_bool_binop_done;
                  }
                  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L83_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 584, __pyx_L83_error)
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __pyx_t_10 = __pyx_t_15;
                  __pyx_L90_bool_binop_done:;
                  if (__pyx_t_10) {

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":586
 *                             if curr_func_name != info.pydev_func_name and frame.f_back:
 *                                 # try to find function call name using bytecode analysis
 *                                 curr_func_name = find_last_call_name(frame.f_back)             # <<<<<<<<<<<<<<
 *                             if curr_func_name == info.pydev_func_name:
 *                                 stop = find_last_func_call_order(frame.f_back, context_start_line) \
 */
                    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_find_last_call_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 586, __pyx_L83_error)
                    __Pyx_GOTREF(__pyx_t_4);
                    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 586, __pyx_L83_error)
                    __Pyx_GOTREF(__pyx_t_12);
                    __pyx_t_11 = NULL;
                    __pyx_t_5 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_4))) {
                      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_4);
                      if (likely(__pyx_t_11)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                        __Pyx_INCREF(__pyx_t_11);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_4, function);
                        __pyx_t_5 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
                      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
                      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
                      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 586, __pyx_L83_error)
                      __Pyx_GOTREF(__pyx_t_1);
                      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                    }
                    __Pyx_DECREF_SET(__pyx_v_curr_func_name, __pyx_t_1);
                    __pyx_t_1 = 0;

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":584
 *                     else:
 *                         try:
 *                             if curr_func_name != info.pydev_func_name and frame.f_back:             # <<<<<<<<<<<<<<
 *                                 # try to find function call name using bytecode analysis
 *                                 curr_func_name = find_last_call_name(frame.f_back)
 */
                  }

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":587
 *                                 # try to find function call name using bytecode analysis
 *                                 curr_func_name = find_last_call_name(frame.f_back)
 *                             if curr_func_name == info.pydev_func_name:             # <<<<<<<<<<<<<<
 *                                 stop = find_last_func_call_order(frame.f_back, context_start_line) \
 *                                        == info.pydev_smart_step_context.call_order
 */
                  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_func_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L83_error)
                  __Pyx_GOTREF(__pyx_t_1);
                  __pyx_t_4 = PyObject_RichCompare(__pyx_v_curr_func_name, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 587, __pyx_L83_error)
                  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 587, __pyx_L83_error)
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  if (__pyx_t_10) {

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":588
 *                                 curr_func_name = find_last_call_name(frame.f_back)
 *                             if curr_func_name == info.pydev_func_name:
 *                                 stop = find_last_func_call_order(frame.f_back, context_start_line) \             # <<<<<<<<<<<<<<
 *                                        == info.pydev_smart_step_context.call_order
 *                         except:
 */
                    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_find_last_func_call_order); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 588, __pyx_L83_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 588, __pyx_L83_error)
                    __Pyx_GOTREF(__pyx_t_12);
                    __pyx_t_11 = NULL;
                    __pyx_t_5 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_1))) {
                      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_1);
                      if (likely(__pyx_t_11)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                        __Pyx_INCREF(__pyx_t_11);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_1, function);
                        __pyx_t_5 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_t_12, __pyx_v_context_start_line};
                      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
                      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
                      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 588, __pyx_L83_error)
                      __Pyx_GOTREF(__pyx_t_4);
                      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                    }

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":589
 *                             if curr_func_name == info.pydev_func_name:
 *                                 stop = find_last_func_call_order(frame.f_back, context_start_line) \
 *                                        == info.pydev_smart_step_context.call_order             # <<<<<<<<<<<<<<
 *                         except:
 *                             pydev_log.debug("Exception while handling smart step into "
 */
                    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_smart_step_context); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L83_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_call_order); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 589, __pyx_L83_error)
                    __Pyx_GOTREF(__pyx_t_12);
                    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                    __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_t_12, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L83_error)
                    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
                    __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_1);
                    __pyx_t_1 = 0;

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":587
 *                                 # try to find function call name using bytecode analysis
 *                                 curr_func_name = find_last_call_name(frame.f_back)
 *                             if curr_func_name == info.pydev_func_name:             # <<<<<<<<<<<<<<
 *                                 stop = find_last_func_call_order(frame.f_back, context_start_line) \
 *                                        == info.pydev_smart_step_context.call_order
 */
                  }

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":583
 *                         stop = True
 *                     else:
 *                         try:             # <<<<<<<<<<<<<<
 *                             if curr_func_name != info.pydev_func_name and frame.f_back:
 *                                 # try to find function call name using bytecode analysis
 */
                }
                __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
                __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
                __Pyx_XDECREF(__pyx_t_20); __pyx_t_20 = 0;
                goto __pyx_L88_try_end;
                __pyx_L83_error:;
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":590
 *                                 stop = find_last_func_call_order(frame.f_back, context_start_line) \
 *                                        == info.pydev_smart_step_context.call_order
 *                         except:             # <<<<<<<<<<<<<<
 *                             pydev_log.debug("Exception while handling smart step into "
 *                                             "in frame tracer, step into will be "
 */
                /*except:*/ {
                  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
                  if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_12, &__pyx_t_4) < 0) __PYX_ERR(0, 590, __pyx_L85_except_error)
                  __Pyx_XGOTREF(__pyx_t_1);
                  __Pyx_XGOTREF(__pyx_t_12);
                  __Pyx_XGOTREF(__pyx_t_4);

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":591
 *                                        == info.pydev_smart_step_context.call_order
 *                         except:
 *                             pydev_log.debug("Exception while handling smart step into "             # <<<<<<<<<<<<<<
 *                                             "in frame tracer, step into will be "
 *                                             "performed instead.")
 */
                  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pydev_log); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 591, __pyx_L85_except_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_debug); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 591, __pyx_L85_except_error)
                  __Pyx_GOTREF(__pyx_t_16);
                  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  __pyx_t_3 = NULL;
                  __pyx_t_5 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (unlikely(PyMethod_Check(__pyx_t_16))) {
                    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_16);
                    if (likely(__pyx_t_3)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
                      __Pyx_INCREF(__pyx_t_3);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_16, function);
                      __pyx_t_5 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_kp_s_Exception_while_handling_smart_s};
                    __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
                    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 591, __pyx_L85_except_error)
                    __Pyx_GOTREF(__pyx_t_11);
                    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":594
 *                                             "in frame tracer, step into will be "
 *                                             "performed instead.")
 *                             info.pydev_smart_step_context.reset()             # <<<<<<<<<<<<<<
 *                             stop = True  # act as if we did a step into
 * 
 */
                  __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_smart_step_context); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 594, __pyx_L85_except_error)
                  __Pyx_GOTREF(__pyx_t_16);
                  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_reset); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 594, __pyx_L85_except_error)
                  __Pyx_GOTREF(__pyx_t_3);
                  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                  __pyx_t_16 = NULL;
                  __pyx_t_5 = 0;
                  #if CYTHON_UNPACK_METHODS
                  if (likely(PyMethod_Check(__pyx_t_3))) {
                    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_3);
                    if (likely(__pyx_t_16)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
                      __Pyx_INCREF(__pyx_t_16);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_3, function);
                      __pyx_t_5 = 1;
                    }
                  }
                  #endif
                  {
                    PyObject *__pyx_callargs[2] = {__pyx_t_16, NULL};
                    __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
                    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                    if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 594, __pyx_L85_except_error)
                    __Pyx_GOTREF(__pyx_t_11);
                    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":595
 *                                             "performed instead.")
 *                             info.pydev_smart_step_context.reset()
 *                             stop = True  # act as if we did a step into             # <<<<<<<<<<<<<<
 * 
 *             elif step_cmd == CMD_STEP_INTO:
 */
                  __Pyx_INCREF(Py_True);
                  __Pyx_DECREF_SET(__pyx_v_stop, Py_True);
                  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
                  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                  goto __pyx_L84_exception_handled;
                }

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":583
 *                         stop = True
 *                     else:
 *                         try:             # <<<<<<<<<<<<<<
 *                             if curr_func_name != info.pydev_func_name and frame.f_back:
 *                                 # try to find function call name using bytecode analysis
 */
                __pyx_L85_except_error:;
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
                goto __pyx_L62_error;
                __pyx_L84_exception_handled:;
                __Pyx_XGIVEREF(__pyx_t_18);
                __Pyx_XGIVEREF(__pyx_t_19);
                __Pyx_XGIVEREF(__pyx_t_20);
                __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
                __pyx_L88_try_end:;
              }
            }
            __pyx_L80:;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":579
 *                     curr_func_name = ''
 * 
 *                 if smart_stop_frame and smart_stop_frame is frame.f_back:             # <<<<<<<<<<<<<<
 *                     if curr_func_name == info.pydev_func_name and not IS_CPYTHON:
 *                         stop = True
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":566
 *             stop = False
 * 
 *             if step_cmd == CMD_SMART_STEP_INTO:             # <<<<<<<<<<<<<<
 *                 if smart_stop_frame is frame and not is_within_context:
 *                     # We don't stop on jumps in multiline statements, which
 */
          goto __pyx_L68;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":597
 *                             stop = True  # act as if we did a step into
 * 
 *             elif step_cmd == CMD_STEP_INTO:             # <<<<<<<<<<<<<<
 *                 stop = True
 *                 if py_db.plugin is not None:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CMD_STEP_INTO); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 597, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 597, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 597, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_10) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":598
 * 
 *             elif step_cmd == CMD_STEP_INTO:
 *                 stop = True             # <<<<<<<<<<<<<<
 *                 if py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)
 */
          __Pyx_INCREF(Py_True);
          __Pyx_DECREF_SET(__pyx_v_stop, Py_True);

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":599
 *             elif step_cmd == CMD_STEP_INTO:
 *                 stop = True
 *                 if py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 599, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_10 = (__pyx_t_12 != Py_None);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_10) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":600
 *                 stop = True
 *                 if py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)             # <<<<<<<<<<<<<<
 *                     if result:
 *                         stop, plugin_stop = result
 */
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 600, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_cmd_step_into); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 600, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_4 = NULL;
            __pyx_t_5 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_5 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[7] = {__pyx_t_4, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_line, __pyx_v_args, __pyx_v_stop_info, __pyx_v_stop};
              __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 6+__pyx_t_5);
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 600, __pyx_L62_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":601
 *                 if py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         stop, plugin_stop = result
 * 
 */
            __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 601, __pyx_L62_error)
            if (__pyx_t_10) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":602
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:
 *                         stop, plugin_stop = result             # <<<<<<<<<<<<<<
 * 
 *             elif step_cmd == CMD_STEP_INTO_MY_CODE:
 */
              if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
                PyObject* sequence = __pyx_v_result;
                Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                if (unlikely(size != 2)) {
                  if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                  else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                  __PYX_ERR(0, 602, __pyx_L62_error)
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                if (likely(PyTuple_CheckExact(sequence))) {
                  __pyx_t_12 = PyTuple_GET_ITEM(sequence, 0); 
                  __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
                } else {
                  __pyx_t_12 = PyList_GET_ITEM(sequence, 0); 
                  __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
                }
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_1);
                #else
                __pyx_t_12 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 602, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_12);
                __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 602, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_1);
                #endif
              } else {
                Py_ssize_t index = -1;
                __pyx_t_4 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 602, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
                index = 0; __pyx_t_12 = __pyx_t_13(__pyx_t_4); if (unlikely(!__pyx_t_12)) goto __pyx_L97_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_12);
                index = 1; __pyx_t_1 = __pyx_t_13(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L97_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_1);
                if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_4), 2) < 0) __PYX_ERR(0, 602, __pyx_L62_error)
                __pyx_t_13 = NULL;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                goto __pyx_L98_unpacking_done;
                __pyx_L97_unpacking_failed:;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_13 = NULL;
                if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                __PYX_ERR(0, 602, __pyx_L62_error)
                __pyx_L98_unpacking_done:;
              }
              __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_12);
              __pyx_t_12 = 0;
              __Pyx_DECREF_SET(__pyx_v_plugin_stop, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":601
 *                 if py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         stop, plugin_stop = result
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":599
 *             elif step_cmd == CMD_STEP_INTO:
 *                 stop = True
 *                 if py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_into(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":597
 *                             stop = True  # act as if we did a step into
 * 
 *             elif step_cmd == CMD_STEP_INTO:             # <<<<<<<<<<<<<<
 *                 stop = True
 *                 if py_db.plugin is not None:
 */
          goto __pyx_L68;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":604
 *                         stop, plugin_stop = result
 * 
 *             elif step_cmd == CMD_STEP_INTO_MY_CODE:             # <<<<<<<<<<<<<<
 *                 stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CMD_STEP_INTO_MY_CODE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 604, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_12 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 604, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 604, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (__pyx_t_10) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":605
 * 
 *             elif step_cmd == CMD_STEP_INTO_MY_CODE:
 *                 stop = py_db.in_project_scope(frame.f_code.co_filename)             # <<<<<<<<<<<<<<
 * 
 *             elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 605, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_code); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 605, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 605, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_11};
            __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 605, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_12);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":604
 *                         stop, plugin_stop = result
 * 
 *             elif step_cmd == CMD_STEP_INTO_MY_CODE:             # <<<<<<<<<<<<<<
 *                 stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 */
          goto __pyx_L68;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":607
 *                 stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 *             elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):             # <<<<<<<<<<<<<<
 *                 stop = stop_frame is frame
 *                 if stop:
 */
        __Pyx_INCREF(__pyx_v_step_cmd);
        __pyx_t_12 = __pyx_v_step_cmd;
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_11 = PyObject_RichCompare(__pyx_t_12, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 607, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 607, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (!__pyx_t_15) {
        } else {
          __pyx_t_10 = __pyx_t_15;
          goto __pyx_L99_bool_binop_done;
        }
        __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_CMD_STEP_INTO_COROUTINE); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 607, __pyx_L62_error)
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_12, __pyx_t_11, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 607, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 607, __pyx_L62_error)
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_10 = __pyx_t_15;
        __pyx_L99_bool_binop_done:;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_15 = __pyx_t_10;
        if (__pyx_t_15) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":608
 * 
 *             elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 *                 stop = stop_frame is frame             # <<<<<<<<<<<<<<
 *                 if stop:
 *                     # The only case we shouldn't stop on a line, is when
 */
          __pyx_t_15 = (__pyx_v_stop_frame == __pyx_v_frame);
          __pyx_t_12 = __Pyx_PyBool_FromLong(__pyx_t_15); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 608, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_12);
          __pyx_t_12 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":609
 *             elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 *                 stop = stop_frame is frame
 *                 if stop:             # <<<<<<<<<<<<<<
 *                     # The only case we shouldn't stop on a line, is when
 *                     # we are traversing though asynchronous framework machinery
 */
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 609, __pyx_L62_error)
          if (__pyx_t_15) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":612
 *                     # The only case we shouldn't stop on a line, is when
 *                     # we are traversing though asynchronous framework machinery
 *                     if step_cmd == CMD_STEP_INTO_COROUTINE:             # <<<<<<<<<<<<<<
 *                         stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 */
            __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_CMD_STEP_INTO_COROUTINE); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 612, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_12);
            __pyx_t_1 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_12, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 612, __pyx_L62_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 612, __pyx_L62_error)
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (__pyx_t_15) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":613
 *                     # we are traversing though asynchronous framework machinery
 *                     if step_cmd == CMD_STEP_INTO_COROUTINE:
 *                         stop = py_db.in_project_scope(frame.f_code.co_filename)             # <<<<<<<<<<<<<<
 * 
 *                 if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 */
              __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 613, __pyx_L62_error)
              __Pyx_GOTREF(__pyx_t_12);
              __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_code); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 613, __pyx_L62_error)
              __Pyx_GOTREF(__pyx_t_11);
              __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 613, __pyx_L62_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              __pyx_t_11 = NULL;
              __pyx_t_5 = 0;
              #if CYTHON_UNPACK_METHODS
              if (likely(PyMethod_Check(__pyx_t_12))) {
                __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_12);
                if (likely(__pyx_t_11)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
                  __Pyx_INCREF(__pyx_t_11);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_12, function);
                  __pyx_t_5 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_4};
                __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_12, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
                __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 613, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_1);
                __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
              }
              __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_1);
              __pyx_t_1 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":612
 *                     # The only case we shouldn't stop on a line, is when
 *                     # we are traversing though asynchronous framework machinery
 *                     if step_cmd == CMD_STEP_INTO_COROUTINE:             # <<<<<<<<<<<<<<
 *                         stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":609
 *             elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 *                 stop = stop_frame is frame
 *                 if stop:             # <<<<<<<<<<<<<<
 *                     # The only case we shouldn't stop on a line, is when
 *                     # we are traversing though asynchronous framework machinery
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":615
 *                         stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 *                 if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 615, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_12); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 615, __pyx_L62_error)
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_12); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(0, 615, __pyx_L62_error)
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (__pyx_t_10) {
          } else {
            __pyx_t_15 = __pyx_t_10;
            goto __pyx_L104_bool_binop_done;
          }
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 615, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_10 = (__pyx_t_12 != Py_None);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_15 = __pyx_t_10;
          __pyx_L104_bool_binop_done:;
          if (__pyx_t_15) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":616
 * 
 *                 if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'line', args, stop_info, stop)             # <<<<<<<<<<<<<<
 *                     if result:
 *                         stop, plugin_stop = result
 */
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 616, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_cmd_step_over); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 616, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = NULL;
            __pyx_t_5 = 0;
            #if CYTHON_UNPACK_METHODS
            if (likely(PyMethod_Check(__pyx_t_4))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_4, function);
                __pyx_t_5 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[7] = {__pyx_t_1, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_line, __pyx_v_args, __pyx_v_stop_info, __pyx_v_stop};
              __pyx_t_12 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_5, 6+__pyx_t_5);
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 616, __pyx_L62_error)
              __Pyx_GOTREF(__pyx_t_12);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            }
            __Pyx_XDECREF_SET(__pyx_v_result, __pyx_t_12);
            __pyx_t_12 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":617
 *                 if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         stop, plugin_stop = result
 *             else:
 */
            __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 617, __pyx_L62_error)
            if (__pyx_t_15) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":618
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:
 *                         stop, plugin_stop = result             # <<<<<<<<<<<<<<
 *             else:
 *                 stop = False
 */
              if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
                PyObject* sequence = __pyx_v_result;
                Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
                if (unlikely(size != 2)) {
                  if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                  else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                  __PYX_ERR(0, 618, __pyx_L62_error)
                }
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                if (likely(PyTuple_CheckExact(sequence))) {
                  __pyx_t_12 = PyTuple_GET_ITEM(sequence, 0); 
                  __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
                } else {
                  __pyx_t_12 = PyList_GET_ITEM(sequence, 0); 
                  __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
                }
                __Pyx_INCREF(__pyx_t_12);
                __Pyx_INCREF(__pyx_t_4);
                #else
                __pyx_t_12 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 618, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_12);
                __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 618, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_4);
                #endif
              } else {
                Py_ssize_t index = -1;
                __pyx_t_1 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 618, __pyx_L62_error)
                __Pyx_GOTREF(__pyx_t_1);
                __pyx_t_13 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
                index = 0; __pyx_t_12 = __pyx_t_13(__pyx_t_1); if (unlikely(!__pyx_t_12)) goto __pyx_L107_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_12);
                index = 1; __pyx_t_4 = __pyx_t_13(__pyx_t_1); if (unlikely(!__pyx_t_4)) goto __pyx_L107_unpacking_failed;
                __Pyx_GOTREF(__pyx_t_4);
                if (__Pyx_IternextUnpackEndCheck(__pyx_t_13(__pyx_t_1), 2) < 0) __PYX_ERR(0, 618, __pyx_L62_error)
                __pyx_t_13 = NULL;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                goto __pyx_L108_unpacking_done;
                __pyx_L107_unpacking_failed:;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __pyx_t_13 = NULL;
                if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
                __PYX_ERR(0, 618, __pyx_L62_error)
                __pyx_L108_unpacking_done:;
              }
              __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_12);
              __pyx_t_12 = 0;
              __Pyx_DECREF_SET(__pyx_v_plugin_stop, __pyx_t_4);
              __pyx_t_4 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":617
 *                 if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:             # <<<<<<<<<<<<<<
 *                         stop, plugin_stop = result
 *             else:
 */
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":615
 *                         stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 *                 if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                     result = py_db.plugin.cmd_step_over(py_db, frame, 'line', args, stop_info, stop)
 *                     if result:
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":607
 *                 stop = py_db.in_project_scope(frame.f_code.co_filename)
 * 
 *             elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):             # <<<<<<<<<<<<<<
 *                 stop = stop_frame is frame
 *                 if stop:
 */
          goto __pyx_L68;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":620
 *                         stop, plugin_stop = result
 *             else:
 *                 stop = False             # <<<<<<<<<<<<<<
 * 
 *             if plugin_stop:
 */
        /*else*/ {
          __Pyx_INCREF(Py_False);
          __Pyx_DECREF_SET(__pyx_v_stop, Py_False);
        }
        __pyx_L68:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":622
 *                 stop = False
 * 
 *             if plugin_stop:             # <<<<<<<<<<<<<<
 *                 py_db.plugin.stop(py_db, frame, 'line', args, stop_info, None, step_cmd)
 *             elif stop:
 */
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_plugin_stop); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 622, __pyx_L62_error)
        if (__pyx_t_15) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":623
 * 
 *             if plugin_stop:
 *                 py_db.plugin.stop(py_db, frame, 'line', args, stop_info, None, step_cmd)             # <<<<<<<<<<<<<<
 *             elif stop:
 *                 py_db.set_suspend(thread, step_cmd)
 */
          __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 623, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_stop); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 623, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __pyx_t_12 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[8] = {__pyx_t_12, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_line, __pyx_v_args, __pyx_v_stop_info, Py_None, __pyx_v_step_cmd};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 7+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 623, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":622
 *                 stop = False
 * 
 *             if plugin_stop:             # <<<<<<<<<<<<<<
 *                 py_db.plugin.stop(py_db, frame, 'line', args, stop_info, None, step_cmd)
 *             elif stop:
 */
          goto __pyx_L109;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":624
 *             if plugin_stop:
 *                 py_db.plugin.stop(py_db, frame, 'line', args, stop_info, None, step_cmd)
 *             elif stop:             # <<<<<<<<<<<<<<
 *                 py_db.set_suspend(thread, step_cmd)
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 */
        __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 624, __pyx_L62_error)
        if (__pyx_t_15) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":625
 *                 py_db.plugin.stop(py_db, frame, 'line', args, stop_info, None, step_cmd)
 *             elif stop:
 *                 py_db.set_suspend(thread, step_cmd)             # <<<<<<<<<<<<<<
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 * 
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_set_suspend); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 625, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_12, __pyx_v_thread, __pyx_v_step_cmd};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 2+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 625, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":626
 *             elif stop:
 *                 py_db.set_suspend(thread, step_cmd)
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)             # <<<<<<<<<<<<<<
 * 
 *         except KeyboardInterrupt:
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_do_wait_suspend); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L62_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_12 = NULL;
          __pyx_t_5 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_1))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_1);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_1, function);
              __pyx_t_5 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_12, __pyx_v_thread, __pyx_v_frame, __pyx_n_s_line, Py_None};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_5, 4+__pyx_t_5);
            __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 626, __pyx_L62_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":624
 *             if plugin_stop:
 *                 py_db.plugin.stop(py_db, frame, 'line', args, stop_info, None, step_cmd)
 *             elif stop:             # <<<<<<<<<<<<<<
 *                 py_db.set_suspend(thread, step_cmd)
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 */
        }
        __pyx_L109:;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":560
 * 
 *         # Step handling. We stop when we hit the right frame.
 *         try:             # <<<<<<<<<<<<<<
 *             plugin_stop = False
 *             args = (py_db, filename, info, thread)
 */
      }
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L67_try_end;
      __pyx_L62_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":628
 *                 py_db.do_wait_suspend(thread, frame, 'line', None)
 * 
 *         except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *             _clear_run_state(info)
 *             raise
 */
      __pyx_t_17 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
      if (__pyx_t_17) {
        __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_1, &__pyx_t_12) < 0) __PYX_ERR(0, 628, __pyx_L64_except_error)
        __Pyx_XGOTREF(__pyx_t_4);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_12);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":629
 * 
 *         except KeyboardInterrupt:
 *             _clear_run_state(info)             # <<<<<<<<<<<<<<
 *             raise
 *         except:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_clear_run_state); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 629, __pyx_L64_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_16 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_16)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_16);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_v_info};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 629, __pyx_L64_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":630
 *         except KeyboardInterrupt:
 *             _clear_run_state(info)
 *             raise             # <<<<<<<<<<<<<<
 *         except:
 *             traceback.print_exc()
 */
        __Pyx_GIVEREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ErrRestoreWithState(__pyx_t_4, __pyx_t_1, __pyx_t_12);
        __pyx_t_4 = 0; __pyx_t_1 = 0; __pyx_t_12 = 0; 
        __PYX_ERR(0, 630, __pyx_L64_except_error)
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":631
 *             _clear_run_state(info)
 *             raise
 *         except:             # <<<<<<<<<<<<<<
 *             traceback.print_exc()
 *             info.pydev_step_cmd = -1
 */
      /*except:*/ {
        __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_12, &__pyx_t_1, &__pyx_t_4) < 0) __PYX_ERR(0, 631, __pyx_L64_except_error)
        __Pyx_XGOTREF(__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_4);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":632
 *             raise
 *         except:
 *             traceback.print_exc()             # <<<<<<<<<<<<<<
 *             info.pydev_step_cmd = -1
 *             raise
 */
        __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_traceback); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 632, __pyx_L64_except_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_print_exc); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 632, __pyx_L64_except_error)
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_16))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_16);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_16, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 632, __pyx_L64_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        }
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":633
 *         except:
 *             traceback.print_exc()
 *             info.pydev_step_cmd = -1             # <<<<<<<<<<<<<<
 *             raise
 * 
 */
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd, __pyx_int_neg_1) < 0) __PYX_ERR(0, 633, __pyx_L64_except_error)

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":634
 *             traceback.print_exc()
 *             info.pydev_step_cmd = -1
 *             raise             # <<<<<<<<<<<<<<
 * 
 *         if py_db.quitting:
 */
        __Pyx_GIVEREF(__pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_1);
        __Pyx_XGIVEREF(__pyx_t_4);
        __Pyx_ErrRestoreWithState(__pyx_t_12, __pyx_t_1, __pyx_t_4);
        __pyx_t_12 = 0; __pyx_t_1 = 0; __pyx_t_4 = 0; 
        __PYX_ERR(0, 634, __pyx_L64_except_error)
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":560
 * 
 *         # Step handling. We stop when we hit the right frame.
 *         try:             # <<<<<<<<<<<<<<
 *             plugin_stop = False
 *             args = (py_db, filename, info, thread)
 */
      __pyx_L64_except_error:;
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
      goto __pyx_L5_error;
      __pyx_L67_try_end:;
    }

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":636
 *             raise
 * 
 *         if py_db.quitting:             # <<<<<<<<<<<<<<
 *             raise KeyboardInterrupt()
 *     finally:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_quitting); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 636, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 636, __pyx_L5_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(__pyx_t_15)) {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":637
 * 
 *         if py_db.quitting:
 *             raise KeyboardInterrupt()             # <<<<<<<<<<<<<<
 *     finally:
 *         info.is_tracing = False
 */
      __pyx_t_4 = __Pyx_PyObject_CallNoArg(__pyx_builtin_KeyboardInterrupt); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 637, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(0, 637, __pyx_L5_error)

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":636
 *             raise
 * 
 *         if py_db.quitting:             # <<<<<<<<<<<<<<
 *             raise KeyboardInterrupt()
 *     finally:
 */
    }
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":639
 *             raise KeyboardInterrupt()
 *     finally:
 *         info.is_tracing = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*finally:*/ {
    /*normal exit:*/{
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_is_tracing, Py_False) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
      goto __pyx_L6;
    }
    __pyx_L5_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_20);
      __Pyx_XGOTREF(__pyx_t_19);
      __Pyx_XGOTREF(__pyx_t_18);
      __pyx_t_17 = __pyx_lineno; __pyx_t_21 = __pyx_clineno; __pyx_t_22 = __pyx_filename;
      {
        if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_is_tracing, Py_False) < 0) __PYX_ERR(0, 639, __pyx_L116_error)
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_19, __pyx_t_18);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
      __pyx_lineno = __pyx_t_17; __pyx_clineno = __pyx_t_21; __pyx_filename = __pyx_t_22;
      goto __pyx_L1_error;
      __pyx_L116_error:;
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_19, __pyx_t_18);
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
      goto __pyx_L1_error;
    }
    __pyx_L4_return: {
      __pyx_t_18 = __pyx_r;
      __pyx_r = 0;
      if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_is_tracing, Py_False) < 0) __PYX_ERR(0, 639, __pyx_L1_error)
      __pyx_r = __pyx_t_18;
      __pyx_t_18 = 0;
      goto __pyx_L0;
    }
    __pyx_L6:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":448
 * 
 * 
 * def py_line_callback(code, line_number):             # <<<<<<<<<<<<<<
 *     frame = _getframe(1)
 *     thread = get_current_thread()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_line_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_thread);
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_py_db);
  __Pyx_XDECREF(__pyx_v_stop_frame);
  __Pyx_XDECREF(__pyx_v_step_cmd);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XDECREF(__pyx_v_breakpoints_for_file);
  __Pyx_XDECREF(__pyx_v_frame_cache_key);
  __Pyx_XDECREF(__pyx_v_line_cache_key);
  __Pyx_XDECREF(__pyx_v_flag);
  __Pyx_XDECREF(__pyx_v_breakpoint);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_bp_type);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_smart_stop_frame);
  __Pyx_XDECREF(__pyx_v_context_start_line);
  __Pyx_XDECREF(__pyx_v_context_end_line);
  __Pyx_XDECREF(__pyx_v_is_within_context);
  __Pyx_XDECREF(__pyx_v_new_frame);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_eval_result);
  __Pyx_XDECREF(__pyx_v_cmd);
  __Pyx_XDECREF(__pyx_v_plugin_stop);
  __Pyx_XDECREF(__pyx_v_stop_info);
  __Pyx_XDECREF(__pyx_v_curr_func_name);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":642
 * 
 * 
 * def py_raise_callback(code, instruction_offset, exception):             # <<<<<<<<<<<<<<
 *     # print('PY_RAISE %s %s %s' % (code.co_name, code.co_filename, exception))
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_33py_raise_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_33py_raise_callback = {"py_raise_callback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_33py_raise_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_33py_raise_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_code = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instruction_offset = 0;
  PyObject *__pyx_v_exception = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("py_raise_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,&__pyx_n_s_instruction_offset,&__pyx_n_s_exception,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 642, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instruction_offset)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 642, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("py_raise_callback", 1, 3, 3, 1); __PYX_ERR(0, 642, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_exception)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 642, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("py_raise_callback", 1, 3, 3, 2); __PYX_ERR(0, 642, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "py_raise_callback") < 0)) __PYX_ERR(0, 642, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_code = values[0];
    __pyx_v_instruction_offset = values[1];
    __pyx_v_exception = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("py_raise_callback", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 642, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_raise_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_32py_raise_callback(__pyx_self, __pyx_v_code, __pyx_v_instruction_offset, __pyx_v_exception);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_32py_raise_callback(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset, PyObject *__pyx_v_exception) {
  PyObject *__pyx_v_exc_info = NULL;
  PyObject *__pyx_v_py_db = NULL;
  PyObject *__pyx_v_thread = NULL;
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_has_exception_breakpoints = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_should_stop = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  unsigned int __pyx_t_9;
  struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_raise_callback", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":645
 *     # print('PY_RAISE %s %s %s' % (code.co_name, code.co_filename, exception))
 * 
 *     exc_info = (type(exception), exception, exception.__traceback__)             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_exception, __pyx_n_s_traceback_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)Py_TYPE(__pyx_v_exception)));
  __Pyx_GIVEREF(((PyObject *)Py_TYPE(__pyx_v_exception)));
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)Py_TYPE(__pyx_v_exception)))) __PYX_ERR(0, 645, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_exception);
  __Pyx_GIVEREF(__pyx_v_exception);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_exception)) __PYX_ERR(0, 645, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_v_exc_info = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":647
 *     exc_info = (type(exception), exception, exception.__traceback__)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":648
 * 
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         py_db = None
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_py_db = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":647
 *     exc_info = (type(exception), exception, exception.__traceback__)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":649
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         py_db = None
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_raise_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_2, &__pyx_t_7) < 0) __PYX_ERR(0, 649, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_1);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":650
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 *         py_db = None             # <<<<<<<<<<<<<<
 * 
 *     if py_db is None:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_py_db, Py_None);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":647
 *     exc_info = (type(exception), exception, exception.__traceback__)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
    __pyx_L8_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":652
 *         py_db = None
 * 
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  __pyx_t_8 = (__pyx_v_py_db == Py_None);
  if (__pyx_t_8) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":653
 * 
 *     if py_db is None:
 *         return             # <<<<<<<<<<<<<<
 * 
 *     thread = get_current_thread()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":652
 *         py_db = None
 * 
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":655
 *         return
 * 
 *     thread = get_current_thread()             # <<<<<<<<<<<<<<
 *     info = _get_additional_info(thread)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_current_thread); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 655, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 655, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_thread = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":656
 * 
 *     thread = get_current_thread()
 *     info = _get_additional_info(thread)             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_additional_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = NULL;
  __pyx_t_9 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_1)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_9 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_thread};
    __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 656, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_v_info = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":658
 *     info = _get_additional_info(thread)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         frame = _getframe(1)
 *         if frame is _get_top_level_frame():
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_4, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":659
 * 
 *     try:
 *         frame = _getframe(1)             # <<<<<<<<<<<<<<
 *         if frame is _get_top_level_frame():
 *             _stop_on_unhandled_exception(exc_info, py_db, thread)
 */
      __pyx_t_10.__pyx_n = 1;
      __pyx_t_10.depth = __pyx_int_1;
      __pyx_t_7 = __pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(&__pyx_t_10); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 659, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_v_frame = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":660
 *     try:
 *         frame = _getframe(1)
 *         if frame is _get_top_level_frame():             # <<<<<<<<<<<<<<
 *             _stop_on_unhandled_exception(exc_info, py_db, thread)
 *             return
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_top_level_frame); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 660, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 0+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 660, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      }
      __pyx_t_8 = (__pyx_v_frame == __pyx_t_7);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":661
 *         frame = _getframe(1)
 *         if frame is _get_top_level_frame():
 *             _stop_on_unhandled_exception(exc_info, py_db, thread)             # <<<<<<<<<<<<<<
 *             return
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_stop_on_unhandled_exception_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 661, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_1, __pyx_v_exc_info, __pyx_v_py_db, __pyx_v_thread};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 3+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 661, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":662
 *         if frame is _get_top_level_frame():
 *             _stop_on_unhandled_exception(exc_info, py_db, thread)
 *             return             # <<<<<<<<<<<<<<
 * 
 *         has_exception_breakpoints = (py_db.break_on_caught_exceptions
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        goto __pyx_L16_try_return;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":660
 *     try:
 *         frame = _getframe(1)
 *         if frame is _get_top_level_frame():             # <<<<<<<<<<<<<<
 *             _stop_on_unhandled_exception(exc_info, py_db, thread)
 *             return
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":664
 *             return
 * 
 *         has_exception_breakpoints = (py_db.break_on_caught_exceptions             # <<<<<<<<<<<<<<
 *                                      or py_db.has_plugin_exception_breaks
 *                                      or py_db.stop_on_failed_tests)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_break_on_caught_exceptions); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 664, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 664, __pyx_L12_error)
      if (!__pyx_t_8) {
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_7 = __pyx_t_2;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L19_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":665
 * 
 *         has_exception_breakpoints = (py_db.break_on_caught_exceptions
 *                                      or py_db.has_plugin_exception_breaks             # <<<<<<<<<<<<<<
 *                                      or py_db.stop_on_failed_tests)
 *         if has_exception_breakpoints:
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_has_plugin_exception_breaks); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 665, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 665, __pyx_L12_error)
      if (!__pyx_t_8) {
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      } else {
        __Pyx_INCREF(__pyx_t_2);
        __pyx_t_7 = __pyx_t_2;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L19_bool_binop_done;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":666
 *         has_exception_breakpoints = (py_db.break_on_caught_exceptions
 *                                      or py_db.has_plugin_exception_breaks
 *                                      or py_db.stop_on_failed_tests)             # <<<<<<<<<<<<<<
 *         if has_exception_breakpoints:
 *             args = (
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_stop_on_failed_tests); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 666, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_7 = __pyx_t_2;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_L19_bool_binop_done:;
      __pyx_v_has_exception_breakpoints = __pyx_t_7;
      __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":667
 *                                      or py_db.has_plugin_exception_breaks
 *                                      or py_db.stop_on_failed_tests)
 *         if has_exception_breakpoints:             # <<<<<<<<<<<<<<
 *             args = (
 *                 py_db,
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_has_exception_breakpoints); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 667, __pyx_L12_error)
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":670
 *             args = (
 *                 py_db,
 *                 _get_abs_path_real_path_and_base_from_frame(frame)[1],             # <<<<<<<<<<<<<<
 *                 info, thread,
 *                 global_cache_skips,
 */
        __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_get_abs_path_real_path_and_base_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_frame};
          __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 670, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_7, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 670, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":672
 *                 _get_abs_path_real_path_and_base_from_frame(frame)[1],
 *                 info, thread,
 *                 global_cache_skips,             # <<<<<<<<<<<<<<
 *                 global_cache_frame_skips
 *             )
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_global_cache_skips); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 672, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":673
 *                 info, thread,
 *                 global_cache_skips,
 *                 global_cache_frame_skips             # <<<<<<<<<<<<<<
 *             )
 *             should_stop, frame = should_stop_on_exception(
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_global_cache_frame_skips); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 673, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":669
 *         if has_exception_breakpoints:
 *             args = (
 *                 py_db,             # <<<<<<<<<<<<<<
 *                 _get_abs_path_real_path_and_base_from_frame(frame)[1],
 *                 info, thread,
 */
        __pyx_t_11 = PyTuple_New(6); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 669, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_INCREF(__pyx_v_py_db);
        __Pyx_GIVEREF(__pyx_v_py_db);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_v_py_db)) __PYX_ERR(0, 669, __pyx_L12_error);
        __Pyx_GIVEREF(__pyx_t_2);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_2)) __PYX_ERR(0, 669, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_info);
        __Pyx_GIVEREF(__pyx_v_info);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 2, __pyx_v_info)) __PYX_ERR(0, 669, __pyx_L12_error);
        __Pyx_INCREF(__pyx_v_thread);
        __Pyx_GIVEREF(__pyx_v_thread);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 3, __pyx_v_thread)) __PYX_ERR(0, 669, __pyx_L12_error);
        __Pyx_GIVEREF(__pyx_t_7);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 4, __pyx_t_7)) __PYX_ERR(0, 669, __pyx_L12_error);
        __Pyx_GIVEREF(__pyx_t_1);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 5, __pyx_t_1)) __PYX_ERR(0, 669, __pyx_L12_error);
        __pyx_t_2 = 0;
        __pyx_t_7 = 0;
        __pyx_t_1 = 0;
        __pyx_v_args = ((PyObject*)__pyx_t_11);
        __pyx_t_11 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":675
 *                 global_cache_frame_skips
 *             )
 *             should_stop, frame = should_stop_on_exception(             # <<<<<<<<<<<<<<
 *                 args, frame, 'exception', exc_info)
 *             if should_stop:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_should_stop_on_exception); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_1);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":676
 *             )
 *             should_stop, frame = should_stop_on_exception(
 *                 args, frame, 'exception', exc_info)             # <<<<<<<<<<<<<<
 *             if should_stop:
 *                 handle_exception(args, frame, 'exception', exc_info)
 */
        __pyx_t_7 = NULL;
        __pyx_t_9 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_7)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
            __pyx_t_9 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_7, __pyx_v_args, __pyx_v_frame, __pyx_n_s_exception, __pyx_v_exc_info};
          __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_1, __pyx_callargs+1-__pyx_t_9, 4+__pyx_t_9);
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 675, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
          PyObject* sequence = __pyx_t_11;
          Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            __PYX_ERR(0, 675, __pyx_L12_error)
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_7);
          #else
          __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 675, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 675, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          #endif
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_2 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 675, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2);
          index = 0; __pyx_t_1 = __pyx_t_12(__pyx_t_2); if (unlikely(!__pyx_t_1)) goto __pyx_L23_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          index = 1; __pyx_t_7 = __pyx_t_12(__pyx_t_2); if (unlikely(!__pyx_t_7)) goto __pyx_L23_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_7);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_2), 2) < 0) __PYX_ERR(0, 675, __pyx_L12_error)
          __pyx_t_12 = NULL;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          goto __pyx_L24_unpacking_done;
          __pyx_L23_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_12 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          __PYX_ERR(0, 675, __pyx_L12_error)
          __pyx_L24_unpacking_done:;
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":675
 *                 global_cache_frame_skips
 *             )
 *             should_stop, frame = should_stop_on_exception(             # <<<<<<<<<<<<<<
 *                 args, frame, 'exception', exc_info)
 *             if should_stop:
 */
        __pyx_v_should_stop = __pyx_t_1;
        __pyx_t_1 = 0;
        __Pyx_DECREF_SET(__pyx_v_frame, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":677
 *             should_stop, frame = should_stop_on_exception(
 *                 args, frame, 'exception', exc_info)
 *             if should_stop:             # <<<<<<<<<<<<<<
 *                 handle_exception(args, frame, 'exception', exc_info)
 *     except KeyboardInterrupt:
 */
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_should_stop); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 677, __pyx_L12_error)
        if (__pyx_t_8) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":678
 *                 args, frame, 'exception', exc_info)
 *             if should_stop:
 *                 handle_exception(args, frame, 'exception', exc_info)             # <<<<<<<<<<<<<<
 *     except KeyboardInterrupt:
 *         _clear_run_state(info)
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_handle_exception); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 678, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_1 = NULL;
          __pyx_t_9 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_9 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_1, __pyx_v_args, __pyx_v_frame, __pyx_n_s_exception, __pyx_v_exc_info};
            __pyx_t_11 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_9, 4+__pyx_t_9);
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 678, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":677
 *             should_stop, frame = should_stop_on_exception(
 *                 args, frame, 'exception', exc_info)
 *             if should_stop:             # <<<<<<<<<<<<<<
 *                 handle_exception(args, frame, 'exception', exc_info)
 *     except KeyboardInterrupt:
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":667
 *                                      or py_db.has_plugin_exception_breaks
 *                                      or py_db.stop_on_failed_tests)
 *         if has_exception_breakpoints:             # <<<<<<<<<<<<<<
 *             args = (
 *                 py_db,
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":658
 *     info = _get_additional_info(thread)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         frame = _getframe(1)
 *         if frame is _get_top_level_frame():
 */
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L17_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":679
 *             if should_stop:
 *                 handle_exception(args, frame, 'exception', exc_info)
 *     except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *         _clear_run_state(info)
 *         raise
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_raise_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_7, &__pyx_t_1) < 0) __PYX_ERR(0, 679, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":680
 *                 handle_exception(args, frame, 'exception', exc_info)
 *     except KeyboardInterrupt:
 *         _clear_run_state(info)             # <<<<<<<<<<<<<<
 *         raise
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_clear_run_state); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 680, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_14 = NULL;
      __pyx_t_9 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_13);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_13, function);
          __pyx_t_9 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_14, __pyx_v_info};
        __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_9, 1+__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 680, __pyx_L14_except_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":681
 *     except KeyboardInterrupt:
 *         _clear_run_state(info)
 *         raise             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_GIVEREF(__pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_1);
      __Pyx_ErrRestoreWithState(__pyx_t_11, __pyx_t_7, __pyx_t_1);
      __pyx_t_11 = 0; __pyx_t_7 = 0; __pyx_t_1 = 0; 
      __PYX_ERR(0, 681, __pyx_L14_except_error)
    }
    goto __pyx_L14_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":658
 *     info = _get_additional_info(thread)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         frame = _getframe(1)
 *         if frame is _get_top_level_frame():
 */
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L16_try_return:;
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_4, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L17_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":642
 * 
 * 
 * def py_raise_callback(code, instruction_offset, exception):             # <<<<<<<<<<<<<<
 *     # print('PY_RAISE %s %s %s' % (code.co_name, code.co_filename, exception))
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_raise_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_exc_info);
  __Pyx_XDECREF(__pyx_v_py_db);
  __Pyx_XDECREF(__pyx_v_thread);
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_has_exception_breakpoints);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_should_stop);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":684
 * 
 * 
 * def py_return_callback(code, instruction_offset, retval):             # <<<<<<<<<<<<<<
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_35py_return_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_35py_return_callback = {"py_return_callback", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_35py_return_callback, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_35py_return_callback(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_code = 0;
  CYTHON_UNUSED PyObject *__pyx_v_instruction_offset = 0;
  PyObject *__pyx_v_retval = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("py_return_callback (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_code,&__pyx_n_s_instruction_offset,&__pyx_n_s_retval,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_code)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 684, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_instruction_offset)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 684, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("py_return_callback", 1, 3, 3, 1); __PYX_ERR(0, 684, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_retval)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 684, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("py_return_callback", 1, 3, 3, 2); __PYX_ERR(0, 684, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "py_return_callback") < 0)) __PYX_ERR(0, 684, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v_code = values[0];
    __pyx_v_instruction_offset = values[1];
    __pyx_v_retval = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("py_return_callback", 1, 3, 3, __pyx_nargs); __PYX_ERR(0, 684, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_return_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_34py_return_callback(__pyx_self, __pyx_v_code, __pyx_v_instruction_offset, __pyx_v_retval);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_34py_return_callback(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_code, CYTHON_UNUSED PyObject *__pyx_v_instruction_offset, PyObject *__pyx_v_retval) {
  PyObject *__pyx_v_py_db = NULL;
  PyObject *__pyx_v_frame = NULL;
  PyObject *__pyx_v_thread = NULL;
  PyObject *__pyx_v_info = NULL;
  PyObject *__pyx_v_stop_frame = NULL;
  PyObject *__pyx_v_filename = NULL;
  PyObject *__pyx_v_plugin_stop = NULL;
  PyObject *__pyx_v_args = NULL;
  PyObject *__pyx_v_stop_info = NULL;
  PyObject *__pyx_v_stop = NULL;
  PyObject *__pyx_v_smart_stop_frame = NULL;
  PyObject *__pyx_v_step_cmd = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_back = NULL;
  PyObject *__pyx_v_back_code = NULL;
  PyObject *__pyx_v_f_back = NULL;
  PyObject *__pyx_v_f_code = NULL;
  PyObject *__pyx_v_back_filename = NULL;
  PyObject *__pyx_v_base_back_filename = NULL;
  PyObject *__pyx_v_file_type = NULL;
  PyObject *__pyx_v_breakpoints_for_back_file = NULL;
  PyObject *__pyx_v_breakpoint = NULL;
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_base = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  struct __pyx_opt_args_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe __pyx_t_9;
  unsigned int __pyx_t_10;
  int __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  PyObject *__pyx_t_19 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("py_return_callback", 1);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":686
 * def py_return_callback(code, instruction_offset, retval):
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":687
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg             # <<<<<<<<<<<<<<
 *     except AttributeError:
 *         py_db = None
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 687, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_global_dbg); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 687, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_py_db = __pyx_t_5;
      __pyx_t_5 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":686
 * def py_return_callback(code, instruction_offset, retval):
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":688
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:             # <<<<<<<<<<<<<<
 *         py_db = None
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_return_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(0, 688, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":689
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 *         py_db = None             # <<<<<<<<<<<<<<
 * 
 *     if py_db is None:
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_py_db, Py_None);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":686
 * def py_return_callback(code, instruction_offset, retval):
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:             # <<<<<<<<<<<<<<
 *         py_db = GlobalDebuggerHolder.global_dbg
 *     except AttributeError:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L8_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":691
 *         py_db = None
 * 
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 * 
 */
  __pyx_t_8 = (__pyx_v_py_db == Py_None);
  if (__pyx_t_8) {

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":692
 * 
 *     if py_db is None:
 *         return monitoring.DISABLE             # <<<<<<<<<<<<<<
 * 
 *     frame = _getframe(1)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_DISABLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 692, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":691
 *         py_db = None
 * 
 *     if py_db is None:             # <<<<<<<<<<<<<<
 *         return monitoring.DISABLE
 * 
 */
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":694
 *         return monitoring.DISABLE
 * 
 *     frame = _getframe(1)             # <<<<<<<<<<<<<<
 *     thread = get_current_thread()
 *     info = _get_additional_info(thread)
 */
  __pyx_t_9.__pyx_n = 1;
  __pyx_t_9.depth = __pyx_int_1;
  __pyx_t_4 = __pyx_f_14_pydevd_bundle_29pydevd_pep_669_tracing_cython__getframe(&__pyx_t_9); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_frame = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":695
 * 
 *     frame = _getframe(1)
 *     thread = get_current_thread()             # <<<<<<<<<<<<<<
 *     info = _get_additional_info(thread)
 *     stop_frame = info.pydev_step_stop
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_get_current_thread); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 0+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 695, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_thread = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":696
 *     frame = _getframe(1)
 *     thread = get_current_thread()
 *     info = _get_additional_info(thread)             # <<<<<<<<<<<<<<
 *     stop_frame = info.pydev_step_stop
 *     filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_get_additional_info); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_thread};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_v_info = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":697
 *     thread = get_current_thread()
 *     info = _get_additional_info(thread)
 *     stop_frame = info.pydev_step_stop             # <<<<<<<<<<<<<<
 *     filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]
 *     plugin_stop = False
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_stop_frame = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":698
 *     info = _get_additional_info(thread)
 *     stop_frame = info.pydev_step_stop
 *     filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]             # <<<<<<<<<<<<<<
 *     plugin_stop = False
 *     args = (py_db, filename, info, thread)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_get_abs_path_real_path_and_base_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = NULL;
  __pyx_t_10 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
      __pyx_t_10 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_v_frame};
    __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __pyx_t_7 = __Pyx_GetItemInt(__pyx_t_4, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_filename = __pyx_t_7;
  __pyx_t_7 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":699
 *     stop_frame = info.pydev_step_stop
 *     filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]
 *     plugin_stop = False             # <<<<<<<<<<<<<<
 *     args = (py_db, filename, info, thread)
 *     stop_info = {}
 */
  __Pyx_INCREF(Py_False);
  __pyx_v_plugin_stop = Py_False;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":700
 *     filename = _get_abs_path_real_path_and_base_from_frame(frame)[1]
 *     plugin_stop = False
 *     args = (py_db, filename, info, thread)             # <<<<<<<<<<<<<<
 *     stop_info = {}
 *     stop = False
 */
  __pyx_t_7 = PyTuple_New(4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_v_py_db);
  __Pyx_GIVEREF(__pyx_v_py_db);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_py_db)) __PYX_ERR(0, 700, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_filename);
  __Pyx_GIVEREF(__pyx_v_filename);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_filename)) __PYX_ERR(0, 700, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_info);
  __Pyx_GIVEREF(__pyx_v_info);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_v_info)) __PYX_ERR(0, 700, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_thread);
  __Pyx_GIVEREF(__pyx_v_thread);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_v_thread)) __PYX_ERR(0, 700, __pyx_L1_error);
  __pyx_v_args = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":701
 *     plugin_stop = False
 *     args = (py_db, filename, info, thread)
 *     stop_info = {}             # <<<<<<<<<<<<<<
 *     stop = False
 *     smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_stop_info = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":702
 *     args = (py_db, filename, info, thread)
 *     stop_info = {}
 *     stop = False             # <<<<<<<<<<<<<<
 *     smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 * 
 */
  __Pyx_INCREF(Py_False);
  __pyx_v_stop = Py_False;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":703
 *     stop_info = {}
 *     stop = False
 *     smart_stop_frame = info.pydev_smart_step_context.smart_step_stop             # <<<<<<<<<<<<<<
 * 
 *     try:
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_smart_step_context); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_smart_step_stop); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_v_smart_stop_frame = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":705
 *     smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db.show_return_values or py_db.remove_return_values_flag:
 *             manage_return_values(py_db, frame, 'return', retval)
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":706
 * 
 *     try:
 *         if py_db.show_return_values or py_db.remove_return_values_flag:             # <<<<<<<<<<<<<<
 *             manage_return_values(py_db, frame, 'return', retval)
 * 
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_show_return_values); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 706, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 706, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_11) {
      } else {
        __pyx_t_8 = __pyx_t_11;
        goto __pyx_L19_bool_binop_done;
      }
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_remove_return_values_flag); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 706, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 706, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __pyx_t_11;
      __pyx_L19_bool_binop_done:;
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":707
 *     try:
 *         if py_db.show_return_values or py_db.remove_return_values_flag:
 *             manage_return_values(py_db, frame, 'return', retval)             # <<<<<<<<<<<<<<
 * 
 *         step_cmd = info.pydev_step_cmd
 */
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_manage_return_values); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 707, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[5] = {__pyx_t_5, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_return, __pyx_v_retval};
          __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 707, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":706
 * 
 *     try:
 *         if py_db.show_return_values or py_db.remove_return_values_flag:             # <<<<<<<<<<<<<<
 *             manage_return_values(py_db, frame, 'return', retval)
 * 
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":709
 *             manage_return_values(py_db, frame, 'return', retval)
 * 
 *         step_cmd = info.pydev_step_cmd             # <<<<<<<<<<<<<<
 * 
 *         if step_cmd == CMD_SMART_STEP_INTO and smart_stop_frame is frame:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 709, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_step_cmd = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":711
 *         step_cmd = info.pydev_step_cmd
 * 
 *         if step_cmd == CMD_SMART_STEP_INTO and smart_stop_frame is frame:             # <<<<<<<<<<<<<<
 *             stop = True
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CMD_SMART_STEP_INTO); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 711, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 711, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 711, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (__pyx_t_11) {
      } else {
        __pyx_t_8 = __pyx_t_11;
        goto __pyx_L22_bool_binop_done;
      }
      __pyx_t_11 = (__pyx_v_smart_stop_frame == __pyx_v_frame);
      __pyx_t_8 = __pyx_t_11;
      __pyx_L22_bool_binop_done:;
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":712
 * 
 *         if step_cmd == CMD_SMART_STEP_INTO and smart_stop_frame is frame:
 *             stop = True             # <<<<<<<<<<<<<<
 * 
 *         elif step_cmd == CMD_STEP_INTO:
 */
        __Pyx_INCREF(Py_True);
        __Pyx_DECREF_SET(__pyx_v_stop, Py_True);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":711
 *         step_cmd = info.pydev_step_cmd
 * 
 *         if step_cmd == CMD_SMART_STEP_INTO and smart_stop_frame is frame:             # <<<<<<<<<<<<<<
 *             stop = True
 * 
 */
        goto __pyx_L21;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":714
 *             stop = True
 * 
 *         elif step_cmd == CMD_STEP_INTO:             # <<<<<<<<<<<<<<
 *             stop = True
 *             if py_db.plugin is not None:
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CMD_STEP_INTO); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 714, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 714, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 714, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_8) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":715
 * 
 *         elif step_cmd == CMD_STEP_INTO:
 *             stop = True             # <<<<<<<<<<<<<<
 *             if py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)
 */
        __Pyx_INCREF(Py_True);
        __Pyx_DECREF_SET(__pyx_v_stop, Py_True);

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":716
 *         elif step_cmd == CMD_STEP_INTO:
 *             stop = True
 *             if py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)
 *                 if result:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 716, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = (__pyx_t_4 != Py_None);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_8) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":717
 *             stop = True
 *             if py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)             # <<<<<<<<<<<<<<
 *                 if result:
 *                     stop, plugin_stop = result
 */
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 717, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_cmd_step_into); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 717, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_5))) {
            __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
            if (likely(__pyx_t_7)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_5, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[7] = {__pyx_t_7, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_return, __pyx_v_args, __pyx_v_stop_info, Py_True};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_10, 6+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 717, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          }
          __pyx_v_result = __pyx_t_4;
          __pyx_t_4 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":718
 *             if py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     stop, plugin_stop = result
 * 
 */
          __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 718, __pyx_L12_error)
          if (__pyx_t_8) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":719
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)
 *                 if result:
 *                     stop, plugin_stop = result             # <<<<<<<<<<<<<<
 * 
 *         elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 */
            if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
              PyObject* sequence = __pyx_v_result;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 719, __pyx_L12_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_4 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_4 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_5);
              #else
              __pyx_t_4 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 719, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 719, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              #endif
            } else {
              Py_ssize_t index = -1;
              __pyx_t_7 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 719, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_7);
              index = 0; __pyx_t_4 = __pyx_t_12(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L26_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_4);
              index = 1; __pyx_t_5 = __pyx_t_12(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L26_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_5);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_7), 2) < 0) __PYX_ERR(0, 719, __pyx_L12_error)
              __pyx_t_12 = NULL;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              goto __pyx_L27_unpacking_done;
              __pyx_L26_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __pyx_t_12 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 719, __pyx_L12_error)
              __pyx_L27_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_4);
            __pyx_t_4 = 0;
            __Pyx_DECREF_SET(__pyx_v_plugin_stop, __pyx_t_5);
            __pyx_t_5 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":718
 *             if py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     stop, plugin_stop = result
 * 
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":716
 *         elif step_cmd == CMD_STEP_INTO:
 *             stop = True
 *             if py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.cmd_step_into(py_db, frame, 'return', args, stop_info, True)
 *                 if result:
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":714
 *             stop = True
 * 
 *         elif step_cmd == CMD_STEP_INTO:             # <<<<<<<<<<<<<<
 *             stop = True
 *             if py_db.plugin is not None:
 */
        goto __pyx_L21;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":721
 *                     stop, plugin_stop = result
 * 
 *         elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):             # <<<<<<<<<<<<<<
 *             stop = stop_frame is frame
 *             if stop:
 */
      __Pyx_INCREF(__pyx_v_step_cmd);
      __pyx_t_5 = __pyx_v_step_cmd;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 721, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 721, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 721, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (!__pyx_t_11) {
      } else {
        __pyx_t_8 = __pyx_t_11;
        goto __pyx_L28_bool_binop_done;
      }
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CMD_STEP_INTO_COROUTINE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 721, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 721, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 721, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = __pyx_t_11;
      __pyx_L28_bool_binop_done:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_11 = __pyx_t_8;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":722
 * 
 *         elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 *             stop = stop_frame is frame             # <<<<<<<<<<<<<<
 *             if stop:
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 */
        __pyx_t_11 = (__pyx_v_stop_frame == __pyx_v_frame);
        __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 722, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":723
 *         elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 *             stop = stop_frame is frame
 *             if stop:             # <<<<<<<<<<<<<<
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 *                 if not stop:
 */
        __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 723, __pyx_L12_error)
        if (__pyx_t_11) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":724
 *             stop = stop_frame is frame
 *             if stop:
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)             # <<<<<<<<<<<<<<
 *                 if not stop:
 *                     if frame.f_back:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 724, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 724, __pyx_L12_error)
          if (__pyx_t_11) {
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          } else {
            __Pyx_INCREF(__pyx_t_4);
            __pyx_t_5 = __pyx_t_4;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            goto __pyx_L31_bool_binop_done;
          }
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 724, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 724, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_f_code); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 724, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 724, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_14 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_14)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_14, __pyx_t_13};
            __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 724, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_4);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_5 = __pyx_t_4;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_L31_bool_binop_done:;
          __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_5);
          __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":725
 *             if stop:
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 *                 if not stop:             # <<<<<<<<<<<<<<
 *                     if frame.f_back:
 *                         back = frame.f_back
 */
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 725, __pyx_L12_error)
          __pyx_t_8 = (!__pyx_t_11);
          if (__pyx_t_8) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":726
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 *                 if not stop:
 *                     if frame.f_back:             # <<<<<<<<<<<<<<
 *                         back = frame.f_back
 *                         info.pydev_step_stop = back
 */
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 726, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 726, __pyx_L12_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_8) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":727
 *                 if not stop:
 *                     if frame.f_back:
 *                         back = frame.f_back             # <<<<<<<<<<<<<<
 *                         info.pydev_step_stop = back
 *                         back_code = back.f_code
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 727, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_v_back = __pyx_t_5;
              __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":728
 *                     if frame.f_back:
 *                         back = frame.f_back
 *                         info.pydev_step_stop = back             # <<<<<<<<<<<<<<
 *                         back_code = back.f_code
 *                         if not py_db.in_project_scope(back_code.co_filename):
 */
              if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop, __pyx_v_back) < 0) __PYX_ERR(0, 728, __pyx_L12_error)

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":729
 *                         back = frame.f_back
 *                         info.pydev_step_stop = back
 *                         back_code = back.f_code             # <<<<<<<<<<<<<<
 *                         if not py_db.in_project_scope(back_code.co_filename):
 *                             stop = not step_cmd == CMD_STEP_INTO_COROUTINE
 */
              __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_back, __pyx_n_s_f_code); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 729, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_v_back_code = __pyx_t_5;
              __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":730
 *                         info.pydev_step_stop = back
 *                         back_code = back.f_code
 *                         if not py_db.in_project_scope(back_code.co_filename):             # <<<<<<<<<<<<<<
 *                             stop = not step_cmd == CMD_STEP_INTO_COROUTINE
 * 
 */
              __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_in_project_scope); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 730, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_back_code, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 730, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_13 = NULL;
              __pyx_t_10 = 0;
              #if CYTHON_UNPACK_METHODS
              if (likely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
                if (likely(__pyx_t_13)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_13);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_4, function);
                  __pyx_t_10 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_7};
                __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 730, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 730, __pyx_L12_error)
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __pyx_t_11 = (!__pyx_t_8);
              if (__pyx_t_11) {

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":731
 *                         back_code = back.f_code
 *                         if not py_db.in_project_scope(back_code.co_filename):
 *                             stop = not step_cmd == CMD_STEP_INTO_COROUTINE             # <<<<<<<<<<<<<<
 * 
 *                     else:
 */
                __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_CMD_STEP_INTO_COROUTINE); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 731, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                __pyx_t_4 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 731, __pyx_L12_error)
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 731, __pyx_L12_error)
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_4 = __Pyx_PyBool_FromLong((!__pyx_t_11)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 731, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_4);
                __pyx_t_4 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":730
 *                         info.pydev_step_stop = back
 *                         back_code = back.f_code
 *                         if not py_db.in_project_scope(back_code.co_filename):             # <<<<<<<<<<<<<<
 *                             stop = not step_cmd == CMD_STEP_INTO_COROUTINE
 * 
 */
              }

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":726
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 *                 if not stop:
 *                     if frame.f_back:             # <<<<<<<<<<<<<<
 *                         back = frame.f_back
 *                         info.pydev_step_stop = back
 */
              goto __pyx_L34;
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":735
 *                     else:
 *                         # if there's no back frame, we just stop as soon as possible
 *                         info.pydev_step_cmd = CMD_STEP_INTO             # <<<<<<<<<<<<<<
 *                         info.pydev_step_stop = None
 * 
 */
            /*else*/ {
              __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CMD_STEP_INTO); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 735, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_cmd, __pyx_t_4) < 0) __PYX_ERR(0, 735, __pyx_L12_error)
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":736
 *                         # if there's no back frame, we just stop as soon as possible
 *                         info.pydev_step_cmd = CMD_STEP_INTO
 *                         info.pydev_step_stop = None             # <<<<<<<<<<<<<<
 * 
 *             if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 */
              if (__Pyx_PyObject_SetAttrStr(__pyx_v_info, __pyx_n_s_pydev_step_stop, Py_None) < 0) __PYX_ERR(0, 736, __pyx_L12_error)
            }
            __pyx_L34:;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":725
 *             if stop:
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 *                 if not stop:             # <<<<<<<<<<<<<<
 *                     if frame.f_back:
 *                         back = frame.f_back
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":723
 *         elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):
 *             stop = stop_frame is frame
 *             if stop:             # <<<<<<<<<<<<<<
 *                 stop = frame.f_back and py_db.in_project_scope(frame.f_back.f_code.co_filename)
 *                 if not stop:
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":738
 *                         info.pydev_step_stop = None
 * 
 *             if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.cmd_step_over(py_db, frame, 'return', args, stop_info, stop)
 *                 if result:
 */
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 738, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 738, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 738, __pyx_L12_error)
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (__pyx_t_8) {
        } else {
          __pyx_t_11 = __pyx_t_8;
          goto __pyx_L37_bool_binop_done;
        }
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 738, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_8 = (__pyx_t_5 != Py_None);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_11 = __pyx_t_8;
        __pyx_L37_bool_binop_done:;
        if (__pyx_t_11) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":739
 * 
 *             if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_over(py_db, frame, 'return', args, stop_info, stop)             # <<<<<<<<<<<<<<
 *                 if result:
 *                     stop, plugin_stop = result
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 739, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_cmd_step_over); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 739, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[7] = {__pyx_t_4, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_return, __pyx_v_args, __pyx_v_stop_info, __pyx_v_stop};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 6+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 739, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __pyx_v_result = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":740
 *             if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_over(py_db, frame, 'return', args, stop_info, stop)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     stop, plugin_stop = result
 * 
 */
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_result); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 740, __pyx_L12_error)
          if (__pyx_t_11) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":741
 *                 result = py_db.plugin.cmd_step_over(py_db, frame, 'return', args, stop_info, stop)
 *                 if result:
 *                     stop, plugin_stop = result             # <<<<<<<<<<<<<<
 * 
 *         elif step_cmd == CMD_STEP_RETURN:
 */
            if ((likely(PyTuple_CheckExact(__pyx_v_result))) || (PyList_CheckExact(__pyx_v_result))) {
              PyObject* sequence = __pyx_v_result;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 2)) {
                if (size > 2) __Pyx_RaiseTooManyValuesError(2);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 741, __pyx_L12_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_7 = PyTuple_GET_ITEM(sequence, 1); 
              } else {
                __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_7 = PyList_GET_ITEM(sequence, 1); 
              }
              __Pyx_INCREF(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_7);
              #else
              __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 741, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __pyx_t_7 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 741, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_7);
              #endif
            } else {
              Py_ssize_t index = -1;
              __pyx_t_4 = PyObject_GetIter(__pyx_v_result); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 741, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_4);
              index = 0; __pyx_t_5 = __pyx_t_12(__pyx_t_4); if (unlikely(!__pyx_t_5)) goto __pyx_L40_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_5);
              index = 1; __pyx_t_7 = __pyx_t_12(__pyx_t_4); if (unlikely(!__pyx_t_7)) goto __pyx_L40_unpacking_failed;
              __Pyx_GOTREF(__pyx_t_7);
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_4), 2) < 0) __PYX_ERR(0, 741, __pyx_L12_error)
              __pyx_t_12 = NULL;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              goto __pyx_L41_unpacking_done;
              __pyx_L40_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_12 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 741, __pyx_L12_error)
              __pyx_L41_unpacking_done:;
            }
            __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_5);
            __pyx_t_5 = 0;
            __Pyx_DECREF_SET(__pyx_v_plugin_stop, __pyx_t_7);
            __pyx_t_7 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":740
 *             if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:
 *                 result = py_db.plugin.cmd_step_over(py_db, frame, 'return', args, stop_info, stop)
 *                 if result:             # <<<<<<<<<<<<<<
 *                     stop, plugin_stop = result
 * 
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":738
 *                         info.pydev_step_stop = None
 * 
 *             if step_cmd == CMD_STEP_OVER and py_db.plugin is not None:             # <<<<<<<<<<<<<<
 *                 result = py_db.plugin.cmd_step_over(py_db, frame, 'return', args, stop_info, stop)
 *                 if result:
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":721
 *                     stop, plugin_stop = result
 * 
 *         elif step_cmd in (CMD_STEP_OVER, CMD_STEP_INTO_COROUTINE):             # <<<<<<<<<<<<<<
 *             stop = stop_frame is frame
 *             if stop:
 */
        goto __pyx_L21;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":743
 *                     stop, plugin_stop = result
 * 
 *         elif step_cmd == CMD_STEP_RETURN:             # <<<<<<<<<<<<<<
 *             stop = stop_frame is frame
 * 
 */
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_CMD_STEP_RETURN); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 743, __pyx_L12_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_step_cmd, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 743, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 743, __pyx_L12_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":744
 * 
 *         elif step_cmd == CMD_STEP_RETURN:
 *             stop = stop_frame is frame             # <<<<<<<<<<<<<<
 * 
 *         if hasattr(frame, "f_back"):
 */
        __pyx_t_11 = (__pyx_v_stop_frame == __pyx_v_frame);
        __pyx_t_5 = __Pyx_PyBool_FromLong(__pyx_t_11); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 744, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_stop, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":743
 *                     stop, plugin_stop = result
 * 
 *         elif step_cmd == CMD_STEP_RETURN:             # <<<<<<<<<<<<<<
 *             stop = stop_frame is frame
 * 
 */
      }
      __pyx_L21:;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":746
 *             stop = stop_frame is frame
 * 
 *         if hasattr(frame, "f_back"):             # <<<<<<<<<<<<<<
 *             f_back = frame.f_back
 *             f_code = getattr(f_back, 'f_code', None)
 */
      __pyx_t_11 = __Pyx_HasAttr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 746, __pyx_L12_error)
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":747
 * 
 *         if hasattr(frame, "f_back"):
 *             f_back = frame.f_back             # <<<<<<<<<<<<<<
 *             f_code = getattr(f_back, 'f_code', None)
 *             if f_code is not None:
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 747, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_v_f_back = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":748
 *         if hasattr(frame, "f_back"):
 *             f_back = frame.f_back
 *             f_code = getattr(f_back, 'f_code', None)             # <<<<<<<<<<<<<<
 *             if f_code is not None:
 *                 back_filename = f_code.co_filename
 */
        __pyx_t_5 = __Pyx_GetAttr3(__pyx_v_f_back, __pyx_n_s_f_code, Py_None); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 748, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_v_f_code = __pyx_t_5;
        __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":749
 *             f_back = frame.f_back
 *             f_code = getattr(f_back, 'f_code', None)
 *             if f_code is not None:             # <<<<<<<<<<<<<<
 *                 back_filename = f_code.co_filename
 *                 base_back_filename = os.path.basename(back_filename)
 */
        __pyx_t_11 = (__pyx_v_f_code != Py_None);
        if (__pyx_t_11) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":750
 *             f_code = getattr(f_back, 'f_code', None)
 *             if f_code is not None:
 *                 back_filename = f_code.co_filename             # <<<<<<<<<<<<<<
 *                 base_back_filename = os.path.basename(back_filename)
 *                 file_type = get_file_type(base_back_filename)
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_code, __pyx_n_s_co_filename); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 750, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_v_back_filename = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":751
 *             if f_code is not None:
 *                 back_filename = f_code.co_filename
 *                 base_back_filename = os.path.basename(back_filename)             # <<<<<<<<<<<<<<
 *                 file_type = get_file_type(base_back_filename)
 *                 if stop != (step_cmd == -1):
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_os); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 751, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 751, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_basename); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 751, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_4 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_back_filename};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 751, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __pyx_v_base_back_filename = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":752
 *                 back_filename = f_code.co_filename
 *                 base_back_filename = os.path.basename(back_filename)
 *                 file_type = get_file_type(base_back_filename)             # <<<<<<<<<<<<<<
 *                 if stop != (step_cmd == -1):
 *                     if file_type == PYDEV_FILE:
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_get_file_type); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 752, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_4 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_base_back_filename};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 752, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          __pyx_v_file_type = __pyx_t_5;
          __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":753
 *                 base_back_filename = os.path.basename(back_filename)
 *                 file_type = get_file_type(base_back_filename)
 *                 if stop != (step_cmd == -1):             # <<<<<<<<<<<<<<
 *                     if file_type == PYDEV_FILE:
 *                         stop = False
 */
          __pyx_t_5 = __Pyx_PyInt_EqObjC(__pyx_v_step_cmd, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 753, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_7 = PyObject_RichCompare(__pyx_v_stop, __pyx_t_5, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 753, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 753, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (__pyx_t_11) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":754
 *                 file_type = get_file_type(base_back_filename)
 *                 if stop != (step_cmd == -1):
 *                     if file_type == PYDEV_FILE:             # <<<<<<<<<<<<<<
 *                         stop = False
 *                     elif not stop and step_cmd == -1:
 */
            __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_PYDEV_FILE); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 754, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_5 = PyObject_RichCompare(__pyx_v_file_type, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 754, __pyx_L12_error)
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 754, __pyx_L12_error)
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            if (__pyx_t_11) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":755
 *                 if stop != (step_cmd == -1):
 *                     if file_type == PYDEV_FILE:
 *                         stop = False             # <<<<<<<<<<<<<<
 *                     elif not stop and step_cmd == -1:
 *                         # Check does f_back have breakpoint and should enable line events for f_back
 */
              __Pyx_INCREF(Py_False);
              __Pyx_DECREF_SET(__pyx_v_stop, Py_False);

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":754
 *                 file_type = get_file_type(base_back_filename)
 *                 if stop != (step_cmd == -1):
 *                     if file_type == PYDEV_FILE:             # <<<<<<<<<<<<<<
 *                         stop = False
 *                     elif not stop and step_cmd == -1:
 */
              goto __pyx_L45;
            }

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":756
 *                     if file_type == PYDEV_FILE:
 *                         stop = False
 *                     elif not stop and step_cmd == -1:             # <<<<<<<<<<<<<<
 *                         # Check does f_back have breakpoint and should enable line events for f_back
 *                         breakpoints_for_back_file = py_db.breakpoints.get(back_filename)
 */
            __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(0, 756, __pyx_L12_error)
            __pyx_t_15 = (!__pyx_t_8);
            if (__pyx_t_15) {
            } else {
              __pyx_t_11 = __pyx_t_15;
              goto __pyx_L46_bool_binop_done;
            }
            __pyx_t_15 = (__Pyx_PyInt_BoolEqObjC(__pyx_v_step_cmd, __pyx_int_neg_1, -1L, 0)); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 756, __pyx_L12_error)
            __pyx_t_11 = __pyx_t_15;
            __pyx_L46_bool_binop_done:;
            if (__pyx_t_11) {

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":758
 *                     elif not stop and step_cmd == -1:
 *                         # Check does f_back have breakpoint and should enable line events for f_back
 *                         breakpoints_for_back_file = py_db.breakpoints.get(back_filename)             # <<<<<<<<<<<<<<
 *                         if breakpoints_for_back_file is not None:
 *                             for breakpoint in breakpoints_for_back_file.values():
 */
              __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_breakpoints); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 758, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_7);
              __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 758, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
              __pyx_t_7 = NULL;
              __pyx_t_10 = 0;
              #if CYTHON_UNPACK_METHODS
              if (likely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
                if (likely(__pyx_t_7)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_7);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_4, function);
                  __pyx_t_10 = 1;
                }
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_back_filename};
                __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
                __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
                if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 758, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_5);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __pyx_v_breakpoints_for_back_file = __pyx_t_5;
              __pyx_t_5 = 0;

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":759
 *                         # Check does f_back have breakpoint and should enable line events for f_back
 *                         breakpoints_for_back_file = py_db.breakpoints.get(back_filename)
 *                         if breakpoints_for_back_file is not None:             # <<<<<<<<<<<<<<
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:
 */
              __pyx_t_11 = (__pyx_v_breakpoints_for_back_file != Py_None);
              if (__pyx_t_11) {

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":760
 *                         breakpoints_for_back_file = py_db.breakpoints.get(back_filename)
 *                         if breakpoints_for_back_file is not None:
 *                             for breakpoint in breakpoints_for_back_file.values():             # <<<<<<<<<<<<<<
 *                                 if breakpoint.func_name == f_code.co_name:
 *                                     if _should_enable_line_events_for_code(f_back,
 */
                __pyx_t_16 = 0;
                if (unlikely(__pyx_v_breakpoints_for_back_file == Py_None)) {
                  PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
                  __PYX_ERR(0, 760, __pyx_L12_error)
                }
                __pyx_t_4 = __Pyx_dict_iterator(__pyx_v_breakpoints_for_back_file, 0, __pyx_n_s_values, (&__pyx_t_17), (&__pyx_t_6)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 760, __pyx_L12_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_XDECREF(__pyx_t_5);
                __pyx_t_5 = __pyx_t_4;
                __pyx_t_4 = 0;
                while (1) {
                  __pyx_t_18 = __Pyx_dict_iter_next(__pyx_t_5, __pyx_t_17, &__pyx_t_16, NULL, &__pyx_t_4, NULL, __pyx_t_6);
                  if (unlikely(__pyx_t_18 == 0)) break;
                  if (unlikely(__pyx_t_18 == -1)) __PYX_ERR(0, 760, __pyx_L12_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __Pyx_XDECREF_SET(__pyx_v_breakpoint, __pyx_t_4);
                  __pyx_t_4 = 0;

                  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":761
 *                         if breakpoints_for_back_file is not None:
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:             # <<<<<<<<<<<<<<
 *                                     if _should_enable_line_events_for_code(f_back,
 *                                                                            f_code,
 */
                  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_breakpoint, __pyx_n_s_func_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 761, __pyx_L12_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_f_code, __pyx_n_s_co_name); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 761, __pyx_L12_error)
                  __Pyx_GOTREF(__pyx_t_7);
                  __pyx_t_13 = PyObject_RichCompare(__pyx_t_4, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 761, __pyx_L12_error)
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                  __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 761, __pyx_L12_error)
                  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                  if (__pyx_t_11) {

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":762
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:
 *                                     if _should_enable_line_events_for_code(f_back,             # <<<<<<<<<<<<<<
 *                                                                            f_code,
 *                                                                            back_filename,
 */
                    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_should_enable_line_events_for_c); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 762, __pyx_L12_error)
                    __Pyx_GOTREF(__pyx_t_7);

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":765
 *                                                                            f_code,
 *                                                                            back_filename,
 *                                                                            info):             # <<<<<<<<<<<<<<
 *                                         _enable_line_tracing(f_code)
 *                                         _enable_return_tracing(f_code)
 */
                    __pyx_t_4 = NULL;
                    __pyx_t_10 = 0;
                    #if CYTHON_UNPACK_METHODS
                    if (unlikely(PyMethod_Check(__pyx_t_7))) {
                      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
                      if (likely(__pyx_t_4)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                        __Pyx_INCREF(__pyx_t_4);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_7, function);
                        __pyx_t_10 = 1;
                      }
                    }
                    #endif
                    {
                      PyObject *__pyx_callargs[5] = {__pyx_t_4, __pyx_v_f_back, __pyx_v_f_code, __pyx_v_back_filename, __pyx_v_info};
                      __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
                      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 762, __pyx_L12_error)
                      __Pyx_GOTREF(__pyx_t_13);
                      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                    }

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":762
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:
 *                                     if _should_enable_line_events_for_code(f_back,             # <<<<<<<<<<<<<<
 *                                                                            f_code,
 *                                                                            back_filename,
 */
                    __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 762, __pyx_L12_error)
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                    if (__pyx_t_11) {

                      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":766
 *                                                                            back_filename,
 *                                                                            info):
 *                                         _enable_line_tracing(f_code)             # <<<<<<<<<<<<<<
 *                                         _enable_return_tracing(f_code)
 *                                     break
 */
                      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_enable_line_tracing); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 766, __pyx_L12_error)
                      __Pyx_GOTREF(__pyx_t_7);
                      __pyx_t_4 = NULL;
                      __pyx_t_10 = 0;
                      #if CYTHON_UNPACK_METHODS
                      if (unlikely(PyMethod_Check(__pyx_t_7))) {
                        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
                        if (likely(__pyx_t_4)) {
                          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                          __Pyx_INCREF(__pyx_t_4);
                          __Pyx_INCREF(function);
                          __Pyx_DECREF_SET(__pyx_t_7, function);
                          __pyx_t_10 = 1;
                        }
                      }
                      #endif
                      {
                        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_f_code};
                        __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
                        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 766, __pyx_L12_error)
                        __Pyx_GOTREF(__pyx_t_13);
                        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                      }
                      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

                      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":767
 *                                                                            info):
 *                                         _enable_line_tracing(f_code)
 *                                         _enable_return_tracing(f_code)             # <<<<<<<<<<<<<<
 *                                     break
 *                 if stop:
 */
                      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_enable_return_tracing); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 767, __pyx_L12_error)
                      __Pyx_GOTREF(__pyx_t_7);
                      __pyx_t_4 = NULL;
                      __pyx_t_10 = 0;
                      #if CYTHON_UNPACK_METHODS
                      if (unlikely(PyMethod_Check(__pyx_t_7))) {
                        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
                        if (likely(__pyx_t_4)) {
                          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
                          __Pyx_INCREF(__pyx_t_4);
                          __Pyx_INCREF(function);
                          __Pyx_DECREF_SET(__pyx_t_7, function);
                          __pyx_t_10 = 1;
                        }
                      }
                      #endif
                      {
                        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_f_code};
                        __pyx_t_13 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
                        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
                        if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 767, __pyx_L12_error)
                        __Pyx_GOTREF(__pyx_t_13);
                        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
                      }
                      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

                      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":762
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:
 *                                     if _should_enable_line_events_for_code(f_back,             # <<<<<<<<<<<<<<
 *                                                                            f_code,
 *                                                                            back_filename,
 */
                    }

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":768
 *                                         _enable_line_tracing(f_code)
 *                                         _enable_return_tracing(f_code)
 *                                     break             # <<<<<<<<<<<<<<
 *                 if stop:
 *                     _enable_line_tracing(f_code)
 */
                    goto __pyx_L50_break;

                    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":761
 *                         if breakpoints_for_back_file is not None:
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:             # <<<<<<<<<<<<<<
 *                                     if _should_enable_line_events_for_code(f_back,
 *                                                                            f_code,
 */
                  }
                }
                __pyx_L50_break:;
                __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

                /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":759
 *                         # Check does f_back have breakpoint and should enable line events for f_back
 *                         breakpoints_for_back_file = py_db.breakpoints.get(back_filename)
 *                         if breakpoints_for_back_file is not None:             # <<<<<<<<<<<<<<
 *                             for breakpoint in breakpoints_for_back_file.values():
 *                                 if breakpoint.func_name == f_code.co_name:
 */
              }

              /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":756
 *                     if file_type == PYDEV_FILE:
 *                         stop = False
 *                     elif not stop and step_cmd == -1:             # <<<<<<<<<<<<<<
 *                         # Check does f_back have breakpoint and should enable line events for f_back
 *                         breakpoints_for_back_file = py_db.breakpoints.get(back_filename)
 */
            }
            __pyx_L45:;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":753
 *                 base_back_filename = os.path.basename(back_filename)
 *                 file_type = get_file_type(base_back_filename)
 *                 if stop != (step_cmd == -1):             # <<<<<<<<<<<<<<
 *                     if file_type == PYDEV_FILE:
 *                         stop = False
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":769
 *                                         _enable_return_tracing(f_code)
 *                                     break
 *                 if stop:             # <<<<<<<<<<<<<<
 *                     _enable_line_tracing(f_code)
 *                     _enable_return_tracing(f_code)
 */
          __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 769, __pyx_L12_error)
          if (__pyx_t_11) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":770
 *                                     break
 *                 if stop:
 *                     _enable_line_tracing(f_code)             # <<<<<<<<<<<<<<
 *                     _enable_return_tracing(f_code)
 * 
 */
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_enable_line_tracing); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 770, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_7 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_f_code};
              __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 770, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":771
 *                 if stop:
 *                     _enable_line_tracing(f_code)
 *                     _enable_return_tracing(f_code)             # <<<<<<<<<<<<<<
 * 
 *         if plugin_stop:
 */
            __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_enable_return_tracing); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 771, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_7 = NULL;
            __pyx_t_10 = 0;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_13))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_13);
              if (likely(__pyx_t_7)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_7);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_13, function);
                __pyx_t_10 = 1;
              }
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_v_f_code};
              __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_13, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 771, __pyx_L12_error)
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            }
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":769
 *                                         _enable_return_tracing(f_code)
 *                                     break
 *                 if stop:             # <<<<<<<<<<<<<<
 *                     _enable_line_tracing(f_code)
 *                     _enable_return_tracing(f_code)
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":749
 *             f_back = frame.f_back
 *             f_code = getattr(f_back, 'f_code', None)
 *             if f_code is not None:             # <<<<<<<<<<<<<<
 *                 back_filename = f_code.co_filename
 *                 base_back_filename = os.path.basename(back_filename)
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":746
 *             stop = stop_frame is frame
 * 
 *         if hasattr(frame, "f_back"):             # <<<<<<<<<<<<<<
 *             f_back = frame.f_back
 *             f_code = getattr(f_back, 'f_code', None)
 */
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":773
 *                     _enable_return_tracing(f_code)
 * 
 *         if plugin_stop:             # <<<<<<<<<<<<<<
 *             py_db.plugin.stop(py_db, frame, 'return', args, stop_info, None, step_cmd)
 *         elif stop:
 */
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_plugin_stop); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 773, __pyx_L12_error)
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":774
 * 
 *         if plugin_stop:
 *             py_db.plugin.stop(py_db, frame, 'return', args, stop_info, None, step_cmd)             # <<<<<<<<<<<<<<
 *         elif stop:
 *             back = frame.f_back
 */
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_plugin); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 774, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_n_s_stop); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 774, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = NULL;
        __pyx_t_10 = 0;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
          if (likely(__pyx_t_13)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_7, function);
            __pyx_t_10 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[8] = {__pyx_t_13, __pyx_v_py_db, __pyx_v_frame, __pyx_n_s_return, __pyx_v_args, __pyx_v_stop_info, Py_None, __pyx_v_step_cmd};
          __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 7+__pyx_t_10);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 774, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":773
 *                     _enable_return_tracing(f_code)
 * 
 *         if plugin_stop:             # <<<<<<<<<<<<<<
 *             py_db.plugin.stop(py_db, frame, 'return', args, stop_info, None, step_cmd)
 *         elif stop:
 */
        goto __pyx_L54;
      }

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":775
 *         if plugin_stop:
 *             py_db.plugin.stop(py_db, frame, 'return', args, stop_info, None, step_cmd)
 *         elif stop:             # <<<<<<<<<<<<<<
 *             back = frame.f_back
 *             if back is not None:
 */
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_stop); if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(0, 775, __pyx_L12_error)
      if (__pyx_t_11) {

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":776
 *             py_db.plugin.stop(py_db, frame, 'return', args, stop_info, None, step_cmd)
 *         elif stop:
 *             back = frame.f_back             # <<<<<<<<<<<<<<
 *             if back is not None:
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)
 */
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_frame, __pyx_n_s_f_back); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 776, __pyx_L12_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_XDECREF_SET(__pyx_v_back, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":777
 *         elif stop:
 *             back = frame.f_back
 *             if back is not None:             # <<<<<<<<<<<<<<
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)
 *                 if (base, back.f_code.co_name) in (DEBUG_START, DEBUG_START_PY3K):
 */
        __pyx_t_11 = (__pyx_v_back != Py_None);
        if (__pyx_t_11) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":778
 *             back = frame.f_back
 *             if back is not None:
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)             # <<<<<<<<<<<<<<
 *                 if (base, back.f_code.co_name) in (DEBUG_START, DEBUG_START_PY3K):
 *                     back = None
 */
          __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_get_abs_path_real_path_and_base); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 778, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_7);
          __pyx_t_13 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_7))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_7);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_7, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_v_back};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_7, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 778, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          }
          if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
            PyObject* sequence = __pyx_t_5;
            Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
            if (unlikely(size != 3)) {
              if (size > 3) __Pyx_RaiseTooManyValuesError(3);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              __PYX_ERR(0, 778, __pyx_L12_error)
            }
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_13 = PyTuple_GET_ITEM(sequence, 1); 
              __pyx_t_4 = PyTuple_GET_ITEM(sequence, 2); 
            } else {
              __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_13 = PyList_GET_ITEM(sequence, 1); 
              __pyx_t_4 = PyList_GET_ITEM(sequence, 2); 
            }
            __Pyx_INCREF(__pyx_t_7);
            __Pyx_INCREF(__pyx_t_13);
            __Pyx_INCREF(__pyx_t_4);
            #else
            __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 778, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_7);
            __pyx_t_13 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 778, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_4 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 778, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_4);
            #endif
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_14 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 778, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
            __pyx_t_12 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_14);
            index = 0; __pyx_t_7 = __pyx_t_12(__pyx_t_14); if (unlikely(!__pyx_t_7)) goto __pyx_L56_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_7);
            index = 1; __pyx_t_13 = __pyx_t_12(__pyx_t_14); if (unlikely(!__pyx_t_13)) goto __pyx_L56_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_13);
            index = 2; __pyx_t_4 = __pyx_t_12(__pyx_t_14); if (unlikely(!__pyx_t_4)) goto __pyx_L56_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_4);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_12(__pyx_t_14), 3) < 0) __PYX_ERR(0, 778, __pyx_L12_error)
            __pyx_t_12 = NULL;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            goto __pyx_L57_unpacking_done;
            __pyx_L56_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_12 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            __PYX_ERR(0, 778, __pyx_L12_error)
            __pyx_L57_unpacking_done:;
          }
          __pyx_v__ = __pyx_t_7;
          __pyx_t_7 = 0;
          __Pyx_XDECREF_SET(__pyx_v_base_back_filename, __pyx_t_13);
          __pyx_t_13 = 0;
          __pyx_v_base = __pyx_t_4;
          __pyx_t_4 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":779
 *             if back is not None:
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)
 *                 if (base, back.f_code.co_name) in (DEBUG_START, DEBUG_START_PY3K):             # <<<<<<<<<<<<<<
 *                     back = None
 * 
 */
          __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_back, __pyx_n_s_f_code); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_co_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_INCREF(__pyx_v_base);
          __Pyx_GIVEREF(__pyx_v_base);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_base)) __PYX_ERR(0, 779, __pyx_L12_error);
          __Pyx_GIVEREF(__pyx_t_4);
          if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4)) __PYX_ERR(0, 779, __pyx_L12_error);
          __pyx_t_4 = 0;
          __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_DEBUG_START); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_13 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (!__pyx_t_15) {
          } else {
            __pyx_t_11 = __pyx_t_15;
            goto __pyx_L59_bool_binop_done;
          }
          __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_n_s_DEBUG_START_PY3K); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_t_13, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __pyx_t_15 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_15 < 0))) __PYX_ERR(0, 779, __pyx_L12_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_t_11 = __pyx_t_15;
          __pyx_L59_bool_binop_done:;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __pyx_t_15 = __pyx_t_11;
          if (__pyx_t_15) {

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":780
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)
 *                 if (base, back.f_code.co_name) in (DEBUG_START, DEBUG_START_PY3K):
 *                     back = None             # <<<<<<<<<<<<<<
 * 
 *             if back is not None:
 */
            __Pyx_INCREF(Py_None);
            __Pyx_DECREF_SET(__pyx_v_back, Py_None);

            /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":779
 *             if back is not None:
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)
 *                 if (base, back.f_code.co_name) in (DEBUG_START, DEBUG_START_PY3K):             # <<<<<<<<<<<<<<
 *                     back = None
 * 
 */
          }

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":777
 *         elif stop:
 *             back = frame.f_back
 *             if back is not None:             # <<<<<<<<<<<<<<
 *                 _, base_back_filename, base = get_abs_path_real_path_and_base_from_frame(back)
 *                 if (base, back.f_code.co_name) in (DEBUG_START, DEBUG_START_PY3K):
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":782
 *                     back = None
 * 
 *             if back is not None:             # <<<<<<<<<<<<<<
 *                 # if we're in a return, we want it to appear to the user in the previous frame!
 *                 py_db.set_suspend(thread, step_cmd)
 */
        __pyx_t_15 = (__pyx_v_back != Py_None);
        if (__pyx_t_15) {

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":784
 *             if back is not None:
 *                 # if we're in a return, we want it to appear to the user in the previous frame!
 *                 py_db.set_suspend(thread, step_cmd)             # <<<<<<<<<<<<<<
 *                 py_db.do_wait_suspend(thread, back, 'return', retval)
 *     except KeyboardInterrupt:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_set_suspend); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 784, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_13 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[3] = {__pyx_t_13, __pyx_v_thread, __pyx_v_step_cmd};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 2+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 784, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":785
 *                 # if we're in a return, we want it to appear to the user in the previous frame!
 *                 py_db.set_suspend(thread, step_cmd)
 *                 py_db.do_wait_suspend(thread, back, 'return', retval)             # <<<<<<<<<<<<<<
 *     except KeyboardInterrupt:
 *         _clear_run_state(info)
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_py_db, __pyx_n_s_do_wait_suspend); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 785, __pyx_L12_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_13 = NULL;
          __pyx_t_10 = 0;
          #if CYTHON_UNPACK_METHODS
          if (likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
              __pyx_t_10 = 1;
            }
          }
          #endif
          {
            PyObject *__pyx_callargs[5] = {__pyx_t_13, __pyx_v_thread, __pyx_v_back, __pyx_n_s_return, __pyx_v_retval};
            __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_10, 4+__pyx_t_10);
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 785, __pyx_L12_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          }
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

          /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":782
 *                     back = None
 * 
 *             if back is not None:             # <<<<<<<<<<<<<<
 *                 # if we're in a return, we want it to appear to the user in the previous frame!
 *                 py_db.set_suspend(thread, step_cmd)
 */
        }

        /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":775
 *         if plugin_stop:
 *             py_db.plugin.stop(py_db, frame, 'return', args, stop_info, None, step_cmd)
 *         elif stop:             # <<<<<<<<<<<<<<
 *             back = frame.f_back
 *             if back is not None:
 */
      }
      __pyx_L54:;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":705
 *     smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db.show_return_values or py_db.remove_return_values_flag:
 *             manage_return_values(py_db, frame, 'return', retval)
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L17_try_end;
    __pyx_L12_error:;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":786
 *                 py_db.set_suspend(thread, step_cmd)
 *                 py_db.do_wait_suspend(thread, back, 'return', retval)
 *     except KeyboardInterrupt:             # <<<<<<<<<<<<<<
 *         _clear_run_state(info)
 *         raise
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_KeyboardInterrupt);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_return_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_13) < 0) __PYX_ERR(0, 786, __pyx_L14_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_13);

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":787
 *                 py_db.do_wait_suspend(thread, back, 'return', retval)
 *     except KeyboardInterrupt:
 *         _clear_run_state(info)             # <<<<<<<<<<<<<<
 *         raise
 */
      __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_n_s_clear_run_state); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 787, __pyx_L14_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_19 = NULL;
      __pyx_t_10 = 0;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_19 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_19)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_19);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
          __pyx_t_10 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_19, __pyx_v_info};
        __pyx_t_7 = __Pyx_PyObject_FastCall(__pyx_t_14, __pyx_callargs+1-__pyx_t_10, 1+__pyx_t_10);
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 787, __pyx_L14_except_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      }
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":788
 *     except KeyboardInterrupt:
 *         _clear_run_state(info)
 *         raise             # <<<<<<<<<<<<<<
 */
      __Pyx_GIVEREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_4, __pyx_t_13);
      __pyx_t_5 = 0; __pyx_t_4 = 0; __pyx_t_13 = 0; 
      __PYX_ERR(0, 788, __pyx_L14_except_error)
    }
    goto __pyx_L14_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":705
 *     smart_stop_frame = info.pydev_smart_step_context.smart_step_stop
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         if py_db.show_return_values or py_db.remove_return_values_flag:
 *             manage_return_values(py_db, frame, 'return', retval)
 */
    __pyx_L14_except_error:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    goto __pyx_L1_error;
    __pyx_L17_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":684
 * 
 * 
 * def py_return_callback(code, instruction_offset, retval):             # <<<<<<<<<<<<<<
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_19);
  __Pyx_AddTraceback("_pydevd_bundle.pydevd_pep_669_tracing_cython.py_return_callback", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_py_db);
  __Pyx_XDECREF(__pyx_v_frame);
  __Pyx_XDECREF(__pyx_v_thread);
  __Pyx_XDECREF(__pyx_v_info);
  __Pyx_XDECREF(__pyx_v_stop_frame);
  __Pyx_XDECREF(__pyx_v_filename);
  __Pyx_XDECREF(__pyx_v_plugin_stop);
  __Pyx_XDECREF(__pyx_v_args);
  __Pyx_XDECREF(__pyx_v_stop_info);
  __Pyx_XDECREF(__pyx_v_stop);
  __Pyx_XDECREF(__pyx_v_smart_stop_frame);
  __Pyx_XDECREF(__pyx_v_step_cmd);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_back);
  __Pyx_XDECREF(__pyx_v_back_code);
  __Pyx_XDECREF(__pyx_v_f_back);
  __Pyx_XDECREF(__pyx_v_f_code);
  __Pyx_XDECREF(__pyx_v_back_filename);
  __Pyx_XDECREF(__pyx_v_base_back_filename);
  __Pyx_XDECREF(__pyx_v_file_type);
  __Pyx_XDECREF(__pyx_v_breakpoints_for_back_file);
  __Pyx_XDECREF(__pyx_v_breakpoint);
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_base);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
    {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
    {&__pyx_n_s_ADD, __pyx_k_ADD, sizeof(__pyx_k_ADD), 0, 0, 1, 1},
    {&__pyx_n_s_ALL, __pyx_k_ALL, sizeof(__pyx_k_ALL), 0, 0, 1, 1},
    {&__pyx_n_s_AttributeError, __pyx_k_AttributeError, sizeof(__pyx_k_AttributeError), 0, 0, 1, 1},
    {&__pyx_n_s_CALL, __pyx_k_CALL, sizeof(__pyx_k_CALL), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_SET_BREAK, __pyx_k_CMD_SET_BREAK, sizeof(__pyx_k_CMD_SET_BREAK), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_SMART_STEP_INTO, __pyx_k_CMD_SMART_STEP_INTO, sizeof(__pyx_k_CMD_SMART_STEP_INTO), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_STEP_INTO, __pyx_k_CMD_STEP_INTO, sizeof(__pyx_k_CMD_STEP_INTO), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_STEP_INTO_COROUTINE, __pyx_k_CMD_STEP_INTO_COROUTINE, sizeof(__pyx_k_CMD_STEP_INTO_COROUTINE), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_STEP_INTO_MY_CODE, __pyx_k_CMD_STEP_INTO_MY_CODE, sizeof(__pyx_k_CMD_STEP_INTO_MY_CODE), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_STEP_OVER, __pyx_k_CMD_STEP_OVER, sizeof(__pyx_k_CMD_STEP_OVER), 0, 0, 1, 1},
    {&__pyx_n_s_CMD_STEP_RETURN, __pyx_k_CMD_STEP_RETURN, sizeof(__pyx_k_CMD_STEP_RETURN), 0, 0, 1, 1},
    {&__pyx_n_s_DEBUGGER_ID, __pyx_k_DEBUGGER_ID, sizeof(__pyx_k_DEBUGGER_ID), 0, 0, 1, 1},
    {&__pyx_n_s_DEBUG_START, __pyx_k_DEBUG_START, sizeof(__pyx_k_DEBUG_START), 0, 0, 1, 1},
    {&__pyx_n_s_DEBUG_START_PY3K, __pyx_k_DEBUG_START_PY3K, sizeof(__pyx_k_DEBUG_START_PY3K), 0, 0, 1, 1},
    {&__pyx_n_s_DISABLE, __pyx_k_DISABLE, sizeof(__pyx_k_DISABLE), 0, 0, 1, 1},
    {&__pyx_n_s_DONT_TRACE, __pyx_k_DONT_TRACE, sizeof(__pyx_k_DONT_TRACE), 0, 0, 1, 1},
    {&__pyx_n_s_EVENT_ACTIONS, __pyx_k_EVENT_ACTIONS, sizeof(__pyx_k_EVENT_ACTIONS), 0, 0, 1, 1},
    {&__pyx_kp_s_Exception_while_handling_smart_s, __pyx_k_Exception_while_handling_smart_s, sizeof(__pyx_k_Exception_while_handling_smart_s), 0, 0, 1, 0},
    {&__pyx_n_s_GlobalDebuggerHolder, __pyx_k_GlobalDebuggerHolder, sizeof(__pyx_k_GlobalDebuggerHolder), 0, 0, 1, 1},
    {&__pyx_n_s_IS_CPYTHON, __pyx_k_IS_CPYTHON, sizeof(__pyx_k_IS_CPYTHON), 0, 0, 1, 1},
    {&__pyx_n_s_KeyboardInterrupt, __pyx_k_KeyboardInterrupt, sizeof(__pyx_k_KeyboardInterrupt), 0, 0, 1, 1},
    {&__pyx_n_s_LINE, __pyx_k_LINE, sizeof(__pyx_k_LINE), 0, 0, 1, 1},
    {&__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER, __pyx_k_NORM_PATHS_AND_BASE_CONTAINER, sizeof(__pyx_k_NORM_PATHS_AND_BASE_CONTAINER), 0, 0, 1, 1},
    {&__pyx_n_s_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 0, 1, 1},
    {&__pyx_n_s_PYDEVD_TOOL_NAME, __pyx_k_PYDEVD_TOOL_NAME, sizeof(__pyx_k_PYDEVD_TOOL_NAME), 0, 0, 1, 1},
    {&__pyx_n_s_PYDEV_FILE, __pyx_k_PYDEV_FILE, sizeof(__pyx_k_PYDEV_FILE), 0, 0, 1, 1},
    {&__pyx_n_s_PY_RETURN, __pyx_k_PY_RETURN, sizeof(__pyx_k_PY_RETURN), 0, 0, 1, 1},
    {&__pyx_n_s_PY_START, __pyx_k_PY_START, sizeof(__pyx_k_PY_START), 0, 0, 1, 1},
    {&__pyx_n_s_RAISE, __pyx_k_RAISE, sizeof(__pyx_k_RAISE), 0, 0, 1, 1},
    {&__pyx_n_s_REMOVE, __pyx_k_REMOVE, sizeof(__pyx_k_REMOVE), 0, 0, 1, 1},
    {&__pyx_n_s_STATE_RUN, __pyx_k_STATE_RUN, sizeof(__pyx_k_STATE_RUN), 0, 0, 1, 1},
    {&__pyx_n_s_STATE_SUSPEND, __pyx_k_STATE_SUSPEND, sizeof(__pyx_k_STATE_SUSPEND), 0, 0, 1, 1},
    {&__pyx_n_s_SystemExit, __pyx_k_SystemExit, sizeof(__pyx_k_SystemExit), 0, 0, 1, 1},
    {&__pyx_kp_s__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 1, 0},
    {&__pyx_n_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 1},
    {&__pyx_n_s__31, __pyx_k__31, sizeof(__pyx_k__31), 0, 0, 1, 1},
    {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
    {&__pyx_n_s_abs_path_real_path_and_base, __pyx_k_abs_path_real_path_and_base, sizeof(__pyx_k_abs_path_real_path_and_base), 0, 0, 1, 1},
    {&__pyx_n_s_action, __pyx_k_action, sizeof(__pyx_k_action), 0, 0, 1, 1},
    {&__pyx_n_s_add_command, __pyx_k_add_command, sizeof(__pyx_k_add_command), 0, 0, 1, 1},
    {&__pyx_n_s_add_new_breakpoint, __pyx_k_add_new_breakpoint, sizeof(__pyx_k_add_new_breakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_additional_info, __pyx_k_additional_info, sizeof(__pyx_k_additional_info), 0, 0, 1, 1},
    {&__pyx_n_s_arg0, __pyx_k_arg0, sizeof(__pyx_k_arg0), 0, 0, 1, 1},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_analyser, __pyx_k_asyncio_analyser, sizeof(__pyx_k_asyncio_analyser), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_back, __pyx_k_back, sizeof(__pyx_k_back), 0, 0, 1, 1},
    {&__pyx_n_s_back_code, __pyx_k_back_code, sizeof(__pyx_k_back_code), 0, 0, 1, 1},
    {&__pyx_n_s_back_filename, __pyx_k_back_filename, sizeof(__pyx_k_back_filename), 0, 0, 1, 1},
    {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
    {&__pyx_n_s_base_back_filename, __pyx_k_base_back_filename, sizeof(__pyx_k_base_back_filename), 0, 0, 1, 1},
    {&__pyx_n_s_basename, __pyx_k_basename, sizeof(__pyx_k_basename), 0, 0, 1, 1},
    {&__pyx_n_s_bootstrap_inner, __pyx_k_bootstrap_inner, sizeof(__pyx_k_bootstrap_inner), 0, 0, 1, 1},
    {&__pyx_n_s_bp_type, __pyx_k_bp_type, sizeof(__pyx_k_bp_type), 0, 0, 1, 1},
    {&__pyx_n_s_break_on_caught_exceptions, __pyx_k_break_on_caught_exceptions, sizeof(__pyx_k_break_on_caught_exceptions), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoint, __pyx_k_breakpoint, sizeof(__pyx_k_breakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoints, __pyx_k_breakpoints, sizeof(__pyx_k_breakpoints), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoints_for_back_file, __pyx_k_breakpoints_for_back_file, sizeof(__pyx_k_breakpoints_for_back_file), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoints_for_file, __pyx_k_breakpoints_for_file, sizeof(__pyx_k_breakpoints_for_file), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoints_in_frame_cache, __pyx_k_breakpoints_in_frame_cache, sizeof(__pyx_k_breakpoints_in_frame_cache), 0, 0, 1, 1},
    {&__pyx_n_s_breakpoints_in_line_cache, __pyx_k_breakpoints_in_line_cache, sizeof(__pyx_k_breakpoints_in_line_cache), 0, 0, 1, 1},
    {&__pyx_n_s_call, __pyx_k_call, sizeof(__pyx_k_call), 0, 0, 1, 1},
    {&__pyx_n_s_call_callback, __pyx_k_call_callback, sizeof(__pyx_k_call_callback), 0, 0, 1, 1},
    {&__pyx_n_s_call_order, __pyx_k_call_order, sizeof(__pyx_k_call_order), 0, 0, 1, 1},
    {&__pyx_n_s_callable, __pyx_k_callable, sizeof(__pyx_k_callable), 0, 0, 1, 1},
    {&__pyx_n_s_callback, __pyx_k_callback, sizeof(__pyx_k_callback), 0, 0, 1, 1},
    {&__pyx_n_s_can_not_skip, __pyx_k_can_not_skip, sizeof(__pyx_k_can_not_skip), 0, 0, 1, 1},
    {&__pyx_n_s_can_skip, __pyx_k_can_skip, sizeof(__pyx_k_can_skip), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_clear_run_state, __pyx_k_clear_run_state, sizeof(__pyx_k_clear_run_state), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_cmd, __pyx_k_cmd, sizeof(__pyx_k_cmd), 0, 0, 1, 1},
    {&__pyx_n_s_cmd_factory, __pyx_k_cmd_factory, sizeof(__pyx_k_cmd_factory), 0, 0, 1, 1},
    {&__pyx_n_s_cmd_step_into, __pyx_k_cmd_step_into, sizeof(__pyx_k_cmd_step_into), 0, 0, 1, 1},
    {&__pyx_n_s_cmd_step_over, __pyx_k_cmd_step_over, sizeof(__pyx_k_cmd_step_over), 0, 0, 1, 1},
    {&__pyx_n_s_co_filename, __pyx_k_co_filename, sizeof(__pyx_k_co_filename), 0, 0, 1, 1},
    {&__pyx_n_s_co_firstlineno, __pyx_k_co_firstlineno, sizeof(__pyx_k_co_firstlineno), 0, 0, 1, 1},
    {&__pyx_n_s_co_name, __pyx_k_co_name, sizeof(__pyx_k_co_name), 0, 0, 1, 1},
    {&__pyx_n_s_code, __pyx_k_code, sizeof(__pyx_k_code), 0, 0, 1, 1},
    {&__pyx_n_s_context_end_line, __pyx_k_context_end_line, sizeof(__pyx_k_context_end_line), 0, 0, 1, 1},
    {&__pyx_n_s_context_start_line, __pyx_k_context_start_line, sizeof(__pyx_k_context_start_line), 0, 0, 1, 1},
    {&__pyx_n_s_curr_func_name, __pyx_k_curr_func_name, sizeof(__pyx_k_curr_func_name), 0, 0, 1, 1},
    {&__pyx_n_s_current_events, __pyx_k_current_events, sizeof(__pyx_k_current_events), 0, 0, 1, 1},
    {&__pyx_n_s_current_thread, __pyx_k_current_thread, sizeof(__pyx_k_current_thread), 0, 0, 1, 1},
    {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
    {&__pyx_n_s_debugger, __pyx_k_debugger, sizeof(__pyx_k_debugger), 0, 0, 1, 1},
    {&__pyx_n_s_do_wait_suspend, __pyx_k_do_wait_suspend, sizeof(__pyx_k_do_wait_suspend), 0, 0, 1, 1},
    {&__pyx_n_s_enable_line_tracing, __pyx_k_enable_line_tracing, sizeof(__pyx_k_enable_line_tracing), 0, 0, 1, 1},
    {&__pyx_n_s_enable_pep669_monitoring, __pyx_k_enable_pep669_monitoring, sizeof(__pyx_k_enable_pep669_monitoring), 0, 0, 1, 1},
    {&__pyx_n_s_enable_return_tracing, __pyx_k_enable_return_tracing, sizeof(__pyx_k_enable_return_tracing), 0, 0, 1, 1},
    {&__pyx_n_s_end_line, __pyx_k_end_line, sizeof(__pyx_k_end_line), 0, 0, 1, 1},
    {&__pyx_n_s_eval_result, __pyx_k_eval_result, sizeof(__pyx_k_eval_result), 0, 0, 1, 1},
    {&__pyx_n_s_event, __pyx_k_event, sizeof(__pyx_k_event), 0, 0, 1, 1},
    {&__pyx_n_s_event_type, __pyx_k_event_type, sizeof(__pyx_k_event_type), 0, 0, 1, 1},
    {&__pyx_n_s_events, __pyx_k_events, sizeof(__pyx_k_events), 0, 0, 1, 1},
    {&__pyx_n_s_exc_info, __pyx_k_exc_info, sizeof(__pyx_k_exc_info), 0, 0, 1, 1},
    {&__pyx_n_s_exception, __pyx_k_exception, sizeof(__pyx_k_exception), 0, 0, 1, 1},
    {&__pyx_n_s_exec, __pyx_k_exec, sizeof(__pyx_k_exec), 0, 0, 1, 1},
    {&__pyx_n_s_exist_result, __pyx_k_exist_result, sizeof(__pyx_k_exist_result), 0, 0, 1, 1},
    {&__pyx_n_s_expression, __pyx_k_expression, sizeof(__pyx_k_expression), 0, 0, 1, 1},
    {&__pyx_n_s_f_back, __pyx_k_f_back, sizeof(__pyx_k_f_back), 0, 0, 1, 1},
    {&__pyx_n_s_f_code, __pyx_k_f_code, sizeof(__pyx_k_f_code), 0, 0, 1, 1},
    {&__pyx_n_s_f_lineno, __pyx_k_f_lineno, sizeof(__pyx_k_f_lineno), 0, 0, 1, 1},
    {&__pyx_n_s_f_unhandled, __pyx_k_f_unhandled, sizeof(__pyx_k_f_unhandled), 0, 0, 1, 1},
    {&__pyx_n_s_file_type, __pyx_k_file_type, sizeof(__pyx_k_file_type), 0, 0, 1, 1},
    {&__pyx_n_s_filename, __pyx_k_filename, sizeof(__pyx_k_filename), 0, 0, 1, 1},
    {&__pyx_n_s_find_last_call_name, __pyx_k_find_last_call_name, sizeof(__pyx_k_find_last_call_name), 0, 0, 1, 1},
    {&__pyx_n_s_find_last_func_call_order, __pyx_k_find_last_func_call_order, sizeof(__pyx_k_find_last_func_call_order), 0, 0, 1, 1},
    {&__pyx_n_s_finish_debugging_session, __pyx_k_finish_debugging_session, sizeof(__pyx_k_finish_debugging_session), 0, 0, 1, 1},
    {&__pyx_n_s_flag, __pyx_k_flag, sizeof(__pyx_k_flag), 0, 0, 1, 1},
    {&__pyx_n_s_frame, __pyx_k_frame, sizeof(__pyx_k_frame), 0, 0, 1, 1},
    {&__pyx_n_s_frame_cache_key, __pyx_k_frame_cache_key, sizeof(__pyx_k_frame_cache_key), 0, 0, 1, 1},
    {&__pyx_n_s_func_name, __pyx_k_func_name, sizeof(__pyx_k_func_name), 0, 0, 1, 1},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_get_abs_path_real_path_and_base, __pyx_k_get_abs_path_real_path_and_base, sizeof(__pyx_k_get_abs_path_real_path_and_base), 0, 0, 1, 1},
    {&__pyx_n_s_get_abs_path_real_path_and_base_2, __pyx_k_get_abs_path_real_path_and_base_2, sizeof(__pyx_k_get_abs_path_real_path_and_base_2), 0, 0, 1, 1},
    {&__pyx_n_s_get_additional_info, __pyx_k_get_additional_info, sizeof(__pyx_k_get_additional_info), 0, 0, 1, 1},
    {&__pyx_n_s_get_breakpoint, __pyx_k_get_breakpoint, sizeof(__pyx_k_get_breakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_get_current_thread, __pyx_k_get_current_thread, sizeof(__pyx_k_get_current_thread), 0, 0, 1, 1},
    {&__pyx_n_s_get_events, __pyx_k_get_events, sizeof(__pyx_k_get_events), 0, 0, 1, 1},
    {&__pyx_n_s_get_file_type, __pyx_k_get_file_type, sizeof(__pyx_k_get_file_type), 0, 0, 1, 1},
    {&__pyx_n_s_get_local_events, __pyx_k_get_local_events, sizeof(__pyx_k_get_local_events), 0, 0, 1, 1},
    {&__pyx_n_s_get_tool, __pyx_k_get_tool, sizeof(__pyx_k_get_tool), 0, 0, 1, 1},
    {&__pyx_n_s_get_top_level_frame, __pyx_k_get_top_level_frame, sizeof(__pyx_k_get_top_level_frame), 0, 0, 1, 1},
    {&__pyx_n_s_getframe, __pyx_k_getframe, sizeof(__pyx_k_getframe), 0, 0, 1, 1},
    {&__pyx_n_s_global_cache_frame_skips, __pyx_k_global_cache_frame_skips, sizeof(__pyx_k_global_cache_frame_skips), 0, 0, 1, 1},
    {&__pyx_n_s_global_cache_skips, __pyx_k_global_cache_skips, sizeof(__pyx_k_global_cache_skips), 0, 0, 1, 1},
    {&__pyx_n_s_global_dbg, __pyx_k_global_dbg, sizeof(__pyx_k_global_dbg), 0, 0, 1, 1},
    {&__pyx_n_s_handle_breakpoint_condition, __pyx_k_handle_breakpoint_condition, sizeof(__pyx_k_handle_breakpoint_condition), 0, 0, 1, 1},
    {&__pyx_n_s_handle_breakpoint_expression, __pyx_k_handle_breakpoint_expression, sizeof(__pyx_k_handle_breakpoint_expression), 0, 0, 1, 1},
    {&__pyx_n_s_handle_exception, __pyx_k_handle_exception, sizeof(__pyx_k_handle_exception), 0, 0, 1, 1},
    {&__pyx_n_s_has_breakpoint_in_frame, __pyx_k_has_breakpoint_in_frame, sizeof(__pyx_k_has_breakpoint_in_frame), 0, 0, 1, 1},
    {&__pyx_n_s_has_condition, __pyx_k_has_condition, sizeof(__pyx_k_has_condition), 0, 0, 1, 1},
    {&__pyx_n_s_has_exception_breakpoints, __pyx_k_has_exception_breakpoints, sizeof(__pyx_k_has_exception_breakpoints), 0, 0, 1, 1},
    {&__pyx_n_s_has_plugin_exception_breaks, __pyx_k_has_plugin_exception_breaks, sizeof(__pyx_k_has_plugin_exception_breaks), 0, 0, 1, 1},
    {&__pyx_n_s_has_plugin_line_breaks, __pyx_k_has_plugin_line_breaks, sizeof(__pyx_k_has_plugin_line_breaks), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_in_project_scope, __pyx_k_in_project_scope, sizeof(__pyx_k_in_project_scope), 0, 0, 1, 1},
    {&__pyx_n_s_info, __pyx_k_info, sizeof(__pyx_k_info), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_instruction_offset, __pyx_k_instruction_offset, sizeof(__pyx_k_instruction_offset), 0, 0, 1, 1},
    {&__pyx_kp_s_invalid, __pyx_k_invalid, sizeof(__pyx_k_invalid), 0, 0, 1, 0},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_n_s_is_filter_enabled, __pyx_k_is_filter_enabled, sizeof(__pyx_k_is_filter_enabled), 0, 0, 1, 1},
    {&__pyx_n_s_is_filter_libraries, __pyx_k_is_filter_libraries, sizeof(__pyx_k_is_filter_libraries), 0, 0, 1, 1},
    {&__pyx_n_s_is_ignored_by_filters, __pyx_k_is_ignored_by_filters, sizeof(__pyx_k_is_ignored_by_filters), 0, 0, 1, 1},
    {&__pyx_n_s_is_logpoint, __pyx_k_is_logpoint, sizeof(__pyx_k_is_logpoint), 0, 0, 1, 1},
    {&__pyx_n_s_is_pep669_monitoring_enabled, __pyx_k_is_pep669_monitoring_enabled, sizeof(__pyx_k_is_pep669_monitoring_enabled), 0, 0, 1, 1},
    {&__pyx_n_s_is_stepping, __pyx_k_is_stepping, sizeof(__pyx_k_is_stepping), 0, 0, 1, 1},
    {&__pyx_n_s_is_thread_alive, __pyx_k_is_thread_alive, sizeof(__pyx_k_is_thread_alive), 0, 0, 1, 1},
    {&__pyx_n_s_is_tracing, __pyx_k_is_tracing, sizeof(__pyx_k_is_tracing), 0, 0, 1, 1},
    {&__pyx_n_s_is_within_context, __pyx_k_is_within_context, sizeof(__pyx_k_is_within_context), 0, 0, 1, 1},
    {&__pyx_kp_s_lambda, __pyx_k_lambda, sizeof(__pyx_k_lambda), 0, 0, 1, 0},
    {&__pyx_n_s_line, __pyx_k_line, sizeof(__pyx_k_line), 0, 0, 1, 1},
    {&__pyx_n_s_line_cache_key, __pyx_k_line_cache_key, sizeof(__pyx_k_line_cache_key), 0, 0, 1, 1},
    {&__pyx_n_s_line_number, __pyx_k_line_number, sizeof(__pyx_k_line_number), 0, 0, 1, 1},
    {&__pyx_n_s_linesep, __pyx_k_linesep, sizeof(__pyx_k_linesep), 0, 0, 1, 1},
    {&__pyx_n_s_local_events, __pyx_k_local_events, sizeof(__pyx_k_local_events), 0, 0, 1, 1},
    {&__pyx_n_s_log_event, __pyx_k_log_event, sizeof(__pyx_k_log_event), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_make_frame_cache_key, __pyx_k_make_frame_cache_key, sizeof(__pyx_k_make_frame_cache_key), 0, 0, 1, 1},
    {&__pyx_n_s_make_io_message, __pyx_k_make_io_message, sizeof(__pyx_k_make_io_message), 0, 0, 1, 1},
    {&__pyx_n_s_manage_return_values, __pyx_k_manage_return_values, sizeof(__pyx_k_manage_return_values), 0, 0, 1, 1},
    {&__pyx_n_s_modify_global_events, __pyx_k_modify_global_events, sizeof(__pyx_k_modify_global_events), 0, 0, 1, 1},
    {&__pyx_kp_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 0},
    {&__pyx_n_s_monitoring, __pyx_k_monitoring, sizeof(__pyx_k_monitoring), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_s_new_frame, __pyx_k_new_frame, sizeof(__pyx_k_new_frame), 0, 0, 1, 1},
    {&__pyx_n_s_not_processed, __pyx_k_not_processed, sizeof(__pyx_k_not_processed), 0, 0, 1, 1},
    {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
    {&__pyx_n_s_os_path, __pyx_k_os_path, sizeof(__pyx_k_os_path), 0, 0, 1, 1},
    {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
    {&__pyx_n_s_plugin, __pyx_k_plugin, sizeof(__pyx_k_plugin), 0, 0, 1, 1},
    {&__pyx_n_s_plugin_manager, __pyx_k_plugin_manager, sizeof(__pyx_k_plugin_manager), 0, 0, 1, 1},
    {&__pyx_n_s_plugin_stop, __pyx_k_plugin_stop, sizeof(__pyx_k_plugin_stop), 0, 0, 1, 1},
    {&__pyx_n_s_print_exc, __pyx_k_print_exc, sizeof(__pyx_k_print_exc), 0, 0, 1, 1},
    {&__pyx_n_s_py_db, __pyx_k_py_db, sizeof(__pyx_k_py_db), 0, 0, 1, 1},
    {&__pyx_n_s_py_line_callback, __pyx_k_py_line_callback, sizeof(__pyx_k_py_line_callback), 0, 0, 1, 1},
    {&__pyx_n_s_py_raise_callback, __pyx_k_py_raise_callback, sizeof(__pyx_k_py_raise_callback), 0, 0, 1, 1},
    {&__pyx_n_s_py_return_callback, __pyx_k_py_return_callback, sizeof(__pyx_k_py_return_callback), 0, 0, 1, 1},
    {&__pyx_n_s_py_start_callback, __pyx_k_py_start_callback, sizeof(__pyx_k_py_start_callback), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_bundle, __pyx_k_pydev_bundle, sizeof(__pyx_k_pydev_bundle), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_bundle_pydev_is_thread_al, __pyx_k_pydev_bundle_pydev_is_thread_al, sizeof(__pyx_k_pydev_bundle_pydev_is_thread_al), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_func_name, __pyx_k_pydev_func_name, sizeof(__pyx_k_pydev_func_name), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_log, __pyx_k_pydev_log, sizeof(__pyx_k_pydev_log), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_message, __pyx_k_pydev_message, sizeof(__pyx_k_pydev_message), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_smart_step_context, __pyx_k_pydev_smart_step_context, sizeof(__pyx_k_pydev_smart_step_context), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_state, __pyx_k_pydev_state, sizeof(__pyx_k_pydev_state), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_step_cmd, __pyx_k_pydev_step_cmd, sizeof(__pyx_k_pydev_step_cmd), 0, 0, 1, 1},
    {&__pyx_n_s_pydev_step_stop, __pyx_k_pydev_step_stop, sizeof(__pyx_k_pydev_step_stop), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd, __pyx_k_pydevd, sizeof(__pyx_k_pydevd), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_bundle_pydevd_breakpoint, __pyx_k_pydevd_bundle_pydevd_breakpoint, sizeof(__pyx_k_pydevd_bundle_pydevd_breakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_bundle_pydevd_bytecode_u, __pyx_k_pydevd_bundle_pydevd_bytecode_u, sizeof(__pyx_k_pydevd_bundle_pydevd_bytecode_u), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_bundle_pydevd_comm_const, __pyx_k_pydevd_bundle_pydevd_comm_const, sizeof(__pyx_k_pydevd_bundle_pydevd_comm_const), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_bundle_pydevd_constants, __pyx_k_pydevd_bundle_pydevd_constants, sizeof(__pyx_k_pydevd_bundle_pydevd_constants), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_bundle_pydevd_dont_trace, __pyx_k_pydevd_bundle_pydevd_dont_trace, sizeof(__pyx_k_pydevd_bundle_pydevd_dont_trace), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_bundle_pydevd_pep_669_tr, __pyx_k_pydevd_bundle_pydevd_pep_669_tr, sizeof(__pyx_k_pydevd_bundle_pydevd_pep_669_tr), 0, 0, 1, 1},
    {&__pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_k_pydevd_bundle_pydevd_pep_669_tr_2, sizeof(__pyx_k_pydevd_bundle_pydevd_pep_669_tr_2), 0, 0, 1, 0},
    {&__pyx_n_s_pydevd_bundle_pydevd_trace_disp, __pyx_k_pydevd_bundle_pydevd_trace_disp, sizeof(__pyx_k_pydevd_bundle_pydevd_trace_disp), 0, 0, 1, 1},
    {&__pyx_n_s_pydevd_file_utils, __pyx_k_pydevd_file_utils, sizeof(__pyx_k_pydevd_file_utils), 0, 0, 1, 1},
    {&__pyx_n_s_quitting, __pyx_k_quitting, sizeof(__pyx_k_quitting), 0, 0, 1, 1},
    {&__pyx_n_s_register_callback, __pyx_k_register_callback, sizeof(__pyx_k_register_callback), 0, 0, 1, 1},
    {&__pyx_n_s_remove_breakpoint, __pyx_k_remove_breakpoint, sizeof(__pyx_k_remove_breakpoint), 0, 0, 1, 1},
    {&__pyx_n_s_remove_return_values_flag, __pyx_k_remove_return_values_flag, sizeof(__pyx_k_remove_return_values_flag), 0, 0, 1, 1},
    {&__pyx_n_s_reset, __pyx_k_reset, sizeof(__pyx_k_reset), 0, 0, 1, 1},
    {&__pyx_n_s_restart_events, __pyx_k_restart_events, sizeof(__pyx_k_restart_events), 0, 0, 1, 1},
    {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_retval, __pyx_k_retval, sizeof(__pyx_k_retval), 0, 0, 1, 1},
    {&__pyx_n_s_set_additional_thread_info, __pyx_k_set_additional_thread_info, sizeof(__pyx_k_set_additional_thread_info), 0, 0, 1, 1},
    {&__pyx_n_s_set_events, __pyx_k_set_events, sizeof(__pyx_k_set_events), 0, 0, 1, 1},
    {&__pyx_n_s_set_local_events, __pyx_k_set_local_events, sizeof(__pyx_k_set_local_events), 0, 0, 1, 1},
    {&__pyx_n_s_set_suspend, __pyx_k_set_suspend, sizeof(__pyx_k_set_suspend), 0, 0, 1, 1},
    {&__pyx_n_s_should_enable_line_events_for_c, __pyx_k_should_enable_line_events_for_c, sizeof(__pyx_k_should_enable_line_events_for_c), 0, 0, 1, 1},
    {&__pyx_n_s_should_stop, __pyx_k_should_stop, sizeof(__pyx_k_should_stop), 0, 0, 1, 1},
    {&__pyx_n_s_should_stop_on_exception, __pyx_k_should_stop_on_exception, sizeof(__pyx_k_should_stop_on_exception), 0, 0, 1, 1},
    {&__pyx_n_s_show_return_values, __pyx_k_show_return_values, sizeof(__pyx_k_show_return_values), 0, 0, 1, 1},
    {&__pyx_n_s_smart_step_stop, __pyx_k_smart_step_stop, sizeof(__pyx_k_smart_step_stop), 0, 0, 1, 1},
    {&__pyx_n_s_smart_stop_frame, __pyx_k_smart_stop_frame, sizeof(__pyx_k_smart_stop_frame), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_splitext, __pyx_k_splitext, sizeof(__pyx_k_splitext), 0, 0, 1, 1},
    {&__pyx_n_s_start_line, __pyx_k_start_line, sizeof(__pyx_k_start_line), 0, 0, 1, 1},
    {&__pyx_n_s_step_cmd, __pyx_k_step_cmd, sizeof(__pyx_k_step_cmd), 0, 0, 1, 1},
    {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
    {&__pyx_n_s_stop_frame, __pyx_k_stop_frame, sizeof(__pyx_k_stop_frame), 0, 0, 1, 1},
    {&__pyx_n_s_stop_info, __pyx_k_stop_info, sizeof(__pyx_k_stop_info), 0, 0, 1, 1},
    {&__pyx_n_s_stop_on_failed_tests, __pyx_k_stop_on_failed_tests, sizeof(__pyx_k_stop_on_failed_tests), 0, 0, 1, 1},
    {&__pyx_n_s_stop_on_unhandled_exception, __pyx_k_stop_on_unhandled_exception, sizeof(__pyx_k_stop_on_unhandled_exception), 0, 0, 1, 1},
    {&__pyx_n_s_stop_on_unhandled_exception_2, __pyx_k_stop_on_unhandled_exception_2, sizeof(__pyx_k_stop_on_unhandled_exception_2), 0, 0, 1, 1},
    {&__pyx_n_s_suspend, __pyx_k_suspend, sizeof(__pyx_k_suspend), 0, 0, 1, 1},
    {&__pyx_n_s_suspend_other_threads, __pyx_k_suspend_other_threads, sizeof(__pyx_k_suspend_other_threads), 0, 0, 1, 1},
    {&__pyx_n_s_suspend_policy, __pyx_k_suspend_policy, sizeof(__pyx_k_suspend_policy), 0, 0, 1, 1},
    {&__pyx_n_s_suspended_at_unhandled, __pyx_k_suspended_at_unhandled, sizeof(__pyx_k_suspended_at_unhandled), 0, 0, 1, 1},
    {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_thread, __pyx_k_thread, sizeof(__pyx_k_thread), 0, 0, 1, 1},
    {&__pyx_n_s_thread_analyser, __pyx_k_thread_analyser, sizeof(__pyx_k_thread_analyser), 0, 0, 1, 1},
    {&__pyx_n_s_threading, __pyx_k_threading, sizeof(__pyx_k_threading), 0, 0, 1, 1},
    {&__pyx_n_s_traceback, __pyx_k_traceback, sizeof(__pyx_k_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_traceback_2, __pyx_k_traceback_2, sizeof(__pyx_k_traceback_2), 0, 0, 1, 1},
    {&__pyx_n_s_use_tool_id, __pyx_k_use_tool_id, sizeof(__pyx_k_use_tool_id), 0, 0, 1, 1},
    {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
    {&__pyx_n_s_will_be_stopped, __pyx_k_will_be_stopped, sizeof(__pyx_k_will_be_stopped), 0, 0, 1, 1},
    {&__pyx_n_s_writer, __pyx_k_writer, sizeof(__pyx_k_writer), 0, 0, 1, 1},
    {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
    {&__pyx_n_s_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_AttributeError = __Pyx_GetBuiltinName(__pyx_n_s_AttributeError); if (!__pyx_builtin_AttributeError) __PYX_ERR(0, 41, __pyx_L1_error)
  __pyx_builtin_SystemExit = __Pyx_GetBuiltinName(__pyx_n_s_SystemExit); if (!__pyx_builtin_SystemExit) __PYX_ERR(0, 297, __pyx_L1_error)
  __pyx_builtin_KeyboardInterrupt = __Pyx_GetBuiltinName(__pyx_n_s_KeyboardInterrupt); if (!__pyx_builtin_KeyboardInterrupt) __PYX_ERR(0, 552, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":49
 * }
 * 
 * def _make_frame_cache_key(code):             # <<<<<<<<<<<<<<
 *     return code.co_firstlineno, code.co_name, code.co_filename
 * 
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_n_s_code); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);
  __pyx_codeobj__6 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__5, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_make_frame_cache_key, 49, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__6)) __PYX_ERR(0, 49, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":53
 * 
 * 
 * def _get_additional_info(thread):             # <<<<<<<<<<<<<<
 *     try:
 *         additional_info = thread.additional_info
 */
  __pyx_tuple__7 = PyTuple_Pack(2, __pyx_n_s_thread, __pyx_n_s_additional_info); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);
  __pyx_codeobj__8 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__7, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_get_additional_info, 53, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__8)) __PYX_ERR(0, 53, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":63
 * 
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):             # <<<<<<<<<<<<<<
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 */
  __pyx_tuple__9 = PyTuple_Pack(2, __pyx_n_s_frame, __pyx_n_s_abs_path_real_path_and_base); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);
  __pyx_codeobj__10 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__9, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_get_abs_path_real_path_and_base_2, 63, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__10)) __PYX_ERR(0, 63, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":74
 * 
 * 
 * def _should_enable_line_events_for_code(frame, code, filename, info, will_be_stopped=False):             # <<<<<<<<<<<<<<
 *     line_number = frame.f_lineno
 * 
 */
  __pyx_tuple__11 = PyTuple_Pack(20, __pyx_n_s_frame, __pyx_n_s_code, __pyx_n_s_filename, __pyx_n_s_info, __pyx_n_s_will_be_stopped, __pyx_n_s_line_number, __pyx_n_s_py_db, __pyx_n_s_plugin_manager, __pyx_n_s_stop_frame, __pyx_n_s_step_cmd, __pyx_n_s_breakpoints_for_file, __pyx_n_s_can_skip, __pyx_n_s_frame_cache_key, __pyx_n_s_line_cache_key, __pyx_n_s_breakpoints_in_line_cache, __pyx_n_s_breakpoints_in_frame_cache, __pyx_n_s_has_breakpoint_in_frame, __pyx_n_s_curr_func_name, __pyx_n_s_breakpoint, __pyx_n_s_f_code); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);
  __pyx_codeobj__12 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 20, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__11, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_should_enable_line_events_for_c, 74, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__12)) __PYX_ERR(0, 74, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":157
 * 
 * 
 * def _clear_run_state(info):             # <<<<<<<<<<<<<<
 *     info.pydev_step_stop = None
 *     info.pydev_step_cmd = -1
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_n_s_info); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);
  __pyx_codeobj__14 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__13, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_clear_run_state, 157, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__14)) __PYX_ERR(0, 157, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":175
 * 
 * 
 * def _get_top_level_frame():             # <<<<<<<<<<<<<<
 *     f_unhandled = _getframe()
 * 
 */
  __pyx_tuple__15 = PyTuple_Pack(3, __pyx_n_s_f_unhandled, __pyx_n_s_filename, __pyx_n_s_name_2); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_get_top_level_frame, 175, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) __PYX_ERR(0, 175, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":192
 * 
 * 
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):             # <<<<<<<<<<<<<<
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:
 */
  __pyx_tuple__17 = PyTuple_Pack(4, __pyx_n_s_exc_info, __pyx_n_s_py_db, __pyx_n_s_thread, __pyx_n_s_additional_info); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);
  __pyx_codeobj__18 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__17, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_stop_on_unhandled_exception_2, 192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__18)) __PYX_ERR(0, 192, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":200
 * 
 * 
 * def enable_pep669_monitoring():             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */
  __pyx_tuple__19 = PyTuple_Pack(4, __pyx_n_s_DEBUGGER_ID, __pyx_n_s_event_type, __pyx_n_s_callback, __pyx_n_s_debugger); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);
  __pyx_codeobj__20 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__19, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_enable_pep669_monitoring, 200, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__20)) __PYX_ERR(0, 200, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":224
 * 
 * 
 * def add_new_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     breakpoint._not_processed = True
 *     monitoring.restart_events()
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_n_s_breakpoint); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);
  __pyx_codeobj__22 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__21, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_add_new_breakpoint, 224, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__22)) __PYX_ERR(0, 224, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":230
 * 
 * 
 * def remove_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     if getattr(breakpoint, '_not_processed', None):
 *         breakpoint._not_processed = False
 */
  __pyx_codeobj__23 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__21, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_remove_breakpoint, 230, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__23)) __PYX_ERR(0, 230, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":236
 * 
 * 
 * def _modify_global_events(action, event):             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */
  __pyx_tuple__24 = PyTuple_Pack(4, __pyx_n_s_action, __pyx_n_s_event, __pyx_n_s_DEBUGGER_ID, __pyx_n_s_current_events); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);
  __pyx_codeobj__25 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__24, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_modify_global_events, 236, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__25)) __PYX_ERR(0, 236, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":245
 * 
 * 
 * def _enable_return_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */
  __pyx_tuple__26 = PyTuple_Pack(2, __pyx_n_s_code, __pyx_n_s_local_events); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);
  __pyx_codeobj__27 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__26, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_enable_return_tracing, 245, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__27)) __PYX_ERR(0, 245, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":251
 * 
 * 
 * def _enable_line_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__26, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_enable_line_tracing, 251, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(0, 251, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":257
 * 
 * 
 * def call_callback(code, instruction_offset, callable, arg0):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */
  __pyx_tuple__29 = PyTuple_Pack(14, __pyx_n_s_code, __pyx_n_s_instruction_offset, __pyx_n_s_callable, __pyx_n_s_arg0, __pyx_n_s_py_db, __pyx_n_s_frame, __pyx_n_s_thread, __pyx_n_s_frame_cache_key, __pyx_n_s_info, __pyx_n_s_pydev_step_cmd, __pyx_n_s_is_stepping, __pyx_n_s_abs_path_real_path_and_base, __pyx_n_s_filename, __pyx_n_s_breakpoints_for_file); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);
  __pyx_codeobj__30 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 14, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__29, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_call_callback, 257, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__30)) __PYX_ERR(0, 257, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":308
 * 
 * 
 * def py_start_callback(code, instruction_offset):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */
  __pyx_tuple__32 = PyTuple_Pack(25, __pyx_n_s_code, __pyx_n_s_instruction_offset, __pyx_n_s_py_db, __pyx_n_s_frame, __pyx_n_s_thread, __pyx_n_s_frame_cache_key, __pyx_n_s_info, __pyx_n_s_pydev_step_cmd, __pyx_n_s_is_stepping, __pyx_n_s_abs_path_real_path_and_base, __pyx_n_s_filename, __pyx_n_s_file_type, __pyx_n_s_breakpoints_for_file, __pyx_n_s_args, __pyx_n_s_result, __pyx_n_s_flag, __pyx_n_s_breakpoint, __pyx_n_s_new_frame, __pyx_n_s_bp_type, __pyx_n_s_eval_result, __pyx_n_s_cmd, __pyx_n_s_stop_info, __pyx_n_s_stop_frame, __pyx_n_s_plugin_stop, __pyx_n_s__31); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);
  __pyx_codeobj__33 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 25, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__32, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_py_start_callback, 308, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__33)) __PYX_ERR(0, 308, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":448
 * 
 * 
 * def py_line_callback(code, line_number):             # <<<<<<<<<<<<<<
 *     frame = _getframe(1)
 *     thread = get_current_thread()
 */
  __pyx_tuple__34 = PyTuple_Pack(29, __pyx_n_s_code, __pyx_n_s_line_number, __pyx_n_s_frame, __pyx_n_s_thread, __pyx_n_s_info, __pyx_n_s_py_db, __pyx_n_s_stop_frame, __pyx_n_s_step_cmd, __pyx_n_s_filename, __pyx_n_s_breakpoints_for_file, __pyx_n_s_frame_cache_key, __pyx_n_s_line_cache_key, __pyx_n_s_flag, __pyx_n_s_breakpoint, __pyx_n_s_stop, __pyx_n_s_exist_result, __pyx_n_s_bp_type, __pyx_n_s_args, __pyx_n_s_smart_stop_frame, __pyx_n_s_context_start_line, __pyx_n_s_context_end_line, __pyx_n_s_is_within_context, __pyx_n_s_new_frame, __pyx_n_s_result, __pyx_n_s_eval_result, __pyx_n_s_cmd, __pyx_n_s_plugin_stop, __pyx_n_s_stop_info, __pyx_n_s_curr_func_name); if (unlikely(!__pyx_tuple__34)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);
  __pyx_codeobj__35 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 29, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__34, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_py_line_callback, 448, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__35)) __PYX_ERR(0, 448, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":642
 * 
 * 
 * def py_raise_callback(code, instruction_offset, exception):             # <<<<<<<<<<<<<<
 *     # print('PY_RAISE %s %s %s' % (code.co_name, code.co_filename, exception))
 * 
 */
  __pyx_tuple__36 = PyTuple_Pack(11, __pyx_n_s_code, __pyx_n_s_instruction_offset, __pyx_n_s_exception, __pyx_n_s_exc_info, __pyx_n_s_py_db, __pyx_n_s_thread, __pyx_n_s_info, __pyx_n_s_frame, __pyx_n_s_has_exception_breakpoints, __pyx_n_s_args, __pyx_n_s_should_stop); if (unlikely(!__pyx_tuple__36)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);
  __pyx_codeobj__37 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__36, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_py_raise_callback, 642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__37)) __PYX_ERR(0, 642, __pyx_L1_error)

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":684
 * 
 * 
 * def py_return_callback(code, instruction_offset, retval):             # <<<<<<<<<<<<<<
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:
 */
  __pyx_tuple__38 = PyTuple_Pack(27, __pyx_n_s_code, __pyx_n_s_instruction_offset, __pyx_n_s_retval, __pyx_n_s_py_db, __pyx_n_s_frame, __pyx_n_s_thread, __pyx_n_s_info, __pyx_n_s_stop_frame, __pyx_n_s_filename, __pyx_n_s_plugin_stop, __pyx_n_s_args, __pyx_n_s_stop_info, __pyx_n_s_stop, __pyx_n_s_smart_stop_frame, __pyx_n_s_step_cmd, __pyx_n_s_result, __pyx_n_s_back, __pyx_n_s_back_code, __pyx_n_s_f_back, __pyx_n_s_f_code, __pyx_n_s_back_filename, __pyx_n_s_base_back_filename, __pyx_n_s_file_type, __pyx_n_s_breakpoints_for_back_file, __pyx_n_s_breakpoint, __pyx_n_s__31, __pyx_n_s_base); if (unlikely(!__pyx_tuple__38)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);
  __pyx_codeobj__39 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 27, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__38, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pydevd_bundle_pydevd_pep_669_tr_2, __pyx_n_s_py_return_callback, 684, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__39)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_108 = PyInt_FromLong(108); if (unlikely(!__pyx_int_108)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_109 = PyInt_FromLong(109); if (unlikely(!__pyx_int_109)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  return 0;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_pydevd_pep_669_tracing_cython(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_pydevd_pep_669_tracing_cython},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "pydevd_pep_669_tracing_cython",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initpydevd_pep_669_tracing_cython(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initpydevd_pep_669_tracing_cython(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_pydevd_pep_669_tracing_cython(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_pydevd_pep_669_tracing_cython(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_pydevd_pep_669_tracing_cython(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'pydevd_pep_669_tracing_cython' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("pydevd_pep_669_tracing_cython", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "pydevd_pep_669_tracing_cython" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_pydevd_pep_669_tracing_cython(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main__pydevd_bundle__pydevd_pep_669_tracing_cython) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "_pydevd_bundle.pydevd_pep_669_tracing_cython")) {
      if (unlikely((PyDict_SetItemString(modules, "_pydevd_bundle.pydevd_pep_669_tracing_cython", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":9
 * #  Copyright 2000-2024 JetBrains s.r.o. and contributors. Use of this source code is governed by the Apache 2.0 license.
 * 
 * import os             # <<<<<<<<<<<<<<
 * import sys
 * import threading
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_os, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_2) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":10
 * 
 * import os
 * import sys             # <<<<<<<<<<<<<<
 * import threading
 * import traceback
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_sys, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_2) < 0) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":11
 * import os
 * import sys
 * import threading             # <<<<<<<<<<<<<<
 * import traceback
 * from os.path import splitext, basename
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_threading, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_threading, __pyx_t_2) < 0) __PYX_ERR(0, 11, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":12
 * import sys
 * import threading
 * import traceback             # <<<<<<<<<<<<<<
 * from os.path import splitext, basename
 * 
 */
  __pyx_t_2 = __Pyx_ImportDottedModule(__pyx_n_s_traceback, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_traceback, __pyx_t_2) < 0) __PYX_ERR(0, 12, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":13
 * import threading
 * import traceback
 * from os.path import splitext, basename             # <<<<<<<<<<<<<<
 * 
 * from _pydev_bundle import pydev_log
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_splitext);
  __Pyx_GIVEREF(__pyx_n_s_splitext);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_splitext)) __PYX_ERR(0, 13, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_basename);
  __Pyx_GIVEREF(__pyx_n_s_basename);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_basename)) __PYX_ERR(0, 13, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_os_path, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_splitext); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_splitext, __pyx_t_2) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_basename); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_basename, __pyx_t_2) < 0) __PYX_ERR(0, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":15
 * from os.path import splitext, basename
 * 
 * from _pydev_bundle import pydev_log             # <<<<<<<<<<<<<<
 * from _pydev_bundle.pydev_is_thread_alive import is_thread_alive
 * from _pydevd_bundle.pydevd_breakpoints import stop_on_unhandled_exception
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_pydev_log);
  __Pyx_GIVEREF(__pyx_n_s_pydev_log);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_pydev_log)) __PYX_ERR(0, 15, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pydev_bundle, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_pydev_log); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pydev_log, __pyx_t_3) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":16
 * 
 * from _pydev_bundle import pydev_log
 * from _pydev_bundle.pydev_is_thread_alive import is_thread_alive             # <<<<<<<<<<<<<<
 * from _pydevd_bundle.pydevd_breakpoints import stop_on_unhandled_exception
 * from _pydevd_bundle.pydevd_bytecode_utils import (
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_is_thread_alive);
  __Pyx_GIVEREF(__pyx_n_s_is_thread_alive);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_is_thread_alive)) __PYX_ERR(0, 16, __pyx_L1_error);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_pydev_bundle_pydev_is_thread_al, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_is_thread_alive); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_is_thread_alive, __pyx_t_2) < 0) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":17
 * from _pydev_bundle import pydev_log
 * from _pydev_bundle.pydev_is_thread_alive import is_thread_alive
 * from _pydevd_bundle.pydevd_breakpoints import stop_on_unhandled_exception             # <<<<<<<<<<<<<<
 * from _pydevd_bundle.pydevd_bytecode_utils import (
 *     find_last_call_name, find_last_func_call_order)
 */
  __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_stop_on_unhandled_exception);
  __Pyx_GIVEREF(__pyx_n_s_stop_on_unhandled_exception);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_stop_on_unhandled_exception)) __PYX_ERR(0, 17, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pydevd_bundle_pydevd_breakpoint, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_stop_on_unhandled_exception); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stop_on_unhandled_exception, __pyx_t_3) < 0) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":19
 * from _pydevd_bundle.pydevd_breakpoints import stop_on_unhandled_exception
 * from _pydevd_bundle.pydevd_bytecode_utils import (
 *     find_last_call_name, find_last_func_call_order)             # <<<<<<<<<<<<<<
 * from _pydevd_bundle.pydevd_comm_constants import (
 *     CMD_STEP_OVER, CMD_SMART_STEP_INTO, CMD_SET_BREAK, CMD_STEP_INTO,
 */
  __pyx_t_2 = PyList_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_find_last_call_name);
  __Pyx_GIVEREF(__pyx_n_s_find_last_call_name);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_find_last_call_name)) __PYX_ERR(0, 19, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_find_last_func_call_order);
  __Pyx_GIVEREF(__pyx_n_s_find_last_func_call_order);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_find_last_func_call_order)) __PYX_ERR(0, 19, __pyx_L1_error);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":18
 * from _pydev_bundle.pydev_is_thread_alive import is_thread_alive
 * from _pydevd_bundle.pydevd_breakpoints import stop_on_unhandled_exception
 * from _pydevd_bundle.pydevd_bytecode_utils import (             # <<<<<<<<<<<<<<
 *     find_last_call_name, find_last_func_call_order)
 * from _pydevd_bundle.pydevd_comm_constants import (
 */
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_pydevd_bundle_pydevd_bytecode_u, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_find_last_call_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_find_last_call_name, __pyx_t_2) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_find_last_func_call_order); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_find_last_func_call_order, __pyx_t_2) < 0) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":21
 *     find_last_call_name, find_last_func_call_order)
 * from _pydevd_bundle.pydevd_comm_constants import (
 *     CMD_STEP_OVER, CMD_SMART_STEP_INTO, CMD_SET_BREAK, CMD_STEP_INTO,             # <<<<<<<<<<<<<<
 *     CMD_STEP_INTO_MY_CODE, CMD_STEP_INTO_COROUTINE, CMD_STEP_RETURN)
 * from _pydevd_bundle.pydevd_constants import (
 */
  __pyx_t_3 = PyList_New(7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_CMD_STEP_OVER);
  __Pyx_GIVEREF(__pyx_n_s_CMD_STEP_OVER);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_CMD_STEP_OVER)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CMD_SMART_STEP_INTO);
  __Pyx_GIVEREF(__pyx_n_s_CMD_SMART_STEP_INTO);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_CMD_SMART_STEP_INTO)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CMD_SET_BREAK);
  __Pyx_GIVEREF(__pyx_n_s_CMD_SET_BREAK);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_CMD_SET_BREAK)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CMD_STEP_INTO);
  __Pyx_GIVEREF(__pyx_n_s_CMD_STEP_INTO);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 3, __pyx_n_s_CMD_STEP_INTO)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CMD_STEP_INTO_MY_CODE);
  __Pyx_GIVEREF(__pyx_n_s_CMD_STEP_INTO_MY_CODE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 4, __pyx_n_s_CMD_STEP_INTO_MY_CODE)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CMD_STEP_INTO_COROUTINE);
  __Pyx_GIVEREF(__pyx_n_s_CMD_STEP_INTO_COROUTINE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 5, __pyx_n_s_CMD_STEP_INTO_COROUTINE)) __PYX_ERR(0, 21, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_CMD_STEP_RETURN);
  __Pyx_GIVEREF(__pyx_n_s_CMD_STEP_RETURN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 6, __pyx_n_s_CMD_STEP_RETURN)) __PYX_ERR(0, 21, __pyx_L1_error);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":20
 * from _pydevd_bundle.pydevd_bytecode_utils import (
 *     find_last_call_name, find_last_func_call_order)
 * from _pydevd_bundle.pydevd_comm_constants import (             # <<<<<<<<<<<<<<
 *     CMD_STEP_OVER, CMD_SMART_STEP_INTO, CMD_SET_BREAK, CMD_STEP_INTO,
 *     CMD_STEP_INTO_MY_CODE, CMD_STEP_INTO_COROUTINE, CMD_STEP_RETURN)
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pydevd_bundle_pydevd_comm_const, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_STEP_OVER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_STEP_OVER, __pyx_t_3) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_SMART_STEP_INTO); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_SMART_STEP_INTO, __pyx_t_3) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_SET_BREAK); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_SET_BREAK, __pyx_t_3) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_STEP_INTO); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_STEP_INTO, __pyx_t_3) < 0) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_STEP_INTO_MY_CODE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_STEP_INTO_MY_CODE, __pyx_t_3) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_STEP_INTO_COROUTINE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_STEP_INTO_COROUTINE, __pyx_t_3) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_CMD_STEP_RETURN); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CMD_STEP_RETURN, __pyx_t_3) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":24
 *     CMD_STEP_INTO_MY_CODE, CMD_STEP_INTO_COROUTINE, CMD_STEP_RETURN)
 * from _pydevd_bundle.pydevd_constants import (
 *     PYDEVD_TOOL_NAME, STATE_RUN, STATE_SUSPEND, GlobalDebuggerHolder, IS_CPYTHON)             # <<<<<<<<<<<<<<
 * from _pydevd_bundle.pydevd_dont_trace_files import DONT_TRACE, PYDEV_FILE
 * from _pydevd_bundle.pydevd_trace_dispatch import (
 */
  __pyx_t_2 = PyList_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_PYDEVD_TOOL_NAME);
  __Pyx_GIVEREF(__pyx_n_s_PYDEVD_TOOL_NAME);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PYDEVD_TOOL_NAME)) __PYX_ERR(0, 24, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_STATE_RUN);
  __Pyx_GIVEREF(__pyx_n_s_STATE_RUN);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_STATE_RUN)) __PYX_ERR(0, 24, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_STATE_SUSPEND);
  __Pyx_GIVEREF(__pyx_n_s_STATE_SUSPEND);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_STATE_SUSPEND)) __PYX_ERR(0, 24, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_GlobalDebuggerHolder);
  __Pyx_GIVEREF(__pyx_n_s_GlobalDebuggerHolder);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_GlobalDebuggerHolder)) __PYX_ERR(0, 24, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_IS_CPYTHON);
  __Pyx_GIVEREF(__pyx_n_s_IS_CPYTHON);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_IS_CPYTHON)) __PYX_ERR(0, 24, __pyx_L1_error);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":23
 *     CMD_STEP_OVER, CMD_SMART_STEP_INTO, CMD_SET_BREAK, CMD_STEP_INTO,
 *     CMD_STEP_INTO_MY_CODE, CMD_STEP_INTO_COROUTINE, CMD_STEP_RETURN)
 * from _pydevd_bundle.pydevd_constants import (             # <<<<<<<<<<<<<<
 *     PYDEVD_TOOL_NAME, STATE_RUN, STATE_SUSPEND, GlobalDebuggerHolder, IS_CPYTHON)
 * from _pydevd_bundle.pydevd_dont_trace_files import DONT_TRACE, PYDEV_FILE
 */
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_pydevd_bundle_pydevd_constants, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PYDEVD_TOOL_NAME); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PYDEVD_TOOL_NAME, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_STATE_RUN); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STATE_RUN, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_STATE_SUSPEND); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_STATE_SUSPEND, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_GlobalDebuggerHolder); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GlobalDebuggerHolder, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_IS_CPYTHON); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_IS_CPYTHON, __pyx_t_2) < 0) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":25
 * from _pydevd_bundle.pydevd_constants import (
 *     PYDEVD_TOOL_NAME, STATE_RUN, STATE_SUSPEND, GlobalDebuggerHolder, IS_CPYTHON)
 * from _pydevd_bundle.pydevd_dont_trace_files import DONT_TRACE, PYDEV_FILE             # <<<<<<<<<<<<<<
 * from _pydevd_bundle.pydevd_trace_dispatch import (
 *     set_additional_thread_info, handle_breakpoint_condition,
 */
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_DONT_TRACE);
  __Pyx_GIVEREF(__pyx_n_s_DONT_TRACE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_DONT_TRACE)) __PYX_ERR(0, 25, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_PYDEV_FILE);
  __Pyx_GIVEREF(__pyx_n_s_PYDEV_FILE);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_PYDEV_FILE)) __PYX_ERR(0, 25, __pyx_L1_error);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pydevd_bundle_pydevd_dont_trace, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_DONT_TRACE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DONT_TRACE, __pyx_t_3) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_PYDEV_FILE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_PYDEV_FILE, __pyx_t_3) < 0) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":27
 * from _pydevd_bundle.pydevd_dont_trace_files import DONT_TRACE, PYDEV_FILE
 * from _pydevd_bundle.pydevd_trace_dispatch import (
 *     set_additional_thread_info, handle_breakpoint_condition,             # <<<<<<<<<<<<<<
 *     handle_breakpoint_expression, DEBUG_START, DEBUG_START_PY3K,
 *     should_stop_on_exception, handle_exception, manage_return_values)
 */
  __pyx_t_2 = PyList_New(8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_set_additional_thread_info);
  __Pyx_GIVEREF(__pyx_n_s_set_additional_thread_info);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_set_additional_thread_info)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_handle_breakpoint_condition);
  __Pyx_GIVEREF(__pyx_n_s_handle_breakpoint_condition);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_handle_breakpoint_condition)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_handle_breakpoint_expression);
  __Pyx_GIVEREF(__pyx_n_s_handle_breakpoint_expression);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_handle_breakpoint_expression)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DEBUG_START);
  __Pyx_GIVEREF(__pyx_n_s_DEBUG_START);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 3, __pyx_n_s_DEBUG_START)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_DEBUG_START_PY3K);
  __Pyx_GIVEREF(__pyx_n_s_DEBUG_START_PY3K);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 4, __pyx_n_s_DEBUG_START_PY3K)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_should_stop_on_exception);
  __Pyx_GIVEREF(__pyx_n_s_should_stop_on_exception);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 5, __pyx_n_s_should_stop_on_exception)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_handle_exception);
  __Pyx_GIVEREF(__pyx_n_s_handle_exception);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 6, __pyx_n_s_handle_exception)) __PYX_ERR(0, 27, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_manage_return_values);
  __Pyx_GIVEREF(__pyx_n_s_manage_return_values);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 7, __pyx_n_s_manage_return_values)) __PYX_ERR(0, 27, __pyx_L1_error);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":26
 *     PYDEVD_TOOL_NAME, STATE_RUN, STATE_SUSPEND, GlobalDebuggerHolder, IS_CPYTHON)
 * from _pydevd_bundle.pydevd_dont_trace_files import DONT_TRACE, PYDEV_FILE
 * from _pydevd_bundle.pydevd_trace_dispatch import (             # <<<<<<<<<<<<<<
 *     set_additional_thread_info, handle_breakpoint_condition,
 *     handle_breakpoint_expression, DEBUG_START, DEBUG_START_PY3K,
 */
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_pydevd_bundle_pydevd_trace_disp, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_set_additional_thread_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_set_additional_thread_info, __pyx_t_2) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_handle_breakpoint_condition); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_handle_breakpoint_condition, __pyx_t_2) < 0) __PYX_ERR(0, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_handle_breakpoint_expression); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_handle_breakpoint_expression, __pyx_t_2) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_DEBUG_START); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DEBUG_START, __pyx_t_2) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_DEBUG_START_PY3K); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DEBUG_START_PY3K, __pyx_t_2) < 0) __PYX_ERR(0, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_should_stop_on_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_should_stop_on_exception, __pyx_t_2) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_handle_exception); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_handle_exception, __pyx_t_2) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_manage_return_values); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_manage_return_values, __pyx_t_2) < 0) __PYX_ERR(0, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":31
 *     should_stop_on_exception, handle_exception, manage_return_values)
 * from pydevd_file_utils import (
 *     NORM_PATHS_AND_BASE_CONTAINER, get_abs_path_real_path_and_base_from_frame)             # <<<<<<<<<<<<<<
 * 
 * get_current_thread = threading.current_thread
 */
  __pyx_t_3 = PyList_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER);
  __Pyx_GIVEREF(__pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER)) __PYX_ERR(0, 31, __pyx_L1_error);
  __Pyx_INCREF(__pyx_n_s_get_abs_path_real_path_and_base);
  __Pyx_GIVEREF(__pyx_n_s_get_abs_path_real_path_and_base);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_get_abs_path_real_path_and_base)) __PYX_ERR(0, 31, __pyx_L1_error);

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":30
 *     handle_breakpoint_expression, DEBUG_START, DEBUG_START_PY3K,
 *     should_stop_on_exception, handle_exception, manage_return_values)
 * from pydevd_file_utils import (             # <<<<<<<<<<<<<<
 *     NORM_PATHS_AND_BASE_CONTAINER, get_abs_path_real_path_and_base_from_frame)
 * 
 */
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_pydevd_file_utils, __pyx_t_3, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NORM_PATHS_AND_BASE_CONTAINER, __pyx_t_3) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_get_abs_path_real_path_and_base); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 30, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_abs_path_real_path_and_base, __pyx_t_3) < 0) __PYX_ERR(0, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":33
 *     NORM_PATHS_AND_BASE_CONTAINER, get_abs_path_real_path_and_base_from_frame)
 * 
 * get_current_thread = threading.current_thread             # <<<<<<<<<<<<<<
 * get_file_type = DONT_TRACE.get
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_threading); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_current_thread); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_current_thread, __pyx_t_3) < 0) __PYX_ERR(0, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":34
 * 
 * get_current_thread = threading.current_thread
 * get_file_type = DONT_TRACE.get             # <<<<<<<<<<<<<<
 * 
 * global_cache_skips = {}
 */
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_DONT_TRACE); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_file_type, __pyx_t_2) < 0) __PYX_ERR(0, 34, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":36
 * get_file_type = DONT_TRACE.get
 * 
 * global_cache_skips = {}             # <<<<<<<<<<<<<<
 * global_cache_frame_skips = {}
 * 
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_global_cache_skips, __pyx_t_2) < 0) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":37
 * 
 * global_cache_skips = {}
 * global_cache_frame_skips = {}             # <<<<<<<<<<<<<<
 * 
 * try:
 */
  __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_global_cache_frame_skips, __pyx_t_2) < 0) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":39
 * global_cache_frame_skips = {}
 * 
 * try:             # <<<<<<<<<<<<<<
 *     monitoring = sys.monitoring
 * except AttributeError:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_4, &__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_5);
    /*try:*/ {

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":40
 * 
 * try:
 *     monitoring = sys.monitoring             # <<<<<<<<<<<<<<
 * except AttributeError:
 *     pass
 */
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_sys); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_monitoring); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 40, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (PyDict_SetItem(__pyx_d, __pyx_n_s_monitoring, __pyx_t_3) < 0) __PYX_ERR(0, 40, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":39
 * global_cache_frame_skips = {}
 * 
 * try:             # <<<<<<<<<<<<<<
 *     monitoring = sys.monitoring
 * except AttributeError:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L7_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":41
 * try:
 *     monitoring = sys.monitoring
 * except AttributeError:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
    __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_AttributeError);
    if (__pyx_t_6) {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L3_exception_handled;
    }
    goto __pyx_L4_except_error;

    /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":39
 * global_cache_frame_skips = {}
 * 
 * try:             # <<<<<<<<<<<<<<
 *     monitoring = sys.monitoring
 * except AttributeError:
 */
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_4, __pyx_t_5);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_XGIVEREF(__pyx_t_5);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_4, __pyx_t_5);
    __pyx_L7_try_end:;
  }

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":45
 * 
 * _EVENT_ACTIONS = {
 *     "ADD": lambda x, y: x | y,             # <<<<<<<<<<<<<<
 *     "REMOVE": lambda x, y: x & ~y,
 * }
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_36lambda, 0, __pyx_kp_s_lambda, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ADD, __pyx_t_2) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":46
 * _EVENT_ACTIONS = {
 *     "ADD": lambda x, y: x | y,
 *     "REMOVE": lambda x, y: x & ~y,             # <<<<<<<<<<<<<<
 * }
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_37lambda1, 0, __pyx_kp_s_lambda, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr, __pyx_d, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_REMOVE, __pyx_t_2) < 0) __PYX_ERR(0, 45, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_EVENT_ACTIONS, __pyx_t_3) < 0) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":49
 * }
 * 
 * def _make_frame_cache_key(code):             # <<<<<<<<<<<<<<
 *     return code.co_firstlineno, code.co_name, code.co_filename
 * 
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_1_make_frame_cache_key, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_make_frame_cache_key, __pyx_t_3) < 0) __PYX_ERR(0, 49, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":53
 * 
 * 
 * def _get_additional_info(thread):             # <<<<<<<<<<<<<<
 *     try:
 *         additional_info = thread.additional_info
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_3_get_additional_info, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_additional_info, __pyx_t_3) < 0) __PYX_ERR(0, 53, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":63
 * 
 * 
 * def _get_abs_path_real_path_and_base_from_frame(frame):             # <<<<<<<<<<<<<<
 *     try:
 *         abs_path_real_path_and_base = NORM_PATHS_AND_BASE_CONTAINER[
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_5_get_abs_path_real_path_and_base_from_frame, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_abs_path_real_path_and_base_2, __pyx_t_3) < 0) __PYX_ERR(0, 63, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":74
 * 
 * 
 * def _should_enable_line_events_for_code(frame, code, filename, info, will_be_stopped=False):             # <<<<<<<<<<<<<<
 *     line_number = frame.f_lineno
 * 
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_7_should_enable_line_events_for_code, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_should_enable_line_events_for_c, __pyx_t_3) < 0) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":157
 * 
 * 
 * def _clear_run_state(info):             # <<<<<<<<<<<<<<
 *     info.pydev_step_stop = None
 *     info.pydev_step_cmd = -1
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_9_clear_run_state, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_clear_run_state, __pyx_t_3) < 0) __PYX_ERR(0, 157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":175
 * 
 * 
 * def _get_top_level_frame():             # <<<<<<<<<<<<<<
 *     f_unhandled = _getframe()
 * 
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_11_get_top_level_frame, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_top_level_frame, __pyx_t_3) < 0) __PYX_ERR(0, 175, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":192
 * 
 * 
 * def _stop_on_unhandled_exception(exc_info, py_db, thread):             # <<<<<<<<<<<<<<
 *     additional_info = _get_additional_info(thread)
 *     if not additional_info.suspended_at_unhandled:
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_13_stop_on_unhandled_exception, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_stop_on_unhandled_exception_2, __pyx_t_3) < 0) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":200
 * 
 * 
 * def enable_pep669_monitoring():             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_15enable_pep669_monitoring, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enable_pep669_monitoring, __pyx_t_3) < 0) __PYX_ERR(0, 200, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":224
 * 
 * 
 * def add_new_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     breakpoint._not_processed = True
 *     monitoring.restart_events()
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_17add_new_breakpoint, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_add_new_breakpoint, __pyx_t_3) < 0) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":230
 * 
 * 
 * def remove_breakpoint(breakpoint):             # <<<<<<<<<<<<<<
 *     if getattr(breakpoint, '_not_processed', None):
 *         breakpoint._not_processed = False
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_19remove_breakpoint, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_remove_breakpoint, __pyx_t_3) < 0) __PYX_ERR(0, 230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":236
 * 
 * 
 * def _modify_global_events(action, event):             # <<<<<<<<<<<<<<
 *     DEBUGGER_ID = monitoring.DEBUGGER_ID
 *     if not monitoring.get_tool(DEBUGGER_ID):
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_21_modify_global_events, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_modify_global_events, __pyx_t_3) < 0) __PYX_ERR(0, 236, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":245
 * 
 * 
 * def _enable_return_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_23_enable_return_tracing, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enable_return_tracing, __pyx_t_3) < 0) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":251
 * 
 * 
 * def _enable_line_tracing(code):             # <<<<<<<<<<<<<<
 *     local_events = monitoring.get_local_events(monitoring.DEBUGGER_ID, code)
 *     monitoring.set_local_events(monitoring.DEBUGGER_ID, code,
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_25_enable_line_tracing, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_enable_line_tracing, __pyx_t_3) < 0) __PYX_ERR(0, 251, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":257
 * 
 * 
 * def call_callback(code, instruction_offset, callable, arg0):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_27call_callback, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_call_callback, __pyx_t_3) < 0) __PYX_ERR(0, 257, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":308
 * 
 * 
 * def py_start_callback(code, instruction_offset):             # <<<<<<<<<<<<<<
 *     try:
 *         py_db = GlobalDebuggerHolder.global_dbg
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_29py_start_callback, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_start_callback, __pyx_t_3) < 0) __PYX_ERR(0, 308, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":448
 * 
 * 
 * def py_line_callback(code, line_number):             # <<<<<<<<<<<<<<
 *     frame = _getframe(1)
 *     thread = get_current_thread()
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_31py_line_callback, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_line_callback, __pyx_t_3) < 0) __PYX_ERR(0, 448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":642
 * 
 * 
 * def py_raise_callback(code, instruction_offset, exception):             # <<<<<<<<<<<<<<
 *     # print('PY_RAISE %s %s %s' % (code.co_name, code.co_filename, exception))
 * 
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_33py_raise_callback, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_raise_callback, __pyx_t_3) < 0) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":684
 * 
 * 
 * def py_return_callback(code, instruction_offset, retval):             # <<<<<<<<<<<<<<
 *     # print('PY_RETURN %s %s %s' % (code, code.co_name, code.co_filename))
 *     try:
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_14_pydevd_bundle_29pydevd_pep_669_tracing_cython_35py_return_callback, NULL, __pyx_n_s_pydevd_bundle_pydevd_pep_669_tr); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_py_return_callback, __pyx_t_3) < 0) __PYX_ERR(0, 684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "_pydevd_bundle/pydevd_pep_669_tracing_cython.pyx":1
 * from __future__ import print_function             # <<<<<<<<<<<<<<
 * 
 * # Important: Autogenerated file.
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init _pydevd_bundle.pydevd_pep_669_tracing_cython", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init _pydevd_bundle.pydevd_pep_669_tracing_cython");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallNoArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a == b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            if (__Pyx_PyLong_IsZero(op1) == 1) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                Py_RETURN_FALSE;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyIntCompare */
static CYTHON_INLINE int __Pyx_PyInt_BoolNeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 0;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        return (a != b);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) != 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 1;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 1;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal != 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        return ((double)a != (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* UnpackTupleError */
static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
#if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        Py_RETURN_FALSE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a != b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            if (__Pyx_PyLong_IsZero(op1) != 1) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                Py_RETURN_TRUE;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                Py_RETURN_TRUE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
#if CYTHON_COMPILING_IN_LIMITED_API
        double a = __pyx_PyFloat_AsDouble(op1);
#else
        double a = PyFloat_AS_DOUBLE(op1);
#endif
        if ((double)a != (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__3;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__4);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* FixUpExtensionType */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* FetchSharedCythonModule */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
#if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if PY_VERSION_HEX >= 0x030d00A4
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_kp_s_);
    }
    return name;
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    }
#endif
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* InitStrings */
#if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
